# Agent Tesla - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Agent Tesla](https://vuldb.com/?actor.agent_tesla). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.agent_tesla](https://vuldb.com/?actor.agent_tesla)

## Campaigns

The following _campaigns_ are known and can be associated with Agent Tesla:

* CVE-2017-11882
* Phishing Korea

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Agent Tesla:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 23 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Agent Tesla.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.9.12.0](https://vuldb.com/?ip.2.9.12.0) | anantes-154-1-77-net.w2-9.abo.wanadoo.fr | - | High
2 | [3.93.18.244](https://vuldb.com/?ip.3.93.18.244) | ec2-3-93-18-244.compute-1.amazonaws.com | - | Medium
3 | [3.217.248.28](https://vuldb.com/?ip.3.217.248.28) | ec2-3-217-248-28.compute-1.amazonaws.com | - | Medium
4 | [5.253.38.46](https://vuldb.com/?ip.5.253.38.46) | - | - | High
5 | [23.95.85.181](https://vuldb.com/?ip.23.95.85.181) | 23-95-85-181-host.colocrossing.com | - | High
6 | [23.95.128.195](https://vuldb.com/?ip.23.95.128.195) | 23-95-128-195-host.colocrossing.com | - | High
7 | [31.3.251.197](https://vuldb.com/?ip.31.3.251.197) | h31-3-251-197.host.redstation.co.uk | - | High
8 | [31.209.137.12](https://vuldb.com/?ip.31.209.137.12) | smtp.vivaldi.net | - | High
9 | [31.220.2.200](https://vuldb.com/?ip.31.220.2.200) | shared.swiftslots.com | - | High
10 | [34.154.74.85](https://vuldb.com/?ip.34.154.74.85) | 85.74.154.34.bc.googleusercontent.com | - | Medium
11 | [34.200.207.31](https://vuldb.com/?ip.34.200.207.31) | ec2-34-200-207-31.compute-1.amazonaws.com | - | Medium
12 | [37.19.196.108](https://vuldb.com/?ip.37.19.196.108) | unn-37-19-196-108.datapacket.com | - | High
13 | [43.230.131.138](https://vuldb.com/?ip.43.230.131.138) | srv1.nusadatacenter.com | - | High
14 | [45.33.8.30](https://vuldb.com/?ip.45.33.8.30) | 45-33-8-30.ip.linodeusercontent.com | - | High
15 | [45.142.215.180](https://vuldb.com/?ip.45.142.215.180) | connectoms.host | - | High
16 | [45.156.25.78](https://vuldb.com/?ip.45.156.25.78) | - | - | High
17 | [46.166.133.164](https://vuldb.com/?ip.46.166.133.164) | cybersubtitles.com | - | High
18 | [47.87.211.157](https://vuldb.com/?ip.47.87.211.157) | - | - | High
19 | [50.17.5.224](https://vuldb.com/?ip.50.17.5.224) | ec2-50-17-5-224.compute-1.amazonaws.com | - | Medium
20 | ... | ... | ... | ...

There are 75 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Agent Tesla_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-36 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Agent Tesla. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/admin/about-us.php` | High
3 | File | `/admin/add-services.php` | High
4 | File | `/admin/admin.php` | High
5 | File | `/admin/ajax.php` | High
6 | File | `/admin/ajax.php?action=save_window` | High
7 | File | `/admin/edit.php` | High
8 | File | `/admin/index3.php` | High
9 | File | `/admin/maintenance/view_designation.php` | High
10 | File | `/admin/reg.php` | High
11 | File | `/admin/service.php` | High
12 | File | `/admin/view_order.php` | High
13 | File | `/api/admin/system/store/order/list` | High
14 | File | `/api/baskets/{name}` | High
15 | File | `/app/options.py` | High
16 | File | `/apply.cgi` | Medium
17 | File | `/artist-display.php` | High
18 | File | `/be/erpc.php` | Medium
19 | File | `/bitrix/admin/ldap_server_edit.php` | High
20 | File | `/booking/show_bookings/` | High
21 | File | `/cgi-bin/ping.cgi` | High
22 | File | `/config/list` | Medium
23 | File | `/Controller/Ajaxfileupload.ashx` | High
24 | File | `/controller/Index.php` | High
25 | File | `/Controls/Generic/EBMK/Handlers/EStatements/DownloadEStatement.ashx` | High
26 | File | `/coreframe/app/order/admin/card.php` | High
27 | File | `/csms/?page=contact_us` | High
28 | File | `/dashboard/add-portfolio.php` | High
29 | File | `/dashboard/add-service.php` | High
30 | File | `/data/app` | Medium
31 | File | `/dede/group_store.php` | High
32 | File | `/dipam/athlete-profile.php` | High
33 | File | `/ecommerce/admin/category/controller.php` | High
34 | File | `/edit-db.php` | Medium
35 | File | `/etc/gsissh/sshd_config` | High
36 | File | `/etc/sudoers` | Medium
37 | File | `/forum/away.php` | High
38 | File | `/forum/PostPrivateMessage` | High
39 | File | `/forums.php?action=post` | High
40 | File | `/general/attendance/manage/ask_duty/delete.php` | High
41 | File | `/general/email/outbox/delete.php` | High
42 | File | `/goform/WifiBasicSet` | High
43 | File | `/include/chart_generator.php` | High
44 | File | `/index1.html` | Medium
45 | File | `/inxedu/demo_inxedu_open/src/main/resources/mybatis/inxedu/website/WebsiteImagesMapper.xml` | High
46 | File | `/items/view_item.php` | High
47 | File | `/LEPTON_stable_2.2.2/upload/admins/media/index.php` | High
48 | File | `/lilac/main.php` | High
49 | File | `/list.php` | Medium
50 | File | `/login.php` | Medium
51 | File | `/login/index.php` | High
52 | File | `/mc` | Low
53 | File | `/mims/login.php` | High
54 | File | `/mkshop/Men/profile.php` | High
55 | File | `/module/admin_bp/add_application.php` | High
56 | File | `/module/report_event/index.php` | High
57 | File | `/modules/profile/index.php` | High
58 | File | `/Moosikay/order.php` | High
59 | File | `/news-portal-script/information.php` | High
60 | File | `/out.php` | Medium
61 | File | `/php-opos/index.php` | High
62 | File | `/preview.php` | Medium
63 | File | `/public/launchNewWindow.jsp` | High
64 | File | `/QueryView.php` | High
65 | File | `/RestAPI` | Medium
66 | File | `/reviewer/system/system/admins/manage/users/user-update.php` | High
67 | File | `/royal_event/companyprofile.php` | High
68 | File | `/search.php` | Medium
69 | File | `/secure/QueryComponent!Default.jspa` | High
70 | File | `/see_more_details.php` | High
71 | File | `/server-status` | High
72 | ... | ... | ...

There are 631 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://1275.ru/ioc/254/gs-002-agent-tesla-spyware-iocs/
* https://1275.ru/ioc/310/gs-032-agent-tesla-spyware-iocs/
* https://app.any.run/tasks/5f20b5d1-d039-48cb-8481-f3c451d8bcf0/#
* https://app.any.run/tasks/91b72945-2a21-4e9e-98c5-132ed8d15714/
* https://app.any.run/tasks/126973bd-0df8-408d-85ae-913ba5c53612/#
* https://asec.ahnlab.com/en/31083/
* https://blog.talosintelligence.com/2020/07/threat-roundup-0724-0731.html
* https://blog.talosintelligence.com/2022/09/threat-roundup-0826-0902.html
* https://blogs.blackberry.com/en/2020/04/threat-spotlight-secret-agent-tesla
* https://community.blueliv.com/#!/s/5f7de53d82df413eb5350fba
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-08-20%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-08-24%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-08-27%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-09-07%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-09-17%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-09-20%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-10-14%20Agent%20Tesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-04-22%20AgentTesla%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-04-22%20AgentTesla%20IOCs%20Rd2
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-05-20%20Agent%20Tesla%20IOCs
* https://github.com/netskopeoss/NetskopeThreatLabsIOCs/tree/main/AgentTesla/IOCs
* https://malware-traffic-analysis.net/2023/11/22/index.html
* https://services.global.ntt/en-us/insights/blog/discovering-a-new-agent-tesla-malware-sample
* https://threatfox.abuse.ch
* https://tracker.viriback.com/index.php?q=31.220.2.200
* https://tracker.viriback.com/index.php?q=95.214.27.98
* https://tracker.viriback.com/index.php?q=107.175.91.120
* https://tracker.viriback.com/index.php?q=107.175.221.154
* https://tracker.viriback.com/index.php?q=137.184.5.20
* https://tracker.viriback.com/index.php?q=139.99.153.90
* https://tracker.viriback.com/index.php?q=185.225.74.69
* https://tracker.viriback.com/index.php?q=185.246.220.133
* https://tracker.viriback.com/index.php?q=198.98.55.114
* https://tracker.viriback.com/index.php?q=209.141.53.247
* https://tria.ge/210823-fk5y59ln7a
* https://tria.ge/211109-bxk6qsbdfn
* https://tria.ge/221206-z6p32sgh4s
* https://twitter.com/Tac_Mangusta/status/1659190159789916160
* https://www.cyber45.com
* https://www.fortinet.com/blog/threat-research/phishing-campaign-targeting-korean-to-deliver-agent-tesla-new-variant
* https://www.zscaler.com/blogs/security-research/agent-tesla-rat-delivered-quantum-builder-new-ttps
* https://www.zscaler.com/blogs/security-research/threat-actors-exploit-cve-2017-11882-deliver-agent-tesla

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
