# Ghost RAT - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Ghost RAT](https://vuldb.com/?actor.ghost_rat). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ghost_rat](https://vuldb.com/?actor.ghost_rat)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Ghost RAT:

* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Ghost RAT.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [1.13.249.49](https://vuldb.com/?ip.1.13.249.49) | - | - | High
2 | [2.58.64.219](https://vuldb.com/?ip.2.58.64.219) | - | - | High
3 | [3.13.191.225](https://vuldb.com/?ip.3.13.191.225) | ec2-3-13-191-225.us-east-2.compute.amazonaws.com | - | Medium
4 | [3.14.182.203](https://vuldb.com/?ip.3.14.182.203) | ec2-3-14-182-203.us-east-2.compute.amazonaws.com | - | Medium
5 | [3.17.7.232](https://vuldb.com/?ip.3.17.7.232) | ec2-3-17-7-232.us-east-2.compute.amazonaws.com | - | Medium
6 | [3.22.30.40](https://vuldb.com/?ip.3.22.30.40) | ec2-3-22-30-40.us-east-2.compute.amazonaws.com | - | Medium
7 | [3.134.39.220](https://vuldb.com/?ip.3.134.39.220) | ec2-3-134-39-220.us-east-2.compute.amazonaws.com | - | Medium
8 | [3.134.125.175](https://vuldb.com/?ip.3.134.125.175) | ec2-3-134-125-175.us-east-2.compute.amazonaws.com | - | Medium
9 | [3.141.177.1](https://vuldb.com/?ip.3.141.177.1) | ec2-3-141-177-1.us-east-2.compute.amazonaws.com | - | Medium
10 | [3.142.81.166](https://vuldb.com/?ip.3.142.81.166) | ec2-3-142-81-166.us-east-2.compute.amazonaws.com | - | Medium
11 | [13.58.157.220](https://vuldb.com/?ip.13.58.157.220) | ec2-13-58-157-220.us-east-2.compute.amazonaws.com | - | Medium
12 | [18.189.106.45](https://vuldb.com/?ip.18.189.106.45) | ec2-18-189-106-45.us-east-2.compute.amazonaws.com | - | Medium
13 | [23.106.215.217](https://vuldb.com/?ip.23.106.215.217) | - | - | High
14 | [23.225.73.110](https://vuldb.com/?ip.23.225.73.110) | - | - | High
15 | [23.251.41.162](https://vuldb.com/?ip.23.251.41.162) | - | - | High
16 | [38.47.204.154](https://vuldb.com/?ip.38.47.204.154) | - | - | High
17 | [38.181.20.78](https://vuldb.com/?ip.38.181.20.78) | - | - | High
18 | [38.181.58.21](https://vuldb.com/?ip.38.181.58.21) | uhn19.pm.com | - | High
19 | [39.109.113.141](https://vuldb.com/?ip.39.109.113.141) | - | - | High
20 | [43.129.192.59](https://vuldb.com/?ip.43.129.192.59) | - | - | High
21 | [43.136.78.18](https://vuldb.com/?ip.43.136.78.18) | - | - | High
22 | [43.142.38.153](https://vuldb.com/?ip.43.142.38.153) | - | - | High
23 | [43.248.137.153](https://vuldb.com/?ip.43.248.137.153) | - | - | High
24 | [43.249.195.178](https://vuldb.com/?ip.43.249.195.178) | - | - | High
25 | [43.255.241.176](https://vuldb.com/?ip.43.255.241.176) | 43-255-241-176.static.bestidc.net | - | High
26 | [45.153.241.207](https://vuldb.com/?ip.45.153.241.207) | - | - | High
27 | [47.92.53.65](https://vuldb.com/?ip.47.92.53.65) | - | - | High
28 | [47.97.103.217](https://vuldb.com/?ip.47.97.103.217) | - | - | High
29 | ... | ... | ... | ...

There are 110 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Ghost RAT_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1055 | CWE-74 | Injection | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 5 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Ghost RAT. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/debug/pprof` | Medium
2 | File | `/yxcms/index.php?r=admin/extendfield/mesedit&tabid=12&id=4` | High
3 | File | `common.php` | Medium
4 | ... | ... | ...

There are 8 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://app.any.run/tasks/81b90352-c3d4-4094-8e38-86dc4110411d/
* https://app.any.run/tasks/571ba149-8de2-4b77-af61-c7fc259eacc3
* https://bazaar.abuse.ch/sample/78be65f626e4a9e81c655b36c96dacc8898287d4954cbffd98788e602369f8ca/
* https://bazaar.abuse.ch/sample/133224bb212564ed0b687341512fa57fe2a55e54defededb5517ac8d8b239677/
* https://bazaar.abuse.ch/sample/ca15a055b2e1d06a8fbd3a22341aeda29bbc19688b778dc3a15c615f0367bc21/
* https://mobile.twitter.com/1ZRR4H/status/1523791593278345217
* https://search.censys.io/hosts/1.13.249.49
* https://search.censys.io/hosts/43.136.78.18
* https://search.censys.io/hosts/43.248.137.153
* https://search.censys.io/hosts/61.147.93.153
* https://search.censys.io/hosts/61.147.199.238
* https://search.censys.io/hosts/85.214.255.25
* https://search.censys.io/hosts/101.43.129.115
* https://search.censys.io/hosts/103.45.128.143
* https://search.censys.io/hosts/103.148.245.125
* https://search.censys.io/hosts/103.165.81.82
* https://search.censys.io/hosts/106.52.216.65
* https://search.censys.io/hosts/116.63.35.42
* https://search.censys.io/hosts/121.5.136.143
* https://search.censys.io/hosts/121.22.243.241
* https://search.censys.io/hosts/121.62.16.112
* https://search.censys.io/hosts/124.222.227.63
* https://search.censys.io/hosts/124.223.199.81
* https://search.censys.io/hosts/125.229.22.79
* https://search.censys.io/hosts/129.204.53.10
* https://search.censys.io/hosts/134.122.135.75
* https://search.censys.io/hosts/134.122.135.81
* https://search.censys.io/hosts/149.88.73.191
* https://search.censys.io/hosts/154.23.141.34
* https://search.censys.io/hosts/156.224.27.167
* https://search.censys.io/hosts/180.97.238.254
* https://search.censys.io/hosts/202.63.172.122
* https://search.censys.io/hosts/211.101.247.155
* https://search.censys.io/hosts/222.222.106.47
* https://threatfox.abuse.ch
* https://www.virustotal.com/gui/file/d565948a3b1b0d86166b62553864a7739284a292cc9c832fddf696bb274f8166/detection

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
