# Glupteba - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Glupteba](https://vuldb.com/?actor.glupteba). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.glupteba](https://vuldb.com/?actor.glupteba)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Glupteba:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [FR](https://vuldb.com/?country.fr)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Glupteba.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [3.33.249.248](https://vuldb.com/?ip.3.33.249.248) | a6adcb4b9bf816abe.awsglobalaccelerator.com | - | High
2 | [5.8.10.194](https://vuldb.com/?ip.5.8.10.194) | - | - | High
3 | [5.9.72.48](https://vuldb.com/?ip.5.9.72.48) | cpanelbk.pcready.me | - | High
4 | [5.79.87.139](https://vuldb.com/?ip.5.79.87.139) | - | - | High
5 | [5.79.87.153](https://vuldb.com/?ip.5.79.87.153) | - | - | High
6 | [5.101.6.132](https://vuldb.com/?ip.5.101.6.132) | amoglo.ru | - | High
7 | [20.60.148.196](https://vuldb.com/?ip.20.60.148.196) | - | - | High
8 | [20.60.161.225](https://vuldb.com/?ip.20.60.161.225) | - | - | High
9 | [20.150.38.228](https://vuldb.com/?ip.20.150.38.228) | - | - | High
10 | [20.150.70.36](https://vuldb.com/?ip.20.150.70.36) | - | - | High
11 | [20.150.79.68](https://vuldb.com/?ip.20.150.79.68) | - | - | High
12 | [20.209.34.36](https://vuldb.com/?ip.20.209.34.36) | - | - | High
13 | [23.5.238.97](https://vuldb.com/?ip.23.5.238.97) | a23-5-238-97.deploy.static.akamaitechnologies.com | - | High
14 | [37.48.81.151](https://vuldb.com/?ip.37.48.81.151) | - | - | High
15 | [40.90.22.185](https://vuldb.com/?ip.40.90.22.185) | - | - | High
16 | [40.112.72.205](https://vuldb.com/?ip.40.112.72.205) | - | - | High
17 | [43.231.4.7](https://vuldb.com/?ip.43.231.4.7) | - | - | High
18 | [45.15.156.202](https://vuldb.com/?ip.45.15.156.202) | - | - | High
19 | [45.90.34.87](https://vuldb.com/?ip.45.90.34.87) | - | - | High
20 | [46.165.244.129](https://vuldb.com/?ip.46.165.244.129) | - | - | High
21 | [46.165.249.167](https://vuldb.com/?ip.46.165.249.167) | - | - | High
22 | [46.165.249.195](https://vuldb.com/?ip.46.165.249.195) | - | - | High
23 | [46.165.249.201](https://vuldb.com/?ip.46.165.249.201) | - | - | High
24 | [46.165.249.203](https://vuldb.com/?ip.46.165.249.203) | - | - | High
25 | [46.165.250.25](https://vuldb.com/?ip.46.165.250.25) | - | - | High
26 | [51.159.136.111](https://vuldb.com/?ip.51.159.136.111) | 111-136-159-51.instances.scw.cloud | - | High
27 | [62.204.41.159](https://vuldb.com/?ip.62.204.41.159) | - | - | High
28 | [69.55.5.249](https://vuldb.com/?ip.69.55.5.249) | - | - | High
29 | [69.64.46.27](https://vuldb.com/?ip.69.64.46.27) | dragon085.startdedicated.de | - | High
30 | [72.21.81.240](https://vuldb.com/?ip.72.21.81.240) | - | - | High
31 | [72.21.91.29](https://vuldb.com/?ip.72.21.91.29) | - | - | High
32 | [74.67.240.204](https://vuldb.com/?ip.74.67.240.204) | cpe-74-67-240-204.twcny.res.rr.com | - | High
33 | ... | ... | ... | ...

There are 129 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Glupteba_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059 | CWE-94 | Cross Site Scripting | High
2 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
3 | T1068 | CWE-264, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
4 | ... | ... | ... | ...

There are 5 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Glupteba. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/departments/view_department.php` | High
2 | File | `/pages/processlogin.php` | High
3 | File | `/wfo/control/emp_selector_pu` | High
4 | ... | ... | ...

There are 17 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2020/09/threat-roundup-0828-0904.html
* https://blog.talosintelligence.com/2020/12/threat-roundup-1204-1211.html
* https://blog.talosintelligence.com/2021/01/threat-roundup-0108-0115.html
* https://blog.talosintelligence.com/2021/01/threat-roundup-0115-0122.html
* https://blog.talosintelligence.com/threat-roundup-0505-0512-3/
* https://blog.talosintelligence.com/threat-roundup-0526-0602/
* https://blog.talosintelligence.com/threat-roundup-1013-1020/
* https://blog.talosintelligence.com/threat-roundup-feb-24-march-3-2023/
* https://github.com/eset/malware-ioc/tree/master/glupteba
* https://www.cyber45.com

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
