# Jordan Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Jordan Unknown](https://vuldb.com/?actor.jordan_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.jordan_unknown](https://vuldb.com/?actor.jordan_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Jordan Unknown:

* [JO](https://vuldb.com/?country.jo)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Jordan Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.17.24.0](https://vuldb.com/?ip.2.17.24.0) | a2-17-24-0.deploy.static.akamaitechnologies.com | - | High
2 | [5.45.128.0](https://vuldb.com/?ip.5.45.128.0) | - | - | High
3 | [5.198.240.0](https://vuldb.com/?ip.5.198.240.0) | - | - | High
4 | [5.199.184.0](https://vuldb.com/?ip.5.199.184.0) | - | - | High
5 | [34.99.162.0](https://vuldb.com/?ip.34.99.162.0) | 0.162.99.34.bc.googleusercontent.com | - | Medium
6 | [34.99.234.0](https://vuldb.com/?ip.34.99.234.0) | 0.234.99.34.bc.googleusercontent.com | - | Medium
7 | [34.103.178.0](https://vuldb.com/?ip.34.103.178.0) | 0.178.103.34.bc.googleusercontent.com | - | Medium
8 | [34.103.234.0](https://vuldb.com/?ip.34.103.234.0) | 0.234.103.34.bc.googleusercontent.com | - | Medium
9 | [34.124.73.0](https://vuldb.com/?ip.34.124.73.0) | 0.73.124.34.bc.googleusercontent.com | - | Medium
10 | [37.17.192.0](https://vuldb.com/?ip.37.17.192.0) | - | - | High
11 | [37.44.32.0](https://vuldb.com/?ip.37.44.32.0) | - | - | High
12 | [37.75.144.0](https://vuldb.com/?ip.37.75.144.0) | - | - | High
13 | [37.75.146.0](https://vuldb.com/?ip.37.75.146.0) | - | - | High
14 | [37.75.148.0](https://vuldb.com/?ip.37.75.148.0) | - | - | High
15 | [37.123.64.0](https://vuldb.com/?ip.37.123.64.0) | - | - | High
16 | [37.152.0.0](https://vuldb.com/?ip.37.152.0.0) | - | - | High
17 | [37.202.64.0](https://vuldb.com/?ip.37.202.64.0) | - | - | High
18 | [37.220.112.0](https://vuldb.com/?ip.37.220.112.0) | - | - | High
19 | [37.252.222.0](https://vuldb.com/?ip.37.252.222.0) | - | - | High
20 | [45.67.60.0](https://vuldb.com/?ip.45.67.60.0) | - | - | High
21 | [45.142.197.0](https://vuldb.com/?ip.45.142.197.0) | - | - | High
22 | [45.142.198.0](https://vuldb.com/?ip.45.142.198.0) | - | - | High
23 | [46.23.112.0](https://vuldb.com/?ip.46.23.112.0) | - | - | High
24 | [46.32.96.0](https://vuldb.com/?ip.46.32.96.0) | - | - | High
25 | [46.185.128.0](https://vuldb.com/?ip.46.185.128.0) | - | - | High
26 | [46.248.192.0](https://vuldb.com/?ip.46.248.192.0) | - | - | High
27 | [57.83.24.0](https://vuldb.com/?ip.57.83.24.0) | - | - | High
28 | [57.88.128.0](https://vuldb.com/?ip.57.88.128.0) | - | - | High
29 | [57.188.4.0](https://vuldb.com/?ip.57.188.4.0) | - | - | High
30 | [62.72.160.0](https://vuldb.com/?ip.62.72.160.0) | - | - | High
31 | [77.245.0.0](https://vuldb.com/?ip.77.245.0.0) | - | - | High
32 | [79.134.128.0](https://vuldb.com/?ip.79.134.128.0) | - | - | High
33 | [79.173.192.0](https://vuldb.com/?ip.79.173.192.0) | 79.173.x.0.go.com.jo | - | High
34 | [80.10.8.0](https://vuldb.com/?ip.80.10.8.0) | - | - | High
35 | ... | ... | ... | ...

There are 134 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Jordan Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059 | CWE-94 | Cross Site Scripting | High
2 | T1505 | CWE-89 | SQL Injection | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Jordan Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | Argument | `filter_order_Dir/cat/filter_letter` | High
2 | Argument | `quesList` | Medium
3 | Network Port | `tcp/3389 (rdp)` | High

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_jo.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
