# Monaco Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Monaco Unknown](https://vuldb.com/?actor.monaco_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.monaco_unknown](https://vuldb.com/?actor.monaco_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Monaco Unknown:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [ES](https://vuldb.com/?country.es)
* ...

There are 5 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Monaco Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.61.24](https://vuldb.com/?ip.5.62.61.24) | r-24-61-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.16](https://vuldb.com/?ip.5.62.63.16) | r-16-63-62-5.consumer-pool.prcdn.net | - | High
3 | [34.99.172.0](https://vuldb.com/?ip.34.99.172.0) | 0.172.99.34.bc.googleusercontent.com | - | Medium
4 | [34.99.244.0](https://vuldb.com/?ip.34.99.244.0) | 0.244.99.34.bc.googleusercontent.com | - | Medium
5 | [34.103.188.0](https://vuldb.com/?ip.34.103.188.0) | 0.188.103.34.bc.googleusercontent.com | - | Medium
6 | [34.103.239.0](https://vuldb.com/?ip.34.103.239.0) | 0.239.103.34.bc.googleusercontent.com | - | Medium
7 | [37.44.224.0](https://vuldb.com/?ip.37.44.224.0) | - | - | High
8 | [45.12.70.139](https://vuldb.com/?ip.45.12.70.139) | schema-if.alltieinc.com | - | High
9 | [45.12.71.139](https://vuldb.com/?ip.45.12.71.139) | - | - | High
10 | [45.42.186.0](https://vuldb.com/?ip.45.42.186.0) | 45-42-186-0.ip.dedicated.static.bmcsvc.com | - | High
11 | [45.138.10.0](https://vuldb.com/?ip.45.138.10.0) | - | - | High
12 | [45.138.68.0](https://vuldb.com/?ip.45.138.68.0) | - | - | High
13 | [57.79.182.0](https://vuldb.com/?ip.57.79.182.0) | - | - | High
14 | [57.79.192.0](https://vuldb.com/?ip.57.79.192.0) | - | - | High
15 | [57.79.248.0](https://vuldb.com/?ip.57.79.248.0) | - | - | High
16 | [80.94.96.0](https://vuldb.com/?ip.80.94.96.0) | - | - | High
17 | [82.113.0.0](https://vuldb.com/?ip.82.113.0.0) | 0.0.113.82.static.monaco.mc | - | High
18 | [82.113.2.0](https://vuldb.com/?ip.82.113.2.0) | - | - | High
19 | [82.113.2.128](https://vuldb.com/?ip.82.113.2.128) | - | - | High
20 | [82.113.2.192](https://vuldb.com/?ip.82.113.2.192) | - | - | High
21 | [82.113.2.200](https://vuldb.com/?ip.82.113.2.200) | - | - | High
22 | [82.113.2.212](https://vuldb.com/?ip.82.113.2.212) | - | - | High
23 | [82.113.2.216](https://vuldb.com/?ip.82.113.2.216) | - | - | High
24 | [82.113.2.224](https://vuldb.com/?ip.82.113.2.224) | - | - | High
25 | [82.113.3.0](https://vuldb.com/?ip.82.113.3.0) | 0.3.113.82.static.monaco.mc | - | High
26 | ... | ... | ... | ...

There are 102 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Monaco Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-35, CWE-36 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 13 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Monaco Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/` | Low
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/APR/signup.php` | High
4 | File | `/cgi-bin/wlogin.cgi` | High
5 | File | `/E-mobile/App/System/File/downfile.php` | High
6 | File | `/Electron/download` | High
7 | File | `/mims/login.php` | High
8 | File | `/php-scrm/login.php` | High
9 | File | `/proxy` | Low
10 | File | `/reviewer/system/system/admins/manage/users/user-update.php` | High
11 | File | `/scripts/unlock_tasks.php` | High
12 | File | `/send_order.cgi?parameter=access_detect` | High
13 | File | `/text/pdf/PdfReader.java` | High
14 | File | `/textpattern/index.php` | High
15 | File | `/tmp` | Low
16 | File | `/wp-admin/admin-ajax.php` | High
17 | File | `account-signup.php` | High
18 | File | `account/signup.php` | High
19 | File | `addentry.php` | Medium
20 | File | `addressbook/backends/ldap/e-book-backend-ldap.c` | High
21 | File | `admin.jcomments.php` | High
22 | File | `admin.php` | Medium
23 | File | `admin/admin_editor.php` | High
24 | File | `admin/conf_users_edit.php` | High
25 | File | `admin/data.php` | High
26 | File | `admin/edit_category.php` | High
27 | File | `admin/operations/currency.php` | High
28 | File | `awstats.pl` | Medium
29 | ... | ... | ...

There are 245 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_mc.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_mc.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_mc.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
