# MuddyWater - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [MuddyWater](https://vuldb.com/?actor.muddywater). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.muddywater](https://vuldb.com/?actor.muddywater)

## Campaigns

The following _campaigns_ are known and can be associated with MuddyWater:

* BlackWater
* Ligolo
* Log4j
* ...

There are 4 more campaign items available. Please use our online service to access the data.

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with MuddyWater:

* [US](https://vuldb.com/?country.us)
* [JP](https://vuldb.com/?country.jp)
* [ES](https://vuldb.com/?country.es)
* ...

There are 28 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of MuddyWater.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [1.5.1.1](https://vuldb.com/?ip.1.5.1.1) | - | - | High
2 | [5.9.0.155](https://vuldb.com/?ip.5.9.0.155) | static.155.0.9.5.clients.your-server.de | - | High
3 | [5.199.133.149](https://vuldb.com/?ip.5.199.133.149) | ve958.venus.servdiscount-customer.com | - | High
4 | [7.236.212.22](https://vuldb.com/?ip.7.236.212.22) | - | - | High
5 | [23.94.7.9](https://vuldb.com/?ip.23.94.7.9) | unsupervised.etcharb.com | - | High
6 | [23.94.7.134](https://vuldb.com/?ip.23.94.7.134) | landau.etcharb.com | - | High
7 | [23.94.24.76](https://vuldb.com/?ip.23.94.24.76) | 23-94-24-76-host.colocrossing.com | - | High
8 | [23.94.24.77](https://vuldb.com/?ip.23.94.24.77) | 23-94-24-77-host.colocrossing.com | - | High
9 | [23.94.24.78](https://vuldb.com/?ip.23.94.24.78) | 23-94-24-78-host.colocrossing.com | - | High
10 | [23.95.8.149](https://vuldb.com/?ip.23.95.8.149) | 23-95-8-149-host.colocrossing.com | - | High
11 | [31.171.154.67](https://vuldb.com/?ip.31.171.154.67) | - | Seedworm | High
12 | [37.120.237.204](https://vuldb.com/?ip.37.120.237.204) | - | - | High
13 | [37.120.237.248](https://vuldb.com/?ip.37.120.237.248) | - | - | High
14 | [37.187.204.27](https://vuldb.com/?ip.37.187.204.27) | smtp1.hosterdaddy.com | - | High
15 | [38.132.99.167](https://vuldb.com/?ip.38.132.99.167) | - | BlackWater | High
16 | [45.67.230.91](https://vuldb.com/?ip.45.67.230.91) | vm1552984.stark-industries.solutions | - | High
17 | [45.86.230.20](https://vuldb.com/?ip.45.86.230.20) | mta0.officeportal-centers.gq | PhonyC2 | High
18 | [45.132.75.101](https://vuldb.com/?ip.45.132.75.101) | edc1.6nc051221c.co | - | High
19 | [45.142.212.61](https://vuldb.com/?ip.45.142.212.61) | vm218389.pq.hosting | - | High
20 | [45.142.213.17](https://vuldb.com/?ip.45.142.213.17) | vm218393.pq.hosting | - | High
21 | [45.150.64.23](https://vuldb.com/?ip.45.150.64.23) | vm1804325.stark-industries.solutions | - | High
22 | [45.150.64.39](https://vuldb.com/?ip.45.150.64.39) | vm1518947.stark-industries.solutions | - | High
23 | [45.150.64.239](https://vuldb.com/?ip.45.150.64.239) | vm1715150.stark-industries.solutions | - | High
24 | [45.153.231.104](https://vuldb.com/?ip.45.153.231.104) | vm218397.pq.hosting | - | High
25 | [45.159.248.244](https://vuldb.com/?ip.45.159.248.244) | vm1355757.stark-industries.solutions | PhonyC2 | High
26 | [46.99.148.96](https://vuldb.com/?ip.46.99.148.96) | - | Seedworm | High
27 | [46.166.129.159](https://vuldb.com/?ip.46.166.129.159) | gcn.warrirge.com | - | High
28 | [46.249.35.243](https://vuldb.com/?ip.46.249.35.243) | uhteronia.xyz | PhonyC2 | High
29 | [51.77.97.65](https://vuldb.com/?ip.51.77.97.65) | ip65.ip-51-77-97.eu | - | High
30 | [51.255.19.178](https://vuldb.com/?ip.51.255.19.178) | pru2.6nc110821hdb.co | - | High
31 | ... | ... | ... | ...

There are 118 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _MuddyWater_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23, CWE-24, CWE-36 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by MuddyWater. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/#ProductSerie/view/` | High
2 | File | `/Account/login.php` | High
3 | File | `/add_classes.php` | High
4 | File | `/admin.php?p=/Area/index#tab=t2` | High
5 | File | `/admin/` | Low
6 | File | `/admin/action/edit_chicken.php` | High
7 | File | `/admin/action/new-father.php` | High
8 | File | `/admin/action/update-deworm.php` | High
9 | File | `/admin/admin_login_process.php` | High
10 | File | `/admin/article.php?action=write` | High
11 | File | `/admin/book_add.php` | High
12 | File | `/admin/book_row.php` | High
13 | File | `/admin/edit_teacher.php` | High
14 | File | `/admin/index.php?act=reset_admin_psw` | High
15 | File | `/Admin/login.php` | High
16 | File | `/admin/makehtml_freelist_action.php` | High
17 | File | `/admin/pages/edit_chicken.php` | High
18 | File | `/admin/pages/student-print.php` | High
19 | File | `/admin/pages/update_go.php` | High
20 | File | `/admin/regester.php` | High
21 | File | `/admin/return_add.php` | High
22 | File | `/admin/students.php` | High
23 | File | `/admin/update-clients.php` | High
24 | File | `/admin/uploads/` | High
25 | File | `/admin/users` | Medium
26 | File | `/admin/view_sendlist.php` | High
27 | File | `/adminapi/system/crud` | High
28 | File | `/adminapi/system/file/openfile` | High
29 | File | `/admin_ping.htm` | High
30 | File | `/admin_route/dec_service_credits.php` | High
31 | File | `/advanced-tools/nova/bin/netwatch` | High
32 | File | `/ample/app/action/edit_product.php` | High
33 | File | `/api.php` | Medium
34 | File | `/api/controllers/admin/app/AppController.php` | High
35 | File | `/api/controllers/admin/app/ComboController.php` | High
36 | File | `/api/controllers/common/UploadsController.php` | High
37 | File | `/api/controllers/merchant/app/ComboController.php` | High
38 | File | `/api/controllers/merchant/design/MaterialController.php` | High
39 | File | `/api/controllers/merchant/shop/PosterController.php` | High
40 | File | `/app/api/controller/default/Sqlite.php` | High
41 | File | `/app/Http/Controllers/ImageController.php` | High
42 | File | `/application/index/common.php` | High
43 | File | `/application/index/controller/Datament.php` | High
44 | File | `/application/index/controller/File.php` | High
45 | File | `/application/index/controller/Icon.php` | High
46 | File | `/application/index/controller/Pay.php` | High
47 | File | `/application/index/controller/Screen.php` | High
48 | File | `/application/index/controller/Unity.php` | High
49 | File | `/application/pay/controller/Api.php` | High
50 | File | `/application/plugins/controller/Upload.php` | High
51 | File | `/application/websocket/controller/Setting.php` | High
52 | File | `/apply/index.php` | High
53 | File | `/apps/reg_go.php` | High
54 | File | `/assets/php/upload.php` | High
55 | File | `/att_add.php` | Medium
56 | File | `/auth/user/all.api` | High
57 | File | `/bin/boa` | Medium
58 | File | `/bin/webs` | Medium
59 | File | `/boafrm/formMapDelDevice` | High
60 | File | `/boafrm/formSystemCheck` | High
61 | File | `/ccm/system/dialogs/file/delete/1/submit` | High
62 | File | `/cgi-bin/cstecgi.cgi` | High
63 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
64 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
65 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=ie8` | High
66 | File | `/classes/Master.php? f=save_medicine` | High
67 | File | `/classes/Users.php?f=save` | High
68 | ... | ... | ...

There are 597 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/05/recent-muddywater-associated-blackwater.html
* https://blog.talosintelligence.com/2022/01/iranian-apt-muddywater-targets-turkey.html
* https://blog.talosintelligence.com/2022/03/iranian-supergroup-muddywater.html
* https://github.com/blackorbird/APT_REPORT/blob/master/muddywater/wp_new_muddywater_findings_uncovered.pdf
* https://github.com/deepinstinct/Israel-Cyber-Warfare-Threat-Actors/blob/main/IOCs-MuddyC2GO.csv
* https://jp.security.ntt/tech_blog/102hq2r
* https://reaqta.com/2017/11/muddywater-apt-targeting-middle-east/
* https://securelist.com/muddywater/88059/
* https://symantec-enterprise-blogs.security.com/blogs/threat-intelligence/iran-apt-seedworm-africa-telecoms
* https://symantec-enterprise-blogs.security.com/blogs/threat-intelligence/seedworm-espionage-group
* https://twitter.com/ShadowChasing1/status/1481621068255137794
* https://unit42.paloaltonetworks.com/unit42-muddying-the-water-targeted-attacks-in-the-middle-east/
* https://www.cisa.gov/uscert/ncas/alerts/aa22-055a
* https://www.clearskysec.com/wp-content/uploads/2019/06/Clearsky-Iranian-APT-group-%E2%80%98MuddyWater%E2%80%99-Adds-Exploits-to-Their-Arsenal.pdf
* https://www.deepinstinct.com/blog/muddyc2go-latest-c2-framework-used-by-iranian-apt-muddywater-spotted-in-israel
* https://www.deepinstinct.com/blog/muddywater-en-able-spear-phishing-with-new-ttps
* https://www.deepinstinct.com/blog/phonyc2-revealing-a-new-malicious-command-control-framework-by-muddywater
* https://www.mandiant.com/resources/telegram-malware-iranian-espionage
* https://www.microsoft.com/security/blog/2022/08/25/mercury-leveraging-log4j-2-vulnerabilities-in-unpatched-systems-to-target-israeli-organizations/
* https://www.threatminer.org/_reports/2019/TheMuddyWatersofAPTAttacks-CheckPointResearch.pdf#viewer.action=download

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
