# Nanocore - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Nanocore](https://vuldb.com/?actor.nanocore). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.nanocore](https://vuldb.com/?actor.nanocore)

## Campaigns

The following _campaigns_ are known and can be associated with Nanocore:

* Tax-Themed Phishing

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Nanocore:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [LU](https://vuldb.com/?country.lu)
* ...

There are 17 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Nanocore.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.57.90.16](https://vuldb.com/?ip.2.57.90.16) | - | - | High
2 | [3.18.7.81](https://vuldb.com/?ip.3.18.7.81) | ec2-3-18-7-81.us-east-2.compute.amazonaws.com | - | Medium
3 | [3.220.57.224](https://vuldb.com/?ip.3.220.57.224) | ec2-3-220-57-224.compute-1.amazonaws.com | - | Medium
4 | [3.232.242.170](https://vuldb.com/?ip.3.232.242.170) | ec2-3-232-242-170.compute-1.amazonaws.com | - | Medium
5 | [5.79.68.107](https://vuldb.com/?ip.5.79.68.107) | - | - | High
6 | [8.8.8.8](https://vuldb.com/?ip.8.8.8.8) | dns.google | - | High
7 | [20.42.65.92](https://vuldb.com/?ip.20.42.65.92) | - | - | High
8 | [23.7.178.157](https://vuldb.com/?ip.23.7.178.157) | a23-7-178-157.deploy.static.akamaitechnologies.com | - | High
9 | [23.192.63.45](https://vuldb.com/?ip.23.192.63.45) | a23-192-63-45.deploy.static.akamaitechnologies.com | - | High
10 | [23.193.194.148](https://vuldb.com/?ip.23.193.194.148) | a23-193-194-148.deploy.static.akamaitechnologies.com | - | High
11 | [23.221.227.169](https://vuldb.com/?ip.23.221.227.169) | a23-221-227-169.deploy.static.akamaitechnologies.com | - | High
12 | [23.230.152.134](https://vuldb.com/?ip.23.230.152.134) | - | - | High
13 | [23.235.221.158](https://vuldb.com/?ip.23.235.221.158) | vps53141.inmotionhosting.com | Tax-Themed Phishing | High
14 | [31.31.196.51](https://vuldb.com/?ip.31.31.196.51) | server222.hosting.reg.ru | - | High
15 | [34.102.136.180](https://vuldb.com/?ip.34.102.136.180) | 180.136.102.34.bc.googleusercontent.com | - | Medium
16 | [34.117.168.233](https://vuldb.com/?ip.34.117.168.233) | 233.168.117.34.bc.googleusercontent.com | - | Medium
17 | [34.237.212.127](https://vuldb.com/?ip.34.237.212.127) | ec2-34-237-212-127.compute-1.amazonaws.com | - | Medium
18 | [35.76.115.170](https://vuldb.com/?ip.35.76.115.170) | ec2-35-76-115-170.ap-northeast-1.compute.amazonaws.com | - | Medium
19 | [35.169.217.142](https://vuldb.com/?ip.35.169.217.142) | ec2-35-169-217-142.compute-1.amazonaws.com | - | Medium
20 | [35.205.61.67](https://vuldb.com/?ip.35.205.61.67) | 67.61.205.35.bc.googleusercontent.com | - | Medium
21 | [35.208.225.54](https://vuldb.com/?ip.35.208.225.54) | 54.225.208.35.bc.googleusercontent.com | - | Medium
22 | [37.0.14.207](https://vuldb.com/?ip.37.0.14.207) | - | - | High
23 | [37.0.14.209](https://vuldb.com/?ip.37.0.14.209) | - | - | High
24 | [37.49.224.172](https://vuldb.com/?ip.37.49.224.172) | - | - | High
25 | [37.235.1.174](https://vuldb.com/?ip.37.235.1.174) | resolver1.freedns.zone.powered.by.virtexxa.com | - | High
26 | [37.235.1.177](https://vuldb.com/?ip.37.235.1.177) | resolver2.freedns.zone.powered.by.virtexxa.com | - | High
27 | [38.6.77.91](https://vuldb.com/?ip.38.6.77.91) | - | - | High
28 | [38.48.189.90](https://vuldb.com/?ip.38.48.189.90) | - | - | High
29 | [38.79.142.66](https://vuldb.com/?ip.38.79.142.66) | box6.dnsexit.com | - | High
30 | [39.96.26.145](https://vuldb.com/?ip.39.96.26.145) | - | - | High
31 | [44.219.130.155](https://vuldb.com/?ip.44.219.130.155) | ec2-44-219-130-155.compute-1.amazonaws.com | - | Medium
32 | [45.12.253.242](https://vuldb.com/?ip.45.12.253.242) | - | - | High
33 | [45.33.6.223](https://vuldb.com/?ip.45.33.6.223) | sqlite.org | - | High
34 | ... | ... | ... | ...

There are 132 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Nanocore_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Nanocore. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/api/admin/system/store/order/list` | High
3 | File | `/api/sys/set_passwd` | High
4 | File | `/bin/boa` | Medium
5 | File | `/cgi-bin/wapopen` | High
6 | File | `/cgi-bin/wlogin.cgi` | High
7 | File | `/csms/?page=contact_us` | High
8 | File | `/dev/urandom` | Medium
9 | File | `/etc/ajenti/config.yml` | High
10 | File | `/etc/quantum/quantum.conf` | High
11 | File | `/exec/` | Low
12 | File | `/forum/away.php` | High
13 | File | `/getcfg.php` | Medium
14 | File | `/goform/telnet` | High
15 | File | `/HNAP1` | Low
16 | File | `/mgmt/tm/util/bash` | High
17 | File | `/modules/profile/index.php` | High
18 | File | `/modules/projects/vw_files.php` | High
19 | File | `/plain` | Low
20 | File | `/rom-0` | Low
21 | File | `/staff/tools/custom-fields` | High
22 | File | `/tmp/phpglibccheck` | High
23 | File | `/uncpath/` | Medium
24 | File | `/upload` | Low
25 | File | `/var/tmp/sess_*` | High
26 | File | `/xyhai.php?s=/Auth/editUser` | High
27 | File | `/_next` | Low
28 | File | `action.php` | Medium
29 | File | `actionHandler/ajax_managed_services.php` | High
30 | File | `actionphp/download.File.php` | High
31 | File | `add_comment.php` | High
32 | File | `admin/admin.php` | High
33 | File | `admin/admin.shtml` | High
34 | File | `admin/content.php` | High
35 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
36 | File | `admin_gallery.php3` | High
37 | File | `affich.php` | Medium
38 | File | `agent/Core/Controller/SendRequest.cpp` | High
39 | File | `ajax-actions.php` | High
40 | File | `ajax/telemetry.php` | High
41 | File | `akeyActivationLogin.do` | High
42 | File | `album_portal.php` | High
43 | ... | ... | ...

There are 375 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/09/threat-roundup-0913-0920.html
* https://blog.talosintelligence.com/2021/07/threat-roundup-0716-0723.html
* https://blog.talosintelligence.com/2021/12/threat-roundup-1126-1203.html
* https://blog.talosintelligence.com/2022/04/threat-roundup-0401-0408.html
* https://blog.talosintelligence.com/2022/07/threat-roundup-0715-0722.html
* https://blog.talosintelligence.com/2022/08/threat-roundup-0812-0819.html
* https://blog.talosintelligence.com/2022/09/threat-roundup-0826-0902.html
* https://blog.talosintelligence.com/2022/09/threat-roundup-0909-0916.html
* https://blog.talosintelligence.com/2022/09/threat-roundup-0916-0923.html
* https://blog.talosintelligence.com/threat-roundup-0113-0120/
* https://blog.talosintelligence.com/threat-roundup-0120-0127/
* https://blog.talosintelligence.com/threat-roundup-0217-0224/
* https://blog.talosintelligence.com/threat-roundup-0526-0602/
* https://blog.talosintelligence.com/threat-roundup-1013-1020/
* https://blog.talosintelligence.com/threat-roundup-1021-1028-2/
* https://blog.talosintelligence.com/threat-roundup-1028-1104/
* https://blog.talosintelligence.com/threat-roundup-1209-1216/
* https://blog.talosintelligence.com/threat-roundup-feb-24-march-3-2023/
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-01-12%20Remcos%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-02-15%20Nanocore%20IOCs
* https://isc.sans.edu/forums/diary/Malspam+delivers+NanoCore+RAT/21615/
* https://unit42.paloaltonetworks.com/nanocorerat-behind-an-increase-in-tax-themed-phishing-e-mails/
* https://www.cyber45.com

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
