# NetSupportManager RAT - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [NetSupportManager RAT](https://vuldb.com/?actor.netsupportmanager_rat). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.netsupportmanager_rat](https://vuldb.com/?actor.netsupportmanager_rat)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with NetSupportManager RAT:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of NetSupportManager RAT.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.39.110.142](https://vuldb.com/?ip.5.39.110.142) | ip142.ip-5-39-110.eu | - | High
2 | [5.42.74.53](https://vuldb.com/?ip.5.42.74.53) | - | - | High
3 | [5.42.82.229](https://vuldb.com/?ip.5.42.82.229) | - | - | High
4 | [5.45.72.55](https://vuldb.com/?ip.5.45.72.55) | - | - | High
5 | [5.45.74.233](https://vuldb.com/?ip.5.45.74.233) | zmta37.corpresponse.com | - | High
6 | [5.45.83.127](https://vuldb.com/?ip.5.45.83.127) | - | - | High
7 | [5.79.72.218](https://vuldb.com/?ip.5.79.72.218) | - | - | High
8 | [5.181.156.45](https://vuldb.com/?ip.5.181.156.45) | 5-181-156-45.mivocloud.com | - | High
9 | [5.181.156.60](https://vuldb.com/?ip.5.181.156.60) | 5-181-156-60.mivocloud.com | - | High
10 | [5.181.156.118](https://vuldb.com/?ip.5.181.156.118) | 5-181-156-118.mivocloud.com | - | High
11 | [5.181.156.235](https://vuldb.com/?ip.5.181.156.235) | 5-181-156-235.mivocloud.com | - | High
12 | [5.181.159.27](https://vuldb.com/?ip.5.181.159.27) | no-rdns.mivocloud.com | - | High
13 | [5.252.176.69](https://vuldb.com/?ip.5.252.176.69) | 5-252-176-69.mivocloud.com | - | High
14 | [5.252.177.111](https://vuldb.com/?ip.5.252.177.111) | no-rdns.mivocloud.com | - | High
15 | [5.252.177.126](https://vuldb.com/?ip.5.252.177.126) | no-rdns.mivocloud.com | - | High
16 | [5.252.177.214](https://vuldb.com/?ip.5.252.177.214) | no-rdns.mivocloud.com | - | High
17 | [5.252.178.51](https://vuldb.com/?ip.5.252.178.51) | 5-252-178-51.mivocloud.com | - | High
18 | [5.252.179.5](https://vuldb.com/?ip.5.252.179.5) | 5-252-179-5.mivocloud.com | - | High
19 | [5.252.179.13](https://vuldb.com/?ip.5.252.179.13) | 5-252-179-13.mivocloud.com | - | High
20 | [5.252.179.17](https://vuldb.com/?ip.5.252.179.17) | mail-good-treat.livewirearea.com | - | High
21 | [5.252.179.50](https://vuldb.com/?ip.5.252.179.50) | no-rdns.mivocloud.com | - | High
22 | [5.252.179.60](https://vuldb.com/?ip.5.252.179.60) | no-rdns.mivocloud.com | - | High
23 | [5.252.179.89](https://vuldb.com/?ip.5.252.179.89) | no-rdns.mivocloud.com | - | High
24 | [5.252.179.93](https://vuldb.com/?ip.5.252.179.93) | no-rdns.mivocloud.com | - | High
25 | [5.252.179.97](https://vuldb.com/?ip.5.252.179.97) | 5-252-179-97.mivocloud.com | - | High
26 | [5.252.179.111](https://vuldb.com/?ip.5.252.179.111) | 5-252-179-111.mivocloud.com | - | High
27 | [23.163.0.13](https://vuldb.com/?ip.23.163.0.13) | ht087348.fronews.com | - | High
28 | [23.227.193.80](https://vuldb.com/?ip.23.227.193.80) | 23-227-193-80.static.hvvc.us | - | High
29 | [37.61.213.242](https://vuldb.com/?ip.37.61.213.242) | - | - | High
30 | [45.11.180.120](https://vuldb.com/?ip.45.11.180.120) | - | - | High
31 | [45.11.180.127](https://vuldb.com/?ip.45.11.180.127) | - | - | High
32 | [45.15.157.144](https://vuldb.com/?ip.45.15.157.144) | - | - | High
33 | [45.15.158.212](https://vuldb.com/?ip.45.15.158.212) | - | - | High
34 | ... | ... | ... | ...

There are 134 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _NetSupportManager RAT_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Argument Injection | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by NetSupportManager RAT. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/index2.html` | High
2 | File | `/api/baskets/{name}` | High
3 | File | `/api/RecordingList/DownloadRecord?file=` | High
4 | File | `/api/v4/users/ids` | High
5 | File | `/apply.cgi` | Medium
6 | File | `/cgi-bin/wlogin.cgi` | High
7 | File | `/debug/pprof` | Medium
8 | File | `/etc/shadow` | Medium
9 | File | `/forum/away.php` | High
10 | File | `/inc/parser/xhtml.php` | High
11 | File | `/include/makecvs.php` | High
12 | File | `/index.php?p=admin/actions/users/send-password-reset-email` | High
13 | File | `/out.php` | Medium
14 | File | `/rapi/read_url` | High
15 | File | `/requests.php` | High
16 | File | `/scripts/unlock_tasks.php` | High
17 | File | `/SysInfo1.htm` | High
18 | File | `/sysinfo_json.cgi` | High
19 | File | `/system/dataPerm/list` | High
20 | File | `/system/user/modules/mod_users/controller.php` | High
21 | File | `/wp-admin/admin-post.php?es_skip=1&option_name` | High
22 | File | `/wp-admin/admin.php?page=wp_file_manager_properties` | High
23 | File | `adclick.php` | Medium
24 | ... | ... | ...

There are 196 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://bazaar.abuse.ch/sample/1a9b3968a2f3a4ae0c9c51e6fc41a48829ac4a0fa118a7530c36715638ef0209/
* https://bazaar.abuse.ch/sample/4a9f42167f399abfbb42a5ee4d52922eb3f7f1ce88d23824f01d13e50609b8b9/
* https://bazaar.abuse.ch/sample/6fe2ea8db2edb522cd33b8d2539ed73cc708f086a65a0e6f8577b4a001d36bd5/
* https://bazaar.abuse.ch/sample/26cad4ec29bc07d7b2c32c94dbbef397391babf1c78cc533950b325aaf11bba8/
* https://bazaar.abuse.ch/sample/48a8c57895c2cfdf13a402e669a9964f56128521404e47b4727672f8ca91a90d/
* https://bazaar.abuse.ch/sample/73e0975c94ebcdec46fd23664ccecf8953dd70eea1f4e5813e7f8cd8d2dbc4f9/
* https://bazaar.abuse.ch/sample/759e159da0592063bb0eb967dd45802caa0a1538867994868d5b883f099286a5/
* https://bazaar.abuse.ch/sample/2174b4c58eb43aac8e5e0061ff0bc45125f4cb64404d552fe25ea6ac1777113d/
* https://bazaar.abuse.ch/sample/38669dd5ccced3c29f3eb6bad7a04fbdc2cc81ea6f7c76b03cf1c4fee6c5f3f0/
* https://bazaar.abuse.ch/sample/933861b75227a3f4727b5872fa9da1b049e420632f8a9198987e8bfbaf7da9e6/
* https://bazaar.abuse.ch/sample/ae2a4c07177c85d3a2611ebbdf54dcee400b6ce6c3b91b2ab5917cdb5966e244/
* https://bazaar.abuse.ch/sample/ae49d8d6d68069696428ebd3fce5a003af4a6ccaf4f67331eea37a0cd4dfbb77/
* https://bazaar.abuse.ch/sample/c9e6dc44db59f1883e850babac21890e5723d2627a623c47f709e3bb7d073e35/
* https://bazaar.abuse.ch/sample/cf4b26813e325da0c821da65e1417bea0045f8349204518b58381609b6662803/
* https://bazaar.abuse.ch/sample/d4f6598a76b92b919bccac6394429a94e7e28da1a86d53e3cd5b204e9c9dc8a8/
* https://bazaar.abuse.ch/sample/fbfec78acd4e7bdd01056de5d866e26db68430bbdc3e0c58f7e123f5b1f3edbe/
* https://infosec.exchange/@malware_traffic/109762477310102114
* https://infosec.exchange/@monitorsg/110845381557169819
* https://infosec.exchange/@monitorsg/111049253426039837
* https://infosec.exchange/@monitorsg/111205676690966247
* https://infosec.exchange/@monitorsg/111326725139303203
* https://infosec.exchange/@monitorsg/111361167778679052
* https://infosec.exchange/@monitorsg/111363999964962348
* https://infosec.exchange/@monitorsg/111499908067388170
* https://infosec.exchange/@monitorsg/111800012173855855
* https://ioc.exchange/@monitorsg@infosec.exchange/111216539556327619
* https://ioc.exchange/@rmceoin@infosec.exchange/110866235650646824
* https://threatfox.abuse.ch
* https://twitter.com/AnFam17/status/1671789322259800064
* https://twitter.com/BroadAnalysis/status/1544348111488929796
* https://twitter.com/Iamdeadlyz/status/1626286411879190528
* https://twitter.com/phage_nz/status/1562229369669828608
* https://twitter.com/pollo290987/status/1562087034948386817
* https://twitter.com/pollo290987/status/1654206717251530753
* https://twitter.com/StopMalvertisin/status/1648223628067237890
* https://urlhaus.abuse.ch/host/navitainer.net/
* https://urlhaus.abuse.ch/url/2733214/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
