# Silence - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Silence](https://vuldb.com/?actor.silence). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.silence](https://vuldb.com/?actor.silence)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Silence:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 9 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Silence.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.8.88.254](https://vuldb.com/?ip.5.8.88.254) | - | - | High
2 | [5.39.30.110](https://vuldb.com/?ip.5.39.30.110) | ip110.ip-5-39-30.eu | - | High
3 | [5.39.218.162](https://vuldb.com/?ip.5.39.218.162) | - | - | High
4 | [5.39.218.205](https://vuldb.com/?ip.5.39.218.205) | - | - | High
5 | [5.39.218.210](https://vuldb.com/?ip.5.39.218.210) | mail.qbmail.biz | - | High
6 | [5.39.221.46](https://vuldb.com/?ip.5.39.221.46) | - | - | High
7 | [5.39.221.60](https://vuldb.com/?ip.5.39.221.60) | - | - | High
8 | [5.154.191.105](https://vuldb.com/?ip.5.154.191.105) | - | - | High
9 | [5.188.231.47](https://vuldb.com/?ip.5.188.231.47) | - | - | High
10 | [5.188.231.89](https://vuldb.com/?ip.5.188.231.89) | - | - | High
11 | [5.200.55.198](https://vuldb.com/?ip.5.200.55.198) | - | - | High
12 | [5.200.56.161](https://vuldb.com/?ip.5.200.56.161) | - | - | High
13 | [31.31.204.161](https://vuldb.com/?ip.31.31.204.161) | - | - | High
14 | [31.41.47.190](https://vuldb.com/?ip.31.41.47.190) | official.zzar.top | - | High
15 | [31.207.45.85](https://vuldb.com/?ip.31.207.45.85) | - | - | High
16 | [45.182.189.71](https://vuldb.com/?ip.45.182.189.71) | - | - | High
17 | [45.182.189.91](https://vuldb.com/?ip.45.182.189.91) | - | - | High
18 | [45.182.189.103](https://vuldb.com/?ip.45.182.189.103) | - | - | High
19 | [45.182.189.118](https://vuldb.com/?ip.45.182.189.118) | - | - | High
20 | [45.182.189.119](https://vuldb.com/?ip.45.182.189.119) | - | - | High
21 | [45.182.189.120](https://vuldb.com/?ip.45.182.189.120) | - | - | High
22 | [45.182.189.200](https://vuldb.com/?ip.45.182.189.200) | - | - | High
23 | [46.30.43.83](https://vuldb.com/?ip.46.30.43.83) | free.eurobyte.ru | - | High
24 | [46.161.40.92](https://vuldb.com/?ip.46.161.40.92) | - | - | High
25 | [46.161.40.128](https://vuldb.com/?ip.46.161.40.128) | - | - | High
26 | [46.170.125.222](https://vuldb.com/?ip.46.170.125.222) | 3.silopol.eu | - | High
27 | [46.183.221.37](https://vuldb.com/?ip.46.183.221.37) | ip-221-37.dataclub.info | - | High
28 | [46.183.221.89](https://vuldb.com/?ip.46.183.221.89) | ip-221-89.dataclub.info | - | High
29 | ... | ... | ... | ...

There are 111 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Silence_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Silence. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?p=products` | Medium
2 | File | `/admin/controller/JobLogController.java` | High
3 | File | `/api/` | Low
4 | File | `/api/admin/store/product/list` | High
5 | File | `/api/baskets/{name}` | High
6 | File | `/api/stl/actions/search` | High
7 | File | `/api/sys/login` | High
8 | File | `/api/sys/set_passwd` | High
9 | File | `/api/trackedEntityInstances` | High
10 | File | `/api/v2/cli/commands` | High
11 | File | `/app/options.py` | High
12 | File | `/aux` | Low
13 | File | `/bin/ate` | Medium
14 | File | `/booking/show_bookings/` | High
15 | File | `/cgi-bin` | Medium
16 | File | `/cgi-bin/wlogin.cgi` | High
17 | File | `/changePassword` | High
18 | File | `/Content/Template/root/reverse-shell.aspx` | High
19 | File | `/dashboard/add-blog.php` | High
20 | File | `/data/remove` | Medium
21 | File | `/debug/pprof` | Medium
22 | File | `/ecshop/admin/template.php` | High
23 | File | `/env` | Low
24 | File | `/etc/passwd` | Medium
25 | File | `/forms/doLogin` | High
26 | File | `/forum/away.php` | High
27 | File | `/group1/uploa` | High
28 | File | `/index.php` | Medium
29 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
30 | File | `/php-sms/admin/?page=user/manage_user` | High
31 | File | `/resources//../` | High
32 | File | `/rom-0` | Low
33 | File | `/ServletAPI/accounts/login` | High
34 | File | `/testConnection` | High
35 | File | `/tmp/ppd.trace` | High
36 | File | `/uncpath/` | Medium
37 | File | `/user/inc/workidajax.php` | High
38 | File | `/user/updatePwd` | High
39 | File | `/userLogin.asp` | High
40 | ... | ... | ...

There are 347 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://cyberforensicator.com/2019/01/20/silence-dissecting-malicious-chm-files-and-performing-forensic-analysis/
* https://securelist.com/the-silence/83009/
* https://threatfox.abuse.ch
* https://www.group-ib.com/resources/threat-research/silence_2.0.going_global.pdf
* https://www.group-ib.com/resources/threat-research/silence_moving-into-the-darkside.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
