# TAG-53 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [TAG-53](https://vuldb.com/?actor.tag-53). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.tag-53](https://vuldb.com/?actor.tag-53)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with TAG-53:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of TAG-53.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.61.63.19](https://vuldb.com/?ip.5.61.63.19) | - | - | High
2 | [23.94.96.12](https://vuldb.com/?ip.23.94.96.12) | 23-94-96-12-host.colocrossing.com | - | High
3 | [23.94.99.19](https://vuldb.com/?ip.23.94.99.19) | 23-94-99-19-host.colocrossing.com | - | High
4 | [23.94.99.22](https://vuldb.com/?ip.23.94.99.22) | 23-94-99-22-host.colocrossing.com | - | High
5 | [23.94.99.26](https://vuldb.com/?ip.23.94.99.26) | 23-94-99-26-host.colocrossing.com | - | High
6 | [23.94.99.30](https://vuldb.com/?ip.23.94.99.30) | 23-94-99-30-host.colocrossing.com | - | High
7 | [23.94.152.50](https://vuldb.com/?ip.23.94.152.50) | 23-94-152-50-host.colocrossing.com | - | High
8 | [23.94.231.161](https://vuldb.com/?ip.23.94.231.161) | 23-94-231-161-host.colocrossing.com | - | High
9 | [23.94.236.80](https://vuldb.com/?ip.23.94.236.80) | 23-94-236-80-host.colocrossing.com | - | High
10 | [23.254.201.243](https://vuldb.com/?ip.23.254.201.243) | hwsrv-1007024.hostwindsdns.com | - | High
11 | [23.254.253.127](https://vuldb.com/?ip.23.254.253.127) | client-23-254-253-127.hostwindsdns.com | - | High
12 | [45.8.146.119](https://vuldb.com/?ip.45.8.146.119) | vm1538642.stark-industries.solutions | - | High
13 | [45.8.146.213](https://vuldb.com/?ip.45.8.146.213) | jbreak.com | - | High
14 | [45.8.146.227](https://vuldb.com/?ip.45.8.146.227) | vm1562338.stark-industries.solutions | - | High
15 | [45.66.248.9](https://vuldb.com/?ip.45.66.248.9) | - | - | High
16 | [45.66.249.83](https://vuldb.com/?ip.45.66.249.83) | - | - | High
17 | [45.66.249.101](https://vuldb.com/?ip.45.66.249.101) | mta0.containers-xchange.com | - | High
18 | [45.86.230.61](https://vuldb.com/?ip.45.86.230.61) | - | - | High
19 | [45.86.230.104](https://vuldb.com/?ip.45.86.230.104) | rtgfv6j8k5.seafood24x7here.info | - | High
20 | [45.86.230.171](https://vuldb.com/?ip.45.86.230.171) | 6qd0xg42xj.alantrislifecoaching.com | - | High
21 | [45.86.230.198](https://vuldb.com/?ip.45.86.230.198) | - | - | High
22 | [45.137.155.33](https://vuldb.com/?ip.45.137.155.33) | son.hfcegytp.com | - | High
23 | [45.144.30.160](https://vuldb.com/?ip.45.144.30.160) | vm1241811.stark-industries.solutions | - | High
24 | [45.144.31.92](https://vuldb.com/?ip.45.144.31.92) | vm854909.stark-industries.solutions | - | High
25 | [45.153.229.79](https://vuldb.com/?ip.45.153.229.79) | vm726095.stark-industries.solutions | - | High
26 | ... | ... | ... | ...

There are 99 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _TAG-53_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1059.007 | CWE-79 | Cross Site Scripting | High
2 | T1505 | CWE-89 | SQL Injection | High
3 | T1592 | CWE-200 | Configuration | High

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by TAG-53. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/secure/QueryComponent!Default.jspa` | High
2 | File | `/v1/tasks/create/` | High
3 | File | `/xxl-job-admin/jobinfo` | High
4 | ... | ... | ...

There are 5 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://go.recordedfuture.com/hubfs/reports/cta-2023-0802.pdf
* https://www.recordedfuture.com/exposing-tag-53-credential-harvesting-infrastructure-for-russia-aligned-espionage-operations

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
