# XLoader - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [XLoader](https://vuldb.com/?actor.xloader). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.xloader](https://vuldb.com/?actor.xloader)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with XLoader:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 9 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of XLoader.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.227.38.74](https://vuldb.com/?ip.23.227.38.74) | shops.myshopify.com | - | High
2 | [31.220.18.33](https://vuldb.com/?ip.31.220.18.33) | - | - | High
3 | [34.102.136.180](https://vuldb.com/?ip.34.102.136.180) | 180.136.102.34.bc.googleusercontent.com | - | Medium
4 | [45.15.25.154](https://vuldb.com/?ip.45.15.25.154) | - | - | High
5 | [45.132.241.87](https://vuldb.com/?ip.45.132.241.87) | - | - | High
6 | [62.72.14.220](https://vuldb.com/?ip.62.72.14.220) | - | - | High
7 | [63.250.33.199](https://vuldb.com/?ip.63.250.33.199) | service-order.quarantine-pnap.web-hosting.com | - | High
8 | [63.250.34.108](https://vuldb.com/?ip.63.250.34.108) | - | - | High
9 | [63.250.34.114](https://vuldb.com/?ip.63.250.34.114) | health-camera.quarantine-pnap.web-hosting.com | - | High
10 | [63.250.34.223](https://vuldb.com/?ip.63.250.34.223) | - | - | High
11 | [63.250.35.46](https://vuldb.com/?ip.63.250.35.46) | server1.cygnatech.eu | - | High
12 | [63.250.35.57](https://vuldb.com/?ip.63.250.35.57) | server1.allwarks.shop | - | High
13 | [63.250.41.119](https://vuldb.com/?ip.63.250.41.119) | - | - | High
14 | [63.250.44.164](https://vuldb.com/?ip.63.250.44.164) | server1.millionfans.net | - | High
15 | [63.250.44.230](https://vuldb.com/?ip.63.250.44.230) | server1.gotobuyersguide.com | - | High
16 | [63.250.44.249](https://vuldb.com/?ip.63.250.44.249) | posevibe.com | - | High
17 | [63.250.44.253](https://vuldb.com/?ip.63.250.44.253) | server1.hyipboybtc.com | - | High
18 | [64.32.8.70](https://vuldb.com/?ip.64.32.8.70) | customer.sharktech.net | - | High
19 | [64.190.62.111](https://vuldb.com/?ip.64.190.62.111) | - | - | High
20 | [66.29.130.171](https://vuldb.com/?ip.66.29.130.171) | - | - | High
21 | [66.29.131.110](https://vuldb.com/?ip.66.29.131.110) | - | - | High
22 | [66.29.131.244](https://vuldb.com/?ip.66.29.131.244) | server1.rozaro-host.com | - | High
23 | [66.29.133.79](https://vuldb.com/?ip.66.29.133.79) | - | - | High
24 | [66.29.133.181](https://vuldb.com/?ip.66.29.133.181) | - | - | High
25 | [66.29.135.47](https://vuldb.com/?ip.66.29.135.47) | server1.inforistic.com | - | High
26 | [66.29.135.231](https://vuldb.com/?ip.66.29.135.231) | - | - | High
27 | [66.29.139.154](https://vuldb.com/?ip.66.29.139.154) | main-too.quarantine-pnap-vlan52.web-hosting.com | - | High
28 | ... | ... | ... | ...

There are 107 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _XLoader_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 12 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by XLoader. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/api/sys/set_passwd` | High
2 | File | `/bin/boa` | Medium
3 | File | `/cgi-bin/wapopen` | High
4 | File | `/cgi-bin/wlogin.cgi` | High
5 | File | `/dev/urandom` | Medium
6 | File | `/etc/quantum/quantum.conf` | High
7 | File | `/exec/` | Low
8 | File | `/getcfg.php` | Medium
9 | File | `/HNAP1` | Low
10 | File | `/mgmt/tm/util/bash` | High
11 | File | `/modules/projects/vw_files.php` | High
12 | File | `/plain` | Low
13 | File | `/staff/tools/custom-fields` | High
14 | File | `/uncpath/` | Medium
15 | File | `/xyhai.php?s=/Auth/editUser` | High
16 | File | `/_next` | Low
17 | ... | ... | ...

There are 134 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.cyble.com/2022/07/01/xloader-returns-with-new-infection-technique/
* https://community.blueliv.com/#!/s/610c31d282df417a0032f54d
* https://research.checkpoint.com/2021/stealth-is-never-enough-or-revealing-formbook-successors-cc-infrastructure/
* https://research.checkpoint.com/2022/xloader-botnet-find-me-if-you-can/
* https://www.sentinelone.com/blog/xloaders-latest-trick-new-macos-variant-disguised-as-signed-officenote-app/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
