# YaBucks - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [YaBucks](https://vuldb.com/?actor.yabucks). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.yabucks](https://vuldb.com/?actor.yabucks)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with YaBucks:

* [US](https://vuldb.com/?country.us)
* [AG](https://vuldb.com/?country.ag)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 6 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of YaBucks.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [3.138.54.87](https://vuldb.com/?ip.3.138.54.87) | ec2-3-138-54-87.us-east-2.compute.amazonaws.com | - | Medium
2 | [3.140.179.210](https://vuldb.com/?ip.3.140.179.210) | ec2-3-140-179-210.us-east-2.compute.amazonaws.com | - | Medium
3 | [3.141.79.17](https://vuldb.com/?ip.3.141.79.17) | ec2-3-141-79-17.us-east-2.compute.amazonaws.com | - | Medium
4 | [3.143.123.90](https://vuldb.com/?ip.3.143.123.90) | ec2-3-143-123-90.us-east-2.compute.amazonaws.com | - | Medium
5 | [3.223.115.185](https://vuldb.com/?ip.3.223.115.185) | ec2-3-223-115-185.compute-1.amazonaws.com | - | Medium
6 | [3.224.108.191](https://vuldb.com/?ip.3.224.108.191) | ec2-3-224-108-191.compute-1.amazonaws.com | - | Medium
7 | [13.70.194.134](https://vuldb.com/?ip.13.70.194.134) | - | - | High
8 | [18.119.154.66](https://vuldb.com/?ip.18.119.154.66) | ec2-18-119-154-66.us-east-2.compute.amazonaws.com | - | Medium
9 | [18.211.9.206](https://vuldb.com/?ip.18.211.9.206) | ec2-18-211-9-206.compute-1.amazonaws.com | - | Medium
10 | [23.20.239.12](https://vuldb.com/?ip.23.20.239.12) | ec2-23-20-239-12.compute-1.amazonaws.com | - | Medium
11 | [23.195.69.108](https://vuldb.com/?ip.23.195.69.108) | a23-195-69-108.deploy.static.akamaitechnologies.com | - | High
12 | [23.202.231.167](https://vuldb.com/?ip.23.202.231.167) | a23-202-231-167.deploy.static.akamaitechnologies.com | - | High
13 | [23.202.231.168](https://vuldb.com/?ip.23.202.231.168) | a23-202-231-168.deploy.static.akamaitechnologies.com | - | High
14 | [23.217.138.108](https://vuldb.com/?ip.23.217.138.108) | a23-217-138-108.deploy.static.akamaitechnologies.com | - | High
15 | [23.246.252.106](https://vuldb.com/?ip.23.246.252.106) | 6a.fc.f617.ip4.static.sl-reverse.com | - | High
16 | [34.102.136.180](https://vuldb.com/?ip.34.102.136.180) | 180.136.102.34.bc.googleusercontent.com | - | Medium
17 | [34.117.168.233](https://vuldb.com/?ip.34.117.168.233) | 233.168.117.34.bc.googleusercontent.com | - | Medium
18 | [34.206.145.143](https://vuldb.com/?ip.34.206.145.143) | ec2-34-206-145-143.compute-1.amazonaws.com | - | Medium
19 | [35.171.109.224](https://vuldb.com/?ip.35.171.109.224) | ec2-35-171-109-224.compute-1.amazonaws.com | - | Medium
20 | ... | ... | ... | ...

There are 77 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _YaBucks_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by YaBucks. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/products/index.php` | High
2 | File | `/changeimage.php` | High
3 | File | `/goform/dir_setWanWifi` | High
4 | File | `/libsystem/login.php` | High
5 | File | `/opt/tms/bin/cli` | High
6 | File | `/preferences/tags` | High
7 | ... | ... | ...

There are 45 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://ddanchev.blogspot.com/2022/10/exposing-portfolio-of-yabucks-pay-per.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
