# Zegost - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Zegost](https://vuldb.com/?actor.zegost). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.zegost](https://vuldb.com/?actor.zegost)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Zegost:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 12 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Zegost.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [14.17.74.162](https://vuldb.com/?ip.14.17.74.162) | - | - | High
2 | [14.113.128.7](https://vuldb.com/?ip.14.113.128.7) | - | - | High
3 | [14.113.128.191](https://vuldb.com/?ip.14.113.128.191) | - | - | High
4 | [14.210.50.189](https://vuldb.com/?ip.14.210.50.189) | - | - | High
5 | [14.210.91.15](https://vuldb.com/?ip.14.210.91.15) | - | - | High
6 | [14.210.95.203](https://vuldb.com/?ip.14.210.95.203) | - | - | High
7 | [14.210.98.141](https://vuldb.com/?ip.14.210.98.141) | - | - | High
8 | [14.210.109.122](https://vuldb.com/?ip.14.210.109.122) | - | - | High
9 | [14.210.222.241](https://vuldb.com/?ip.14.210.222.241) | - | - | High
10 | [20.189.173.20](https://vuldb.com/?ip.20.189.173.20) | - | - | High
11 | [20.210.205.20](https://vuldb.com/?ip.20.210.205.20) | - | - | High
12 | [23.89.5.60](https://vuldb.com/?ip.23.89.5.60) | mtx77mcs683.webex.com | - | High
13 | [27.40.253.131](https://vuldb.com/?ip.27.40.253.131) | - | - | High
14 | [34.107.221.82](https://vuldb.com/?ip.34.107.221.82) | 82.221.107.34.bc.googleusercontent.com | - | Medium
15 | [35.244.181.201](https://vuldb.com/?ip.35.244.181.201) | 201.181.244.35.bc.googleusercontent.com | - | Medium
16 | [43.230.169.58](https://vuldb.com/?ip.43.230.169.58) | - | - | High
17 | [43.248.201.133](https://vuldb.com/?ip.43.248.201.133) | - | - | High
18 | [45.35.20.197](https://vuldb.com/?ip.45.35.20.197) | unassigned.psychz.net | - | High
19 | [45.39.189.31](https://vuldb.com/?ip.45.39.189.31) | - | - | High
20 | [45.114.11.195](https://vuldb.com/?ip.45.114.11.195) | - | - | High
21 | [45.119.125.223](https://vuldb.com/?ip.45.119.125.223) | - | - | High
22 | [47.111.82.157](https://vuldb.com/?ip.47.111.82.157) | - | - | High
23 | [49.2.123.56](https://vuldb.com/?ip.49.2.123.56) | - | - | High
24 | [50.63.202.70](https://vuldb.com/?ip.50.63.202.70) | ip-50-63-202-70.ip.secureserver.net | - | High
25 | [50.63.202.73](https://vuldb.com/?ip.50.63.202.73) | ip-50-63-202-73.ip.secureserver.net | - | High
26 | [50.63.202.88](https://vuldb.com/?ip.50.63.202.88) | ip-50-63-202-88.ip.secureserver.net | - | High
27 | [52.168.117.173](https://vuldb.com/?ip.52.168.117.173) | - | - | High
28 | [54.76.135.1](https://vuldb.com/?ip.54.76.135.1) | ec2-54-76-135-1.eu-west-1.compute.amazonaws.com | - | Medium
29 | [58.221.72.157](https://vuldb.com/?ip.58.221.72.157) | - | - | High
30 | [58.250.136.113](https://vuldb.com/?ip.58.250.136.113) | - | - | High
31 | [59.35.32.87](https://vuldb.com/?ip.59.35.32.87) | 87.32.35.59.broad.st.gd.dynamic.163data.com.cn | - | High
32 | ... | ... | ... | ...

There are 124 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Zegost_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-24 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Zegost. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/act/ActDao.xml` | High
2 | File | `/admin/inquiries/view_inquiry.php` | High
3 | File | `/admin/maintenance/view_designation.php` | High
4 | File | `/admin/pages/edit_chicken.php` | High
5 | File | `/admin/pages/student-print.php` | High
6 | File | `/admin/report/index.php` | High
7 | File | `/admin_route/inc_service_credits.php` | High
8 | File | `/ajax.php?action=read_msg` | High
9 | File | `/api/admin/system/store/order/list` | High
10 | File | `/api/clusters/local/topics/{topic}/messages` | High
11 | File | `/api/gen/clients/{language}` | High
12 | File | `/api/runscript` | High
13 | File | `/app/Http/Controllers/ImageController.php` | High
14 | File | `/application/index/controller/Icon.php` | High
15 | File | `/cgi-bin/cstecgi.cgi` | High
16 | File | `/cgi-bin/webadminget.cgi` | High
17 | File | `/classes/Master.php?f=delete_appointment` | High
18 | File | `/classes/Master.php?f=delete_service` | High
19 | File | `/classes/Master.php?f=save_course` | High
20 | File | `/csms/?page=contact_us` | High
21 | File | `/ctcprotocol/Protocol` | High
22 | File | `/Duty/AjaxHandle/UploadHandler.ashx` | High
23 | File | `/ebics-server/ebics.aspx` | High
24 | File | `/ecommerce/admin/settings/setDiscount.php` | High
25 | File | `/forum/away.php` | High
26 | File | `/general/attendance/manage/ask_duty/delete.php` | High
27 | File | `/goform/net\_Web\_get_value` | High
28 | File | `/GponForm/usb_restore_Form?script/` | High
29 | File | `/group1/uploa` | High
30 | File | `/hedwig.cgi` | Medium
31 | File | `/HNAP1` | Low
32 | File | `/HNAP1/SetClientInfo` | High
33 | File | `/inc/topBarNav.php` | High
34 | File | `/Interface/DevManage/VM.php` | High
35 | File | `/menu.html` | Medium
36 | File | `/modules/profile/index.php` | High
37 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
38 | File | `/oauth/idp/.well-known/openid-configuration` | High
39 | File | `/out.php` | Medium
40 | File | `/php-fusion/infusions/shoutbox_panel/shoutbox_archive.php` | High
41 | File | `/plugin` | Low
42 | File | `/register.do` | Medium
43 | File | `/resources//../` | High
44 | File | `/spip.php` | Medium
45 | ... | ... | ...

There are 389 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/05/threat-roundup-0517-0524.html
* https://blog.talosintelligence.com/2019/08/threat-roundup-0726-0802.html
* https://blog.talosintelligence.com/2020/10/threat-roundup-1016-1023.html
* https://blog.talosintelligence.com/2020/11/threat-roundup-1106-1113.html
* https://blog.talosintelligence.com/2021/01/threat-roundup-0108-0115.html
* https://blog.talosintelligence.com/2021/03/threat-roundup-0226-0305.html
* https://blog.talosintelligence.com/2021/03/threat-roundup-0305-0312.html
* https://blog.talosintelligence.com/2021/04/threat-roundup-0409-0416.html
* https://blog.talosintelligence.com/2021/04/threat-roundup-0416-0423.html
* https://blog.talosintelligence.com/2021/05/threat-roundup-0507-0514.html
* https://blog.talosintelligence.com/2021/05/threat-roundup-0514-0521.html
* https://blog.talosintelligence.com/2021/05/threat-roundup-0521-0528.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0528-0604.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0604-0611.html
* https://blog.talosintelligence.com/2021/07/threat-roundup-0702-0709.html
* https://blog.talosintelligence.com/2021/07/threat-roundup-0716-0723.html
* https://blog.talosintelligence.com/2021/11/threat-roundup-1112-1119.html
* https://blog.talosintelligence.com/2022/02/threat-roundup-0211-0218.html
* https://blog.talosintelligence.com/2022/04/threat-roundup-0325-0401.html
* https://blog.talosintelligence.com/2022/04/threat-roundup-0401-0408.html
* https://blog.talosintelligence.com/2022/04/threat-roundup-0415-0422.html
* https://blog.talosintelligence.com/2022/05/threat-roundup-0513-0520.html
* https://blog.talosintelligence.com/2022/06/threat-roundup-0527-0603.html
* https://blog.talosintelligence.com/2022/10/threat-roundup-1014-1021.html
* https://blog.talosintelligence.com/threat-roundup-0120-0127/
* https://blog.talosintelligence.com/threat-roundup-1028-1104/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
