# Asylum Ambuscade - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Asylum Ambuscade_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Asylum Ambuscade:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 17 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Asylum Ambuscade or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Asylum Ambuscade.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.39.222.150](https://vuldb.com/?ip.5.39.222.150) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
2 | [5.44.42.27](https://vuldb.com/?ip.5.44.42.27) | mexomail-smtp.ip-ptr.tech | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
3 | [5.230.68.137](https://vuldb.com/?ip.5.230.68.137) | placeholder.noezserver.de | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
4 | [5.230.71.166](https://vuldb.com/?ip.5.230.71.166) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
5 | [5.230.72.38](https://vuldb.com/?ip.5.230.72.38) | placeholder.noezserver.de | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
6 | [5.230.72.148](https://vuldb.com/?ip.5.230.72.148) | placeholder.noezserver.de | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
7 | [5.230.73.57](https://vuldb.com/?ip.5.230.73.57) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
8 | [5.230.73.63](https://vuldb.com/?ip.5.230.73.63) | ringbirdapp.com | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
9 | [5.230.73.241](https://vuldb.com/?ip.5.230.73.241) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
10 | [5.230.73.247](https://vuldb.com/?ip.5.230.73.247) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
11 | [5.230.73.248](https://vuldb.com/?ip.5.230.73.248) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
12 | [5.230.73.250](https://vuldb.com/?ip.5.230.73.250) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
13 | [5.252.118.132](https://vuldb.com/?ip.5.252.118.132) | mail2.delivery2023.info | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
14 | [5.252.118.204](https://vuldb.com/?ip.5.252.118.204) | acceptable-scarecrow.aeza.network | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
15 | [5.255.88.222](https://vuldb.com/?ip.5.255.88.222) | alphawolve.com | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
16 | [23.106.123.119](https://vuldb.com/?ip.23.106.123.119) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
17 | [31.192.105.28](https://vuldb.com/?ip.31.192.105.28) | - | [Asylum Ambuscade](https://vuldb.com/?actor.asylum_ambuscade) | High
18 | [45.61.137.231](https://vuldb.com/?ip.45.61.137.231) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
19 | ... | ... | ... | ...

There are 72 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Asylum Ambuscade. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Asylum Ambuscade. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/acms/classes/Master.php?f=delete_cargo` | High
2 | File | `/admin.add` | Medium
3 | File | `/admin.php/news/admin/topic/save` | High
4 | File | `/admin/ajax.php` | High
5 | File | `/admin/api/theme-edit/` | High
6 | File | `/admin/comn/service/update.json` | High
7 | File | `/admin/fst_upload.inc.php` | High
8 | File | `/admin/index2.html` | High
9 | File | `/admin/login.php` | High
10 | File | `/admin/maintenance/view_designation.php` | High
11 | File | `/admin/robot/approval/list` | High
12 | File | `/api/jolokia org.jolokia.http.HttpRequestHandler#handlePostRequest` | High
13 | File | `/api/RecordingList/DownloadRecord?file=` | High
14 | File | `/apply.cgi` | Medium
15 | File | `/cgi-bin/adm.cgi` | High
16 | File | `/cgi-bin/go` | Medium
17 | File | `/cgi-bin/uploadWeiXinPic` | High
18 | File | `/cgi-bin/wapopen` | High
19 | File | `/contact.php` | Medium
20 | File | `/CPE` | Low
21 | File | `/debug/pprof` | Medium
22 | File | `/etc/gsissh/sshd_config` | High
23 | File | `/face-recognition-php/facepay-master/camera.php` | High
24 | File | `/forum/away.php` | High
25 | File | `/forum/PostPrivateMessage` | High
26 | File | `/home/masterConsole` | High
27 | File | `/hrm/employeeadd.php` | High
28 | File | `/hrm/employeeview.php` | High
29 | File | `/librarian/bookdetails.php` | High
30 | File | `/mgmt/tm/util/bash` | High
31 | File | `/mics/j_spring_security_check` | High
32 | File | `/ofcms/company-c-47` | High
33 | File | `/opt/vyatta/share/vyatta-cfg/templates/system/static-host-mapping/host-name/node.def` | High
34 | File | `/owa/auth/logon.aspx` | High
35 | File | `/pms/update_user.php?user_id=1` | High
36 | File | `/scripts/unlock_tasks.php` | High
37 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
38 | File | `/secure/ViewCollectors` | High
39 | File | `/Session` | Medium
40 | File | `/spip.php` | Medium
41 | File | `/staff_login.php` | High
42 | File | `/system/user/modules/mod_users/controller.php` | High
43 | File | `/uncpath/` | Medium
44 | File | `/usr/bin/pkexec` | High
45 | ... | ... | ...

There are 390 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.proofpoint.com/us/blog/threat-insight/asylum-ambuscade-state-actor-uses-compromised-private-ukrainian-military-emails
* https://www.welivesecurity.com/2023/06/08/asylum-ambuscade-crimeware-or-cyberespionage/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
