# Credit Card Shop - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Credit Card Shop_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Credit Card Shop:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 14 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Credit Card Shop or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Credit Card Shop.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.188.89.22](https://vuldb.com/?ip.5.188.89.22) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [5.188.89.114](https://vuldb.com/?ip.5.188.89.114) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [27.102.118.142](https://vuldb.com/?ip.27.102.118.142) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | [35.198.119.28](https://vuldb.com/?ip.35.198.119.28) | 28.119.198.35.bc.googleusercontent.com | [Unknown](https://vuldb.com/?actor.unknown) | Medium
5 | [37.60.177.31](https://vuldb.com/?ip.37.60.177.31) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
6 | [45.34.127.236](https://vuldb.com/?ip.45.34.127.236) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
7 | [45.63.40.156](https://vuldb.com/?ip.45.63.40.156) | 45.63.40.156.vultrusercontent.com | [Unknown](https://vuldb.com/?actor.unknown) | High
8 | [45.149.222.144](https://vuldb.com/?ip.45.149.222.144) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
9 | [46.21.248.49](https://vuldb.com/?ip.46.21.248.49) | diversos02.hiddencontatosgroup.com.de | [Unknown](https://vuldb.com/?actor.unknown) | High
10 | [46.21.249.114](https://vuldb.com/?ip.46.21.249.114) | compraservidorcloudsbrastempspll07.arquivospessoalpr.net | [Unknown](https://vuldb.com/?actor.unknown) | High
11 | [47.52.233.0](https://vuldb.com/?ip.47.52.233.0) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
12 | [47.74.137.231](https://vuldb.com/?ip.47.74.137.231) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
13 | [47.74.176.216](https://vuldb.com/?ip.47.74.176.216) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
14 | [47.74.186.197](https://vuldb.com/?ip.47.74.186.197) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
15 | ... | ... | ... | ...

There are 55 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Credit Card Shop. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Credit Card Shop. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?ajax-request=jnews` | High
2 | File | `/?p=products` | Medium
3 | File | `/admin.php/accessory/filesdel.html` | High
4 | File | `/admin/?page=user/manage` | High
5 | File | `/admin/add-new.php` | High
6 | File | `/admin/controller/JobLogController.java` | High
7 | File | `/admin/doctors.php` | High
8 | File | `/admin/login.php` | High
9 | File | `/alphaware/summary.php` | High
10 | File | `/api/` | Low
11 | File | `/api/admin/store/product/list` | High
12 | File | `/api/baskets/{name}` | High
13 | File | `/api/stl/actions/search` | High
14 | File | `/api/sys/login` | High
15 | File | `/api/sys/set_passwd` | High
16 | File | `/api/trackedEntityInstances` | High
17 | File | `/api/v2/cli/commands` | High
18 | File | `/aux` | Low
19 | File | `/bin/ate` | Medium
20 | File | `/boat/login.php` | High
21 | File | `/booking/show_bookings/` | High
22 | File | `/cgi-bin` | Medium
23 | File | `/cgi-bin/wlogin.cgi` | High
24 | File | `/changePassword` | High
25 | File | `/classes/Users.php` | High
26 | File | `/Content/Template/root/reverse-shell.aspx` | High
27 | File | `/dashboard/add-blog.php` | High
28 | File | `/data/remove` | Medium
29 | File | `/debug/pprof` | Medium
30 | File | `/ecshop/admin/template.php` | High
31 | File | `/env` | Low
32 | File | `/etc/passwd` | Medium
33 | File | `/etc/postfix/sender_login` | High
34 | File | `/forum/away.php` | High
35 | File | `/group1/uploa` | High
36 | File | `/index.php` | Medium
37 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
38 | File | `/pharmacy-sales-and-inventory-system/manage_user.php` | High
39 | File | `/php-sms/admin/?page=user/manage_user` | High
40 | File | `/preview.php` | Medium
41 | File | `/reservation/add_message.php` | High
42 | File | `/resources//../` | High
43 | File | `/Session` | Medium
44 | File | `/testConnection` | High
45 | File | `/tmp/ppd.trace` | High
46 | File | `/user/inc/workidajax.php` | High
47 | ... | ... | ...

There are 412 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://ddanchev.blogspot.com/2022/10/exposing-compilation-of-stolen-credit.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
