# Cuba - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Cuba_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Cuba:

* [VN](https://vuldb.com/?country.vn)
* [US](https://vuldb.com/?country.us)

## Actors

These _actors_ are associated with Cuba or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [UNC2596](https://vuldb.com/?actor.unc2596) | High
2 | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
3 | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Cuba.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [4.16.176.34](https://vuldb.com/?ip.4.16.176.34) | VIASAT-FEDE.ear2.Miami1.Level3.net | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
2 | [5.62.56.72](https://vuldb.com/?ip.5.62.56.72) | r-72-56-62-5.consumer-pool.prcdn.net | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
3 | [5.62.58.68](https://vuldb.com/?ip.5.62.58.68) | r-68-58-62-5.consumer-pool.prcdn.net | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
4 | [5.101.221.128](https://vuldb.com/?ip.5.101.221.128) | - | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
5 | [8.17.107.0](https://vuldb.com/?ip.8.17.107.0) | - | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
6 | [8.17.109.0](https://vuldb.com/?ip.8.17.109.0) | - | [Cuba Unknown](https://vuldb.com/?actor.cuba_unknown) | High
7 | [10.13.102.1](https://vuldb.com/?ip.10.13.102.1) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
8 | [10.13.102.58](https://vuldb.com/?ip.10.13.102.58) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
9 | [10.14.100.20](https://vuldb.com/?ip.10.14.100.20) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
10 | [10.133.78.41](https://vuldb.com/?ip.10.133.78.41) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
11 | [23.160.193.145](https://vuldb.com/?ip.23.160.193.145) | server1.wlook.com | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
12 | [23.227.197.229](https://vuldb.com/?ip.23.227.197.229) | 23-227-197-229.static.hvvc.us | [UNC2596](https://vuldb.com/?actor.unc2596) | High
13 | [23.227.198.246](https://vuldb.com/?ip.23.227.198.246) | 23-227-198-246.static.hvvc.us | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
14 | [31.44.184.84](https://vuldb.com/?ip.31.44.184.84) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
15 | [31.44.184.100](https://vuldb.com/?ip.31.44.184.100) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
16 | [31.184.192.44](https://vuldb.com/?ip.31.184.192.44) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
17 | [31.184.194.42](https://vuldb.com/?ip.31.184.194.42) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
18 | [31.184.198.74](https://vuldb.com/?ip.31.184.198.74) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
19 | [31.184.198.80](https://vuldb.com/?ip.31.184.198.80) | directingme.com | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
20 | [31.184.198.82](https://vuldb.com/?ip.31.184.198.82) | harms.directingme.com | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
21 | [31.184.198.83](https://vuldb.com/?ip.31.184.198.83) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
22 | [31.184.198.84](https://vuldb.com/?ip.31.184.198.84) | - | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
23 | [31.184.198.85](https://vuldb.com/?ip.31.184.198.85) | mta1.thomsai.com | [Cuba Ransomware](https://vuldb.com/?actor.cuba_ransomware) | High
24 | ... | ... | ... | ...

There are 94 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Cuba. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-29, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Cuba. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.env` | Low
2 | File | `/accounts/password_change/` | High
3 | File | `/act/ActDao.xml` | High
4 | File | `/admin/action/new-father.php` | High
5 | File | `/admin/clientview.php` | High
6 | File | `/admin/edit_teacher.php` | High
7 | File | `/admin/fields/manage_field.php` | High
8 | File | `/admin/regester.php` | High
9 | File | `/admin/update-clients.php` | High
10 | File | `/admin_ping.htm` | High
11 | File | `/admin_route/dec_service_credits.php` | High
12 | File | `/admin_route/inc_service_credits.php` | High
13 | File | `/api/baskets/{name}` | High
14 | File | `/api/cron/settings/setJob/` | High
15 | File | `/api/sys/set_passwd` | High
16 | File | `/api/v1/terminal/sessions/?limit=1` | High
17 | File | `/app/api/controller/default/Sqlite.php` | High
18 | File | `/apply.cgi` | Medium
19 | File | `/arch/x86/mm/cpu_entry_area.c` | High
20 | File | `/authenticationendpoint/login.do` | High
21 | File | `/b2b-supermarket/shopping-cart` | High
22 | File | `/bin/boa` | Medium
23 | File | `/boaform/device_reset.cgi` | High
24 | File | `/boafrm/formMapDelDevice` | High
25 | File | `/bsms_ci/index.php` | High
26 | File | `/bsms_ci/index.php/user/edit_user/` | High
27 | File | `/catalog/compare` | High
28 | File | `/cgi-bin/cstecgi.cgi` | High
29 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
30 | File | `/cgi-bin/downloadFile.cgi` | High
31 | File | `/cgi-bin/kerbynet` | High
32 | File | `/cgi-bin/koha/catalogue/search.pl` | High
33 | File | `/cgi-bin/R14.2/cgi-bin/R14.2/host.pl` | High
34 | File | `/cgi-bin/R14.2/easy1350.pl` | High
35 | File | `/cgi-bin/wlogin.cgi` | High
36 | File | `/clinic/disease_symptoms_view.php` | High
37 | File | `/config/getuser` | High
38 | File | `/core/redirect` | High
39 | File | `/dashboard/snapshot/*?orgId=0` | High
40 | File | `/debug/pprof` | Medium
41 | File | `/DXR.axd` | Medium
42 | File | `/emap/devicePoint_addImgIco?hasSubsystem=true` | High
43 | File | `/forum/away.php` | High
44 | ... | ... | ...

There are 377 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_cu.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_cu.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_cu.netset
* https://securelist.com/cuba-ransomware/110533/
* https://www.cisa.gov/uscert/ncas/alerts/aa22-335a
* https://www.mandiant.com/resources/unc2596-cuba-ransomware

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
