# DarkGate - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _DarkGate_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with DarkGate:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [VN](https://vuldb.com/?country.vn)
* ...

There are 15 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with DarkGate or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [DarkGate](https://vuldb.com/?actor.darkgate) | High
2 | [BattleRoyal](https://vuldb.com/?actor.battleroyal) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of DarkGate.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.2.68.68](https://vuldb.com/?ip.5.2.68.68) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
2 | [5.2.68.77](https://vuldb.com/?ip.5.2.68.77) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
3 | [5.2.68.89](https://vuldb.com/?ip.5.2.68.89) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
4 | [5.34.178.21](https://vuldb.com/?ip.5.34.178.21) | udfurgqxmjzcc.pserver.ru | [DarkGate](https://vuldb.com/?actor.darkgate) | High
5 | [5.181.159.29](https://vuldb.com/?ip.5.181.159.29) | no-rdns.mivocloud.com | [BattleRoyal](https://vuldb.com/?actor.battleroyal) | High
6 | [5.181.159.49](https://vuldb.com/?ip.5.181.159.49) | no-rdns.mivocloud.com | [DarkGate](https://vuldb.com/?actor.darkgate) | High
7 | [5.181.159.64](https://vuldb.com/?ip.5.181.159.64) | no-rdns.mivocloud.com | [DarkGate](https://vuldb.com/?actor.darkgate) | High
8 | [5.181.159.76](https://vuldb.com/?ip.5.181.159.76) | no-rdns.mivocloud.com | [DarkGate](https://vuldb.com/?actor.darkgate) | High
9 | [5.188.87.58](https://vuldb.com/?ip.5.188.87.58) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
10 | [5.252.178.193](https://vuldb.com/?ip.5.252.178.193) | 5-252-178-193.mivocloud.com | [DarkGate](https://vuldb.com/?actor.darkgate) | High
11 | [8.209.99.230](https://vuldb.com/?ip.8.209.99.230) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
12 | [34.16.181.0](https://vuldb.com/?ip.34.16.181.0) | 0.181.16.34.bc.googleusercontent.com | [DarkGate](https://vuldb.com/?actor.darkgate) | Medium
13 | [35.203.111.228](https://vuldb.com/?ip.35.203.111.228) | 228.111.203.35.bc.googleusercontent.com | [DarkGate](https://vuldb.com/?actor.darkgate) | Medium
14 | [35.247.194.72](https://vuldb.com/?ip.35.247.194.72) | 72.194.247.35.bc.googleusercontent.com | [DarkGate](https://vuldb.com/?actor.darkgate) | Medium
15 | [38.180.60.31](https://vuldb.com/?ip.38.180.60.31) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
16 | [45.67.34.69](https://vuldb.com/?ip.45.67.34.69) | vm2117880.stark-industries.solutions | [DarkGate](https://vuldb.com/?actor.darkgate) | High
17 | [45.89.65.198](https://vuldb.com/?ip.45.89.65.198) | 2.server.com | [DarkGate](https://vuldb.com/?actor.darkgate) | High
18 | [45.141.87.89](https://vuldb.com/?ip.45.141.87.89) | - | [DarkGate](https://vuldb.com/?actor.darkgate) | High
19 | [46.21.157.142](https://vuldb.com/?ip.46.21.157.142) | 142.157.21.46.inferno.name | [DarkGate](https://vuldb.com/?actor.darkgate) | High
20 | ... | ... | ... | ...

There are 78 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within DarkGate. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-24, CWE-25, CWE-36 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during DarkGate. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/#ilang=DE&b=c_smartenergy_swgroups` | High
2 | File | `/#ProductSerie/view/` | High
3 | File | `/Account/login.php` | High
4 | File | `/admin/` | Low
5 | File | `/admin/action/add_con.php` | High
6 | File | `/admin/action/delete-vaccine.php` | High
7 | File | `/admin/action/edit_chicken.php` | High
8 | File | `/admin/action/new-father.php` | High
9 | File | `/admin/action/new-feed.php` | High
10 | File | `/admin/action/update-deworm.php` | High
11 | File | `/admin/admin_user.php` | High
12 | File | `/admin/clientview.php` | High
13 | File | `/admin/list_ipAddressPolicy.php` | High
14 | File | `/admin/pages/edit_chicken.php` | High
15 | File | `/admin/pages/student-print.php` | High
16 | File | `/admin/regester.php` | High
17 | File | `/admin/request-received-bydonar.php` | High
18 | File | `/admin/update-clients.php` | High
19 | File | `/adminapi/system/crud` | High
20 | File | `/adminapi/system/file/openfile` | High
21 | File | `/admin_route/dec_service_credits.php` | High
22 | File | `/admin_route/inc_service_credits.php` | High
23 | File | `/api.php` | Medium
24 | File | `/api/v4/teams//channels/deleted` | High
25 | File | `/app/api/controller/default/Sqlite.php` | High
26 | File | `/app/Http/Controllers/ImageController.php` | High
27 | File | `/app/index/controller/Common.php` | High
28 | File | `/application/index/controller/Databasesource.php` | High
29 | File | `/application/index/controller/File.php` | High
30 | File | `/application/index/controller/Icon.php` | High
31 | File | `/application/index/controller/Screen.php` | High
32 | File | `/application/index/controller/Unity.php` | High
33 | File | `/application/plugins/controller/Upload.php` | High
34 | File | `/auth/auth.php?user=1` | High
35 | File | `/b2b-supermarket/shopping-cart` | High
36 | File | `/bin/boa` | Medium
37 | File | `/boaform/device_reset.cgi` | High
38 | File | `/boafrm/formMapDelDevice` | High
39 | File | `/cgi-bin/cstecgi.cgi` | High
40 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
41 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
42 | File | `/cgi-bin/wlogin.cgi` | High
43 | File | `/cgi/cpaddons_report.pl` | High
44 | File | `/change-language/de_DE` | High
45 | File | `/classes/Users.php?f=save` | High
46 | File | `/common/dict/list` | High
47 | File | `/debug/pprof` | Medium
48 | File | `/devinfo` | Medium
49 | File | `/dist/index.js` | High
50 | File | `/filex/proxy-download` | High
51 | File | `/forum/away.php` | High
52 | File | `/general/attendance/manage/ask_duty/delete.php` | High
53 | File | `/general/email/outbox/delete.php` | High
54 | File | `/goform/goform_get_cmd_process` | High
55 | File | `/goform/setDeviceSettings` | High
56 | File | `/goform/SetOnlineDevName` | High
57 | File | `/goform/WifiExtraSet` | High
58 | File | `/hedwig.cgi` | Medium
59 | File | `/hosts/firewall/ip` | High
60 | File | `/importexport.php` | High
61 | File | `/index.jsp#settings` | High
62 | File | `/index.php/ccm/system/file/upload` | High
63 | File | `/index.php/signin` | High
64 | File | `/log/decodmail.php` | High
65 | ... | ... | ...

There are 572 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://app.any.run/tasks/9b94c5e4-d5aa-4eaa-be23-a754f94a617b/
* https://asec.ahnlab.com/en/61000/
* https://github.com/PaloAltoNetworks/Unit42-timely-threat-intel/blob/main/2023-10-25-IOCs-from-DarkGate-activity.txt
* https://github.com/prodaft/malware-ioc/blob/master/PTI-66/DarkGate.md
* https://github.com/stamparm/maltrail/blob/master/trails/static/malware/darkgate.txt
* https://github.com/stamparm/maltrail/commit/447dfd954176b9c1810cce08043ad5cfbf72175b
* https://github.security.telekom.com/2023/08/darkgate-loader.html
* https://isc.sans.edu/diary/rss/30700
* https://labs.withsecure.com/publications/darkgate-malware-campaign
* https://malware-traffic-analysis.net/2023/11/30/index.html
* https://search.censys.io/hosts/94.232.45.90
* https://search.censys.io/hosts/162.33.178.63
* https://search.censys.io/hosts/185.82.219.87
* https://search.censys.io/hosts/195.123.233.126
* https://search.censys.io/hosts/195.123.233.152
* https://search.censys.io/hosts/195.123.233.201
* https://search.censys.io/hosts/195.123.233.206
* https://search.censys.io/hosts/195.211.98.105
* https://search.censys.io/search?resource=hosts&sort=RELEVANCE&per_page=25&virtual_hosts=EXCLUDE&q=services.extended_service_name%3D%22DARKGATE%22
* https://search.censys.io/search?resource=hosts&sort=RELEVANCE&per_page=25&virtual_hosts=EXCLUDE&q=services.service_name%3A+DARKGATE
* https://search.censys.io/search?resource=hosts&sort=RELEVANCE&per_page=25&virtual_hosts=EXCLUDE&q=services.service_name%3A+DARKGATE+and+not+labels%3A+tarpit&ref=threatfox
* https://threatfox.abuse.ch
* https://tria.ge/230811-bmv8ysbf8s/behavioral2
* https://tria.ge/230822-xp3lpsgc6v/behavioral2
* https://tria.ge/230828-zp22aaah9s/behavioral1
* https://tria.ge/231026-31zl3sbe25
* https://tria.ge/231102-ssnvhafg98/behavioral2
* https://tria.ge/231102-zyfveahf27
* https://tria.ge/231120-vg8fwahc22
* https://tria.ge/240303-p2q5fabb93/behavioral2
* https://twitter.com/0xw4ifu/status/1714738953016746247
* https://twitter.com/AnFam17/status/1701963227955945552
* https://twitter.com/malwrhunterteam/status/1704231060865778097
* https://twitter.com/malwrhunterteam/status/1704483766461173984
* https://twitter.com/r3dbU7z/status/1712256418483519885
* https://twitter.com/ULTRAFRAUD/status/1702067641983119421
* https://urlhaus.abuse.ch/url/2729402/
* https://www.malware-traffic-analysis.net/2024/01/25/index.html
* https://www.malware-traffic-analysis.net/2024/01/30/index.html
* https://www.mandiant.com/resources/blog/detecting-disrupting-malvertising-backdoors
* https://www.proofpoint.com/us/blog/threat-insight/battleroyal-darkgate-cluster-spreads-email-and-fake-browser-updates
* https://www.virustotal.com/gui/file/8ba5c6c94e016941464bc65bd697749e7a2c88fb3a5b420f23cd1aa1ab022eef
* https://www.virustotal.com/gui/file/9921e057693d70d2f6bf13a04abf816c10fe209cff82cb533596ed313b9d2154/detection
* https://www.virustotal.com/gui/file/c2e90c45911b7b6e9d46f4dae5bfefa47e50abddd75cc6d5297cddeee23dd002
* https://www.virustotal.com/gui/file/f0f22f8f3b308b0d8fae34c9eb65ab1e8fde41f9933ef07d1e819163234adbee
* https://www.virustotal.com/gui/file/f12d21bdf3eea879223737eb604feef8c0b15be9b48ad2b1d9d3b43117b0bb3e/detection

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
