# Middle East - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Middle East_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Middle East:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [VN](https://vuldb.com/?country.vn)
* ...

There are 14 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Middle East or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Molerats](https://vuldb.com/?actor.molerats) | High
2 | [Wirte](https://vuldb.com/?actor.wirte) | High
3 | [DNSpionage](https://vuldb.com/?actor.dnspionage) | High
4 | ... | ...

There are 2 more actor items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Middle East.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.34.180.252](https://vuldb.com/?ip.5.34.180.252) | storage-948074.hosted-by.itldc.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
2 | [5.34.181.13](https://vuldb.com/?ip.5.34.181.13) | backups231.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
3 | [23.94.50.197](https://vuldb.com/?ip.23.94.50.197) | 23-94-50-197-host.colocrossing.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
4 | [23.94.218.221](https://vuldb.com/?ip.23.94.218.221) | 23-94-218-221-host.colocrossing.com | [Molerats](https://vuldb.com/?actor.molerats) | High
5 | [23.95.215.100](https://vuldb.com/?ip.23.95.215.100) | 23-95-215-100-host.colocrossing.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
6 | [31.192.105.16](https://vuldb.com/?ip.31.192.105.16) | down-it-niscat.donotbargain.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
7 | [31.192.105.17](https://vuldb.com/?ip.31.192.105.17) | - | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
8 | [31.192.105.28](https://vuldb.com/?ip.31.192.105.28) | - | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
9 | [38.130.75.20](https://vuldb.com/?ip.38.130.75.20) | h20-us75.fcsrv.net | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
10 | [45.63.49.202](https://vuldb.com/?ip.45.63.49.202) | 45.63.49.202.vultr.com | [Molerats](https://vuldb.com/?actor.molerats) | Medium
11 | [45.129.96.174](https://vuldb.com/?ip.45.129.96.174) | free.gmhost.hosting | [Wirte](https://vuldb.com/?actor.wirte) | High
12 | [45.129.97.207](https://vuldb.com/?ip.45.129.97.207) | - | [Wirte](https://vuldb.com/?actor.wirte) | High
13 | [51.68.244.39](https://vuldb.com/?ip.51.68.244.39) | ip39.ip-51-68-244.eu | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
14 | [51.254.76.54](https://vuldb.com/?ip.51.254.76.54) | - | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
15 | [62.109.2.52](https://vuldb.com/?ip.62.109.2.52) | ns.leangroup.ru | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
16 | [66.55.152.164](https://vuldb.com/?ip.66.55.152.164) | 66-55-152-164.choopa.net | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
17 | [68.232.180.122](https://vuldb.com/?ip.68.232.180.122) | 68-232-180-122.choopa.net | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
18 | [70.34.248.149](https://vuldb.com/?ip.70.34.248.149) | 70.34.248.149.vultrusercontent.com | [BackdoorDiplomacy](https://vuldb.com/?actor.backdoordiplomacy) | High
19 | [80.179.42.37](https://vuldb.com/?ip.80.179.42.37) | 80.179.42.37.forward.012.net.il | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
20 | [80.179.42.44](https://vuldb.com/?ip.80.179.42.44) | lnkrten-dazling.linegrace.com | [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown) | High
21 | ... | ... | ... | ...

There are 79 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Middle East. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-24 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-266, CWE-269, CWE-284 | Execution with Unnecessary Privileges | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Middle East. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/addnews.html` | High
2 | File | `/admin/` | Low
3 | File | `/admin/admin_content_tag.php?action=save_content` | High
4 | File | `/admin/admin_user.php` | High
5 | File | `/admin/app/product.php` | High
6 | File | `/admin/category/save` | High
7 | File | `/admin/category_row.php` | High
8 | File | `/admin/ind_backstage.php` | High
9 | File | `/admin/list_ipAddressPolicy.php` | High
10 | File | `/admin/return_add.php` | High
11 | File | `/admin/subject.php` | High
12 | File | `/admin/upload/img` | High
13 | File | `/admin_route/dec_service_credits.php` | High
14 | File | `/api/controllers/merchant/design/MaterialController.php` | High
15 | File | `/app/ajax/sell_return_data.php` | High
16 | File | `/app/api/controller/default/File.php` | High
17 | File | `/application/index/controller/Datament.php` | High
18 | File | `/application/index/controller/File.php` | High
19 | File | `/att_add.php` | Medium
20 | File | `/auth/auth.php?user=1` | High
21 | File | `/b2b-supermarket/catalog/all-products` | High
22 | File | `/bin/boa` | Medium
23 | File | `/boaform/device_reset.cgi` | High
24 | File | `/boaform/wlan_basic_set.cgi` | High
25 | File | `/cgi-bin/cstecgi.cgi` | High
26 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
27 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
28 | File | `/cgi-bin/wlogin.cgi` | High
29 | File | `/cgi/cpaddons_report.pl` | High
30 | File | `/classes/Master.php?f=delete_reminder` | High
31 | File | `/debug/pprof` | Medium
32 | File | `/DXR.axd` | Medium
33 | File | `/Employer/EditProfile.php` | High
34 | File | `/Employer/ManageWalkin.php` | High
35 | File | `/forum/away.php` | High
36 | File | `/goform/goform_get_cmd_process` | High
37 | File | `/HNAP1/` | Low
38 | File | `/im/user/` | Medium
39 | File | `/importexport.php` | High
40 | File | `/libsystem/login.php` | High
41 | File | `/main/checkout.php` | High
42 | File | `/main/doctype.php` | High
43 | File | `/main/webservices/additional_webservices.php` | High
44 | File | `/mc` | Low
45 | File | `/mgmt/` | Low
46 | File | `/net/bluetooth/rfcomm/core.C` | High
47 | File | `/novel/bookSetting/list` | High
48 | File | `/oa/notify/edit` | High
49 | ... | ... | ...

There are 428 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://blog.talosintelligence.com/2020/01/mideast-tensions-preparations.html
* https://community.blueliv.com/#!/s/5fd096f382df413eaf344efc
* https://community.blueliv.com/#!/s/6053819b82df413eaf346332
* https://gblogs.cisco.com/jp/2018/12/talos-dnspionage-campaign-targets-middle-east/)
* https://securelist.com/wirtes-campaign-in-the-middle-east-living-off-the-land-since-at-least-2019/105044/
* https://www.bitdefender.com/files/News/CaseStudies/study/426/Bitdefender-PR-Whitepaper-BackdoorDiplomacy-creat6507-en-EN.pdf
* https://www.zscaler.com/blogs/security-research/new-espionage-attack-molerats-apt-targeting-users-middle-east

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
