# Wilted Tulip - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Wilted Tulip_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Wilted Tulip:

* [US](https://vuldb.com/?country.us)
* [IT](https://vuldb.com/?country.it)
* [PT](https://vuldb.com/?country.pt)
* ...

There are 12 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Wilted Tulip or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [CopyKittens](https://vuldb.com/?actor.copykittens) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Wilted Tulip.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.34.180.252](https://vuldb.com/?ip.5.34.180.252) | vds-uuallex-113169.hosted-by-itldc.com | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
2 | [5.34.181.13](https://vuldb.com/?ip.5.34.181.13) | backups231.com | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
3 | [31.192.105.16](https://vuldb.com/?ip.31.192.105.16) | down-it-niscat.cosmeticdentistwellesley.com | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
4 | [31.192.105.17](https://vuldb.com/?ip.31.192.105.17) | - | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
5 | [31.192.105.28](https://vuldb.com/?ip.31.192.105.28) | - | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
6 | [38.130.75.20](https://vuldb.com/?ip.38.130.75.20) | h20-us75.fcsrv.net | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
7 | [51.254.76.54](https://vuldb.com/?ip.51.254.76.54) | - | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
8 | [62.109.2.52](https://vuldb.com/?ip.62.109.2.52) | ns.leangroup.ru | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
9 | [66.55.152.164](https://vuldb.com/?ip.66.55.152.164) | 66-55-152-164.choopa.net | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
10 | [68.232.180.122](https://vuldb.com/?ip.68.232.180.122) | 68-232-180-122.choopa.net | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
11 | [80.179.42.37](https://vuldb.com/?ip.80.179.42.37) | 80.179.42.37.forward.012.net.il | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
12 | [93.190.138.137](https://vuldb.com/?ip.93.190.138.137) | 93-190-138-137.hosted-by-worldstream.net | [CopyKittens](https://vuldb.com/?actor.copykittens) | High
13 | ... | ... | ... | ...

There are 50 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Wilted Tulip. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Wilted Tulip. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/academy/tutor/filter` | High
2 | File | `/action/factory` | High
3 | File | `/admin.php` | Medium
4 | File | `/admin/` | Low
5 | File | `/admin/add-category.php` | High
6 | File | `/admin/add_user_modal.php` | High
7 | File | `/admin/admin_content_tag.php?action=save_content` | High
8 | File | `/admin/article/article-edit-run.php` | High
9 | File | `/admin/categories/view_category.php` | High
10 | File | `/admin/category_row.php` | High
11 | File | `/admin/ind_backstage.php` | High
12 | File | `/admin/loginc.php` | High
13 | File | `/admin/maintenance/view_designation.php` | High
14 | File | `/admin/project/update/2` | High
15 | File | `/admin/report/index.php` | High
16 | File | `/admin/return_add.php` | High
17 | File | `/admin/upload/img` | High
18 | File | `/admin_route/dec_service_credits.php` | High
19 | File | `/app/ajax/sell_return_data.php` | High
20 | File | `/app/api/controller/default/File.php` | High
21 | File | `/b2b-supermarket/catalog/all-products` | High
22 | File | `/bin/boa` | Medium
23 | File | `/binbloom-master/src/helpers.c` | High
24 | File | `/blog` | Low
25 | File | `/boaform/wlan_basic_set.cgi` | High
26 | File | `/category.php` | High
27 | File | `/cgi-bin/cstecgi.cgi` | High
28 | File | `/classes/Master.php?f=delete_reminder` | High
29 | File | `/contacts/listcontacts.php` | High
30 | File | `/Core/Ap4File.cpp` | High
31 | File | `/data/app` | Medium
32 | File | `/dede/file_manage_control.php` | High
33 | File | `/depotHead/list` | High
34 | File | `/etc/os-release` | High
35 | File | `/etc/pki/pulp/nodes/` | High
36 | File | `/forms/web_runScript` | High
37 | File | `/forum/away.php` | High
38 | File | `/fs/nfsd/nfs4proc.c` | High
39 | File | `/garage/php_action/createBrand.php` | High
40 | File | `/general/search.php?searchtype=simple` | High
41 | File | `/ghost/preview` | High
42 | File | `/goform/AddSysLogRule` | High
43 | File | `/goform/AdvSetWrlsafeset` | High
44 | File | `/goform/qossetting` | High
45 | File | `/goform/setAutoPing` | High
46 | File | `/hrm/employeeview.php` | High
47 | File | `/hss/?page=product_per_brand` | High
48 | File | `/im/user/` | Medium
49 | File | `/index.php` | Medium
50 | File | `/index.php?page=member` | High
51 | File | `/libsystem/login.php` | High
52 | File | `/load.php` | Medium
53 | File | `/main/checkout.php` | High
54 | File | `/meetings/listmeetings.php` | High
55 | File | `/novel/bookSetting/list` | High
56 | File | `/oauth/idp/.well-known/openid-configuration` | High
57 | File | `/odlms/classes/Users.php?f=delete` | High
58 | File | `/php/ping.php` | High
59 | ... | ... | ...

There are 514 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.clearskysec.com/wp-content/uploads/2017/07/Operation_Wilted_Tulip.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
