# Algeria Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Algeria Unknown](https://vuldb.com/?actor.algeria_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.algeria_unknown](https://vuldb.com/?actor.algeria_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Algeria Unknown:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 20 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Algeria Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.61.244](https://vuldb.com/?ip.5.62.61.244) | r-244-61-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.240](https://vuldb.com/?ip.5.62.63.240) | r-240-63-62-5.consumer-pool.prcdn.net | - | High
3 | [31.132.52.0](https://vuldb.com/?ip.31.132.52.0) | - | - | High
4 | [41.77.176.0](https://vuldb.com/?ip.41.77.176.0) | - | - | High
5 | [41.96.0.0](https://vuldb.com/?ip.41.96.0.0) | - | - | High
6 | [41.104.0.0](https://vuldb.com/?ip.41.104.0.0) | - | - | High
7 | [41.108.0.0](https://vuldb.com/?ip.41.108.0.0) | - | - | High
8 | [41.109.0.0](https://vuldb.com/?ip.41.109.0.0) | - | - | High
9 | [41.109.64.0](https://vuldb.com/?ip.41.109.64.0) | - | - | High
10 | [41.109.96.0](https://vuldb.com/?ip.41.109.96.0) | - | - | High
11 | [41.109.112.0](https://vuldb.com/?ip.41.109.112.0) | - | - | High
12 | [41.109.116.0](https://vuldb.com/?ip.41.109.116.0) | - | - | High
13 | [41.109.118.0](https://vuldb.com/?ip.41.109.118.0) | - | - | High
14 | [41.109.120.0](https://vuldb.com/?ip.41.109.120.0) | - | - | High
15 | [41.109.128.0](https://vuldb.com/?ip.41.109.128.0) | - | - | High
16 | [41.110.0.0](https://vuldb.com/?ip.41.110.0.0) | - | - | High
17 | [41.191.252.0](https://vuldb.com/?ip.41.191.252.0) | - | - | High
18 | [41.200.0.0](https://vuldb.com/?ip.41.200.0.0) | - | - | High
19 | [41.210.64.0](https://vuldb.com/?ip.41.210.64.0) | - | - | High
20 | [41.220.144.0](https://vuldb.com/?ip.41.220.144.0) | - | - | High
21 | ... | ... | ... | ...

There are 80 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Algeria Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-25, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Algeria Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%SYSTEMDRIVE%\node_modules\.bin\wmic.exe` | High
2 | File | `/admin/manage-users.php` | High
3 | File | `/admin/save.php` | High
4 | File | `/admin/sys_sql_query.php` | High
5 | File | `/api/baskets/{name}` | High
6 | File | `/api/download` | High
7 | File | `/api/v1/alerts` | High
8 | File | `/api/v1/terminal/sessions/?limit=1` | High
9 | File | `/api/v4/teams//channels/deleted` | High
10 | File | `/b2b-supermarket/shopping-cart` | High
11 | File | `/bitrix/admin/ldap_server_edit.php` | High
12 | File | `/category.php` | High
13 | File | `/categorypage.php` | High
14 | File | `/cgi-bin/luci/api/wireless` | High
15 | File | `/cgi-bin/vitogate.cgi` | High
16 | File | `/change-language/de_DE` | High
17 | File | `/Content/Template/root/reverse-shell.aspx` | High
18 | File | `/core/conditions/AbstractWrapper.java` | High
19 | File | `/debug/pprof` | Medium
20 | File | `/devinfo` | Medium
21 | File | `/dist/index.js` | High
22 | File | `/DXR.axd` | Medium
23 | File | `/etc/passwd` | Medium
24 | File | `/fcgi/scrut_fcgi.fcgi` | High
25 | File | `/forum/away.php` | High
26 | File | `/geoserver/gwc/rest.html` | High
27 | File | `/goform/formSysCmd` | High
28 | File | `/healthcare/Admin/consulting_detail.php` | High
29 | File | `/HNAP1` | Low
30 | File | `/hosts/firewall/ip` | High
31 | File | `/index.php/ccm/system/file/upload` | High
32 | File | `/jeecg-boot/sys/common/upload` | High
33 | File | `/log/decodmail.php` | High
34 | File | `/modals/class_form.php` | High
35 | File | `/oauth/idp/.well-known/openid-configuration` | High
36 | File | `/OA_HTML/cabo/jsps/a.jsp` | High
37 | File | `/php/ping.php` | High
38 | File | `/proxy` | Low
39 | File | `/recipe-result` | High
40 | File | `/register.do` | Medium
41 | File | `/RPS2019Service/status.html` | High
42 | File | `/s/index.php?action=statistics` | High
43 | File | `/scripts/unlock_tasks.php` | High
44 | File | `/setting` | Medium
45 | File | `/sicweb-ajax/tmproot/` | High
46 | File | `/spip.php` | Medium
47 | File | `/subsys/net/l2/wifi/wifi_shell.c` | High
48 | File | `/system/role/list` | High
49 | File | `/SystemManage/User/GetGridJson?_search=false&nd=1680855479750&rows=50&page=1&sidx=F_CreatorTime+desc&sord=asc` | High
50 | File | `/TMS/admin/setting/mail/createorupdate` | High
51 | ... | ... | ...

There are 443 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_dz.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_dz.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_dz.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
