# Andorra Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Andorra Unknown](https://vuldb.com/?actor.andorra_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.andorra_unknown](https://vuldb.com/?actor.andorra_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Andorra Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 24 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Andorra Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.4](https://vuldb.com/?ip.5.62.60.4) | r-4-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.4](https://vuldb.com/?ip.5.62.62.4) | r-4-62-62-5.consumer-pool.prcdn.net | - | High
3 | [34.99.136.0](https://vuldb.com/?ip.34.99.136.0) | 0.136.99.34.bc.googleusercontent.com | - | Medium
4 | [34.99.208.0](https://vuldb.com/?ip.34.99.208.0) | 0.208.99.34.bc.googleusercontent.com | - | Medium
5 | [34.103.152.0](https://vuldb.com/?ip.34.103.152.0) | 0.152.103.34.bc.googleusercontent.com | - | Medium
6 | [34.103.221.0](https://vuldb.com/?ip.34.103.221.0) | 0.221.103.34.bc.googleusercontent.com | - | Medium
7 | [34.103.254.0](https://vuldb.com/?ip.34.103.254.0) | 0.254.103.34.bc.googleusercontent.com | - | Medium
8 | [45.12.70.1](https://vuldb.com/?ip.45.12.70.1) | - | - | High
9 | [45.12.71.1](https://vuldb.com/?ip.45.12.71.1) | - | - | High
10 | [45.42.161.0](https://vuldb.com/?ip.45.42.161.0) | - | - | High
11 | [46.172.224.0](https://vuldb.com/?ip.46.172.224.0) | - | - | High
12 | ... | ... | ... | ...

There are 42 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Andorra Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Andorra Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/?Page=Node/OBJ=/System/DeviceFolder/DeviceFolder/DateTime/Action=Submit` | High
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/admin/add-services.php` | High
5 | File | `/admin/admin.php` | High
6 | File | `/admin/ajax/avatar.php` | High
7 | File | `/admin/edit-services.php` | High
8 | File | `/admin/forgot-password.php` | High
9 | File | `/admin/index.php` | High
10 | File | `/admin/lab.php` | High
11 | File | `/admin/login.php` | High
12 | File | `/admin/payment.php` | High
13 | File | `/admin/show.php` | High
14 | File | `/bin/boa` | Medium
15 | File | `/boat/login.php` | High
16 | File | `/classes/Master.php?f=save_inquiry` | High
17 | File | `/clinic/disease_symptoms_view.php` | High
18 | File | `/default.php?idx=17` | High
19 | File | `/download` | Medium
20 | File | `/env` | Low
21 | File | `/forum/away.php` | High
22 | File | `/index.php` | Medium
23 | File | `/installer/test.php` | High
24 | File | `/librarian/bookdetails.php` | High
25 | File | `/opt/bin/cli` | Medium
26 | File | `/p` | Low
27 | File | `/patient/doctors.php` | High
28 | File | `/phpinventory/editcategory.php` | High
29 | File | `/product-list.php` | High
30 | File | `/spip.php` | Medium
31 | File | `/uncpath/` | Medium
32 | File | `/updown/upload.cgi` | High
33 | File | `/user/del.php` | High
34 | File | `/vicidial/admin.php` | High
35 | File | `/wp-admin/admin-ajax.php` | High
36 | File | `/_next` | Low
37 | File | `123flashchat.php` | High
38 | File | `act.php` | Low
39 | File | `admin.php/pay` | High
40 | File | `admin/bad.php` | High
41 | File | `admin/index.php` | High
42 | File | `admin/index.php/user/del/1` | High
43 | File | `admin/index.php?id=themes&action=edit_chunk` | High
44 | File | `admin/products/controller.php?action=add` | High
45 | File | `administrator/index.php` | High
46 | File | `advertiser/login_confirm.asp` | High
47 | File | `agenda.php` | Medium
48 | File | `ajax/render/widget_php` | High
49 | File | `akocomments.php` | High
50 | File | `album_portal.php` | High
51 | File | `api.php` | Low
52 | File | `app/membership_signup.php` | High
53 | File | `application/home/controller/debug.php` | High
54 | File | `articulo.php` | Medium
55 | File | `artlinks.dispnew.php` | High
56 | File | `author.control.php` | High
57 | ... | ... | ...

There are 493 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_ad.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_ad.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_ad.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2023](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
