# Aoqin Dragon - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Aoqin Dragon](https://vuldb.com/?actor.aoqin_dragon). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.aoqin_dragon](https://vuldb.com/?actor.aoqin_dragon)

## Campaigns

The following _campaigns_ are known and can be associated with Aoqin Dragon:

* Mongall

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Aoqin Dragon:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Aoqin Dragon.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.77.11.148](https://vuldb.com/?ip.45.77.11.148) | 45.77.11.148.vultrusercontent.com | - | High
2 | [59.188.234.233](https://vuldb.com/?ip.59.188.234.233) | - | Mongall | High
3 | [64.27.4.19](https://vuldb.com/?ip.64.27.4.19) | secure.link192.com | Mongall | High
4 | ... | ... | ... | ...

There are 3 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Aoqin Dragon_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Aoqin Dragon. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `#!/system` | Medium
2 | File | `%PROGRAMFILES%\Cylance\Desktop\log` | High
3 | File | `/admin/` | Low
4 | File | `/admin/AddNewState/Add_State` | High
5 | File | `/admin/theme-edit.php` | High
6 | File | `/category.php` | High
7 | File | `/data/syslog.filter.json` | High
8 | File | `/details.php` | Medium
9 | File | `/etc/stunnel.key` | High
10 | File | `/FlexiCapture12/Login/Server/SevaUserProfile` | High
11 | File | `/help/lccon.nsf/` | High
12 | File | `/jsp/xmlhttp/AjaxResponse.jsp` | High
13 | File | `/login.html` | Medium
14 | File | `/member/settings_account.php` | High
15 | File | `/net/mac80211/mac80211/sta_info.c` | High
16 | File | `/nova/bin/igmp-proxy` | High
17 | File | `/otweb/OTPClientLogin` | High
18 | File | `/product.php` | Medium
19 | File | `/tests/add_duration_test.php` | High
20 | File | `/tests/all_tests.php` | High
21 | File | `/var/run/storage_account_root` | High
22 | File | `AccessPoint.aspx` | High
23 | File | `account.asp` | Medium
24 | File | `activate.php` | Medium
25 | File | `addevent.php` | Medium
26 | File | `adherents/cartes/carte.php` | High
27 | File | `admin.php` | Medium
28 | File | `admin/` | Low
29 | File | `admin/?/plugin/file_manager/upload` | High
30 | File | `admin/app/physical/physical.php` | High
31 | File | `admin/edit.php` | High
32 | File | `admin/editusertag.php` | High
33 | File | `admin/eventlist.php` | High
34 | File | `admin/index.php` | High
35 | File | `admin/languages.php` | High
36 | File | `admin/manufacturers.php` | High
37 | File | `admin/newsletters.php` | High
38 | File | `admin/products_attributes.php` | High
39 | File | `admin/products_expected.php` | High
40 | File | `admin/reviews.php` | High
41 | File | `admin/siteprefs.php` | High
42 | File | `admin/worklist/worklist_edit.asp` | High
43 | File | `administrator/index.php` | High
44 | File | `ad_popup.php` | Medium
45 | File | `afd.sys` | Low
46 | File | `agent.exe` | Medium
47 | File | `apps/calendar/export.php` | High
48 | File | `archive.php` | Medium
49 | File | `ask_chat.php` | Medium
50 | File | `attachment.cgi` | High
51 | File | `basic.html#ipsettings` | High
52 | ... | ... | ...

There are 453 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://g-soft.info/security/2668/2668/
* https://www.sentinelone.com/labs/aoqin-dragon-newly-discovered-chinese-linked-apt-has-been-quietly-spying-on-organizations-for-10-years/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
