# Aurora - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Aurora](https://vuldb.com/?actor.aurora). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.aurora](https://vuldb.com/?actor.aurora)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Aurora:

* [DE](https://vuldb.com/?country.de)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Aurora.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.9.85.111](https://vuldb.com/?ip.5.9.85.111) | static.111.85.9.5.clients.your-server.de | - | High
2 | [37.220.87.2](https://vuldb.com/?ip.37.220.87.2) | ipn-37-220-87-2.artem-catv.ru | - | High
3 | [45.15.156.22](https://vuldb.com/?ip.45.15.156.22) | - | - | High
4 | [45.15.156.33](https://vuldb.com/?ip.45.15.156.33) | - | - | High
5 | [45.15.156.80](https://vuldb.com/?ip.45.15.156.80) | - | - | High
6 | ... | ... | ... | ...

There are 22 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Aurora_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Aurora. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/admin/manage_academic.php` | High
4 | File | `/admin/subnets/ripe-query.php` | High
5 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
6 | File | `/cgi-bin/jumpto.php?class=user&page=config_save&isphp=1` | High
7 | File | `/forum/away.php` | High
8 | File | `/fw.login.php` | High
9 | File | `/gfxpoly/convert.c` | High
10 | File | `/GponForm/device_Form?script/` | High
11 | File | `/index.php?/manage/channel/addchannel` | High
12 | File | `/opac/Actions.php?a=login` | High
13 | File | `/opt/tms/bin/cli` | High
14 | File | `/out.php` | Medium
15 | File | `/owa/auth/logon.aspx` | High
16 | File | `/settings/account` | High
17 | File | `/spip.php` | Medium
18 | File | `/st_reg.php` | Medium
19 | File | `/var/log/nginx` | High
20 | File | `/way4acs/enroll` | High
21 | File | `/wp-admin/admin-ajax.php` | High
22 | File | `action.php` | Medium
23 | File | `actions/beats_uploader.php` | High
24 | File | `actions/vote_channel.php` | High
25 | File | `ad.cgi` | Low
26 | File | `adclick.php` | Medium
27 | File | `admin/admin.php` | High
28 | File | `Admin/ADM_Pagina.php` | High
29 | File | `admin/article.php` | High
30 | File | `admin/dashboard.php` | High
31 | File | `Admin/edit-admin.php` | High
32 | File | `admin/partials/ajax/add_field_to_form.php` | High
33 | File | `admin/show.php?rec=update` | High
34 | File | `album.asp` | Medium
35 | File | `allmanageup.pl` | High
36 | File | `allow/block` | Medium
37 | ... | ... | ...

There are 319 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.sekoia.io/aurora-a-rising-stealer-flying-under-the-radar/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
