# B1txor20 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [B1txor20](https://vuldb.com/?actor.b1txor20). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.b1txor20](https://vuldb.com/?actor.b1txor20)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with B1txor20:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 9 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of B1txor20.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.2.69.50](https://vuldb.com/?ip.5.2.69.50) | - | - | High
2 | [23.129.64.216](https://vuldb.com/?ip.23.129.64.216) | - | - | High
3 | [23.154.177.4](https://vuldb.com/?ip.23.154.177.4) | - | - | High
4 | [45.13.104.179](https://vuldb.com/?ip.45.13.104.179) | nosoignons.cust.milkywan.net | - | High
5 | [45.61.185.90](https://vuldb.com/?ip.45.61.185.90) | MiamiTor4.us | - | High
6 | [45.154.255.147](https://vuldb.com/?ip.45.154.255.147) | cust-147.keff.org | - | High
7 | [46.166.139.111](https://vuldb.com/?ip.46.166.139.111) | - | - | High
8 | [51.15.43.205](https://vuldb.com/?ip.51.15.43.205) | 205-43-15-51.instances.scw.cloud | - | High
9 | [62.102.148.68](https://vuldb.com/?ip.62.102.148.68) | - | - | High
10 | [62.102.148.69](https://vuldb.com/?ip.62.102.148.69) | - | - | High
11 | ... | ... | ... | ...

There are 40 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _B1txor20_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-25 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by B1txor20. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/#ProductSerie/view/` | High
2 | File | `/admin/` | Low
3 | File | `/admin/action/add_con.php` | High
4 | File | `/admin/action/new-father.php` | High
5 | File | `/admin/action/new-feed.php` | High
6 | File | `/admin/book_add.php` | High
7 | File | `/admin/book_row.php` | High
8 | File | `/admin/borrow_add.php` | High
9 | File | `/admin/bwdates-report-details.php` | High
10 | File | `/admin/category_row.php` | High
11 | File | `/admin/edit_teacher.php` | High
12 | File | `/Admin/login.php` | High
13 | File | `/admin/makehtml_freelist_action.php` | High
14 | File | `/Admin/News.php` | High
15 | File | `/admin/pages/edit_chicken.php` | High
16 | File | `/admin/pages/update_go.php` | High
17 | File | `/admin/pages/yearlevel.php` | High
18 | File | `/admin/php/crud.php` | High
19 | File | `/admin/regester.php` | High
20 | File | `/admin/return_add.php` | High
21 | File | `/admin/students.php` | High
22 | File | `/admin/users` | Medium
23 | File | `/admin_ping.htm` | High
24 | File | `/admin_route/dec_service_credits.php` | High
25 | File | `/adplanet/PlanetUser` | High
26 | File | `/ample/app/action/edit_product.php` | High
27 | File | `/api.php` | Medium
28 | File | `/api/controllers/admin/app/AppController.php` | High
29 | File | `/api/controllers/common/UploadsController.php` | High
30 | File | `/api/controllers/merchant/design/MaterialController.php` | High
31 | File | `/api/controllers/merchant/shop/PosterController.php` | High
32 | File | `/api/log/killJob` | High
33 | File | `/api/trackedEntityInstances` | High
34 | File | `/app/api/controller/default/File.php` | High
35 | File | `/app/index/controller/Common.php` | High
36 | File | `/application/index/controller/Datament.php` | High
37 | File | `/application/index/controller/Pay.php` | High
38 | File | `/application/index/controller/Screen.php` | High
39 | File | `/application/pay/controller/Api.php` | High
40 | File | `/apply/index.php` | High
41 | File | `/apps/login_auth.php` | High
42 | File | `/apps/reg_go.php` | High
43 | File | `/att_add.php` | Medium
44 | File | `/aux` | Low
45 | File | `/bin/boa` | Medium
46 | File | `/boaform/device_reset.cgi` | High
47 | File | `/boaform/wlan_basic_set.cgi` | High
48 | File | `/boafrm/formMapDelDevice` | High
49 | File | `/build` | Low
50 | File | `/ccm/system/dialogs/file/delete/1/submit` | High
51 | File | `/cgi-bin/cstecgi.cgi` | High
52 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
53 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
54 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=ie8` | High
55 | File | `/cgi-bin/R19.9/easy1350.pl` | High
56 | File | `/Cinema-Reservation/booking.php` | High
57 | File | `/classes/Users.php?f=save` | High
58 | File | `/clientLogin` | Medium
59 | File | `/config,admin.jsp` | High
60 | File | `/core/config-revisions` | High
61 | File | `/cupseasylive/stockissuancedisplay.php` | High
62 | File | `/cupseasylive/taxcodelist.php` | High
63 | File | `/currentsetting.htm` | High
64 | File | `/data/remove` | Medium
65 | File | `/debug/pprof` | Medium
66 | File | `/debuginfo.htm` | High
67 | File | `/download.php?file=author.png` | High
68 | File | `/etc/init.d/update_notifications.sh` | High
69 | File | `/etc/passwd` | Medium
70 | File | `/ext/collect/filter_text.do` | High
71 | ... | ... | ...

There are 626 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/b1txor20-use-of-dns-tunneling_cn/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
