# Babadeda - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Babadeda](https://vuldb.com/?actor.babadeda). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.babadeda](https://vuldb.com/?actor.babadeda)

## Campaigns

The following _campaigns_ are known and can be associated with Babadeda:

* Ukraine

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Babadeda:

* [DE](https://vuldb.com/?country.de)
* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Babadeda.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.48.89.8](https://vuldb.com/?ip.37.48.89.8) | - | - | High
2 | [45.12.5.62](https://vuldb.com/?ip.45.12.5.62) | galya.gitarova.example.com | Ukraine | High
3 | [65.21.127.164](https://vuldb.com/?ip.65.21.127.164) | static.164.127.21.65.clients.your-server.de | - | High
4 | ... | ... | ... | ...

There are 12 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Babadeda_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Babadeda. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin.php?page=batch_manager&mode=unit` | High
2 | File | `/goform/aspForm` | High
3 | File | `/includes/db_adodb.php` | High
4 | File | `/includes/db_connect.php` | High
5 | File | `/includes/session.php` | High
6 | File | `/modules/admin/vw_usr_roles.php` | High
7 | File | `/modules/projects/gantt2.php` | High
8 | File | `/modules/projects/vw_files.php` | High
9 | File | `/modules/public/date_format.php` | High
10 | File | `/modules/tasks/gantt.php` | High
11 | File | `/omps/seller` | Medium
12 | File | `/out.php` | Medium
13 | File | `/php/passport/index.php` | High
14 | File | `/replication` | Medium
15 | File | `/settings` | Medium
16 | File | `/staff/tools/custom-fields` | High
17 | File | `/strings/ctype-latin1.c` | High
18 | File | `/uncpath/` | Medium
19 | File | `/var/WEB-GUI/cgi-bin/telnet.cgi` | High
20 | File | `/Wedding-Management/admin/client_manage_account_details.php?booking_id=31` | High
21 | File | `actions/del.php` | High
22 | File | `addpost_newpoll.php` | High
23 | File | `addsite.php` | Medium
24 | File | `Admin.PHP` | Medium
25 | File | `admin.php` | Medium
26 | File | `admin/define.inc.php` | High
27 | File | `admin/editproductetails.php` | High
28 | File | `admin/general.php` | High
29 | File | `admin/index.php` | High
30 | File | `admin/review.php` | High
31 | File | `admincp/auth/secure.php` | High
32 | File | `affich.php` | Medium
33 | File | `agenda.php3` | Medium
34 | File | `agenda2.php3` | Medium
35 | File | `ajaxdata.php` | Medium
36 | File | `akocomments.php` | High
37 | File | `album_portal.php` | High
38 | File | `al_initialize.php` | High
39 | File | `anjel.index.php` | High
40 | File | `announcements.php` | High
41 | File | `apa_phpinclude.inc.php` | High
42 | File | `api/security/userinfo/delete` | High
43 | File | `application.php` | High
44 | File | `archive.php` | Medium
45 | File | `ardguest.php` | Medium
46 | File | `ashnews.php/ashheadlines.php` | High
47 | File | `AttributionSource.java` | High
48 | File | `auction\auction_common.php` | High
49 | ... | ... | ...

There are 425 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.morphisec.com/nft-malware-new-evasion-abilities
* https://twitter.com/s1ckb017/status/1494047314792665088

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
