# Barys - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Barys](https://vuldb.com/?actor.barys). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.barys](https://vuldb.com/?actor.barys)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Barys:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 3 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Barys.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
2 | [13.107.22.200](https://vuldb.com/?ip.13.107.22.200) | - | - | High
3 | [14.204.51.240](https://vuldb.com/?ip.14.204.51.240) | - | - | High
4 | [14.204.51.250](https://vuldb.com/?ip.14.204.51.250) | - | - | High
5 | [20.36.253.92](https://vuldb.com/?ip.20.36.253.92) | - | - | High
6 | [23.6.69.99](https://vuldb.com/?ip.23.6.69.99) | a23-6-69-99.deploy.static.akamaitechnologies.com | - | High
7 | [23.225.145.234](https://vuldb.com/?ip.23.225.145.234) | - | - | High
8 | [31.170.160.103](https://vuldb.com/?ip.31.170.160.103) | srv39.000webhost.com | - | High
9 | [34.232.187.93](https://vuldb.com/?ip.34.232.187.93) | ec2-34-232-187-93.compute-1.amazonaws.com | - | Medium
10 | [36.248.43.231](https://vuldb.com/?ip.36.248.43.231) | - | - | High
11 | [41.38.1.86](https://vuldb.com/?ip.41.38.1.86) | host-41.38.1.86.tedata.net | - | High
12 | [41.239.65.189](https://vuldb.com/?ip.41.239.65.189) | host-41.239.65.189.tedata.net | - | High
13 | [47.246.136.160](https://vuldb.com/?ip.47.246.136.160) | - | - | High
14 | [52.137.90.34](https://vuldb.com/?ip.52.137.90.34) | - | - | High
15 | [52.185.71.28](https://vuldb.com/?ip.52.185.71.28) | - | - | High
16 | [58.158.177.102](https://vuldb.com/?ip.58.158.177.102) | 58x158x177x102.ap58.ftth.ucom.ne.jp | - | High
17 | [58.215.145.95](https://vuldb.com/?ip.58.215.145.95) | - | - | High
18 | ... | ... | ... | ...

There are 69 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Barys_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 13 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Barys. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `$HOME/.cdrdao` | High
2 | File | `.FBCIndex` | Medium
3 | File | `/cgi-bin` | Medium
4 | File | `/cgi/cpaddons_feature.pl` | High
5 | File | `/dana/nc/ncrun.cgi` | High
6 | File | `/help/helpredir.aspx` | High
7 | File | `/irj/portal/` | Medium
8 | File | `/proc` | Low
9 | File | `/proc/net/ip6_flowlabel` | High
10 | File | `/search` | Low
11 | File | `/tmp/.pk11ipc1` | High
12 | File | `/tmp/adb.log` | Medium
13 | File | `/usr/bin/cu` | Medium
14 | File | `/var/crash/vmcore.log` | High
15 | File | `/_next` | Low
16 | File | `aclient.exe` | Medium
17 | File | `admin` | Low
18 | File | `admin.php` | Medium
19 | File | `admin.rssreader.php` | High
20 | File | `admin/batch_manager_unit.php` | High
21 | File | `admin/configuration/modifier.php` | High
22 | File | `admin/skins.php` | High
23 | File | `admin/system_manage/save.html` | High
24 | File | `admin/system_manage/user_config_add.html` | High
25 | File | `adminconsole` | Medium
26 | File | `adminer.php` | Medium
27 | File | `administrator/mail/download.cfm` | High
28 | File | `admin_board.php` | High
29 | File | `af_netlink.c` | Medium
30 | File | `ajax.php` | Medium
31 | File | `ajaxRequest/methodCall.do` | High
32 | File | `announcements.php` | High
33 | File | `apache2/modsecurity.c` | High
34 | File | `apply.cgi` | Medium
35 | File | `app_new.php` | Medium
36 | File | `aspx` | Low
37 | File | `AttachmentsList.aspx` | High
38 | File | `Atx45.ocx` | Medium
39 | File | `auction_details.php` | High
40 | File | `auth-gss2.c` | Medium
41 | File | `auth.php` | Medium
42 | File | `aut_verifica.inc.php` | High
43 | File | `awsguest.php` | Medium
44 | File | `b2edit.showposts.php` | High
45 | File | `backend.php/screen.php/comment.php` | High
46 | File | `basicfunctions.php` | High
47 | File | `board.cgi` | Medium
48 | File | `bug_actiongroup_ext_page.php` | High
49 | File | `canned_opr.php` | High
50 | File | `cart.cgi` | Medium
51 | File | `cat.asp` | Low
52 | ... | ... | ...

There are 453 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/04/threat-roundup-0329-0405.html
* https://blog.talosintelligence.com/2020/01/threat-roundup-0110-0117.html
* https://blog.talosintelligence.com/2020/06/threat-roundup-0529-0605.html
* https://blog.talosintelligence.com/2020/10/threat-roundup-0925-1002.html
* https://blog.talosintelligence.com/2020/12/threat-roundup-1127-1204.html
* https://blog.talosintelligence.com/2021/06/threat-roundup-0604-0611.html
* https://blog.talosintelligence.com/2021/08/threat-roundup-0820-0827.html
* https://blog.talosintelligence.com/2021/09/threat-roundup-0827-0903.html
* https://blog.talosintelligence.com/2022/01/threat-roundup-0121-0128.html
* https://blog.talosintelligence.com/threat-roundup-0127-0203/
* https://blog.talosintelligence.com/threat-roundup-1202-1209/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
