# Benin Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Benin Unknown](https://vuldb.com/?actor.benin_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.benin_unknown](https://vuldb.com/?actor.benin_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Benin Unknown:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 21 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Benin Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.32](https://vuldb.com/?ip.5.62.60.32) | r-32-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.32](https://vuldb.com/?ip.5.62.62.32) | r-32-62-62-5.consumer-pool.prcdn.net | - | High
3 | [41.74.0.0](https://vuldb.com/?ip.41.74.0.0) | - | - | High
4 | [41.78.96.128](https://vuldb.com/?ip.41.78.96.128) | - | - | High
5 | [41.79.216.0](https://vuldb.com/?ip.41.79.216.0) | - | - | High
6 | [41.85.160.0](https://vuldb.com/?ip.41.85.160.0) | - | - | High
7 | [41.86.224.0](https://vuldb.com/?ip.41.86.224.0) | - | - | High
8 | [41.86.224.128](https://vuldb.com/?ip.41.86.224.128) | - | - | High
9 | [41.86.224.192](https://vuldb.com/?ip.41.86.224.192) | - | - | High
10 | [41.86.224.224](https://vuldb.com/?ip.41.86.224.224) | - | - | High
11 | [41.86.224.240](https://vuldb.com/?ip.41.86.224.240) | - | - | High
12 | [41.86.224.248](https://vuldb.com/?ip.41.86.224.248) | - | - | High
13 | [41.86.224.252](https://vuldb.com/?ip.41.86.224.252) | - | - | High
14 | [41.86.224.255](https://vuldb.com/?ip.41.86.224.255) | - | - | High
15 | [41.86.225.0](https://vuldb.com/?ip.41.86.225.0) | - | - | High
16 | [41.86.226.0](https://vuldb.com/?ip.41.86.226.0) | - | - | High
17 | [41.86.228.0](https://vuldb.com/?ip.41.86.228.0) | - | - | High
18 | ... | ... | ... | ...

There are 66 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Benin Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Benin Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/?Page=Node/OBJ=/System/DeviceFolder/DeviceFolder/DateTime/Action=Submit` | High
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/admin/add-services.php` | High
5 | File | `/admin/ajax/avatar.php` | High
6 | File | `/admin/edit-services.php` | High
7 | File | `/admin/forgot-password.php` | High
8 | File | `/admin/index.php` | High
9 | File | `/admin/lab.php` | High
10 | File | `/admin/login.php` | High
11 | File | `/admin/payment.php` | High
12 | File | `/admin/show.php` | High
13 | File | `/advanced-tools/nova/bin/netwatch` | High
14 | File | `/api/baskets/{name}` | High
15 | File | `/boat/login.php` | High
16 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
17 | File | `/clinic/disease_symptoms_view.php` | High
18 | File | `/default.php?idx=17` | High
19 | File | `/device/device=345/?tab=ports` | High
20 | File | `/download` | Medium
21 | File | `/env` | Low
22 | File | `/forum/away.php` | High
23 | File | `/index.php` | Medium
24 | File | `/opt/bin/cli` | Medium
25 | File | `/p` | Low
26 | File | `/patient/doctors.php` | High
27 | File | `/phpinventory/editcategory.php` | High
28 | File | `/preview.php` | Medium
29 | File | `/product-list.php` | High
30 | File | `/proxy/` | Low
31 | File | `/spip.php` | Medium
32 | File | `/uncpath/` | Medium
33 | File | `/updown/upload.cgi` | High
34 | File | `/user/del.php` | High
35 | File | `/wp-admin/admin-ajax.php` | High
36 | File | `/_next` | Low
37 | File | `123flashchat.php` | High
38 | File | `act.php` | Low
39 | File | `admin.php/pay` | High
40 | File | `admin/admin_menu.php` | High
41 | File | `admin/bad.php` | High
42 | File | `admin/index.php` | High
43 | File | `admin/index.php/user/del/1` | High
44 | ... | ... | ...

There are 377 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_bj.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_bj.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_bj.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
