# BillGates - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [BillGates](https://vuldb.com/?actor.billgates). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.billgates](https://vuldb.com/?actor.billgates)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with BillGates:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of BillGates.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.56.59.45](https://vuldb.com/?ip.2.56.59.45) | - | - | High
2 | [104.129.12.141](https://vuldb.com/?ip.104.129.12.141) | 104.129.12.141.static.quadranet.com | - | High
3 | [154.82.110.5](https://vuldb.com/?ip.154.82.110.5) | - | - | High
4 | ... | ... | ... | ...

There are 3 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _BillGates_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by BillGates. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/api/admin/system/store/order/list` | High
3 | File | `/cgi-bin/wapopen` | High
4 | File | `/csms/?page=contact_us` | High
5 | File | `/etc/ajenti/config.yml` | High
6 | File | `/forum/away.php` | High
7 | File | `/goform/telnet` | High
8 | File | `/modules/profile/index.php` | High
9 | File | `/rom-0` | Low
10 | File | `/tmp/phpglibccheck` | High
11 | File | `/uncpath/` | Medium
12 | File | `/upload` | Low
13 | File | `/var/tmp/sess_*` | High
14 | File | `action.php` | Medium
15 | File | `actionphp/download.File.php` | High
16 | File | `add_comment.php` | High
17 | File | `admin/admin.php` | High
18 | File | `admin/content.php` | High
19 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
20 | File | `admin/memberviewdetails.php` | High
21 | File | `admin_gallery.php3` | High
22 | File | `affich.php` | Medium
23 | File | `agent/Core/Controller/SendRequest.cpp` | High
24 | File | `ajax/telemetry.php` | High
25 | File | `akeyActivationLogin.do` | High
26 | File | `album_portal.php` | High
27 | File | `apache-auth.conf` | High
28 | File | `askapache-firefox-adsense.php` | High
29 | File | `attachment.cgi` | High
30 | File | `blueprints/sections/edit/1` | High
31 | File | `boaform/admin/formPing` | High
32 | File | `books.php` | Medium
33 | File | `cart_add.php` | Medium
34 | File | `CFS.c` | Low
35 | File | `cgi-bin/gnudip.cgi` | High
36 | File | `checktransferstatus.php` | High
37 | File | `checkuser.php` | High
38 | File | `class.SystemAction.php` | High
39 | File | `clientarea.php` | High
40 | File | `cmdmon.c` | Medium
41 | File | `collectivite.class.php` | High
42 | File | `com_android_bluetooth_btservice_AdapterService.cpp` | High
43 | File | `confirm.php` | Medium
44 | File | `contact` | Low
45 | File | `control.c` | Medium
46 | ... | ... | ...

There are 395 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://bazaar.abuse.ch/sample/0f31b2b43e5a106965f948b8e525211929c3d4d7218c6ee09d28528ab70526a5/
* https://bazaar.abuse.ch/sample/93baa3abd9795be2beaa8cacaeb26041882d4f1738ab70b9c703cc674a2117de/
* https://bazaar.abuse.ch/sample/aa7807e6f0b7a0a5bb859b302b9eb2604040f5f4a84414ea1baa93b377b42ca8/
* https://blog.netlab.360.com/ten-families-of-malicious-samples-are-spreading-using-the-log4j2-vulnerability-now/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
