# Black KingDom - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Black KingDom](https://vuldb.com/?actor.black_kingdom). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.black_kingdom](https://vuldb.com/?actor.black_kingdom)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Black KingDom:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 3 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Black KingDom.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [104.21.89.10](https://vuldb.com/?ip.104.21.89.10) | - | - | High
2 | [172.64.80.0](https://vuldb.com/?ip.172.64.80.0) | - | - | High
3 | [185.220.101.204](https://vuldb.com/?ip.185.220.101.204) | tor-exit-204.relayon.org | - | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Black KingDom_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23, CWE-24, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Black KingDom. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.github/workflows/comment.yml` | High
2 | File | `/?r=recruit/resume/edit&op=status` | High
3 | File | `/academy/home/courses` | High
4 | File | `/admin.php?c=upload&f=zip&_noCache=0.1683794968` | High
5 | File | `/admin/` | Low
6 | File | `/admin/?page=user/list` | High
7 | File | `/admin/?page=user/manage_user&id=3` | High
8 | File | `/admin/action/add_con.php` | High
9 | File | `/admin/action/new-father.php` | High
10 | File | `/admin/action/new-feed.php` | High
11 | File | `/admin/addproduct.php` | High
12 | File | `/admin/ajax.php?action=confirm_order` | High
13 | File | `/admin/article/article-edit-run.php` | High
14 | File | `/admin/bookings/manage_booking.php` | High
15 | File | `/admin/bookings/view_booking.php` | High
16 | File | `/admin/book_add.php` | High
17 | File | `/admin/book_row.php` | High
18 | File | `/admin/borrow_add.php` | High
19 | File | `/admin/budget/manage_budget.php` | High
20 | File | `/admin/bwdates-report-details.php` | High
21 | File | `/admin/category_row.php` | High
22 | File | `/admin/cms_admin.php` | High
23 | File | `/admin/contacts/organizations/edit/2` | High
24 | File | `/admin/course.php` | High
25 | File | `/admin/courses/manage_course.php` | High
26 | File | `/admin/curriculum/view_curriculum.php` | High
27 | File | `/admin/departments/view_department.php` | High
28 | File | `/admin/edit_product.php` | High
29 | File | `/admin/edit_subject.php` | High
30 | File | `/admin/edit_teacher.php` | High
31 | File | `/admin/index.php` | High
32 | File | `/admin/index/index.html#/admin/mall.goods/index.html` | High
33 | File | `/admin/inquiries/view_inquiry.php` | High
34 | File | `/admin/leancloud.php` | High
35 | File | `/admin/maintenance/view_designation.php` | High
36 | File | `/admin/makehtml_freelist_action.php` | High
37 | File | `/admin/manage-pages.php` | High
38 | File | `/admin/modal_add_product.php` | High
39 | File | `/Admin/News.php` | High
40 | File | `/admin/pages/edit_chicken.php` | High
41 | File | `/admin/pages/update_go.php` | High
42 | File | `/admin/pages/yearlevel.php` | High
43 | File | `/admin/php/crud.php` | High
44 | File | `/admin/project/update/2` | High
45 | File | `/admin/read.php?mudi=getSignal` | High
46 | File | `/admin/reg.php` | High
47 | File | `/admin/service.php` | High
48 | File | `/admin/services/manage_service.php` | High
49 | File | `/admin/services/view_service.php` | High
50 | File | `/admin/settings/` | High
51 | File | `/admin/students/manage_academic.php` | High
52 | File | `/admin/students/update_status.php` | High
53 | File | `/admin/subject.php` | High
54 | File | `/admin/sys_sql_query.php` | High
55 | File | `/admin/test_status.php` | High
56 | File | `/admin/theme-edit.php` | High
57 | File | `/admin/upload.php` | High
58 | File | `/admin/user/manage_user.php` | High
59 | File | `/admin/userprofile.php` | High
60 | File | `/admin/vote_edit.php` | High
61 | File | `/admin_route/dec_service_credits.php` | High
62 | File | `/adplanet/PlanetUser` | High
63 | File | `/ample/app/action/edit_product.php` | High
64 | File | `/ample/app/ajax/member_data.php` | High
65 | File | `/api/authentication/login` | High
66 | File | `/api/DataDictionary/GetItemList` | High
67 | File | `/api/stl/actions/search` | High
68 | File | `/api/sys/login` | High
69 | File | `/application/pay/controller/Api.php` | High
70 | File | `/apps/reg_go.php` | High
71 | File | `/App_Resource/UEditor/server/upload.aspx` | High
72 | File | `/autheditpwd.php` | High
73 | File | `/author_posts.php` | High
74 | File | `/b2b-supermarket/catalog/all-products` | High
75 | File | `/bin/boa` | Medium
76 | File | `/blog` | Low
77 | File | `/blog-single.php` | High
78 | File | `/boaform/device_reset.cgi` | High
79 | File | `/boaform/wlan_basic_set.cgi` | High
80 | File | `/boafrm/formMapDelDevice` | High
81 | File | `/booking/show_bookings/` | High
82 | File | `/browse` | Low
83 | File | `/category.php` | High
84 | File | `/cgi-bin/` | Medium
85 | File | `/cgi-bin/cstecgi.cgi` | High
86 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
87 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
88 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=ie8` | High
89 | File | `/cgi-bin/ping.cgi` | High
90 | File | `/chaincity/user/ticket/create` | High
91 | File | `/changeimage.php` | High
92 | File | `/classes/Master.php` | High
93 | File | `/classes/Master.php?f=delete_category` | High
94 | File | `/classes/Master.php?f=delete_inquiry` | High
95 | File | `/classes/Master.php?f=delete_item` | High
96 | File | `/classes/Master.php?f=delete_service` | High
97 | File | `/classes/Master.php?f=save_course` | High
98 | File | `/classes/Master.php?f=save_inquiry` | High
99 | File | `/classes/Master.php?f=save_item` | High
100 | File | `/classes/Master.php?f=save_service` | High
101 | File | `/classes/Users.php?f=save` | High
102 | File | `/collection/all` | High
103 | File | `/company/store` | High
104 | File | `/config` | Low
105 | File | `/config,admin.jsp` | High
106 | File | `/contact.php` | Medium
107 | File | `/Controller/Ajaxfileupload.ashx` | High
108 | ... | ... | ...

There are 952 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/sophoslabs/IoCs/blob/master/Ransomware_BlackKingDom.csv

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
