# BoatBotnet - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [BoatBotnet](https://vuldb.com/?actor.boatbotnet). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.boatbotnet](https://vuldb.com/?actor.boatbotnet)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with BoatBotnet:

* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of BoatBotnet.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.249.32.102](https://vuldb.com/?ip.46.249.32.102) | - | - | High
2 | [85.217.144.191](https://vuldb.com/?ip.85.217.144.191) | - | - | High
3 | [87.120.88.117](https://vuldb.com/?ip.87.120.88.117) | - | - | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _BoatBotnet_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 8 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by BoatBotnet. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/blob/master/legacy/application/modules/rest/controllers/ShowImageController.php` | High
2 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
3 | File | `/lan.asp` | Medium
4 | File | `/LogoStore/search.php` | High
5 | File | `/pages/faculty_sched.php` | High
6 | File | `/vicidial/admin.php` | High
7 | File | `account.asp` | Medium
8 | File | `admin/versions.html` | High
9 | File | `admindocumentworker.jsp` | High
10 | File | `album_portal.php` | High
11 | File | `al_initialize.php` | High
12 | File | `announce.php` | Medium
13 | File | `apply.cgi` | Medium
14 | File | `art.php` | Low
15 | ... | ... | ...

There are 119 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://nsfocusglobal.com/from-ripples-to-waves-the-swift-evolution-of-the-boat-botnet/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
