# Bonanza - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Bonanza](https://vuldb.com/?actor.bonanza). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.bonanza](https://vuldb.com/?actor.bonanza)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Bonanza:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Bonanza.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [85.217.144.143](https://vuldb.com/?ip.85.217.144.143) | - | - | High
2 | [109.107.182.2](https://vuldb.com/?ip.109.107.182.2) | hosted-by.yeezyhost.net | - | High
3 | [171.22.28.213](https://vuldb.com/?ip.171.22.28.213) | - | - | High
4 | ... | ... | ... | ...

There are 5 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Bonanza_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 10 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Bonanza. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?r=email/api/mark&op=delFromSend` | High
2 | File | `/admin/addemployee.php` | High
3 | File | `/advanced-tools/nova/bin/netwatch` | High
4 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
5 | File | `/film-rating.php` | High
6 | File | `/index.php` | Medium
7 | File | `/librarian/bookdetails.php` | High
8 | File | `/pages/faculty_sched.php` | High
9 | File | `/php_action/createUser.php` | High
10 | File | `/spip.php` | Medium
11 | File | `/student/bookdetails.php` | High
12 | File | `account.asp` | Medium
13 | File | `add_comment.php` | High
14 | File | `admin.php` | Medium
15 | File | `admin/admin_users.php` | High
16 | File | `admin/conf_users_edit.php` | High
17 | File | `Admin/edit-admin.php` | High
18 | File | `admin/establishment/manage.php` | High
19 | File | `admin/inquiries/view_details.php` | High
20 | File | `admin/skins.php` | High
21 | File | `admin/versions.html` | High
22 | File | `admindocumentworker.jsp` | High
23 | File | `admin_feature.php` | High
24 | File | `album_portal.php` | High
25 | File | `announce.php` | Medium
26 | File | `apply.cgi` | Medium
27 | File | `ardguest.php` | Medium
28 | File | `bb_usage_stats.php` | High
29 | File | `category.cfm` | Medium
30 | File | `category_list.php` | High
31 | ... | ... | ...

There are 263 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.malwarebytes.com/blog/threat-intelligence/2023/10/malvertising-via-dynamic-search-ads-delivers-malware-bonanza

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
