# Bouncing Golf - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Bouncing Golf](https://vuldb.com/?actor.bouncing_golf). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.bouncing_golf](https://vuldb.com/?actor.bouncing_golf)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Bouncing Golf:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 26 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Bouncing Golf.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [54.38.51.159](https://vuldb.com/?ip.54.38.51.159) | - | - | High
2 | [82.211.31.181](https://vuldb.com/?ip.82.211.31.181) | - | - | High
3 | [84.234.96.167](https://vuldb.com/?ip.84.234.96.167) | eronn.erivermle.com | - | High
4 | ... | ... | ... | ...

There are 4 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Bouncing Golf_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Bouncing Golf. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/.env` | Low
3 | File | `/admin/login.php` | High
4 | File | `/admin/students/view_details.php` | High
5 | File | `/cgi-bin/nobody` | High
6 | File | `/cgi-bin/nobody/Search.cgi` | High
7 | File | `/edit-db.php` | Medium
8 | File | `/etc/passwd` | Medium
9 | File | `/forum/away.php` | High
10 | File | `/get_getnetworkconf.cgi` | High
11 | File | `/horde/util/go.php` | High
12 | File | `/librarian/bookdetails.php` | High
13 | File | `/messageboard/view.php` | High
14 | File | `/mobile_seal/get_seal.php` | High
15 | File | `/new` | Low
16 | File | `/nova/bin/detnet` | High
17 | File | `/orrs/admin/reservations/view_details.php` | High
18 | File | `/show_news.php` | High
19 | File | `/tmp` | Low
20 | File | `/uncpath/` | Medium
21 | File | `/userRpm/MediaServerFoldersCfgRpm.htm` | High
22 | File | `/vicidial/AST_agent_time_sheet.php` | High
23 | File | `/ViewUserHover.jspa` | High
24 | File | `account.asp` | Medium
25 | File | `AccountStatus.jsp` | High
26 | File | `adclick.php` | Medium
27 | File | `add.php` | Low
28 | File | `admin.a6mambocredits.php` | High
29 | File | `admin.color.php` | High
30 | File | `admin.cropcanvas.php` | High
31 | File | `admin.joomlaradiov5.php` | High
32 | File | `Admin.PHP` | Medium
33 | File | `admin/products/view_product.php` | High
34 | File | `admin/systemOutOfBand.do` | High
35 | File | `adminAvatars.php` | High
36 | File | `adminBackupdatabase.php` | High
37 | File | `adminForums.php` | High
38 | File | `allopass-error.php` | High
39 | File | `app/application.cpp` | High
40 | File | `ashnews.php/ashheadlines.php` | High
41 | File | `auth-gss2.c` | Medium
42 | ... | ... | ...

There are 361 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://documents.trendmicro.com/assets/appendix-mobile-cyberespionage-campaign-bouncing-golf-affects-middle-east.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
