# Bronze Silhouette - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Bronze Silhouette](https://vuldb.com/?actor.bronze_silhouette). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.bronze_silhouette](https://vuldb.com/?actor.bronze_silhouette)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Bronze Silhouette:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [ES](https://vuldb.com/?country.es)
* ...

There are 1 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Bronze Silhouette.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.227.198.247](https://vuldb.com/?ip.23.227.198.247) | 23-227-198-247.static.hvvc.us | - | High
2 | [104.161.54.203](https://vuldb.com/?ip.104.161.54.203) | we.love.servers.at.ioflood.net | - | High
3 | [109.166.39.139](https://vuldb.com/?ip.109.166.39.139) | - | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Bronze Silhouette_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Argument Injection | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Bronze Silhouette. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/general.cgi` | High
2 | File | `/admin/reminders/manage_reminder.php` | High
3 | File | `/CCMAdmin/serverlist.asp` | High
4 | File | `/cgi/get_param.cgi` | High
5 | File | `/crmeb/app/admin/controller/store/CopyTaobao.php` | High
6 | File | `/crmeb/crmeb/services/UploadService.php` | High
7 | File | `/csms/admin/inquiries/view_details.php` | High
8 | File | `/cstecgi.cgi` | Medium
9 | File | `/files.md5` | Medium
10 | File | `/forum/away.php` | High
11 | File | `/hrm/employeeview.php` | High
12 | File | `/images/` | Medium
13 | File | `/include/chart_generator.php` | High
14 | File | `/librarian/bookdetails.php` | High
15 | File | `/login` | Low
16 | File | `/messageboard/view.php` | High
17 | File | `/modules/profile/index.php` | High
18 | File | `/one_church/userregister.php` | High
19 | File | `/out.php` | Medium
20 | File | `/owa/auth/logon.aspx` | High
21 | File | `/public/plugins/` | High
22 | File | `/SAP_Information_System/controllers/add_admin.php` | High
23 | File | `/SASWebReportStudio/logonAndRender.do` | High
24 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
25 | File | `/secure/admin/ViewInstrumentation.jspa` | High
26 | File | `/SVFE2/pages/feegroups/country_group.jsf` | High
27 | File | `/textpattern/index.php` | High
28 | File | `/upfile.cgi` | Medium
29 | File | `/v2/quantum/save-data-upload-big-file` | High
30 | File | `/wordpress/wp-admin/admin.php` | High
31 | File | `4.edu.php` | Medium
32 | File | `account_footer.php` | High
33 | File | `adclick.php` | Medium
34 | File | `add_edit_cat.asp` | High
35 | File | `add_edit_user.asp` | High
36 | File | `admin.cropcanvas.php` | High
37 | ... | ... | ...

There are 318 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.secureworks.com/blog/chinese-cyberespionage-group-bronze-silhouette-targets-us-government-and-defense-organizations

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
