# Brunei Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Brunei Unknown](https://vuldb.com/?actor.brunei_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.brunei_unknown](https://vuldb.com/?actor.brunei_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Brunei Unknown:

* [US](https://vuldb.com/?country.us)
* [JP](https://vuldb.com/?country.jp)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 24 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Brunei Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.48](https://vuldb.com/?ip.5.62.60.48) | r-48-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.48](https://vuldb.com/?ip.5.62.62.48) | r-48-62-62-5.consumer-pool.prcdn.net | - | High
3 | [5.182.197.0](https://vuldb.com/?ip.5.182.197.0) | - | - | High
4 | [23.247.136.0](https://vuldb.com/?ip.23.247.136.0) | - | - | High
5 | [37.120.151.152](https://vuldb.com/?ip.37.120.151.152) | - | - | High
6 | [37.230.183.0](https://vuldb.com/?ip.37.230.183.0) | - | - | High
7 | [43.225.40.0](https://vuldb.com/?ip.43.225.40.0) | - | - | High
8 | [43.225.136.0](https://vuldb.com/?ip.43.225.136.0) | - | - | High
9 | [43.251.128.0](https://vuldb.com/?ip.43.251.128.0) | - | - | High
10 | [45.12.70.28](https://vuldb.com/?ip.45.12.70.28) | slave.get-eye.com | - | High
11 | [45.12.71.28](https://vuldb.com/?ip.45.12.71.28) | - | - | High
12 | [45.126.140.0](https://vuldb.com/?ip.45.126.140.0) | - | - | High
13 | [45.127.140.0](https://vuldb.com/?ip.45.127.140.0) | - | - | High
14 | [46.36.201.111](https://vuldb.com/?ip.46.36.201.111) | - | - | High
15 | ... | ... | ... | ...

There are 56 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Brunei Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Brunei Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/+CSCOE+/logon.html` | High
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/admin/add-services.php` | High
5 | File | `/admin/ajax/avatar.php` | High
6 | File | `/admin/edit-services.php` | High
7 | File | `/admin/forgot-password.php` | High
8 | File | `/admin/index.php` | High
9 | File | `/admin/lab.php` | High
10 | File | `/admin/login.php` | High
11 | File | `/admin/payment.php` | High
12 | File | `/admin/show.php` | High
13 | File | `/api/file_uploader.php` | High
14 | File | `/api/RecordingList/DownloadRecord?file=` | High
15 | File | `/api/v1/terminal/sessions/?limit=1` | High
16 | File | `/Application/Admin/Controller/ConfigController.class.php` | High
17 | File | `/bin/boa` | Medium
18 | File | `/boat/login.php` | High
19 | File | `/cimom` | Low
20 | File | `/clinic/disease_symptoms_view.php` | High
21 | File | `/default.php?idx=17` | High
22 | File | `/dev/shm` | Medium
23 | File | `/download` | Medium
24 | File | `/env` | Low
25 | File | `/forum/away.php` | High
26 | File | `/GponForm/device_Form?script/` | High
27 | File | `/login/index.php` | High
28 | File | `/mgmt/tm/util/bash` | High
29 | File | `/net` | Low
30 | File | `/opt/bin/cli` | Medium
31 | File | `/p` | Low
32 | File | `/patient/doctors.php` | High
33 | File | `/phpinventory/editcategory.php` | High
34 | File | `/SASWebReportStudio/logonAndRender.do` | High
35 | File | `/service/upload` | High
36 | File | `/setup/finish` | High
37 | File | `/spip.php` | Medium
38 | File | `/sysmanage/edit_manageadmin.php` | High
39 | File | `/uncpath/` | Medium
40 | File | `/updown/upload.cgi` | High
41 | File | `/user/del.php` | High
42 | File | `/viewer/krpano.html` | High
43 | File | `/wp-admin/admin-ajax.php` | High
44 | File | `/_next` | Low
45 | File | `/_vti_pvt/access.cnf` | High
46 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
47 | File | `act.php` | Low
48 | File | `ActionServlet.java` | High
49 | File | `adclick.php` | Medium
50 | File | `admin.php` | Medium
51 | File | `admin.php/pay` | High
52 | File | `admin/bad.php` | High
53 | File | `admin/index.php/user/del/1` | High
54 | ... | ... | ...

There are 466 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_bn.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_bn.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
