# Butterfly - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Butterfly](https://vuldb.com/?actor.butterfly). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.butterfly](https://vuldb.com/?actor.butterfly)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Butterfly:

* [NL](https://vuldb.com/?country.nl)
* [US](https://vuldb.com/?country.us)
* [DE](https://vuldb.com/?country.de)
* ...

There are 15 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Butterfly.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.165.237.75](https://vuldb.com/?ip.46.165.237.75) | - | - | High
2 | [46.183.217.132](https://vuldb.com/?ip.46.183.217.132) | skalli.pereformed.com | - | High
3 | [178.162.197.9](https://vuldb.com/?ip.178.162.197.9) | - | - | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Butterfly_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Butterfly. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/broadcast.php` | High
2 | File | `/admin/sysmon.php` | High
3 | File | `/cgi-bin/webviewer_login_page` | High
4 | File | `/ecrire` | Low
5 | File | `/forum/away.php` | High
6 | File | `/getcfg.php` | Medium
7 | File | `/MicroStrategyWS/happyaxis.jsp` | High
8 | File | `/owa/auth/logon.aspx` | High
9 | File | `/proc/ioports` | High
10 | File | `/search.php` | Medium
11 | File | `/services/details.asp` | High
12 | File | `/tmp` | Low
13 | File | `/uncpath/` | Medium
14 | File | `/Upload.ashx` | Medium
15 | File | `/usr/sbin/suexec` | High
16 | File | `/var/tmp/sess_*` | High
17 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
18 | File | `activateuser.aspx` | High
19 | File | `adclick.php` | Medium
20 | File | `admin/killsource` | High
21 | File | `admin/orion.extfeedbackform_efbf_forms.php` | High
22 | ... | ... | ...

There are 178 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.threatminer.org/report.php?q=butterfly-corporate-spies-out-for-financial-gain.pdf&y=2015

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
