# Cabo Verde Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Cabo Verde Unknown](https://vuldb.com/?actor.cabo_verde_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.cabo_verde_unknown](https://vuldb.com/?actor.cabo_verde_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Cabo Verde Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [PT](https://vuldb.com/?country.pt)
* ...

There are 19 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Cabo Verde Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.72](https://vuldb.com/?ip.5.62.60.72) | r-72-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.72](https://vuldb.com/?ip.5.62.62.72) | r-72-62-62-5.consumer-pool.prcdn.net | - | High
3 | [41.74.128.0](https://vuldb.com/?ip.41.74.128.0) | - | - | High
4 | [41.79.124.0](https://vuldb.com/?ip.41.79.124.0) | - | - | High
5 | [41.215.208.0](https://vuldb.com/?ip.41.215.208.0) | - | - | High
6 | ... | ... | ... | ...

There are 21 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Cabo Verde Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Cabo Verde Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/?Page=Node/OBJ=/System/DeviceFolder/DeviceFolder/DateTime/Action=Submit` | High
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/admin/add-services.php` | High
5 | File | `/admin/ajax/avatar.php` | High
6 | File | `/admin/edit-services.php` | High
7 | File | `/admin/forgot-password.php` | High
8 | File | `/admin/index.php` | High
9 | File | `/admin/lab.php` | High
10 | File | `/admin/login.php` | High
11 | File | `/admin/payment.php` | High
12 | File | `/admin/show.php` | High
13 | File | `/api/json/admin/getmailserversettings` | High
14 | File | `/boat/login.php` | High
15 | File | `/clinic/disease_symptoms_view.php` | High
16 | File | `/default.php?idx=17` | High
17 | File | `/download` | Medium
18 | File | `/env` | Low
19 | File | `/forum/away.php` | High
20 | File | `/home.php` | Medium
21 | File | `/index.php` | Medium
22 | File | `/opt/bin/cli` | Medium
23 | File | `/p` | Low
24 | File | `/patient/doctors.php` | High
25 | File | `/phpinventory/editcategory.php` | High
26 | File | `/product-list.php` | High
27 | File | `/rest/api/2/user/picker` | High
28 | File | `/RestAPI` | Medium
29 | File | `/spip.php` | Medium
30 | File | `/uncpath/` | Medium
31 | File | `/updown/upload.cgi` | High
32 | File | `/user/del.php` | High
33 | File | `/wp-admin/admin-ajax.php` | High
34 | File | `/_next` | Low
35 | File | `123flashchat.php` | High
36 | File | `act.php` | Low
37 | File | `admin.php` | Medium
38 | File | `admin.php/pay` | High
39 | File | `admin/bad.php` | High
40 | File | `admin/index.php` | High
41 | File | `admin/index.php/user/del/1` | High
42 | File | `admin/index.php?id=themes&action=edit_chunk` | High
43 | File | `admin/products/controller.php?action=add` | High
44 | File | `administrator/index.php` | High
45 | ... | ... | ...

There are 393 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_cv.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_cv.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
