# Central African Republic Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Central African Republic Unknown](https://vuldb.com/?actor.central_african_republic_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.central_african_republic_unknown](https://vuldb.com/?actor.central_african_republic_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Central African Republic Unknown:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 17 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Central African Republic Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.76](https://vuldb.com/?ip.5.62.60.76) | r-76-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.76](https://vuldb.com/?ip.5.62.62.76) | r-76-62-62-5.consumer-pool.prcdn.net | - | High
3 | [41.78.120.0](https://vuldb.com/?ip.41.78.120.0) | - | - | High
4 | [41.223.184.0](https://vuldb.com/?ip.41.223.184.0) | - | - | High
5 | [45.12.70.41](https://vuldb.com/?ip.45.12.70.41) | venture-case.get-eye.com | - | High
6 | [45.12.71.41](https://vuldb.com/?ip.45.12.71.41) | - | - | High
7 | ... | ... | ... | ...

There are 24 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Central African Republic Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Central African Republic Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?Page=Node/OBJ=/System/DeviceFolder/DeviceFolder/DateTime/Action=Submit` | High
2 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
3 | File | `/admin/add-services.php` | High
4 | File | `/admin/ajax/avatar.php` | High
5 | File | `/admin/edit-services.php` | High
6 | File | `/admin/forgot-password.php` | High
7 | File | `/admin/index.php` | High
8 | File | `/admin/lab.php` | High
9 | File | `/admin/login.php` | High
10 | File | `/admin/payment.php` | High
11 | File | `/admin/show.php` | High
12 | File | `/boat/login.php` | High
13 | File | `/clinic/disease_symptoms_view.php` | High
14 | File | `/default.php?idx=17` | High
15 | File | `/download` | Medium
16 | File | `/env` | Low
17 | File | `/forum/away.php` | High
18 | File | `/index.php` | Medium
19 | File | `/opt/bin/cli` | Medium
20 | File | `/outgoing.php` | High
21 | File | `/p` | Low
22 | File | `/patient/doctors.php` | High
23 | File | `/phpinventory/editcategory.php` | High
24 | File | `/product-list.php` | High
25 | File | `/s/index.php?action=statistics` | High
26 | File | `/spip.php` | Medium
27 | File | `/uncpath/` | Medium
28 | File | `/updown/upload.cgi` | High
29 | File | `/user/del.php` | High
30 | File | `/wp-admin/admin-ajax.php` | High
31 | File | `/_next` | Low
32 | File | `123flashchat.php` | High
33 | File | `act.php` | Low
34 | File | `admin.php/pay` | High
35 | File | `admin/bad.php` | High
36 | File | `admin/index.php` | High
37 | File | `admin/index.php/user/del/1` | High
38 | File | `admin/index.php?id=themes&action=edit_chunk` | High
39 | File | `admin/products/controller.php?action=add` | High
40 | File | `administrator/index.php` | High
41 | ... | ... | ...

There are 357 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_cf.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_cf.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_cf.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
