# Coper - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Coper](https://vuldb.com/?actor.coper). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.coper](https://vuldb.com/?actor.coper)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Coper:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 12 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Coper.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.57.149.175](https://vuldb.com/?ip.2.57.149.175) | - | - | High
2 | [31.41.244.41](https://vuldb.com/?ip.31.41.244.41) | - | - | High
3 | [62.122.184.165](https://vuldb.com/?ip.62.122.184.165) | - | - | High
4 | [62.233.50.113](https://vuldb.com/?ip.62.233.50.113) | - | - | High
5 | [83.97.73.144](https://vuldb.com/?ip.83.97.73.144) | - | - | High
6 | [83.97.73.246](https://vuldb.com/?ip.83.97.73.246) | - | - | High
7 | [85.209.176.160](https://vuldb.com/?ip.85.209.176.160) | - | - | High
8 | [85.209.176.190](https://vuldb.com/?ip.85.209.176.190) | - | - | High
9 | ... | ... | ... | ...

There are 34 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Coper_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Coper. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `//proc/kcore` | Medium
3 | File | `/admin.php/Admin/adminadd.html` | High
4 | File | `/admin/about-us.php` | High
5 | File | `/admin/action/delete-vaccine.php` | High
6 | File | `/Admin/add-student.php` | High
7 | File | `/admin/config/uploadicon.php` | High
8 | File | `/admin/index2.html` | High
9 | File | `/admin/settings/save.php` | High
10 | File | `/admin/userprofile.php` | High
11 | File | `/api/baskets/{name}` | High
12 | File | `/app/index/controller/Common.php` | High
13 | File | `/apply.cgi` | Medium
14 | File | `/bitrix/admin/ldap_server_edit.php` | High
15 | File | `/cgi-bin/` | Medium
16 | File | `/cgi-bin/downloadFile.cgi` | High
17 | File | `/cgi-bin/wlogin.cgi` | High
18 | File | `/College/admin/teacher.php` | High
19 | File | `/Controls/Generic/EBMK/Handlers/EStatements/DownloadEStatement.ashx` | High
20 | File | `/cwc/login` | Medium
21 | File | `/dcim/rack-roles/` | High
22 | File | `/Duty/AjaxHandle/UploadFloodPlanFileUpdate.ashx` | High
23 | File | `/forms/doLogin` | High
24 | File | `/forum/away.php` | High
25 | File | `/goform/addUserName` | High
26 | File | `/goform/aspForm` | High
27 | File | `/goform/delAd` | High
28 | File | `/goform/wifiSSIDset` | High
29 | File | `/gpac/src/bifs/unquantize.c` | High
30 | File | `/inc/topBarNav.php` | High
31 | File | `/index.asp` | Medium
32 | File | `/index.php` | Medium
33 | File | `/index.php?app=main&func=passport&action=login` | High
34 | File | `/inquiries/view_inquiry.php` | High
35 | File | `/iwguestbook/admin/badwords_edit.asp` | High
36 | File | `/iwguestbook/admin/messages_edit.asp` | High
37 | File | `/jfinal_cms/system/role/list` | High
38 | File | `/kelas/data` | Medium
39 | File | `/listplace/user/ticket/create` | High
40 | File | `/medical/inventories.php` | High
41 | File | `/Moosikay/order.php` | High
42 | File | `/php-sms/admin/quotes/manage_remark.php` | High
43 | File | `/products/details.asp` | High
44 | File | `/secure/QueryComponent!Default.jspa` | High
45 | File | `/squashfs-root/etc_ro/custom.conf` | High
46 | File | `/staff/edit_book_details.php` | High
47 | File | `/SysManage/AddUpdateRole.aspx` | High
48 | ... | ... | ...

There are 418 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://threatfox.abuse.ch
* https://tracker.viriback.com/index.php?q=91.92.254.42

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
