# Dark Caracal - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Dark Caracal](https://vuldb.com/?actor.dark_caracal). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.dark_caracal](https://vuldb.com/?actor.dark_caracal)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Dark Caracal:

* [LA](https://vuldb.com/?country.la)
* [CZ](https://vuldb.com/?country.cz)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Dark Caracal.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [74.208.167.252](https://vuldb.com/?ip.74.208.167.252) | - | - | High
2 | [77.78.103.41](https://vuldb.com/?ip.77.78.103.41) | assigned-77-78-103-41.dc3.cz | - | High
3 | [111.90.140.11](https://vuldb.com/?ip.111.90.140.11) | mail1.nasyshop.info | - | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Dark Caracal_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Dark Caracal. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/dl_sendmail.php` | High
2 | File | `/api/baskets/{name}` | High
3 | File | `/api/v2/cli/commands` | High
4 | File | `/apply.cgi` | Medium
5 | File | `/dede/sys_sql_query.php` | High
6 | File | `/DXR.axd` | Medium
7 | File | `/forum/away.php` | High
8 | File | `/novel/bookSetting/list` | High
9 | File | `/novel/userFeedback/list` | High
10 | File | `/owa/auth/logon.aspx` | High
11 | File | `/spip.php` | Medium
12 | File | `/usr/bin/pkexec` | High
13 | File | `/zm/index.php` | High
14 | File | `adclick.php` | Medium
15 | File | `admin.jcomments.php` | High
16 | File | `admin/file-manager/attachments` | High
17 | ... | ... | ...

There are 138 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://info.lookout.com/rs/051-ESQ-475/images/Lookout_Dark-Caracal_srr_20180118_us_v.1.0.pdf

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
