# DiamondFox - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [DiamondFox](https://vuldb.com/?actor.diamondfox). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.diamondfox](https://vuldb.com/?actor.diamondfox)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with DiamondFox:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 14 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of DiamondFox.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.187.56.97](https://vuldb.com/?ip.37.187.56.97) | ns3228103.ip-37-187-56.eu | - | High
2 | [51.254.240.44](https://vuldb.com/?ip.51.254.240.44) | - | - | High
3 | [63.249.144.71](https://vuldb.com/?ip.63.249.144.71) | - | - | High
4 | [63.249.148.70](https://vuldb.com/?ip.63.249.148.70) | - | - | High
5 | [63.249.149.70](https://vuldb.com/?ip.63.249.149.70) | - | - | High
6 | [64.182.19.61](https://vuldb.com/?ip.64.182.19.61) | - | - | High
7 | [64.182.21.64](https://vuldb.com/?ip.64.182.21.64) | - | - | High
8 | ... | ... | ... | ...

There are 27 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _DiamondFox_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by DiamondFox. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/api/admin/system/store/order/list` | High
3 | File | `/cgi-bin/wapopen` | High
4 | File | `/csms/?page=contact_us` | High
5 | File | `/ctpms/admin/?page=applications/view_application` | High
6 | File | `/download` | Medium
7 | File | `/etc/ajenti/config.yml` | High
8 | File | `/forum/away.php` | High
9 | File | `/goform/telnet` | High
10 | File | `/HNAP1` | Low
11 | File | `/menu.html` | Medium
12 | File | `/modules/profile/index.php` | High
13 | File | `/out.php` | Medium
14 | File | `/rom-0` | Low
15 | File | `/spip.php` | Medium
16 | File | `/tmp/phpglibccheck` | High
17 | File | `/uncpath/` | Medium
18 | File | `/upload` | Low
19 | File | `/usr/sbin/httpd` | High
20 | File | `/var/tmp/sess_*` | High
21 | File | `/webconsole/APIController` | High
22 | File | `/wordpress/wp-admin/admin.php` | High
23 | File | `action.php` | Medium
24 | File | `actionphp/download.File.php` | High
25 | File | `adclick.php` | Medium
26 | File | `add_comment.php` | High
27 | File | `admin-ajax.php` | High
28 | File | `admin.jcomments.php` | High
29 | File | `admin/admin.php` | High
30 | File | `admin/conf_users_edit.php` | High
31 | File | `admin/content.php` | High
32 | File | `admin/index.php` | High
33 | File | `admin/index.php?id=users/action=edit/user_id=1` | High
34 | File | `admin_gallery.php3` | High
35 | File | `affich.php` | Medium
36 | File | `agent/Core/Controller/SendRequest.cpp` | High
37 | File | `ajax/telemetry.php` | High
38 | File | `akeyActivationLogin.do` | High
39 | File | `album_portal.php` | High
40 | File | `apache-auth.conf` | High
41 | ... | ... | ...

There are 357 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/fl0x2208/IOCs-in-CSV-format/blob/6297513d672bd69f1bf488018035892e599e7a9c/DiamondFox%20%20botnet%20panels.csv

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
