# Domestic Kitten - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Domestic Kitten](https://vuldb.com/?actor.domestic_kitten). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.domestic_kitten](https://vuldb.com/?actor.domestic_kitten)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Domestic Kitten:

* [NL](https://vuldb.com/?country.nl)
* [IR](https://vuldb.com/?country.ir)
* [US](https://vuldb.com/?country.us)
* ...

There are 6 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Domestic Kitten.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.4.143.130](https://vuldb.com/?ip.46.4.143.130) | dns.belogy.de | - | High
2 | [62.112.8.37](https://vuldb.com/?ip.62.112.8.37) | customer.worldstream.nl | - | High
3 | [62.112.8.174](https://vuldb.com/?ip.62.112.8.174) | customer.worldstream.nl | - | High
4 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Domestic Kitten_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Domestic Kitten. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.travis.yml` | Medium
2 | File | `/.env` | Low
3 | File | `/admin.php` | Medium
4 | File | `/admin/subnets/ripe-query.php` | High
5 | File | `/appliance/users?action=edit` | High
6 | File | `/apply.cgi` | Medium
7 | File | `/core/conditions/AbstractWrapper.java` | High
8 | File | `/debug/pprof` | Medium
9 | File | `/export` | Low
10 | File | `/file?action=download&file` | High
11 | File | `/hardware` | Medium
12 | File | `/hub/api/user` | High
13 | File | `/librarian/bookdetails.php` | High
14 | File | `/medical/inventories.php` | High
15 | File | `/monitoring` | Medium
16 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
17 | File | `/plugin/LiveChat/getChat.json.php` | High
18 | File | `/plugins/servlet/audit/resource` | High
19 | File | `/plugins/servlet/project-config/PROJECT/roles` | High
20 | File | `/replication` | Medium
21 | File | `/RestAPI` | Medium
22 | File | `/tmp/zarafa-vacation-*` | High
23 | File | `/uncpath/` | Medium
24 | File | `/upload` | Low
25 | File | `/user/loader.php?api=1` | High
26 | ... | ... | ...

There are 219 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2019/10/mobile-malware-and-apt-espionage-prolific-pervasive-and-cross-platform
* https://research.checkpoint.com/2018/domestic-kitten-an-iranian-surveillance-operation/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
