# Dorkbot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Dorkbot](https://vuldb.com/?actor.dorkbot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.dorkbot](https://vuldb.com/?actor.dorkbot)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Dorkbot:

* [NL](https://vuldb.com/?country.nl)
* [US](https://vuldb.com/?country.us)
* [IR](https://vuldb.com/?country.ir)
* ...

There are 17 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Dorkbot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [13.107.21.200](https://vuldb.com/?ip.13.107.21.200) | - | - | High
2 | [20.112.52.29](https://vuldb.com/?ip.20.112.52.29) | - | - | High
3 | [80.82.64.8](https://vuldb.com/?ip.80.82.64.8) | nil-bustle.garished.com | - | High
4 | [80.82.65.199](https://vuldb.com/?ip.80.82.65.199) | no-reverse-dns-configured.com | - | High
5 | [80.82.65.207](https://vuldb.com/?ip.80.82.65.207) | s1.tor-exit.net | - | High
6 | [93.190.139.14](https://vuldb.com/?ip.93.190.139.14) | 93-190-139-14.hosted-by-worldstream.net | - | High
7 | ... | ... | ... | ...

There are 22 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Dorkbot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Dorkbot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%PROGRAMFILES(X86)%\TSplus\UserDesktop\themes.` | High
2 | File | `.travis.yml` | Medium
3 | File | `/admin/maintenance/view_designation.php` | High
4 | File | `/admin/search-appointment.php` | High
5 | File | `/admin/subnets/ripe-query.php` | High
6 | File | `/apply.cgi` | Medium
7 | File | `/config/php.ini` | High
8 | File | `/core/conditions/AbstractWrapper.java` | High
9 | File | `/dcim/sites/add/` | High
10 | File | `/debug/pprof` | Medium
11 | File | `/ecrire` | Low
12 | File | `/export` | Low
13 | File | `/file?action=download&file` | High
14 | File | `/forum/away.php` | High
15 | File | `/hardware` | Medium
16 | File | `/importexport.php` | High
17 | File | `/include/makecvs.php` | High
18 | File | `/librarian/bookdetails.php` | High
19 | File | `/MicroStrategyWS/happyaxis.jsp` | High
20 | File | `/monitoring` | Medium
21 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
22 | File | `/out.php` | Medium
23 | File | `/owa/auth/logon.aspx` | High
24 | File | `/plugin/LiveChat/getChat.json.php` | High
25 | File | `/plugins/servlet/audit/resource` | High
26 | File | `/plugins/servlet/project-config/PROJECT/roles` | High
27 | File | `/products/view_product.php` | High
28 | File | `/recordings/index.php` | High
29 | File | `/replication` | Medium
30 | File | `/rest/api/1.0/render` | High
31 | File | `/RestAPI` | Medium
32 | File | `/search.php` | Medium
33 | File | `/server-status` | High
34 | ... | ... | ...

There are 289 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/09/threat-roundup-0830-0906.html
* https://blog.talosintelligence.com/2022/08/threat-roundup-0812-0819.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
