# Dust Storm - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Dust Storm](https://vuldb.com/?actor.dust_storm). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.dust_storm](https://vuldb.com/?actor.dust_storm)

## Campaigns

The following _campaigns_ are known and can be associated with Dust Storm:

* Dust Storm

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Dust Storm:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [MS](https://vuldb.com/?country.ms)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Dust Storm.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [6.9.2.1](https://vuldb.com/?ip.6.9.2.1) | - | Dust Storm | High
2 | [23.238.229.128](https://vuldb.com/?ip.23.238.229.128) | - | Dust Storm | High
3 | [27.255.72.68](https://vuldb.com/?ip.27.255.72.68) | - | Dust Storm | High
4 | [27.255.72.69](https://vuldb.com/?ip.27.255.72.69) | - | Dust Storm | High
5 | [27.255.72.78](https://vuldb.com/?ip.27.255.72.78) | - | Dust Storm | High
6 | [59.120.59.2](https://vuldb.com/?ip.59.120.59.2) | 59-120-59-2.hinet-ip.hinet.net | Dust Storm | High
7 | [59.188.13.133](https://vuldb.com/?ip.59.188.13.133) | - | Dust Storm | High
8 | ... | ... | ... | ...

There are 27 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Dust Storm_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Dust Storm. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/admin.php` | High
2 | File | `/api/upload.php` | High
3 | File | `/api /v3/auth` | High
4 | File | `/cgi-bin/cstecgi.cgi` | High
5 | File | `/data/remove` | Medium
6 | File | `/debug/pprof` | Medium
7 | File | `/dev/cpu/*/msr` | High
8 | File | `/filemanager/upload/drop` | High
9 | File | `/goform/NatStaticSetting` | High
10 | File | `/include/lang-en.php` | High
11 | File | `/navigation/create?ParentID=%23` | High
12 | File | `/oauth/idp/.well-known/openid-configuration` | High
13 | File | `/preview.php` | Medium
14 | File | `/sbin/conf.d/SuSEconfig.javarunt` | High
15 | File | `/status/` | Medium
16 | File | `/system/dept/edit` | High
17 | File | `/usr/bin/write` | High
18 | File | `/var/spool/fax/outgoing/.last_run` | High
19 | File | `3G/UMTS` | Low
20 | File | `400.htm/500.htm` | High
21 | File | `abitwhizzy.php` | High
22 | File | `acc.php` | Low
23 | File | `accton` | Low
24 | File | `acloudCosAction.php.SQL` | High
25 | File | `adduser` | Low
26 | File | `add_comment.php` | High
27 | File | `add_post.php3` | High
28 | File | `admin/auth.php` | High
29 | File | `admin/index.php` | High
30 | File | `admin/TemplateController.java` | High
31 | File | `ApiController.class.php` | High
32 | File | `app/ctrl/admin/User.php` | High
33 | File | `ArchivesMapper.xml` | High
34 | File | `avatar.php` | Medium
35 | File | `bb-includes/formatting-functions.php` | High
36 | File | `BBStore.php` | Medium
37 | File | `brokenlink.php` | High
38 | File | `browse.php` | Medium
39 | File | `bsc_sms_send.php` | High
40 | File | `cal2.jsp` | Medium
41 | File | `calendar.php` | Medium
42 | File | `categos.php` | Medium
43 | File | `centre.php` | Medium
44 | ... | ... | ...

There are 382 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.threatminer.org/report.php?q=Op_Dust_Storm_Report.pdf&y=2016

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
