# ENT11 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [ENT11](https://vuldb.com/?actor.ent11). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ent11](https://vuldb.com/?actor.ent11)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with ENT11:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 5 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of ENT11.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.94.7.9](https://vuldb.com/?ip.23.94.7.9) | unsupervised.etcharb.com | - | High
2 | [23.94.7.134](https://vuldb.com/?ip.23.94.7.134) | landau.etcharb.com | - | High
3 | [23.94.24.76](https://vuldb.com/?ip.23.94.24.76) | 23-94-24-76-host.colocrossing.com | - | High
4 | [23.94.24.77](https://vuldb.com/?ip.23.94.24.77) | 23-94-24-77-host.colocrossing.com | - | High
5 | [23.94.24.78](https://vuldb.com/?ip.23.94.24.78) | 23-94-24-78-host.colocrossing.com | - | High
6 | [23.95.8.149](https://vuldb.com/?ip.23.95.8.149) | 23-95-8-149-host.colocrossing.com | - | High
7 | [37.187.204.27](https://vuldb.com/?ip.37.187.204.27) | smtp1.hosterdaddy.com | - | High
8 | ... | ... | ... | ...

There are 27 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _ENT11_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 13 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by ENT11. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/cgi-bin/koha/acqui/supplier.pl?op=enter` | High
2 | File | `/cgi-bin/system_mgr.cgi` | High
3 | File | `/download` | Medium
4 | File | `/forum/away.php` | High
5 | File | `/include/helpers/upload.helper.php` | High
6 | File | `/oauth/idp/.well-known/openid-configuration` | High
7 | File | `/opt/IBM/es/lib/libffq.cryptionjni.so` | High
8 | File | `/PROD_ar/twbkwbis.P_FirstMenu` | High
9 | File | `/rom-0` | Low
10 | File | `/spip.php` | Medium
11 | File | `/uncpath/` | Medium
12 | File | `/WWW//app/admin/controller/admincontroller.php` | High
13 | File | `adclick.php` | Medium
14 | File | `add_comment.php` | High
15 | File | `admin/cmsWebFile/list.html?path=../` | High
16 | File | `adminBanned.php` | High
17 | ... | ... | ...

There are 139 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://jp.security.ntt/tech_blog/analysis-of-an-iranian-apts-e400-powgoop-variant-reveals-dozens-of-control-servers-dating-back

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
