# East Europe Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [East Europe Unknown](https://vuldb.com/?actor.east_europe_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.east_europe_unknown](https://vuldb.com/?actor.east_europe_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with East Europe Unknown:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of East Europe Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.188.108.119](https://vuldb.com/?ip.5.188.108.119) | free.ds | - | High
2 | [45.154.12.167](https://vuldb.com/?ip.45.154.12.167) | - | - | High
3 | [91.216.190.58](https://vuldb.com/?ip.91.216.190.58) | - | - | High
4 | ... | ... | ... | ...

There are 3 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _East Europe Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by East Europe Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
2 | File | `/classes/Master.php` | High
3 | File | `/classes/Master.php?f=delete_service` | High
4 | File | `/etc/postfix/sender_login` | High
5 | File | `/file/upload/1` | High
6 | File | `/filemanager/ajax_calls.php` | High
7 | File | `/index.php` | Medium
8 | File | `/Items/*/RemoteImages/Download` | High
9 | File | `/members/view_member.php` | High
10 | File | `/mhds/clinic/view_details.php` | High
11 | File | `/owa/auth/logon.aspx` | High
12 | File | `/rest/api/latest/projectvalidate/key` | High
13 | File | `/restapi/v1/certificates/FFM-SSLInspect` | High
14 | File | `/secure/QueryComponent!Default.jspa` | High
15 | ... | ... | ...

There are 116 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.google/threat-analysis-group/tracking-cyber-activity-eastern-europe/
* https://securityintelligence.com/posts/hive00117-fileless-malware-delivery-eastern-europe/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
