# Golang - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Golang](https://vuldb.com/?actor.golang). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.golang](https://vuldb.com/?actor.golang)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Golang:

* [RU](https://vuldb.com/?country.ru)
* [US](https://vuldb.com/?country.us)
* [IT](https://vuldb.com/?country.it)
* ...

There are 10 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Golang.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [6.43.51.17](https://vuldb.com/?ip.6.43.51.17) | - | - | High
2 | [20.99.160.173](https://vuldb.com/?ip.20.99.160.173) | - | - | High
3 | [34.85.243.241](https://vuldb.com/?ip.34.85.243.241) | 241.243.85.34.bc.googleusercontent.com | - | Medium
4 | [34.105.72.241](https://vuldb.com/?ip.34.105.72.241) | 241.72.105.34.bc.googleusercontent.com | - | Medium
5 | [34.138.96.23](https://vuldb.com/?ip.34.138.96.23) | 23.96.138.34.bc.googleusercontent.com | - | Medium
6 | [34.141.146.114](https://vuldb.com/?ip.34.141.146.114) | 114.146.141.34.bc.googleusercontent.com | - | Medium
7 | [34.141.245.25](https://vuldb.com/?ip.34.141.245.25) | 25.245.141.34.bc.googleusercontent.com | - | Medium
8 | ... | ... | ... | ...

There are 29 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Golang_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23, CWE-35 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Golang. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//proc/kcore` | Medium
2 | File | `/admin.php/news/admin/topic/save` | High
3 | File | `/admin/login.php` | High
4 | File | `/admin/store.php` | High
5 | File | `/admin_ping.htm` | High
6 | File | `/ample/app/action/edit_product.php` | High
7 | File | `/api/dashboard/activity` | High
8 | File | `/app/index/controller/Common.php` | High
9 | File | `/cgi-bin/cstecgi.cgi` | High
10 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
11 | File | `/FTPDiag.asp` | Medium
12 | File | `/goform/setAutoPing` | High
13 | File | `/LandingPages/api/otp/send?id=[ID][ampersand]method=sms` | High
14 | File | `/me` | Low
15 | File | `/myprofile.php` | High
16 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
17 | File | `/opennds_auth/` | High
18 | ... | ... | ...

There are 143 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.fortinet.com/blog/threat-research/new-golang-ransomware-targeting-linux-systems.html
* https://www.trellix.com/about/newsroom/stories/research/skuld-the-infostealer-that-speaks-golang/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
