# Guyana Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Guyana Unknown](https://vuldb.com/?actor.guyana_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.guyana_unknown](https://vuldb.com/?actor.guyana_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Guyana Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [GY](https://vuldb.com/?country.gy)
* ...

There are 23 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Guyana Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.11.28.0](https://vuldb.com/?ip.5.11.28.0) | - | - | High
2 | [5.62.56.116](https://vuldb.com/?ip.5.62.56.116) | r-116-56-62-5.consumer-pool.prcdn.net | - | High
3 | [5.62.58.108](https://vuldb.com/?ip.5.62.58.108) | r-108-58-62-5.consumer-pool.prcdn.net | - | High
4 | [5.102.79.0](https://vuldb.com/?ip.5.102.79.0) | - | - | High
5 | [45.12.70.95](https://vuldb.com/?ip.45.12.70.95) | gliding.yourbandinc.com | - | High
6 | [45.12.71.95](https://vuldb.com/?ip.45.12.71.95) | - | - | High
7 | [45.74.20.128](https://vuldb.com/?ip.45.74.20.128) | - | - | High
8 | [57.74.246.0](https://vuldb.com/?ip.57.74.246.0) | - | - | High
9 | [57.75.112.0](https://vuldb.com/?ip.57.75.112.0) | - | - | High
10 | ... | ... | ... | ...

There are 37 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Guyana Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Guyana Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/manage_academic.php` | High
2 | File | `/admin/photo.php` | High
3 | File | `/admin/upload.php` | High
4 | File | `/admin/user/add` | High
5 | File | `/api/baskets/{name}` | High
6 | File | `/APP_Installation.asp` | High
7 | File | `/blog` | Low
8 | File | `/categorypage.php` | High
9 | File | `/cm/delete` | Medium
10 | File | `/common/logViewer/logViewer.jsf` | High
11 | File | `/controller/Index.php` | High
12 | File | `/crmeb/app/admin/controller/store/CopyTaobao.php` | High
13 | File | `/download` | Medium
14 | File | `/drivers/media/media-device.c` | High
15 | File | `/etc/master.passwd` | High
16 | File | `/etc/tomcat8/Catalina/attack` | High
17 | File | `/export` | Low
18 | File | `/filemanager/upload.php` | High
19 | File | `/forum/away.php` | High
20 | File | `/getcfg.php` | Medium
21 | File | `/goform/SetSpeedWan` | High
22 | File | `/home.php` | Medium
23 | File | `/homeaction.php` | High
24 | File | `/index.php` | Medium
25 | File | `/modules/profile/index.php` | High
26 | File | `/modules/tasks/summary.inc.php` | High
27 | File | `/multi-vendor-shopping-script/product-list.php` | High
28 | File | `/mygym/admin/index.php` | High
29 | File | `/out.php` | Medium
30 | File | `/p` | Low
31 | File | `/preauth` | Medium
32 | File | `/products/details.asp` | High
33 | File | `/recordings/index.php` | High
34 | File | `/see_more_details.php` | High
35 | File | `/show_news.php` | High
36 | File | `/SysInfo.htm` | Medium
37 | File | `/tmp/before` | Medium
38 | File | `/uncpath/` | Medium
39 | File | `/updownload/t.report` | High
40 | File | `/user.profile.php` | High
41 | File | `/var/WEB-GUI/cgi-bin/telnet.cgi` | High
42 | File | `/wordpress/wp-admin/options-general.php` | High
43 | File | `/wp-admin` | Medium
44 | File | `/wp-admin/admin-ajax.php` | High
45 | File | `4.2.0.CP09` | Medium
46 | File | `account.asp` | Medium
47 | File | `adclick.php` | Medium
48 | File | `adm/systools.asp` | High
49 | File | `admin.php` | Medium
50 | File | `admin/admin.shtml` | High
51 | File | `Admin/ADM_Pagina.php` | High
52 | File | `admin/category.inc.php` | High
53 | File | `admin/main.asp` | High
54 | File | `admin/param/param_func.inc.php` | High
55 | File | `admin/theme-edit.php` | High
56 | File | `admin/y_admin.asp` | High
57 | File | `adminer.php` | Medium
58 | File | `administration/admins.php` | High
59 | File | `administrator/components/com_media/helpers/media.php` | High
60 | File | `admin_ok.asp` | Medium
61 | File | `album_portal.php` | High
62 | File | `app.coffee` | Medium
63 | File | `app/Core/Paginator.php` | High
64 | File | `app/index.php/accounts/default/details?id=2&kanbanBoard=1&openToTaskId=1` | High
65 | File | `artlinks.dispnew.php` | High
66 | File | `auth.php` | Medium
67 | File | `awstats.pl` | Medium
68 | ... | ... | ...

There are 595 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_gy.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_gy.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_gy.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
