# IRCflu and Interplanetary Storm - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [IRCflu and Interplanetary Storm](https://vuldb.com/?actor.ircflu_and_interplanetary_storm). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ircflu_and_interplanetary_storm](https://vuldb.com/?actor.ircflu_and_interplanetary_storm)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with IRCflu and Interplanetary Storm:

* [US](https://vuldb.com/?country.us)
* [PL](https://vuldb.com/?country.pl)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 4 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of IRCflu and Interplanetary Storm.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [185.234.216.34](https://vuldb.com/?ip.185.234.216.34) | - | - | High
2 | [193.56.28.120](https://vuldb.com/?ip.193.56.28.120) | - | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _IRCflu and Interplanetary Storm_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by IRCflu and Interplanetary Storm. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/admin/config/uploadicon.php` | High
3 | File | `/admin/loginc.php` | High
4 | File | `/admin/students/view_student.php` | High
5 | File | `/Applications/Calculator.app/Contents/MacOS/Calculator` | High
6 | File | `/cgi-bin/` | Medium
7 | File | `/cgi-bin/luci` | High
8 | File | `/common/info.cgi` | High
9 | File | `/config.cgi?webmin` | High
10 | File | `/data/inc/images.php` | High
11 | File | `/dev/block/mmcblk0rpmb` | High
12 | File | `/edit` | Low
13 | File | `/etc/passwd` | Medium
14 | File | `/etc/stunnel.key` | High
15 | File | `/etc/sysconfig/btrfsmaintenance` | High
16 | File | `/framework/modules/notfound/controllers/notfoundController.php` | High
17 | File | `/gadgets/definitions/uptime.CapacityWhatIfGadget/getmetrics.php` | High
18 | File | `/inquiries/view_inquiry.php` | High
19 | File | `/job-details` | Medium
20 | File | `/mib.db` | Low
21 | File | `/page/add` | Medium
22 | File | `/squashfs-root/www/HNAP1/control/SetWizardConfig.php` | High
23 | File | `/system-info/health` | High
24 | File | `/tmp/s48lose.tmp` | High
25 | File | `/tmp/xbindkeysrc-tmp` | High
26 | File | `/uncpath/` | Medium
27 | File | `/usr/local` | Medium
28 | File | `/var/log/nginx` | High
29 | File | `/var/run/jboss-eap/` | High
30 | File | `admin-ajax.php` | High
31 | File | `admin.jcomments.php` | High
32 | File | `admin.php` | Medium
33 | File | `admin/?n=language&c=language_general&a=doSearchParameter` | High
34 | File | `admin/?n=user&c=admin_user&a=doGetUserInfo` | High
35 | File | `admin/admin_log/index.html?user_id` | High
36 | File | `admin/admin_menu.php` | High
37 | File | `admin/config.php` | High
38 | File | `admin/content.php` | High
39 | File | `admin/edit_category.php` | High
40 | File | `admin/users` | Medium
41 | ... | ... | ...

There are 350 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://labs.bitdefender.com/2020/06/ssh-targeting-golang-bots-becoming-the-new-norm/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
