# Iran Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Iran Unknown](https://vuldb.com/?actor.iran_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.iran_unknown](https://vuldb.com/?actor.iran_unknown)

## Campaigns

The following _campaigns_ are known and can be associated with Iran Unknown:

* Albanian Government

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Iran Unknown:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [ES](https://vuldb.com/?country.es)
* ...

There are 14 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Iran Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.30.189.66](https://vuldb.com/?ip.46.30.189.66) | - | Albanian Government | High
2 | [51.89.181.64](https://vuldb.com/?ip.51.89.181.64) | ip64.ip-51-89-181.eu | - | High
3 | [66.219.22.235](https://vuldb.com/?ip.66.219.22.235) | core96.hostingmadeeasy.com | - | High
4 | [83.171.238.62](https://vuldb.com/?ip.83.171.238.62) | 558.cluster-nbg1.de | - | High
5 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Iran Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Iran Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//etc/RT2870STA.dat` | High
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/administration/theme.php` | High
4 | File | `/api/index.php` | High
5 | File | `/boafrm/formFilter` | High
6 | File | `/cgi-bin/webproc` | High
7 | File | `/clinic/medical_records_view.php` | High
8 | File | `/coreframe/app/pay/admin/index.php` | High
9 | File | `/forum/away.php` | High
10 | File | `/importexport.php` | High
11 | File | `/index.php` | Medium
12 | File | `/mobileredir/openApp.jsp` | High
13 | File | `/ofrs/admin/?page=requests/manage_request` | High
14 | File | `/search` | Low
15 | File | `/spip.php` | Medium
16 | File | `/usr/www/ja/mnt_cmd.cgi` | High
17 | File | `/wp-admin/admin-ajax.php` | High
18 | File | `active.log` | Medium
19 | File | `activenews_view.asp` | High
20 | ... | ... | ...

There are 162 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/blackorbird/APT_REPORT/blob/master/muddywater/Clearsky-Iranian-APT-group-%E2%80%98MuddyWater%E2%80%99-Adds-Exploits-to-Their-Arsenal.pdf
* https://us-cert.cisa.gov/ncas/alerts/aa21-321a
* https://www.cisa.gov/uscert/ncas/alerts/aa22-320a
* https://www.microsoft.com/security/blog/2022/09/08/microsoft-investigates-iranian-attacks-against-the-albanian-government/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
