# Iron - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Iron](https://vuldb.com/?actor.iron). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.iron](https://vuldb.com/?actor.iron)

## Campaigns

The following _campaigns_ are known and can be associated with Iron:

* XBash

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Iron:

* [ES](https://vuldb.com/?country.es)
* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Iron.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.77.250.141](https://vuldb.com/?ip.45.77.250.141) | 45.77.250.141.vultrusercontent.com | - | High
2 | [45.142.214.193](https://vuldb.com/?ip.45.142.214.193) | vm625196.stark-industries.solutions | - | High
3 | [80.92.206.158](https://vuldb.com/?ip.80.92.206.158) | ra.lan-t.ru | - | High
4 | ... | ... | ... | ...

There are 4 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Iron_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-25 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | T1068 | CWE-250, CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
7 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Iron. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%PROGRAMDATA%\ASUS\GamingCenterLib` | High
2 | File | `../FILEDIR` | Medium
3 | File | `/account/login` | High
4 | File | `/adherents/note.php?id=1` | High
5 | File | `/admin/ajax.php` | High
6 | File | `/Admin/dashboard.php` | High
7 | File | `/alphaware/details.php` | High
8 | File | `/Api/ASF` | Medium
9 | File | `/auth/fn.php` | Medium
10 | File | `/cgi-bin/ExportLogs.sh` | High
11 | File | `/cgi-bin/wlogin.cgi` | High
12 | File | `/classes/Users.php?f=save` | High
13 | File | `/clients/editclient.php` | High
14 | File | `/CommunitySSORedirect.jsp` | High
15 | File | `/ctpms/admin/?page=applications/view_application` | High
16 | File | `/dist/index.js` | High
17 | File | `/dl/dl_sendmail.php` | High
18 | File | `/editor/index.php` | High
19 | File | `/Electron/download` | High
20 | File | `/etc/passwd` | Medium
21 | File | `/formStaticDHCP` | High
22 | File | `/formVirtualApp` | High
23 | File | `/formVirtualServ` | High
24 | File | `/goForm/aspForm` | High
25 | File | `/goform/form2WizardStep4` | High
26 | File | `/goform/rlmswitchr_process` | High
27 | File | `/goform/SafeMacFilter` | High
28 | File | `/goform/SafeUrlFilter` | High
29 | File | `/goforms/rlminfo` | High
30 | File | `/include/make.php` | High
31 | File | `/include/Model/Upload.php` | High
32 | File | `/kruxton/sales_report.php` | High
33 | File | `/magnoliaAuthor/.magnolia/` | High
34 | ... | ... | ...

There are 291 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://community.blueliv.com/#!/s/62fb3b7982df417ed03315be
* https://unit42.paloaltonetworks.com/unit42-xbash-combines-botnet-ransomware-coinmining-worm-targets-linux-windows/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
