# Isle of Man Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Isle of Man Unknown](https://vuldb.com/?actor.isle_of_man_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.isle_of_man_unknown](https://vuldb.com/?actor.isle_of_man_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Isle of Man Unknown:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 15 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Isle of Man Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.80.0](https://vuldb.com/?ip.5.62.80.0) | - | - | High
2 | [5.62.92.0](https://vuldb.com/?ip.5.62.92.0) | - | - | High
3 | [5.253.76.0](https://vuldb.com/?ip.5.253.76.0) | ip-76-0.gov.im | - | High
4 | [23.232.247.0](https://vuldb.com/?ip.23.232.247.0) | - | - | High
5 | [37.18.136.0](https://vuldb.com/?ip.37.18.136.0) | - | - | High
6 | [37.25.88.0](https://vuldb.com/?ip.37.25.88.0) | - | - | High
7 | [37.235.55.0](https://vuldb.com/?ip.37.235.55.0) | - | - | High
8 | [43.225.112.0](https://vuldb.com/?ip.43.225.112.0) | - | - | High
9 | [45.12.70.105](https://vuldb.com/?ip.45.12.70.105) | pour-uncover.yourbandinc.com | - | High
10 | [45.12.71.105](https://vuldb.com/?ip.45.12.71.105) | - | - | High
11 | [45.85.196.0](https://vuldb.com/?ip.45.85.196.0) | - | - | High
12 | [46.31.200.0](https://vuldb.com/?ip.46.31.200.0) | - | - | High
13 | [46.226.184.0](https://vuldb.com/?ip.46.226.184.0) | - | - | High
14 | [46.243.144.0](https://vuldb.com/?ip.46.243.144.0) | - | - | High
15 | [62.68.190.111](https://vuldb.com/?ip.62.68.190.111) | bbd62-68-190-111.network.sure.com | - | High
16 | ... | ... | ... | ...

There are 62 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Isle of Man Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Isle of Man Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/.env` | Low
3 | File | `/bin/boa` | Medium
4 | File | `/etc/gsissh/sshd_config` | High
5 | File | `/mc` | Low
6 | File | `/proc/ioports` | High
7 | File | `/server-info` | Medium
8 | File | `/tmp/phpglibccheck` | High
9 | File | `/uncpath/` | Medium
10 | File | `advertiser/login_confirm.asp` | High
11 | File | `akocomments.php` | High
12 | File | `applications/luci-app-ddns/luasrc/model/cbi/ddns/detail.lua` | High
13 | File | `awstats.pl` | Medium
14 | File | `a_login.php` | Medium
15 | ... | ... | ...

There are 123 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_im.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
