# JAFF - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [JAFF](https://vuldb.com/?actor.jaff). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.jaff](https://vuldb.com/?actor.jaff)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with JAFF:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [LV](https://vuldb.com/?country.lv)
* ...

There are 18 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of JAFF.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [6.43.51.17](https://vuldb.com/?ip.6.43.51.17) | - | - | High
2 | [27.254.44.204](https://vuldb.com/?ip.27.254.44.204) | - | - | High
3 | [31.202.130.20](https://vuldb.com/?ip.31.202.130.20) | 31-202-130-20-kh.maxnet.ua | - | High
4 | [37.59.41.180](https://vuldb.com/?ip.37.59.41.180) | ns3002298.ip-37-59-41.eu | - | High
5 | [46.17.46.214](https://vuldb.com/?ip.46.17.46.214) | - | - | High
6 | [46.173.219.234](https://vuldb.com/?ip.46.173.219.234) | - | - | High
7 | [47.91.107.213](https://vuldb.com/?ip.47.91.107.213) | - | - | High
8 | ... | ... | ... | ...

There are 30 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _JAFF_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by JAFF. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/category/list?limit=10&offset=0&order=desc` | High
4 | File | `/cgi-bin/login_action.cgi` | High
5 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
6 | File | `/cgi-bin/touchlist_sync.cgi` | High
7 | File | `/classes/Master.php?f=delete_brand` | High
8 | File | `/diag_ping_admin.asp` | High
9 | File | `/forum/PostPrivateMessage` | High
10 | File | `/goform/formSysCmd` | High
11 | File | `/HNAP1` | Low
12 | File | `/owa/auth/logon.aspx` | High
13 | File | `/pages/systemcall.php?command={COMMAND}` | High
14 | File | `/phppath/php` | Medium
15 | File | `/setSystemAdmin` | High
16 | File | `/shell` | Low
17 | File | `/spip.php` | Medium
18 | File | `/SSOPOST/metaAlias/%realm%/idpv2` | High
19 | File | `/uncpath/` | Medium
20 | File | `/user/loader.php?api=1` | High
21 | File | `/usr/bin/pkexec` | High
22 | File | `/webpages/data` | High
23 | ... | ... | ...

There are 187 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.cyber45.com
* https://www.fortinet.com/blog/threat-research/looking-into-jaff-ransomware.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
