# JanelaRAT - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [JanelaRAT](https://vuldb.com/?actor.janelarat). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.janelarat](https://vuldb.com/?actor.janelarat)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with JanelaRAT:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [BR](https://vuldb.com/?country.br)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of JanelaRAT.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.42.160.15](https://vuldb.com/?ip.45.42.160.15) | - | - | High
2 | [45.42.160.55](https://vuldb.com/?ip.45.42.160.55) | - | - | High
3 | [45.133.18.35](https://vuldb.com/?ip.45.133.18.35) | mail.brandwholesale1.com | - | High
4 | ... | ... | ... | ...

There are 9 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _JanelaRAT_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by JanelaRAT. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/general.cgi` | High
2 | File | `/admin/reminders/manage_reminder.php` | High
3 | File | `/CCMAdmin/serverlist.asp` | High
4 | File | `/cgi/get_param.cgi` | High
5 | File | `/csms/admin/inquiries/view_details.php` | High
6 | File | `/cstecgi.cgi` | Medium
7 | File | `/files.md5` | Medium
8 | File | `/forum/away.php` | High
9 | File | `/hrm/employeeview.php` | High
10 | File | `/include/chart_generator.php` | High
11 | File | `/librarian/bookdetails.php` | High
12 | File | `/login` | Low
13 | File | `/messageboard/view.php` | High
14 | File | `/modules/profile/index.php` | High
15 | File | `/oauth/idp/.well-known/openid-configuration` | High
16 | File | `/one_church/userregister.php` | High
17 | File | `/out.php` | Medium
18 | File | `/public/plugins/` | High
19 | File | `/SAP_Information_System/controllers/add_admin.php` | High
20 | File | `/SASWebReportStudio/logonAndRender.do` | High
21 | File | `/secure/admin/InsightDefaultCustomFieldConfig.jspa` | High
22 | File | `/secure/admin/ViewInstrumentation.jspa` | High
23 | File | `/SVFE2/pages/feegroups/country_group.jsf` | High
24 | File | `/SystemMng.ashx` | High
25 | File | `/textpattern/index.php` | High
26 | File | `/upfile.cgi` | Medium
27 | File | `/v2/quantum/save-data-upload-big-file` | High
28 | File | `/wordpress/wp-admin/admin.php` | High
29 | File | `4.edu.php` | Medium
30 | File | `AccountManagerService.java` | High
31 | File | `account_footer.php` | High
32 | File | `adclick.php` | Medium
33 | File | `addlink.php` | Medium
34 | File | `add_edit_cat.asp` | High
35 | File | `add_edit_user.asp` | High
36 | ... | ... | ...

There are 305 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://twitter.com/0xToxin/status/1719637665434251518
* https://twitter.com/StopMalvertisin/status/1696131096503796048
* https://www.virustotal.com/gui/file/8e2b6a9a8249781d61dfeb65dfd1edc9cc3ad062e148abfd73bf05a359f5912d/detection
* https://www.virustotal.com/gui/file/c3b3cf24665e78be302cd9271ee3e9a8aadbdb1d056fcee39153e4efb1810dff/detection
* https://www.zscaler.com/blogs/security-research/janelarat-repurposed-bx-rat-variant-targeting-latam-fintech

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
