# Karakurt - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Karakurt](https://vuldb.com/?actor.karakurt). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.karakurt](https://vuldb.com/?actor.karakurt)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Karakurt:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [ID](https://vuldb.com/?country.id)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Karakurt.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [1.116.139.11](https://vuldb.com/?ip.1.116.139.11) | - | - | High
2 | [5.45.83.32](https://vuldb.com/?ip.5.45.83.32) | - | - | High
3 | [23.99.177.202](https://vuldb.com/?ip.23.99.177.202) | - | - | High
4 | [31.14.40.64](https://vuldb.com/?ip.31.14.40.64) | - | - | High
5 | [37.252.0.143](https://vuldb.com/?ip.37.252.0.143) | - | - | High
6 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Karakurt_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-28, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Karakurt. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?p=products` | Medium
2 | File | `/admin.php/accessory/filesdel.html` | High
3 | File | `/admin/?page=user/manage` | High
4 | File | `/admin/add-new.php` | High
5 | File | `/admin/controller/JobLogController.java` | High
6 | File | `/admin/course.php` | High
7 | File | `/admin/departments/manage_department.php` | High
8 | File | `/admin/doctors.php` | High
9 | File | `/admin/maintenance/view_designation.php` | High
10 | File | `/admin/manage-pages.php` | High
11 | File | `/admin/manage-users.php` | High
12 | File | `/admin/subject.php` | High
13 | File | `/admin/submit-articles` | High
14 | File | `/admin/success_story.php` | High
15 | File | `/admin/usermanagement.php` | High
16 | File | `/adplanet/PlanetCommentList` | High
17 | File | `/adplanet/PlanetUser` | High
18 | File | `/alphaware/summary.php` | High
19 | File | `/api/` | Low
20 | File | `/api/admin/store/product/list` | High
21 | File | `/api/authentication/login` | High
22 | File | `/api/baskets/{name}` | High
23 | File | `/api/stl/actions/search` | High
24 | File | `/api/sys/login` | High
25 | File | `/api/sys/set_passwd` | High
26 | File | `/api/trackedEntityInstances` | High
27 | File | `/api/v2/cli/commands` | High
28 | File | `/article/DelectArticleById/` | High
29 | File | `/attachments` | Medium
30 | File | `/aux` | Low
31 | File | `/bin/ate` | Medium
32 | File | `/boat/login.php` | High
33 | File | `/booking/show_bookings/` | High
34 | File | `/bsms_ci/index.php/book` | High
35 | File | `/cgi-bin` | Medium
36 | File | `/cgi-bin/cstecgi.cgi` | High
37 | File | `/cgi-bin/wlogin.cgi` | High
38 | File | `/changePassword` | High
39 | File | `/classes/Master.php?f=delete_reminder` | High
40 | File | `/config-manager/save` | High
41 | File | `/Content/Template/root/reverse-shell.aspx` | High
42 | File | `/core/tools/customblock.php` | High
43 | File | `/dashboard/add-blog.php` | High
44 | File | `/data/remove` | Medium
45 | File | `/debug/pprof` | Medium
46 | File | `/ecshop/admin/template.php` | High
47 | File | `/env` | Low
48 | File | `/etc/hosts` | Medium
49 | File | `/forum/away.php` | High
50 | File | `/geoserver/gwc/rest.html` | High
51 | File | `/group1/uploa` | High
52 | File | `/importexport.php` | High
53 | ... | ... | ...

There are 458 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/infinitumitlabs/Karakurt-Hacking-Team-CTI
* https://www.bleepingcomputer.com/news/security/karakurt-revealed-as-data-extortion-arm-of-conti-cybercrime-syndicate/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
