# Liberia Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Liberia Unknown](https://vuldb.com/?actor.liberia_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.liberia_unknown](https://vuldb.com/?actor.liberia_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Liberia Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 18 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Liberia Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.60.224](https://vuldb.com/?ip.5.62.60.224) | r-224-60-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.62.216](https://vuldb.com/?ip.5.62.62.216) | r-216-62-62-5.consumer-pool.prcdn.net | - | High
3 | [41.57.80.0](https://vuldb.com/?ip.41.57.80.0) | - | - | High
4 | [41.57.80.3](https://vuldb.com/?ip.41.57.80.3) | - | - | High
5 | [41.57.80.4](https://vuldb.com/?ip.41.57.80.4) | - | - | High
6 | [41.57.80.8](https://vuldb.com/?ip.41.57.80.8) | - | - | High
7 | [41.57.80.16](https://vuldb.com/?ip.41.57.80.16) | - | - | High
8 | [41.57.80.32](https://vuldb.com/?ip.41.57.80.32) | - | - | High
9 | [41.57.80.64](https://vuldb.com/?ip.41.57.80.64) | - | - | High
10 | [41.57.80.128](https://vuldb.com/?ip.41.57.80.128) | - | - | High
11 | [41.57.81.0](https://vuldb.com/?ip.41.57.81.0) | - | - | High
12 | [41.57.82.0](https://vuldb.com/?ip.41.57.82.0) | - | - | High
13 | [41.57.84.0](https://vuldb.com/?ip.41.57.84.0) | - | - | High
14 | [41.57.88.0](https://vuldb.com/?ip.41.57.88.0) | - | - | High
15 | [41.57.89.0](https://vuldb.com/?ip.41.57.89.0) | - | - | High
16 | [41.57.89.128](https://vuldb.com/?ip.41.57.89.128) | - | - | High
17 | [41.57.89.192](https://vuldb.com/?ip.41.57.89.192) | - | - | High
18 | [41.57.89.224](https://vuldb.com/?ip.41.57.89.224) | - | - | High
19 | ... | ... | ... | ...

There are 73 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Liberia Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Liberia Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/?Page=Node/OBJ=/System/DeviceFolder/DeviceFolder/DateTime/Action=Submit` | High
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/admin/add-services.php` | High
5 | File | `/admin/ajax/avatar.php` | High
6 | File | `/admin/edit-services.php` | High
7 | File | `/admin/forgot-password.php` | High
8 | File | `/admin/index.php` | High
9 | File | `/admin/lab.php` | High
10 | File | `/admin/login.php` | High
11 | File | `/admin/payment.php` | High
12 | File | `/admin/show.php` | High
13 | File | `/boat/login.php` | High
14 | File | `/clinic/disease_symptoms_view.php` | High
15 | File | `/default.php?idx=17` | High
16 | File | `/download` | Medium
17 | File | `/env` | Low
18 | File | `/forum/away.php` | High
19 | File | `/index.php` | Medium
20 | File | `/opt/bin/cli` | Medium
21 | File | `/p` | Low
22 | File | `/patient/doctors.php` | High
23 | File | `/phpinventory/editcategory.php` | High
24 | File | `/php_action/createUser.php` | High
25 | File | `/product-list.php` | High
26 | File | `/spip.php` | Medium
27 | File | `/uapi/doc` | Medium
28 | File | `/uncpath/` | Medium
29 | File | `/updown/upload.cgi` | High
30 | File | `/user/del.php` | High
31 | File | `/wp-admin/admin-ajax.php` | High
32 | File | `/_next` | Low
33 | File | `123flashchat.php` | High
34 | File | `act.php` | Low
35 | File | `admin.php/pay` | High
36 | File | `admin/bad.php` | High
37 | File | `admin/index.php` | High
38 | File | `admin/index.php/user/del/1` | High
39 | File | `admin/index.php?id=themes&action=edit_chunk` | High
40 | File | `admin/products/controller.php?action=add` | High
41 | File | `administrator/index.php` | High
42 | ... | ... | ...

There are 363 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_lr.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_lr.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_lr.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
