# Liechtenstein - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Liechtenstein](https://vuldb.com/?actor.liechtenstein). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.liechtenstein](https://vuldb.com/?actor.liechtenstein)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Liechtenstein:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 23 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Liechtenstein.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.34.248.0](https://vuldb.com/?ip.5.34.248.0) | - | - | High
2 | [5.62.60.232](https://vuldb.com/?ip.5.62.60.232) | r-232-60-62-5.consumer-pool.prcdn.net | - | High
3 | [5.62.62.224](https://vuldb.com/?ip.5.62.62.224) | r-224-62-62-5.consumer-pool.prcdn.net | - | High
4 | [31.6.16.0](https://vuldb.com/?ip.31.6.16.0) | undefined.hostname.localhost | - | High
5 | [31.10.16.0](https://vuldb.com/?ip.31.10.16.0) | - | - | High
6 | [34.99.166.0](https://vuldb.com/?ip.34.99.166.0) | 0.166.99.34.bc.googleusercontent.com | - | Medium
7 | [34.99.238.0](https://vuldb.com/?ip.34.99.238.0) | 0.238.99.34.bc.googleusercontent.com | - | Medium
8 | [34.103.182.0](https://vuldb.com/?ip.34.103.182.0) | 0.182.103.34.bc.googleusercontent.com | - | Medium
9 | [45.12.70.130](https://vuldb.com/?ip.45.12.70.130) | unpleasing.yourbandinc.com | - | High
10 | [45.12.70.253](https://vuldb.com/?ip.45.12.70.253) | scaffolds.globalhilive.com | - | High
11 | [45.12.71.130](https://vuldb.com/?ip.45.12.71.130) | - | - | High
12 | [45.59.166.0](https://vuldb.com/?ip.45.59.166.0) | - | - | High
13 | [45.81.12.0](https://vuldb.com/?ip.45.81.12.0) | - | - | High
14 | [45.83.196.0](https://vuldb.com/?ip.45.83.196.0) | - | - | High
15 | [45.91.204.0](https://vuldb.com/?ip.45.91.204.0) | - | - | High
16 | [45.128.16.0](https://vuldb.com/?ip.45.128.16.0) | - | - | High
17 | [45.136.136.0](https://vuldb.com/?ip.45.136.136.0) | - | - | High
18 | [45.150.100.0](https://vuldb.com/?ip.45.150.100.0) | - | - | High
19 | [46.36.202.23](https://vuldb.com/?ip.46.36.202.23) | - | - | High
20 | ... | ... | ... | ...

There are 78 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Liechtenstein_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Liechtenstein. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.github/workflows/combine-prs.yml` | High
2 | File | `.htaccess` | Medium
3 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
4 | File | `/Admin/add-student.php` | High
5 | File | `/admin/ajax/avatar.php` | High
6 | File | `/admin/api/admin/articles/` | High
7 | File | `/admin/conferences/list/` | High
8 | File | `/admin/edit_admin_details.php?id=admin` | High
9 | File | `/admin/generalsettings.php` | High
10 | File | `/Admin/login.php` | High
11 | File | `/admin/payment.php` | High
12 | File | `/admin/reports.php` | High
13 | File | `/admin/show.php` | High
14 | File | `/admin/showbad.php` | High
15 | File | `/admin_page/all-files-update-ajax.php` | High
16 | File | `/apilog.php` | Medium
17 | File | `/cgi-bin/kerbynet` | High
18 | File | `/cgi-bin/wlogin.cgi` | High
19 | File | `/connectors/index.php` | High
20 | File | `/dms/admin/reports/daily_collection_report.php` | High
21 | File | `/DocSystem/Repos/getReposAllUsers.do` | High
22 | File | `/face-recognition-php/facepay-master/camera.php` | High
23 | File | `/forum/away.php` | High
24 | File | `/hrm/employeeadd.php` | High
25 | File | `/hrm/employeeview.php` | High
26 | File | `/index.php` | Medium
27 | File | `/info.cgi` | Medium
28 | File | `/Items/*/RemoteImages/Download` | High
29 | File | `/items/view_item.php` | High
30 | File | `/jsoa/hntdCustomDesktopActionContent` | High
31 | File | `/lists/admin/` | High
32 | File | `/lookin/info` | Medium
33 | File | `/MagickCore/image.c` | High
34 | File | `/manager/index.php` | High
35 | File | `/medical/inventories.php` | High
36 | File | `/mgmt/tm/util/bash` | High
37 | File | `/modules/profile/index.php` | High
38 | File | `/modules/projects/vw_files.php` | High
39 | File | `/modules/public/calendar.php` | High
40 | File | `/newsDia.php` | Medium
41 | File | `/out.php` | Medium
42 | File | `/patient/doctors.php` | High
43 | File | `/phpinventory/editcategory.php` | High
44 | File | `/proxy` | Low
45 | File | `/public/launchNewWindow.jsp` | High
46 | File | `/Redcock-Farm/farm/category.php` | High
47 | File | `/sacco_shield/manage_user.php` | High
48 | File | `/spip.php` | Medium
49 | File | `/sqlitemanager/main.php?dbsel=-1%20or%2072%20=%2072` | High
50 | File | `/staff/bookdetails.php` | High
51 | File | `/TeleoptiWFM/Administration/GetOneTenant` | High
52 | File | `/updown/upload.cgi` | High
53 | File | `/user/update_booking.php` | High
54 | File | `/WEB-INF/web.xml` | High
55 | File | `/Wedding-Management-PHP/admin/photos_add.php` | High
56 | File | `/Wedding-Management/package_detail.php` | High
57 | File | `/wordpress/wp-admin/options-general.php` | High
58 | File | `/wp-content/plugins/woocommerce/templates/emails/plain/` | High
59 | File | `a2billing/customer/iridium_threed.php` | High
60 | File | `AbstractScheduleJob.java` | High
61 | File | `actionphp/download.File.php` | High
62 | File | `AdClass.php` | Medium
63 | File | `adclick.php` | Medium
64 | ... | ... | ...

There are 560 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_li.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2023](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
