# Lucky Elephant - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Lucky Elephant](https://vuldb.com/?actor.lucky_elephant). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.lucky_elephant](https://vuldb.com/?actor.lucky_elephant)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Lucky Elephant:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 18 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Lucky Elephant.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [77.244.211.55](https://vuldb.com/?ip.77.244.211.55) | - | - | High
2 | [103.243.173.253](https://vuldb.com/?ip.103.243.173.253) | - | - | High
3 | [128.127.105.13](https://vuldb.com/?ip.128.127.105.13) | swe-net-ip.as51430.net | - | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Lucky Elephant_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | T1068 | CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
7 | ... | ... | ... | ...

There are 23 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Lucky Elephant. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//proc/kcore` | Medium
2 | File | `/admin.php/Admin/adminadd.html` | High
3 | File | `/admin/about-us.php` | High
4 | File | `/admin/action/delete-vaccine.php` | High
5 | File | `/Admin/add-student.php` | High
6 | File | `/admin/index.php` | High
7 | File | `/admin/index2.html` | High
8 | File | `/Admin/News.php` | High
9 | File | `/admin/settings/save.php` | High
10 | File | `/admin/userprofile.php` | High
11 | File | `/admin_route/inc_service_credits.php` | High
12 | File | `/api/baskets/{name}` | High
13 | File | `/app/index/controller/Common.php` | High
14 | File | `/apply.cgi` | Medium
15 | File | `/bitrix/admin/ldap_server_edit.php` | High
16 | File | `/cgi-bin/wlogin.cgi` | High
17 | File | `/College/admin/teacher.php` | High
18 | File | `/Controls/Generic/EBMK/Handlers/EStatements/DownloadEStatement.ashx` | High
19 | File | `/dcim/rack-roles/` | High
20 | File | `/forms/doLogin` | High
21 | File | `/forum/away.php` | High
22 | File | `/goform/addUserName` | High
23 | File | `/goform/aspForm` | High
24 | File | `/goform/delAd` | High
25 | File | `/goform/wifiSSIDset` | High
26 | File | `/gpac/src/bifs/unquantize.c` | High
27 | File | `/inc/topBarNav.php` | High
28 | File | `/index.asp` | Medium
29 | File | `/index.php` | Medium
30 | File | `/index.php?app=main&func=passport&action=login` | High
31 | File | `/jfinal_cms/system/role/list` | High
32 | File | `/kelas/data` | Medium
33 | File | `/listplace/user/ticket/create` | High
34 | File | `/log/download.php` | High
35 | File | `/Moosikay/order.php` | High
36 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
37 | File | `/php-sms/admin/quotes/manage_remark.php` | High
38 | File | `/php/ping.php` | High
39 | File | `/products/details.asp` | High
40 | File | `/secure/QueryComponent!Default.jspa` | High
41 | File | `/shell` | Low
42 | File | `/spcgi.cgi` | Medium
43 | File | `/squashfs-root/etc_ro/custom.conf` | High
44 | File | `/staff/edit_book_details.php` | High
45 | ... | ... | ...

There are 387 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.netscout.com/blog/asert/lucky-elephant-campaign-masquerading

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
