# Matryosh - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Matryosh](https://vuldb.com/?actor.matryosh). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.matryosh](https://vuldb.com/?actor.matryosh)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Matryosh:

* [US](https://vuldb.com/?country.us)
* [CA](https://vuldb.com/?country.ca)
* [ES](https://vuldb.com/?country.es)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Matryosh.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.105.34.51](https://vuldb.com/?ip.46.105.34.51) | network.g33k.host | - | High
2 | [51.83.186.134](https://vuldb.com/?ip.51.83.186.134) | vps-c9f4e53f.vps.ovh.net | - | High
3 | [51.195.91.193](https://vuldb.com/?ip.51.195.91.193) | vps-bda5972a.vps.ovh.net | - | High
4 | ... | ... | ... | ...

There are 8 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Matryosh_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Matryosh. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.kedpm/history` | High
2 | File | `/auth/user/all.api` | High
3 | File | `/cgi-bin/` | Medium
4 | File | `/cgi-bin/ExportAllSettings.sh` | High
5 | File | `/cgi-bin/touchlist_sync.cgi` | High
6 | File | `/collection/all` | High
7 | File | `/domain/add` | Medium
8 | File | `/download` | Medium
9 | File | `/etc/ajenti/config.yml` | High
10 | File | `/exponent_constants.php` | High
11 | File | `/goform/` | Medium
12 | File | `/goform/SetNetControlList` | High
13 | File | `/lists/admin/` | High
14 | File | `/status.js` | Medium
15 | File | `/sysmanage/edit_manageadmin.php` | High
16 | File | `/usr/bin/lua` | Medium
17 | File | `/var/lib/dpkg/info/` | High
18 | File | `/vloggers_merch/classes/Master.php?f=delete_category` | High
19 | File | `/websitebaker/admin/preferences/save.php` | High
20 | File | `aai.c` | Low
21 | File | `account/login.php` | High
22 | File | `adclick.php` | Medium
23 | File | `admin-ajax.php` | High
24 | File | `admin.comms.php` | High
25 | File | `admin.php` | Medium
26 | File | `admin/auto.def` | High
27 | File | `admin/blog/add/` | High
28 | File | `admin/home#/person/` | High
29 | File | `admin/mcart_xls_import.php` | High
30 | File | `admin/plugin/file_manager/browse/` | High
31 | File | `admin/services/packages/remove` | High
32 | File | `administrator/components/com_media/helpers/media.php` | High
33 | File | `adm_config_report.php` | High
34 | File | `adm_program/modules/members/members_function.php` | High
35 | File | `album_portal.php` | High
36 | File | `amf.c` | Low
37 | File | `api.c` | Low
38 | File | `api/includes/systems.php` | High
39 | File | `archive_read_support_format_cab.c` | High
40 | File | `assembler/MacroAssemblerARM64.h` | High
41 | ... | ... | ...

There are 352 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/matryosh-botnet-is-spreading-en/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
