# Mauritania Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Mauritania Unknown](https://vuldb.com/?actor.mauritania_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.mauritania_unknown](https://vuldb.com/?actor.mauritania_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Mauritania Unknown:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 21 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Mauritania Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.61.12](https://vuldb.com/?ip.5.62.61.12) | r-12-61-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.4](https://vuldb.com/?ip.5.62.63.4) | r-4-63-62-5.consumer-pool.prcdn.net | - | High
3 | [41.138.128.0](https://vuldb.com/?ip.41.138.128.0) | - | - | High
4 | [41.188.64.0](https://vuldb.com/?ip.41.188.64.0) | - | - | High
5 | [41.221.221.0](https://vuldb.com/?ip.41.221.221.0) | 41-221-221-0.static.pccwglobal.net | - | High
6 | [41.223.96.0](https://vuldb.com/?ip.41.223.96.0) | - | - | High
7 | [45.12.70.152](https://vuldb.com/?ip.45.12.70.152) | system-pudding.alltieinc.com | - | High
8 | [45.12.71.152](https://vuldb.com/?ip.45.12.71.152) | - | - | High
9 | ... | ... | ... | ...

There are 33 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Mauritania Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-425 | Path Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Mauritania Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/acms/admin/cargo_types/view_cargo_type.php` | High
3 | File | `/admin/addemployee.php` | High
4 | File | `/admin/index.php` | High
5 | File | `/apilog.php` | Medium
6 | File | `/appliance/users?action=edit` | High
7 | File | `/downloadmaster/dm_apply.cgi?action_mode=initial&download_type=General&special_cgi=get_language` | High
8 | File | `/filemanager/upload.php` | High
9 | File | `/forum/away.php` | High
10 | File | `/healthcare/Admin/consulting_detail.php` | High
11 | File | `/if.cgi` | Low
12 | File | `/Main_Login.asp?flag=1&productname=RT-AC88U&url=/downloadmaster/task.asp` | High
13 | File | `/mifs/c/i/reg/reg.html` | High
14 | File | `/modules/profile/index.php` | High
15 | File | `/news.dtl.php` | High
16 | File | `/secure/QueryComponent!Default.jspa` | High
17 | File | `/see_more_details.php` | High
18 | File | `/services/details.asp` | High
19 | File | `/setup` | Low
20 | File | `/spip.php` | Medium
21 | File | `/uapi/doc` | Medium
22 | File | `/uncpath/` | Medium
23 | File | `/var/log/nginx` | High
24 | File | `/VPortal/mgtconsole/Subscriptions.jsp` | High
25 | File | `/wp-content/plugins/updraftplus/admin.php` | High
26 | File | `/zm/index.php` | High
27 | File | `act.php` | Low
28 | File | `adclick.php` | Medium
29 | File | `admin` | Low
30 | File | `admin.php` | Medium
31 | File | `admin/adminsignin.html` | High
32 | File | `admin/movieview.php` | High
33 | File | `admin/versions.html` | High
34 | File | `agenda.php` | Medium
35 | File | `ajax_calls.php` | High
36 | File | `api.php` | Low
37 | ... | ... | ...

There are 315 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_mr.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_mr.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_mr.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
