# Middle East Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Middle East Unknown](https://vuldb.com/?actor.middle_east_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.middle_east_unknown](https://vuldb.com/?actor.middle_east_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Middle East Unknown:

* [US](https://vuldb.com/?country.us)
* [VN](https://vuldb.com/?country.vn)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 15 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Middle East Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.34.180.252](https://vuldb.com/?ip.5.34.180.252) | storage-948074.hosted-by.itldc.com | - | High
2 | [5.34.181.13](https://vuldb.com/?ip.5.34.181.13) | backups231.com | - | High
3 | [23.94.50.197](https://vuldb.com/?ip.23.94.50.197) | 23-94-50-197-host.colocrossing.com | - | High
4 | [23.95.215.100](https://vuldb.com/?ip.23.95.215.100) | 23-95-215-100-host.colocrossing.com | - | High
5 | [31.192.105.16](https://vuldb.com/?ip.31.192.105.16) | down-it-niscat.donotbargain.com | - | High
6 | [31.192.105.17](https://vuldb.com/?ip.31.192.105.17) | - | - | High
7 | [31.192.105.28](https://vuldb.com/?ip.31.192.105.28) | - | - | High
8 | [38.130.75.20](https://vuldb.com/?ip.38.130.75.20) | h20-us75.fcsrv.net | - | High
9 | [51.68.244.39](https://vuldb.com/?ip.51.68.244.39) | ip39.ip-51-68-244.eu | - | High
10 | [51.254.76.54](https://vuldb.com/?ip.51.254.76.54) | - | - | High
11 | [62.109.2.52](https://vuldb.com/?ip.62.109.2.52) | ns.leangroup.ru | - | High
12 | [66.55.152.164](https://vuldb.com/?ip.66.55.152.164) | 66-55-152-164.choopa.net | - | High
13 | [68.232.180.122](https://vuldb.com/?ip.68.232.180.122) | 68-232-180-122.choopa.net | - | High
14 | [80.179.42.37](https://vuldb.com/?ip.80.179.42.37) | 80.179.42.37.forward.012.net.il | - | High
15 | [80.179.42.44](https://vuldb.com/?ip.80.179.42.44) | lnkrten-dazling.linegrace.com | - | High
16 | [86.105.18.5](https://vuldb.com/?ip.86.105.18.5) | - | - | High
17 | ... | ... | ... | ...

There are 64 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Middle East Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23, CWE-24, CWE-36 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Middle East Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `$HOME/.terminfo` | High
2 | File | `/academy/tutor/filter` | High
3 | File | `/admin/` | Low
4 | File | `/admin/admin_content_tag.php?action=save_content` | High
5 | File | `/admin/admin_user.php` | High
6 | File | `/admin/article/article-edit-run.php` | High
7 | File | `/admin/category/save` | High
8 | File | `/admin/category_row.php` | High
9 | File | `/admin/ind_backstage.php` | High
10 | File | `/admin/return_add.php` | High
11 | File | `/admin/subject.php` | High
12 | File | `/admin/upload/img` | High
13 | File | `/admin_route/dec_service_credits.php` | High
14 | File | `/app/ajax/sell_return_data.php` | High
15 | File | `/app/api/controller/default/File.php` | High
16 | File | `/auth/auth.php?user=1` | High
17 | File | `/b2b-supermarket/catalog/all-products` | High
18 | File | `/bin/boa` | Medium
19 | File | `/bin/login` | Medium
20 | File | `/bin/mini_upnpd` | High
21 | File | `/boaform/device_reset.cgi` | High
22 | File | `/boaform/wlan_basic_set.cgi` | High
23 | File | `/cgi-bin/cstecgi.cgi` | High
24 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
25 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
26 | File | `/cgi-bin/wlogin.cgi` | High
27 | File | `/cgi/cpaddons_report.pl` | High
28 | File | `/classes/Master.php?f=delete_reminder` | High
29 | File | `/debug/pprof` | Medium
30 | File | `/DXR.axd` | Medium
31 | File | `/forum/away.php` | High
32 | File | `/goform/goform_get_cmd_process` | High
33 | File | `/h/autoSaveDraft` | High
34 | File | `/h/search?action` | High
35 | File | `/HNAP1/` | Low
36 | File | `/im/user/` | Medium
37 | File | `/importexport.php` | High
38 | File | `/index.php?app=main&func=passport&action=login` | High
39 | File | `/index.php?page=member` | High
40 | File | `/libsystem/login.php` | High
41 | File | `/main/checkout.php` | High
42 | File | `/main/doctype.php` | High
43 | File | `/main/webservices/additional_webservices.php` | High
44 | File | `/mc` | Low
45 | File | `/mgmt/` | Low
46 | File | `/novel/bookSetting/list` | High
47 | File | `/oa/notify/edit` | High
48 | File | `/oauth/idp/.well-known/openid-configuration` | High
49 | ... | ... | ...

There are 424 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2020/01/mideast-tensions-preparations.html
* https://community.blueliv.com/#!/s/5fd096f382df413eaf344efc
* https://community.blueliv.com/#!/s/6053819b82df413eaf346332

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
