# Minodo - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Minodo](https://vuldb.com/?actor.minodo). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.minodo](https://vuldb.com/?actor.minodo)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Minodo:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 15 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Minodo.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.182.37.118](https://vuldb.com/?ip.5.182.37.118) | vps.hostry.com | - | High
2 | [5.252.177.8](https://vuldb.com/?ip.5.252.177.8) | no-rdns.mivocloud.com | - | High
3 | [5.252.177.15](https://vuldb.com/?ip.5.252.177.15) | no-rdns.mivocloud.com | - | High
4 | [23.227.193.141](https://vuldb.com/?ip.23.227.193.141) | arthritisdocs.net | - | High
5 | ... | ... | ... | ...

There are 17 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Minodo_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Minodo. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%APPDATA%\Securepoint SSL VPN` | High
2 | File | `/admin/read.php?mudi=announContent` | High
3 | File | `/api/RecordingList/DownloadRecord?file=` | High
4 | File | `/app/options.py` | High
5 | File | `/application/common.php#action_log` | High
6 | File | `/apply.cgi` | Medium
7 | File | `/card_scan.php` | High
8 | File | `/cgi-bin/wlogin.cgi` | High
9 | File | `/changeimage.php` | High
10 | File | `/cwc/login` | Medium
11 | File | `/download` | Medium
12 | File | `/etc/quagga` | Medium
13 | File | `/etc/shadow` | Medium
14 | File | `/forms/doLogin` | High
15 | File | `/goform/L7Im` | Medium
16 | File | `/h/calendar` | Medium
17 | File | `/icingaweb2/navigation/add` | High
18 | File | `/inc/extensions.php` | High
19 | File | `/mhds/clinic/view_details.php` | High
20 | File | `/netflow/jspui/editProfile.jsp` | High
21 | File | `/nova/bin/console` | High
22 | File | `/nova/bin/detnet` | High
23 | File | `/out.php` | Medium
24 | File | `/php-sms/classes/Master.php?f=save_quote` | High
25 | File | `/rapi/read_url` | High
26 | File | `/req_password_user.php` | High
27 | File | `/rom-0` | Low
28 | File | `/scripts/unlock_tasks.php` | High
29 | File | `/secure/QueryComponent!Default.jspa` | High
30 | File | `/ServletAPI/accounts/login` | High
31 | File | `/setNTP.cgi` | Medium
32 | File | `/student/bookdetails.php` | High
33 | File | `/system/user/modules/mod_users/controller.php` | High
34 | ... | ... | ...

There are 286 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://securityintelligence.com/posts/ex-conti-fin7-actors-collaborate-new-backdoor/
* https://twitter.com/TLP_R3D/status/1647632354926534657

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
