# MsraMiner - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [MsraMiner](https://vuldb.com/?actor.msraminer). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.msraminer](https://vuldb.com/?actor.msraminer)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with MsraMiner:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [VN](https://vuldb.com/?country.vn)
* ...

There are 9 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of MsraMiner.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.32.48.160](https://vuldb.com/?ip.45.32.48.160) | 45.32.48.160.vultrusercontent.com | - | High
2 | [45.32.51.130](https://vuldb.com/?ip.45.32.51.130) | 45.32.51.130.vultrusercontent.com | - | High
3 | [45.32.110.163](https://vuldb.com/?ip.45.32.110.163) | 45.32.110.163.vultrusercontent.com | - | High
4 | [45.32.121.95](https://vuldb.com/?ip.45.32.121.95) | 45.32.121.95.vultrusercontent.com | - | High
5 | [45.32.127.108](https://vuldb.com/?ip.45.32.127.108) | 45.32.127.108.vultrusercontent.com | - | High
6 | ... | ... | ... | ...

There are 22 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _MsraMiner_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-24 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by MsraMiner. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/admin` | Low
3 | File | `/admin/update_s6.php` | High
4 | File | `/baseOpLog.do` | High
5 | File | `/category_view.php` | High
6 | File | `/cgi-bin/luci;stok=/locale` | High
7 | File | `/cgi-mod/lookup.cgi` | High
8 | File | `/ClientLog/Document` | High
9 | File | `/domains/list` | High
10 | File | `/forum/away.php` | High
11 | File | `/getcfg.php` | Medium
12 | File | `/goform/SystemCommand` | High
13 | File | `/group1/uploa` | High
14 | File | `/index.php` | Medium
15 | File | `/jeecg-boot/sys/common/upload` | High
16 | File | `/out.php` | Medium
17 | File | `/owa/auth/logon.aspx` | High
18 | File | `/proc/ioports` | High
19 | File | `/rest/api/1.0/render` | High
20 | File | `/rest/collectors/1.0/template/custom` | High
21 | File | `/rom-0` | Low
22 | File | `/scdmz.cmd` | Medium
23 | File | `/ui/artifactimport/upload` | High
24 | File | `/updown/upload.cgi` | High
25 | File | `4.2.0.CP03` | Medium
26 | ... | ... | ...

There are 222 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.cyber45.com

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
