# Mylobot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Mylobot](https://vuldb.com/?actor.mylobot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.mylobot](https://vuldb.com/?actor.mylobot)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Mylobot:

* [US](https://vuldb.com/?country.us)
* [NL](https://vuldb.com/?country.nl)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 29 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Mylobot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [46.166.173.180](https://vuldb.com/?ip.46.166.173.180) | - | - | High
2 | [70.36.107.38](https://vuldb.com/?ip.70.36.107.38) | - | - | High
3 | [70.36.107.39](https://vuldb.com/?ip.70.36.107.39) | - | - | High
4 | [74.222.19.63](https://vuldb.com/?ip.74.222.19.63) | - | - | High
5 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Mylobot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Mylobot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/../conf/config.properties` | High
3 | File | `//proc/kcore` | Medium
4 | File | `/addnews.html` | High
5 | File | `/admin/inquiries/view_details.php` | High
6 | File | `/admin/list_addr_fwresource_ip.php` | High
7 | File | `/admin/login.php` | High
8 | File | `/admin/vca/bia/addacph.cgi` | High
9 | File | `/anony/mjpg.cgi` | High
10 | File | `/api/blade-log/api/list` | High
11 | File | `/cgi-bin/wlogin.cgi` | High
12 | File | `/checkLogin.cgi` | High
13 | File | `/common/logViewer/logViewer.jsf` | High
14 | File | `/Config/SaveUploadedHotspotLogoFile` | High
15 | File | `/core/vb/vurl.php` | High
16 | File | `/CPE` | Low
17 | File | `/dashboard/snapshot/*?orgId=0` | High
18 | File | `/ecrire` | Low
19 | File | `/exponent_constants.php` | High
20 | File | `/forum/away.php` | High
21 | File | `/HNAP1/SetAccessPointMode` | High
22 | File | `/hub/api/user` | High
23 | File | `/include/commrecc.inc.php` | High
24 | File | `/include/comm_post.inc.php` | High
25 | File | `/include/friends.inc.php` | High
26 | File | `/include/menu_v.inc.php` | High
27 | File | `/include/notify.inc.php` | High
28 | File | `/magnoliaPublic/travel/members/login.html` | High
29 | File | `/mhds/clinic/view_details.php` | High
30 | File | `/MicroStrategyWS/happyaxis.jsp` | High
31 | File | `/owa/auth/logon.aspx` | High
32 | File | `/proc` | Low
33 | File | `/products/details.asp` | High
34 | File | `/public/plugins/` | High
35 | File | `/RestAPI` | Medium
36 | File | `/school/model/get_teacher.php` | High
37 | File | `/search.php` | Medium
38 | File | `/spip.php` | Medium
39 | File | `/uncpath/` | Medium
40 | File | `/user/loader.php?api=1` | High
41 | File | `/User/saveUser` | High
42 | File | `/usr/sbin/suexec` | High
43 | File | `/viewer/krpano.html` | High
44 | File | `/ViewUserHover.jspa` | High
45 | File | `/WEB-INF/web.xml` | High
46 | File | `/wp-admin/admin-ajax.php` | High
47 | File | `/wp-content/plugins/woocommerce/templates/emails/plain/` | High
48 | File | `/wp-json/oembed/1.0/embed?url` | High
49 | File | `/wp-json/wc/v3/webhooks` | High
50 | File | `account.asp` | Medium
51 | File | `activateuser.aspx` | High
52 | File | `adclick.php` | Medium
53 | ... | ... | ...

There are 464 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://ioc.hatenablog.com/entry/2018/11/14/000000

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
