# NSA - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [NSA](https://vuldb.com/?actor.nsa). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.nsa](https://vuldb.com/?actor.nsa)

## Campaigns

The following _campaigns_ are known and can be associated with NSA:

* BOUNDLESS INFORMANT

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with NSA:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 29 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of NSA.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [31.6.17.94](https://vuldb.com/?ip.31.6.17.94) | - | BOUNDLESS INFORMANT | High
2 | [37.72.168.84](https://vuldb.com/?ip.37.72.168.84) | 84.168.72.37.static.swiftway.net | BOUNDLESS INFORMANT | High
3 | [37.130.229.100](https://vuldb.com/?ip.37.130.229.100) | uk.server | BOUNDLESS INFORMANT | High
4 | [37.130.229.101](https://vuldb.com/?ip.37.130.229.101) | uk.server | BOUNDLESS INFORMANT | High
5 | [37.220.10.28](https://vuldb.com/?ip.37.220.10.28) | h37-220-10-28.host.redstation.co.uk | BOUNDLESS INFORMANT | High
6 | [50.115.118.140](https://vuldb.com/?ip.50.115.118.140) | sfaaa.net | BOUNDLESS INFORMANT | High
7 | ... | ... | ... | ...

There are 25 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _NSA_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-269, CWE-274, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by NSA. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/.ssh/authorized_keys2` | High
3 | File | `/about.php` | Medium
4 | File | `/admin-ajax.php?action=eps_redirect_save` | High
5 | File | `/admin.php` | Medium
6 | File | `/admin.php/accessory/filesdel.html` | High
7 | File | `/admin/` | Low
8 | File | `/Admin/add-student.php` | High
9 | File | `/admin/api/theme-edit/` | High
10 | File | `/admin/index3.php` | High
11 | File | `/admin/manage-users.php` | High
12 | File | `/admin/photo.php` | High
13 | File | `/adms/admin/?page=vehicles/view_transaction` | High
14 | File | `/anony/mjpg.cgi` | High
15 | File | `/apply.cgi` | Medium
16 | File | `/auth` | Low
17 | File | `/catcompany.php` | High
18 | File | `/cms/category/list` | High
19 | File | `/dashboard/view-chair-list.php` | High
20 | File | `/Default/Bd` | Medium
21 | File | `/ebics-server/ebics.aspx` | High
22 | File | `/egroupware/index.php` | High
23 | File | `/etc/hosts` | Medium
24 | File | `/filemanager/upload.php` | High
25 | File | `/forms/doLogin` | High
26 | File | `/forum/away.php` | High
27 | File | `/GponForm/device_Form?script/` | High
28 | File | `/GponForm/fsetup_Form` | High
29 | File | `/GponForm/usb_restore_Form?script/` | High
30 | File | `/hrm/employeeview.php` | High
31 | File | `/html/device-id` | High
32 | File | `/importexport.php` | High
33 | File | `/includes/decorators/global-translations.jsp` | High
34 | File | `/index.php` | Medium
35 | File | `/loginsave.php` | High
36 | File | `/param.file.tgz` | High
37 | File | `/product_list.php` | High
38 | File | `/public_html/users.php` | High
39 | File | `/secure/QueryComponent!Default.jspa` | High
40 | File | `/see_more_details.php` | High
41 | File | `/server-status` | High
42 | File | `/setSystemAdmin` | High
43 | File | `/uncpath/` | Medium
44 | File | `/user/s.php` | Medium
45 | File | `/usr/local/WowzaStreamingEngine/bin/` | High
46 | File | `/WEB-INF/web.xml` | High
47 | File | `/wireless/guestnetwork.asp` | High
48 | File | `?r=recruit/interview/export&interviews=x` | High
49 | File | `a2dp_aac_decoder.cc` | High
50 | File | `actbar3.ocx` | Medium
51 | File | `adclick.php` | Medium
52 | File | `add-locker-form.php` | High
53 | File | `addentry.php` | Medium
54 | File | `admin.php` | Medium
55 | File | `admin/booking_report.php` | High
56 | File | `admin/executar_login.php` | High
57 | ... | ... | ...

There are 495 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://medium.com/@danchodanchev/how-the-nsa-utilized-iranian-cyber-proxies-to-participate-in-the-boundless-informant-program-e82045d44848

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
