# North Korea Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [North Korea Unknown](https://vuldb.com/?actor.north_korea_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.north_korea_unknown](https://vuldb.com/?actor.north_korea_unknown)

## Campaigns

The following _campaigns_ are known and can be associated with North Korea Unknown:

* H0lyGh0st

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with North Korea Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [VN](https://vuldb.com/?country.vn)
* ...

There are 22 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of North Korea Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.56.160](https://vuldb.com/?ip.5.62.56.160) | r-160-56-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.61.64](https://vuldb.com/?ip.5.62.61.64) | r-64-61-62-5.consumer-pool.prcdn.net | - | High
3 | [45.12.70.122](https://vuldb.com/?ip.45.12.70.122) | engineers.yourbandinc.com | - | High
4 | [45.12.71.122](https://vuldb.com/?ip.45.12.71.122) | - | - | High
5 | [46.36.203.81](https://vuldb.com/?ip.46.36.203.81) | - | - | High
6 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _North Korea Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by North Korea Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin.php?page=batch_manager&mode=unit` | High
2 | File | `/admin/addemployee.php` | High
3 | File | `/admin/upload.php` | High
4 | File | `/apilog.php` | Medium
5 | File | `/APP_Installation.asp` | High
6 | File | `/blog` | Low
7 | File | `/categorypage.php` | High
8 | File | `/drivers/media/media-device.c` | High
9 | File | `/filemanager/upload.php` | High
10 | File | `/forum/away.php` | High
11 | File | `/getcfg.php` | Medium
12 | File | `/goform/aspForm` | High
13 | File | `/healthcare/Admin/consulting_detail.php` | High
14 | File | `/home.php` | Medium
15 | File | `/mifs/c/i/reg/reg.html` | High
16 | File | `/omps/seller` | Medium
17 | File | `/p` | Low
18 | File | `/php/passport/index.php` | High
19 | File | `/preauth` | Medium
20 | File | `/products/details.asp` | High
21 | File | `/replication` | Medium
22 | File | `/see_more_details.php` | High
23 | File | `/settings` | Medium
24 | File | `/show_news.php` | High
25 | File | `/spip.php` | Medium
26 | File | `/staff/tools/custom-fields` | High
27 | File | `/strings/ctype-latin1.c` | High
28 | File | `/uncpath/` | Medium
29 | File | `/updownload/t.report` | High
30 | File | `/user.profile.php` | High
31 | File | `/var/log/nginx` | High
32 | File | `/var/WEB-GUI/cgi-bin/telnet.cgi` | High
33 | File | `/VPortal/mgtconsole/Subscriptions.jsp` | High
34 | File | `/Wedding-Management/admin/client_manage_account_details.php?booking_id=31` | High
35 | File | `/wp-admin` | Medium
36 | File | `/wp-admin/admin-ajax.php` | High
37 | File | `/zm/index.php` | High
38 | File | `adclick.php` | Medium
39 | File | `adm/systools.asp` | High
40 | File | `admin` | Low
41 | File | `admin.php` | Medium
42 | File | `admin/adminsignin.html` | High
43 | File | `admin/category.inc.php` | High
44 | File | `admin/editproductetails.php` | High
45 | File | `admin/main.asp` | High
46 | File | `admin/movieview.php` | High
47 | File | `admin/versions.html` | High
48 | File | `admin/y_admin.asp` | High
49 | File | `adminer.php` | Medium
50 | File | `administrator/components/com_media/helpers/media.php` | High
51 | File | `admin_ok.asp` | Medium
52 | File | `agenda.php` | Medium
53 | File | `album_portal.php` | High
54 | File | `app/Core/Paginator.php` | High
55 | File | `app/index.php/accounts/default/details?id=2&kanbanBoard=1&openToTaskId=1` | High
56 | File | `army.php` | Medium
57 | File | `attendancy.php` | High
58 | File | `AttributionSource.java` | High
59 | File | `auth-gss2.c` | Medium
60 | File | `auth.php` | Medium
61 | File | `awstats.pl` | Medium
62 | File | `bb-login.php` | Medium
63 | File | `bb_admin.php` | Medium
64 | ... | ... | ...

There are 564 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_kp.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_kp.netset
* https://www.microsoft.com/en-us/security/blog/2022/07/14/north-korean-threat-actor-targets-small-and-midsize-businesses-with-h0lygh0st-ransomware/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
