# Palau Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Palau Unknown](https://vuldb.com/?actor.palau_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.palau_unknown](https://vuldb.com/?actor.palau_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Palau Unknown:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [ES](https://vuldb.com/?country.es)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Palau Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.56.164](https://vuldb.com/?ip.5.62.56.164) | r-164-56-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.61.76](https://vuldb.com/?ip.5.62.61.76) | r-76-61-62-5.consumer-pool.prcdn.net | - | High
3 | [45.12.70.186](https://vuldb.com/?ip.45.12.70.186) | rounded-tray.alltieinc.com | - | High
4 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Palau Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-35, CWE-36 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 13 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Palau Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/` | Low
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/admin/upload.php` | High
4 | File | `/APR/signup.php` | High
5 | File | `/blog` | Low
6 | File | `/cgi-bin/wlogin.cgi` | High
7 | File | `/E-mobile/App/System/File/downfile.php` | High
8 | File | `/Electron/download` | High
9 | File | `/healthcare/Admin/consulting_detail.php` | High
10 | File | `/mims/login.php` | High
11 | File | `/php-scrm/login.php` | High
12 | File | `/proxy` | Low
13 | File | `/reviewer/system/system/admins/manage/users/user-update.php` | High
14 | File | `/scripts/unlock_tasks.php` | High
15 | File | `/send_order.cgi?parameter=access_detect` | High
16 | File | `/text/pdf/PdfReader.java` | High
17 | File | `/textpattern/index.php` | High
18 | File | `/tmp` | Low
19 | File | `/wp-admin/admin-ajax.php` | High
20 | File | `/zm/index.php` | High
21 | File | `account-signup.php` | High
22 | File | `account/signup.php` | High
23 | File | `addentry.php` | Medium
24 | File | `addressbook/backends/ldap/e-book-backend-ldap.c` | High
25 | File | `admin.jcomments.php` | High
26 | File | `admin.php` | Medium
27 | File | `admin/admin_editor.php` | High
28 | File | `admin/conf_users_edit.php` | High
29 | File | `admin/data.php` | High
30 | File | `admin/edit_category.php` | High
31 | File | `admin/operations/currency.php` | High
32 | File | `agenda.php` | Medium
33 | File | `album_portal.php` | High
34 | File | `army.php` | Medium
35 | File | `awstats.pl` | Medium
36 | File | `bb-login.php` | Medium
37 | File | `bb_admin.php` | Medium
38 | File | `bb_functions.php` | High
39 | File | `bb_func_search.php` | High
40 | File | `bb_func_unsub.php` | High
41 | File | `blocks/block-Old_Articles.php` | High
42 | ... | ... | ...

There are 367 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_pw.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_pw.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_pw.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
