# Parrot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Parrot](https://vuldb.com/?actor.parrot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.parrot](https://vuldb.com/?actor.parrot)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Parrot:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Parrot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.180.136.119](https://vuldb.com/?ip.5.180.136.119) | free.ihor-hosting.ru | - | High
2 | [15.76.172.110](https://vuldb.com/?ip.15.76.172.110) | - | - | High
3 | [45.76.172.113](https://vuldb.com/?ip.45.76.172.113) | 45.76.172.113.vultrusercontent.com | - | High
4 | ... | ... | ... | ...

There are 11 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Parrot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Parrot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/addnews.html` | High
2 | File | `/addsrv` | Low
3 | File | `/Admin/Views/FileEditor/` | High
4 | File | `/api/RecordingList/DownloadRecord?file=` | High
5 | File | `/apply.cgi` | Medium
6 | File | `/article/add` | Medium
7 | File | `/controller/pay.class.php` | High
8 | File | `/dev/kmem` | Medium
9 | File | `/dev/snd/seq` | Medium
10 | File | `/device/device=140/tab=wifi/view` | High
11 | File | `/etc/passwd` | Medium
12 | File | `/EXCU_SHELL` | Medium
13 | File | `/forum/away.php` | High
14 | File | `/gena.cgi` | Medium
15 | File | `/goform/SetClientState` | High
16 | File | `/goform/SysToolChangePwd` | High
17 | File | `/jerry-core/ecma/base/ecma-gc.c` | High
18 | File | `/jpg/image.jpg` | High
19 | File | `/out.php` | Medium
20 | File | `/product_list.php` | High
21 | File | `/rapi/read_url` | High
22 | File | `/rrps/classes/Master.php?f=delete_category` | High
23 | File | `/rukovoditel_2.4.1/index.php?module=configuration/save&redirect_to=configuration/application` | High
24 | File | `/scripts/unlock_tasks.php` | High
25 | File | `/sec/content/sec_asa_users_local_db_add.html` | High
26 | File | `/see_more_details.php` | High
27 | File | `/src/core/controllers/cm.php` | High
28 | File | `/system/user/modules/mod_users/controller.php` | High
29 | File | `/transmission/web/` | High
30 | File | `/uncpath/` | Medium
31 | File | `/usr/local` | Medium
32 | ... | ... | ...

There are 269 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://1275.ru/ioc/89/parrot-tds-ioc/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
