# Passwordstealera - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Passwordstealera](https://vuldb.com/?actor.passwordstealera). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.passwordstealera](https://vuldb.com/?actor.passwordstealera)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Passwordstealera:

* [US](https://vuldb.com/?country.us)
* [RO](https://vuldb.com/?country.ro)
* [ES](https://vuldb.com/?country.es)
* ...

There are 17 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Passwordstealera.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [3.14.212.173](https://vuldb.com/?ip.3.14.212.173) | ec2-3-14-212-173.us-east-2.compute.amazonaws.com | - | Medium
2 | [3.19.114.185](https://vuldb.com/?ip.3.19.114.185) | ec2-3-19-114-185.us-east-2.compute.amazonaws.com | - | Medium
3 | [18.188.14.65](https://vuldb.com/?ip.18.188.14.65) | ec2-18-188-14-65.us-east-2.compute.amazonaws.com | - | Medium
4 | [23.249.161.111](https://vuldb.com/?ip.23.249.161.111) | - | - | High
5 | [36.84.56.39](https://vuldb.com/?ip.36.84.56.39) | - | - | High
6 | [36.84.57.230](https://vuldb.com/?ip.36.84.57.230) | - | - | High
7 | [37.8.73.90](https://vuldb.com/?ip.37.8.73.90) | - | - | High
8 | [74.118.139.67](https://vuldb.com/?ip.74.118.139.67) | - | - | High
9 | [80.66.255.129](https://vuldb.com/?ip.80.66.255.129) | 80-66-255-129.kj.up.ee | - | High
10 | ... | ... | ... | ...

There are 34 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Passwordstealera_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Passwordstealera. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/cgi-bin/kerbynet` | High
2 | File | `/cgi-bin/supervisor/CloudSetup.cgi` | High
3 | File | `/domain/add` | Medium
4 | File | `/download` | Medium
5 | File | `/etc/sudoers` | Medium
6 | File | `/index.php` | Medium
7 | File | `/index.php/weblinks-categories` | High
8 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
9 | File | `/plain` | Low
10 | File | `/show_group_members.php` | High
11 | File | `/status` | Low
12 | File | `/uncpath/` | Medium
13 | File | `/vdesk` | Low
14 | File | `/web/google_analytics.php` | High
15 | File | `addentry.php` | Medium
16 | File | `admin/login.php` | High
17 | File | `admin_component.php` | High
18 | File | `app/views/journals/index.builder` | High
19 | File | `archive_endian.h` | High
20 | File | `auth-gss2.c` | Medium
21 | File | `bmp.c` | Low
22 | File | `boaform/admin/formPing` | High
23 | ... | ... | ...

There are 196 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2018/12/threat-roundup-1130-1207.html
* https://blog.talosintelligence.com/2020/01/threat-roundup-0117-0124.html
* https://blog.talosintelligence.com/2021/10/threat-roundup-1008-1015.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
