# Polonium - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Polonium](https://vuldb.com/?actor.polonium). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.polonium](https://vuldb.com/?actor.polonium)

## Campaigns

The following _campaigns_ are known and can be associated with Polonium:

* CreepySnail

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Polonium:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 23 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Polonium.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.120.233.89](https://vuldb.com/?ip.37.120.233.89) | no-rdns.m247.com | - | High
2 | [45.80.148.119](https://vuldb.com/?ip.45.80.148.119) | - | - | High
3 | [45.80.148.167](https://vuldb.com/?ip.45.80.148.167) | - | - | High
4 | [45.80.148.186](https://vuldb.com/?ip.45.80.148.186) | - | - | High
5 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Polonium_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Polonium. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/classes/master.php?f=delete_order` | High
3 | File | `/etc/gsissh/sshd_config` | High
4 | File | `/etc/passwd` | Medium
5 | File | `/forms/nslookupHandler` | High
6 | File | `/h/autoSaveDraft` | High
7 | File | `/index.php` | Medium
8 | File | `/librarian/bookdetails.php` | High
9 | File | `/modules/profile/index.php` | High
10 | File | `/news.dtl.php` | High
11 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
12 | File | `/out.php` | Medium
13 | File | `/patient/appointment.php` | High
14 | File | `/php-opos/index.php` | High
15 | File | `/protocol/iscgwtunnel/uploadiscgwrouteconf.php` | High
16 | File | `/ptms/?page=user` | High
17 | File | `/sqfs/bin/sccd` | High
18 | File | `/tmp` | Low
19 | File | `/uncpath/` | Medium
20 | File | `/upload/file.php` | High
21 | File | `/usr/bin/at` | Medium
22 | File | `/usr/local/www/pkg.php` | High
23 | File | `/wp-admin/admin-ajax.php` | High
24 | ... | ... | ...

There are 203 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/eset/malware-ioc/tree/master/polonium
* https://www.microsoft.com/security/blog/2022/06/02/exposing-polonium-activity-and-infrastructure-targeting-israeli-organizations/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
