# PrivateLoader - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [PrivateLoader](https://vuldb.com/?actor.privateloader). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.privateloader](https://vuldb.com/?actor.privateloader)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with PrivateLoader:

* [US](https://vuldb.com/?country.us)
* [LU](https://vuldb.com/?country.lu)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 15 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of PrivateLoader.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.181.80.133](https://vuldb.com/?ip.5.181.80.133) | navbarlatino.alarmedbook.de | - | High
2 | [5.182.36.101](https://vuldb.com/?ip.5.182.36.101) | vz.darytelecom.ru | - | High
3 | [45.15.156.229](https://vuldb.com/?ip.45.15.156.229) | - | - | High
4 | [77.105.147.130](https://vuldb.com/?ip.77.105.147.130) | aggressive-peace.aeza.network | - | High
5 | [79.174.12.174](https://vuldb.com/?ip.79.174.12.174) | king420.lazy.fvds.ru | - | High
6 | [85.208.136.10](https://vuldb.com/?ip.85.208.136.10) | - | - | High
7 | [89.38.131.151](https://vuldb.com/?ip.89.38.131.151) | no-reverse-yet.local | - | High
8 | [89.38.131.155](https://vuldb.com/?ip.89.38.131.155) | no-reverse-yet.local | - | High
9 | [89.185.85.53](https://vuldb.com/?ip.89.185.85.53) | VPS91.lethost.network | - | High
10 | ... | ... | ... | ...

There are 38 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _PrivateLoader_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by PrivateLoader. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/acms/admin/cargo_types/manage_cargo_type.php` | High
3 | File | `/admin.php/singer/admin/singer/del` | High
4 | File | `/admin/?page=product/manage_product&id=2` | High
5 | File | `/Admin/add-student.php` | High
6 | File | `/admin/ajax/avatar.php` | High
7 | File | `/admin/index.PHP` | High
8 | File | `/Admin/News.php` | High
9 | File | `/admin/options` | High
10 | File | `/admin/show.php` | High
11 | File | `/admin/transactions/update_status.php` | High
12 | File | `/admin/view_sendlist.php` | High
13 | File | `/alphaware/summary.php` | High
14 | File | `/api/index.php` | High
15 | File | `/api/sys/login` | High
16 | File | `/api/user/password/sent-reset-email` | High
17 | File | `/baseOpLog.do` | High
18 | File | `/bl-plugins/backup/plugin.php` | High
19 | File | `/catalog_add.php` | High
20 | File | `/cgi-bin/nightled.cgi` | High
21 | File | `/cgi/get_param.cgi` | High
22 | File | `/classes/Users.php` | High
23 | File | `/common/download_agent_installer.php` | High
24 | File | `/common/info.cgi` | High
25 | File | `/common/run_cross_report.php` | High
26 | File | `/confirm` | Medium
27 | File | `/controller/Index.php` | High
28 | File | `/cupseasylive/countrymodify.php` | High
29 | File | `/cwc/login` | Medium
30 | File | `/debug/pprof` | Medium
31 | File | `/dede/group_store.php` | High
32 | File | `/dialog/select_media.php` | High
33 | File | `/doorgets/app/requests/user/emailingRequest.php` | High
34 | File | `/etc/master.passwd` | High
35 | File | `/etc/passwd` | Medium
36 | File | `/EXCU_SHELL` | Medium
37 | File | `/ext/collect/filter_text.do` | High
38 | File | `/fax/fax_send.php` | High
39 | File | `/foms/all-orders.php?status=Cancelled%20by%20Customer` | High
40 | File | `/forum/away.php` | High
41 | File | `/goform/addressNat` | High
42 | File | `/goform/NatStaticSetting` | High
43 | File | `/goform/setMacFilterCfg` | High
44 | File | `/goform/SysToolChangePwd` | High
45 | File | `/goform/WifiBasicSet` | High
46 | File | `/HNAP1` | Low
47 | File | `/home/resume/index` | High
48 | File | `/includes/lib/tree.php` | High
49 | File | `/index.php` | Medium
50 | File | `/index.php?action=seomatic/file/seo-file-link` | High
51 | File | `/intern/controller.php` | High
52 | File | `/LoginRegistration.php` | High
53 | File | `/main?cmd=invalid_browser` | High
54 | File | `/manager?action=getlogcat` | High
55 | File | `/member/ad.php?action=ad` | High
56 | File | `/my_photo_gallery/image.php` | High
57 | File | `/ofrs/admin/?page=reports` | High
58 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
59 | File | `/page.php` | Medium
60 | File | `/pages/permit/permit.php` | High
61 | File | `/patient/doctors.php` | High
62 | File | `/pet_shop/classes/Master.php?f=delete_category` | High
63 | File | `/php-sms/admin/?page=services/manage_service` | High
64 | File | `/phpinventory/editcategory.php` | High
65 | File | `/phpinventory/edituser.php` | High
66 | ... | ... | ...

There are 575 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://app.any.run/tasks/1db5ea31-0daa-4a23-879d-2bd21bc818f4
* https://app.any.run/tasks/3bfdcee7-1163-4cb5-a421-c89ebe581fb3
* https://app.any.run/tasks/107bbcf1-8d11-4f08-bcc0-56e6421de94b
* https://app.any.run/tasks/994d4d9a-2b51-4b70-8146-a44c418dd9fd/
* https://app.any.run/tasks/b558623f-6336-4912-88ce-a05c0bb1cd10
* https://app.any.run/tasks/ee675dd9-ff6d-4f25-8163-193d4836bfb3
* https://community.blueliv.com/#!/s/6274c2b082df417a00331684
* https://community.blueliv.com/#!/s/63280e7d82df417ed0331974
* https://github.com/SEKOIA-IO/Community/blob/main/IOCs/20220914_privateloader_IOC.csv
* https://malpedia.caad.fkie.fraunhofer.de/details/win.privateloader
* https://threatfox.abuse.ch

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
