# PureCrypter - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [PureCrypter](https://vuldb.com/?actor.purecrypter). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.purecrypter](https://vuldb.com/?actor.purecrypter)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with PureCrypter:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [PT](https://vuldb.com/?country.pt)
* ...

There are 3 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of PureCrypter.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [37.0.11.164](https://vuldb.com/?ip.37.0.11.164) | - | - | High
2 | [45.143.201.4](https://vuldb.com/?ip.45.143.201.4) | - | - | High
3 | [62.204.41.69](https://vuldb.com/?ip.62.204.41.69) | - | - | High
4 | ... | ... | ... | ...

There are 5 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _PureCrypter_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by PureCrypter. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/about.php` | Medium
2 | File | `/admin.php` | Medium
3 | File | `/admin/api/theme-edit/` | High
4 | File | `/admin/doctors/view_doctor.php` | High
5 | File | `/admin/modules/bibliography/index.php` | High
6 | File | `/admin/students/manage.php` | High
7 | File | `/adminlogin.asp` | High
8 | File | `/app/controller/Books.php` | High
9 | File | `/aqpg/users/login.php` | High
10 | File | `/controller/Index.php` | High
11 | File | `/coreframe/app/content/admin/content.php` | High
12 | File | `/dev/audio` | Medium
13 | File | `/dl/dl_print.php` | High
14 | File | `/etc/crash` | Medium
15 | File | `/etc/master.passwd` | High
16 | File | `/etc/passwd` | Medium
17 | File | `/face-recognition-php/facepay-master/camera.php` | High
18 | File | `/forum/PostPrivateMessage` | High
19 | File | `/goform/AddSysLogRule` | High
20 | File | `/goform/WifiBasicSet` | High
21 | File | `/home/masterConsole` | High
22 | File | `/Hospital-Management-System-master/contact.php` | High
23 | File | `/hrm/employeeadd.php` | High
24 | File | `/hrm/employeeview.php` | High
25 | File | `/include/friends.inc.php` | High
26 | File | `/index.php?module=configuration/application` | High
27 | File | `/kruxton/receipt.php` | High
28 | File | `/members/view_member.php` | High
29 | File | `/services/view_service.php` | High
30 | File | `/servlet/webacc` | High
31 | File | `/sitemagic/upgrade.php` | High
32 | File | `/userui/ticket_list.php` | High
33 | File | `/usr/5bin/su` | Medium
34 | File | `/wp-admin/options-general.php` | High
35 | File | `/zm/index.php` | High
36 | File | `1.x/src/rogatkin/web/WarRoller.java` | High
37 | File | `abook_database.php` | High
38 | File | `accounts/inc/include.php` | High
39 | File | `action.php` | Medium
40 | File | `adaptive-images-script.php` | High
41 | File | `additem.asp` | Medium
42 | File | `adherents/subscription/info.php` | High
43 | File | `admin.asp` | Medium
44 | File | `admin.php` | Medium
45 | File | `admin.php&r=article/AdminContent/edit` | High
46 | File | `admin/?page=admin` | High
47 | File | `admin/admin.php` | High
48 | File | `admin/admin_users.php` | High
49 | File | `admin/article_save.php` | High
50 | File | `admin/general.php` | High
51 | File | `admin/header.php` | High
52 | File | `admin/inc/change_action.php` | High
53 | File | `admin/index.php` | High
54 | File | `admin/info.php` | High
55 | File | `admin/login.asp` | High
56 | File | `admin/manage-comments.php` | High
57 | File | `admin/manage-news.php` | High
58 | File | `admin/plugin-settings.php` | High
59 | File | `admin/specials.php` | High
60 | File | `admin:de` | Medium
61 | File | `admincp/auth/checklogin.php` | High
62 | File | `admincp/auth/secure.php` | High
63 | File | `administrator/components/com_media/helpers/media.php` | High
64 | File | `administrator/index.php` | High
65 | File | `admin_login.asp` | High
66 | File | `ajax/aj_*.php` | High
67 | File | `ajax_url.php` | Medium
68 | File | `ajx.php` | Low
69 | File | `album_portal.php` | High
70 | File | `al_initialize.php` | High
71 | File | `anjel.index.php` | High
72 | File | `annonces-p-f.php` | High
73 | File | `announce.php` | Medium
74 | File | `announcement.php` | High
75 | File | `announcements.php` | High
76 | File | `app/admin/routing/edit-bgp-mapping-search.php` | High
77 | File | `application/config/config.php` | High
78 | File | `application/controllers/basedata/inventory.php` | High
79 | File | `application/controllers/timedtext.php` | High
80 | File | `apply.cgi` | Medium
81 | File | `apps/app_article/controller/rating.php` | High
82 | File | `article.php` | Medium
83 | File | `articles.php` | Medium
84 | File | `artikel_anzeige.php` | High
85 | File | `AudioFlinger.cpp` | High
86 | File | `auktion.cgi` | Medium
87 | File | `auth.php` | Medium
88 | File | `authfiles/login.asp` | High
89 | File | `basket.php` | Medium
90 | File | `books.php` | Medium
91 | File | `browse-category.php` | High
92 | File | `browse.php` | Medium
93 | File | `browse_videos.php` | High
94 | File | `BrudaNews/BrudaGB` | High
95 | File | `bwlist_inc.html` | High
96 | File | `calendar.php` | Medium
97 | File | `callme_page.php` | High
98 | File | `cart.php` | Medium
99 | File | `cart_add.php` | Medium
100 | File | `case.filemanager.php` | High
101 | File | `catalog.php` | Medium
102 | ... | ... | ...

There are 899 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/purecrypter/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
