# PyXie - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [PyXie](https://vuldb.com/?actor.pyxie). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.pyxie](https://vuldb.com/?actor.pyxie)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with PyXie:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 23 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of PyXie.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [104.200.67.173](https://vuldb.com/?ip.104.200.67.173) | - | - | High
2 | [167.160.36.72](https://vuldb.com/?ip.167.160.36.72) | - | - | High
3 | [172.106.170.81](https://vuldb.com/?ip.172.106.170.81) | unassigned.psychz.net | - | High
4 | ... | ... | ... | ...

There are 4 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _PyXie_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-425 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by PyXie. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/act/ActDao.xml` | High
3 | File | `/addbill.php` | Medium
4 | File | `/admin/clientview.php` | High
5 | File | `/ajax.php?action=read_msg` | High
6 | File | `/ajax/networking/get_netcfg.php` | High
7 | File | `/api/gen/clients/{language}` | High
8 | File | `/app/options.py` | High
9 | File | `/bin/httpd` | Medium
10 | File | `/cgi-bin/wapopen` | High
11 | File | `/ci_spms/admin/category` | High
12 | File | `/ci_spms/admin/search/searching/` | High
13 | File | `/classes/Master.php?f=delete_appointment` | High
14 | File | `/classes/Master.php?f=delete_train` | High
15 | File | `/collection/all` | High
16 | File | `/concat?/%2557EB-INF/web.xml` | High
17 | File | `/config/php.ini` | High
18 | File | `/Content/Template/root/reverse-shell.aspx` | High
19 | File | `/ctcprotocol/Protocol` | High
20 | File | `/dashboard/menu-list.php` | High
21 | File | `/data/remove` | Medium
22 | File | `/ebics-server/ebics.aspx` | High
23 | File | `/ffos/classes/Master.php?f=save_category` | High
24 | File | `/file-manager/rename.php` | High
25 | File | `/forum/away.php` | High
26 | File | `/goform/net\_Web\_get_value` | High
27 | File | `/goforms/rlminfo` | High
28 | File | `/GponForm/usb_restore_Form?script/` | High
29 | File | `/group1/uploa` | High
30 | File | `/hedwig.cgi` | Medium
31 | File | `/HNAP1` | Low
32 | File | `/HNAP1/SetClientInfo` | High
33 | File | `/Items/*/RemoteImages/Download` | High
34 | File | `/login` | Low
35 | File | `/login/index.php` | High
36 | File | `/menu.html` | Medium
37 | File | `/modules/profile/index.php` | High
38 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
39 | File | `/navigate/navigate_download.php` | High
40 | File | `/ocwbs/admin/?page=user/manage_user` | High
41 | File | `/ofrs/admin/?page=user/manage_user` | High
42 | File | `/out.php` | Medium
43 | File | `/password.html` | High
44 | File | `/php_action/fetchSelectedUser.php` | High
45 | File | `/plugin` | Low
46 | ... | ... | ...

There are 400 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2019/12/meet-pyxie-a-nefarious-new-python-rat
* https://threatvector.cylance.com/en_us/home/meet-pyxie-a-nefarious-new-python-rat.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
