# Rancor - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Rancor](https://vuldb.com/?actor.rancor). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.rancor](https://vuldb.com/?actor.rancor)

## Campaigns

The following _campaigns_ are known and can be associated with Rancor:

* PLAINTEE/DDKONG

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Rancor:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [VN](https://vuldb.com/?country.vn)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Rancor.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.76.176.236](https://vuldb.com/?ip.45.76.176.236) | 45.76.176.236.vultr.com | PLAINTEE/DDKONG | Medium
2 | [45.121.146.26](https://vuldb.com/?ip.45.121.146.26) | businesso.top | PLAINTEE/DDKONG | High
3 | [89.46.222.97](https://vuldb.com/?ip.89.46.222.97) | 97.222.46.89.in-addr.arpa | PLAINTEE/DDKONG | High
4 | ... | ... | ... | ...

There are 5 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Rancor_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Rancor. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/bin/login.php` | High
2 | File | `/cgi-bin/wapopen` | High
3 | File | `/cgi/cpaddons_feature.pl` | High
4 | File | `/data/nvram` | Medium
5 | File | `/forum/away.php` | High
6 | File | `/frontend/x3/cpanelpro/filelist-thumbs.html` | High
7 | File | `/fs/cifs/file.c` | High
8 | File | `/goform/login` | High
9 | File | `/horde/util/go.php` | High
10 | File | `/mib.db` | Low
11 | File | `/modules/profile/index.php` | High
12 | File | `/OA_HTML/cabo/jsps/a.jsp` | High
13 | File | `/out.php` | Medium
14 | File | `/system/site.php` | High
15 | File | `adb/adb_client.c` | High
16 | File | `adclick.php` | Medium
17 | File | `add_comment.php` | High
18 | File | `adelogs.adobe.com` | High
19 | File | `admin.php` | Medium
20 | File | `admin/google_search_console/class-gsc-table.php` | High
21 | File | `administrator/components/com_media/helpers/media.php` | High
22 | File | `android/webkit/SearchBoxImpl.java` | High
23 | File | `app-layer-ssh.c` | High
24 | File | `arch_init.c` | Medium
25 | File | `authenticate.c` | High
26 | File | `awstats.pl` | Medium
27 | File | `BKCLogSvr.exe` | High
28 | ... | ... | ...

There are 232 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://unit42.paloaltonetworks.com/unit42-rancor-targeted-attacks-south-east-asia-using-plaintee-ddkong-malware-families/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
