# Ripprbot - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Ripprbot](https://vuldb.com/?actor.ripprbot). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ripprbot](https://vuldb.com/?actor.ripprbot)

## Campaigns

The following _campaigns_ are known and can be associated with Ripprbot:

* DDoS Ukraine

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Ripprbot:

* [US](https://vuldb.com/?country.us)
* [PT](https://vuldb.com/?country.pt)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Ripprbot.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [171.22.109.201](https://vuldb.com/?ip.171.22.109.201) | - | DDoS Ukraine | High
2 | [212.192.246.183](https://vuldb.com/?ip.212.192.246.183) | - | DDoS Ukraine | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Ripprbot_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Ripprbot. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/about.php` | Medium
2 | File | `/admin.php` | Medium
3 | File | `/admin/doctors/view_doctor.php` | High
4 | File | `/admin/modules/bibliography/index.php` | High
5 | File | `/admin/students/manage.php` | High
6 | File | `/adminlogin.asp` | High
7 | File | `/app/controller/Books.php` | High
8 | File | `/aqpg/users/login.php` | High
9 | File | `/controller/Index.php` | High
10 | File | `/coreframe/app/content/admin/content.php` | High
11 | File | `/dev/audio` | Medium
12 | File | `/dl/dl_print.php` | High
13 | File | `/etc/crash` | Medium
14 | File | `/etc/master.passwd` | High
15 | File | `/etc/passwd` | Medium
16 | File | `/goform/AddSysLogRule` | High
17 | File | `/goform/Diagnosis` | High
18 | File | `/goform/WifiBasicSet` | High
19 | File | `/Hospital-Management-System-master/contact.php` | High
20 | File | `/include/friends.inc.php` | High
21 | File | `/index.php?module=configuration/application` | High
22 | File | `/kruxton/receipt.php` | High
23 | File | `/members/view_member.php` | High
24 | File | `/services/view_service.php` | High
25 | File | `/servlet/webacc` | High
26 | File | `/sitemagic/upgrade.php` | High
27 | File | `/userui/ticket_list.php` | High
28 | File | `/usr/5bin/su` | Medium
29 | File | `/wp-admin/options-general.php` | High
30 | File | `/zm/index.php` | High
31 | File | `1.x/src/rogatkin/web/WarRoller.java` | High
32 | File | `abook_database.php` | High
33 | File | `accounts/inc/include.php` | High
34 | File | `adaptive-images-script.php` | High
35 | File | `additem.asp` | Medium
36 | File | `adherents/subscription/info.php` | High
37 | File | `admin.asp` | Medium
38 | File | `admin.php` | Medium
39 | File | `admin/admin.php` | High
40 | File | `admin/admin_users.php` | High
41 | File | `admin/article_save.php` | High
42 | File | `admin/general.php` | High
43 | File | `admin/header.php` | High
44 | File | `admin/inc/change_action.php` | High
45 | File | `admin/index.php` | High
46 | File | `admin/info.php` | High
47 | File | `admin/login.asp` | High
48 | File | `admin/manage-comments.php` | High
49 | File | `admin/manage-news.php` | High
50 | File | `admin/plugin-settings.php` | High
51 | File | `admin/specials.php` | High
52 | File | `admin:de` | Medium
53 | File | `admincp/auth/checklogin.php` | High
54 | File | `admincp/auth/secure.php` | High
55 | File | `administrator/components/com_media/helpers/media.php` | High
56 | File | `administrator/index.php` | High
57 | File | `admin_login.asp` | High
58 | File | `ajax_url.php` | Medium
59 | File | `album_portal.php` | High
60 | File | `al_initialize.php` | High
61 | File | `anjel.index.php` | High
62 | File | `annonces-p-f.php` | High
63 | File | `announce.php` | Medium
64 | File | `announcement.php` | High
65 | File | `announcements.php` | High
66 | File | `app/admin/routing/edit-bgp-mapping-search.php` | High
67 | File | `application/config/config.php` | High
68 | File | `application/controllers/basedata/inventory.php` | High
69 | File | `apply.cgi` | Medium
70 | File | `apps/app_article/controller/rating.php` | High
71 | File | `article.php` | Medium
72 | File | `articles.php` | Medium
73 | File | `artikel_anzeige.php` | High
74 | File | `AudioFlinger.cpp` | High
75 | File | `auktion.cgi` | Medium
76 | File | `auth.php` | Medium
77 | File | `authfiles/login.asp` | High
78 | File | `basket.php` | Medium
79 | File | `books.php` | Medium
80 | File | `browse-category.php` | High
81 | File | `browse.php` | Medium
82 | File | `browse_videos.php` | High
83 | File | `BrudaNews/BrudaGB` | High
84 | File | `bwlist_inc.html` | High
85 | File | `calendar.php` | Medium
86 | File | `callme_page.php` | High
87 | File | `cart.php` | Medium
88 | File | `cart_add.php` | Medium
89 | File | `case.filemanager.php` | High
90 | File | `catalog.php` | Medium
91 | File | `catalogshop.php` | High
92 | File | `catalogue.asp` | High
93 | File | `category.cfm` | Medium
94 | File | `category.php` | Medium
95 | File | `category_list.php` | High
96 | ... | ... | ...

There are 844 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/some_details_of_the_ddos_attacks_targeting_ukraine_and_russia_in_recent_days/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
