# Roaming Mantis - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Roaming Mantis](https://vuldb.com/?actor.roaming_mantis). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.roaming_mantis](https://vuldb.com/?actor.roaming_mantis)

## Campaigns

The following _campaigns_ are known and can be associated with Roaming Mantis:

* Asia Mobile Devices

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Roaming Mantis:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [DE](https://vuldb.com/?country.de)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Roaming Mantis.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [27.124.36.32](https://vuldb.com/?ip.27.124.36.32) | - | - | High
2 | [27.124.36.34](https://vuldb.com/?ip.27.124.36.34) | - | - | High
3 | [27.124.36.52](https://vuldb.com/?ip.27.124.36.52) | - | - | High
4 | [27.124.39.241](https://vuldb.com/?ip.27.124.39.241) | - | - | High
5 | [27.124.39.242](https://vuldb.com/?ip.27.124.39.242) | - | - | High
6 | [27.124.39.243](https://vuldb.com/?ip.27.124.39.243) | - | - | High
7 | [43.240.14.44](https://vuldb.com/?ip.43.240.14.44) | scdc.worra.com | Asia Mobile Devices | High
8 | [61.97.248.6](https://vuldb.com/?ip.61.97.248.6) | faster-returns.viberhow.com | - | High
9 | [61.97.248.7](https://vuldb.com/?ip.61.97.248.7) | vlan-routing.viberhow.com | - | High
10 | [61.97.248.8](https://vuldb.com/?ip.61.97.248.8) | can-man.viberhow.com | - | High
11 | [61.97.248.9](https://vuldb.com/?ip.61.97.248.9) | client-any.viberhow.com | - | High
12 | [91.204.227.19](https://vuldb.com/?ip.91.204.227.19) | - | - | High
13 | [91.204.227.20](https://vuldb.com/?ip.91.204.227.20) | - | - | High
14 | [91.204.227.21](https://vuldb.com/?ip.91.204.227.21) | - | - | High
15 | [91.204.227.22](https://vuldb.com/?ip.91.204.227.22) | - | - | High
16 | [91.204.227.23](https://vuldb.com/?ip.91.204.227.23) | - | - | High
17 | [91.204.227.24](https://vuldb.com/?ip.91.204.227.24) | - | - | High
18 | [91.204.227.25](https://vuldb.com/?ip.91.204.227.25) | - | - | High
19 | [91.204.227.26](https://vuldb.com/?ip.91.204.227.26) | - | - | High
20 | [91.204.227.27](https://vuldb.com/?ip.91.204.227.27) | - | - | High
21 | [91.204.227.28](https://vuldb.com/?ip.91.204.227.28) | - | - | High
22 | ... | ... | ... | ...

There are 84 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Roaming Mantis_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Roaming Mantis. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/addnews.html` | High
3 | File | `/admin/system/database/filedown.php` | High
4 | File | `/api/baskets/{name}` | High
5 | File | `/bin/boa` | Medium
6 | File | `/bin/protest` | Medium
7 | File | `/cgi-bin/cstecgi.cgi` | High
8 | File | `/cgi-bin/ExportSettings.sh` | High
9 | File | `/cgi-bin/upload_vpntar` | High
10 | File | `/getcfg.php` | Medium
11 | File | `/HNAP1` | Low
12 | File | `/htdocs/web/getcfg.php` | High
13 | File | `/lan.asp` | Medium
14 | File | `/MTFWU` | Low
15 | ... | ... | ...

There are 122 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.kaspersky.co.jp/roaming-mantis-update/20383/
* https://blog.sekoia.io/ongoing-roaming-mantis-smishing-campaign-targeting-france/
* https://github.com/SEKOIA-IO/Community/blob/main/IOCs/roamingmantis/roaming_mantis_iocs_20220718.csv
* https://www.cyber45.com

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
