# Saint Pierre and Miquelon Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Saint Pierre and Miquelon Unknown](https://vuldb.com/?actor.saint_pierre_and_miquelon_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.saint_pierre_and_miquelon_unknown](https://vuldb.com/?actor.saint_pierre_and_miquelon_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Saint Pierre and Miquelon Unknown:

* [US](https://vuldb.com/?country.us)
* [ES](https://vuldb.com/?country.es)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 20 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Saint Pierre and Miquelon Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.58.180](https://vuldb.com/?ip.5.62.58.180) | r-180-58-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.92](https://vuldb.com/?ip.5.62.63.92) | r-92-63-62-5.consumer-pool.prcdn.net | - | High
3 | [5.252.112.0](https://vuldb.com/?ip.5.252.112.0) | - | - | High
4 | [45.12.70.181](https://vuldb.com/?ip.45.12.70.181) | technic.alltieinc.com | - | High
5 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Saint Pierre and Miquelon Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Saint Pierre and Miquelon Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/acms/admin/cargo_types/view_cargo_type.php` | High
3 | File | `/admin/index.php` | High
4 | File | `/admin/manage_academic.php` | High
5 | File | `/admin/photo.php` | High
6 | File | `/admin/user/add` | High
7 | File | `/api/baskets/{name}` | High
8 | File | `/appliance/users?action=edit` | High
9 | File | `/cm/delete` | Medium
10 | File | `/common/logViewer/logViewer.jsf` | High
11 | File | `/crmeb/app/admin/controller/store/CopyTaobao.php` | High
12 | File | `/download` | Medium
13 | File | `/etc/master.passwd` | High
14 | File | `/forum/away.php` | High
15 | File | `/homeaction.php` | High
16 | File | `/if.cgi` | Low
17 | File | `/modules/profile/index.php` | High
18 | File | `/modules/tasks/summary.inc.php` | High
19 | File | `/multi-vendor-shopping-script/product-list.php` | High
20 | File | `/news.dtl.php` | High
21 | File | `/out.php` | Medium
22 | File | `/p` | Low
23 | File | `/recordings/index.php` | High
24 | File | `/see_more_details.php` | High
25 | File | `/services/details.asp` | High
26 | File | `/setup` | Low
27 | File | `/show_news.php` | High
28 | File | `/spip.php` | Medium
29 | File | `/student/bookdetails.php` | High
30 | File | `/tmp/before` | Medium
31 | File | `/uncpath/` | Medium
32 | File | `/wordpress/wp-admin/options-general.php` | High
33 | File | `/wp-content/plugins/updraftplus/admin.php` | High
34 | File | `4.2.0.CP09` | Medium
35 | File | `account.asp` | Medium
36 | File | `act.php` | Low
37 | File | `adclick.php` | Medium
38 | File | `admin.php` | Medium
39 | File | `admin/admin.shtml` | High
40 | File | `Admin/ADM_Pagina.php` | High
41 | File | `admin/category.inc.php` | High
42 | File | `admin/param/param_func.inc.php` | High
43 | File | `administration/admins.php` | High
44 | File | `ajax_calls.php` | High
45 | File | `api.php` | Low
46 | File | `artlinks.dispnew.php` | High
47 | File | `auth2-gss.c` | Medium
48 | File | `awstats.pl` | Medium
49 | ... | ... | ...

There are 423 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_pm.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_pm.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
