# Sea Turtle - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Sea Turtle](https://vuldb.com/?actor.sea_turtle). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.sea_turtle](https://vuldb.com/?actor.sea_turtle)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Sea Turtle:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 19 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Sea Turtle.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [62.115.255.163](https://vuldb.com/?ip.62.115.255.163) | - | - | High
2 | [82.102.19.88](https://vuldb.com/?ip.82.102.19.88) | - | - | High
3 | [93.115.22.212](https://vuldb.com/?ip.93.115.22.212) | no-reverse-yet.local | - | High
4 | ... | ... | ... | ...

There are 2 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Sea Turtle_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 16 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Sea Turtle. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.env` | Low
2 | File | `/app/admin/nat/item-add-submit.php` | High
3 | File | `/bin/login` | Medium
4 | File | `/catalog` | Medium
5 | File | `/category.php` | High
6 | File | `/cgi-bin/delete_CA` | High
7 | File | `/chart` | Low
8 | File | `/Config/SaveUploadedHotspotLogoFile` | High
9 | File | `/download` | Medium
10 | File | `/get_getnetworkconf.cgi` | High
11 | File | `/GponForm/device_Form?script/` | High
12 | File | `/includes/rrdtool.inc.php` | High
13 | File | `/Main_AdmStatus_Content.asp` | High
14 | File | `/NAGErrors` | Medium
15 | File | `/pages.php` | Medium
16 | File | `/rest/project-templates/1.0/createshared` | High
17 | File | `/rules/REQUEST-932-APPLICATION-ATTACK-RCE.conf` | High
18 | File | `/rules/REQUEST-933-APPLICATION-ATTACK-PHP.conf` | High
19 | File | `/rules/REQUEST-942-APPLICATION-ATTACK-SQLI.conf` | High
20 | File | `/Search-Results` | High
21 | File | `/see_more_details.php` | High
22 | File | `/sgms/TreeControl` | High
23 | ... | ... | ...

There are 196 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://www.huntandhackett.com/blog/turkish-espionage-campaigns

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
