# Senegal Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Senegal Unknown](https://vuldb.com/?actor.senegal_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.senegal_unknown](https://vuldb.com/?actor.senegal_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Senegal Unknown:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 20 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Senegal Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.61.128](https://vuldb.com/?ip.5.62.61.128) | r-128-61-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.108](https://vuldb.com/?ip.5.62.63.108) | r-108-63-62-5.consumer-pool.prcdn.net | - | High
3 | [41.82.0.0](https://vuldb.com/?ip.41.82.0.0) | - | - | High
4 | [41.194.26.0](https://vuldb.com/?ip.41.194.26.0) | - | - | High
5 | [41.194.208.0](https://vuldb.com/?ip.41.194.208.0) | - | - | High
6 | [41.208.128.0](https://vuldb.com/?ip.41.208.128.0) | - | - | High
7 | [41.214.0.0](https://vuldb.com/?ip.41.214.0.0) | - | - | High
8 | [41.219.0.0](https://vuldb.com/?ip.41.219.0.0) | - | - | High
9 | [45.12.70.206](https://vuldb.com/?ip.45.12.70.206) | fertilising.globalhilive.com | - | High
10 | [45.12.71.206](https://vuldb.com/?ip.45.12.71.206) | - | - | High
11 | [45.59.174.0](https://vuldb.com/?ip.45.59.174.0) | - | - | High
12 | ... | ... | ... | ...

There are 46 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Senegal Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Senegal Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.htaccess` | Medium
2 | File | `/+CSCOE+/logon.html` | High
3 | File | `/acms/admin/cargo_types/view_cargo_type.php` | High
4 | File | `/admin/addemployee.php` | High
5 | File | `/admin/book/create/` | High
6 | File | `/admin/index.php` | High
7 | File | `/apilog.php` | Medium
8 | File | `/appliance/users?action=edit` | High
9 | File | `/etc/ajenti/config.yml` | High
10 | File | `/filemanager/upload.php` | High
11 | File | `/forum/away.php` | High
12 | File | `/healthcare/Admin/consulting_detail.php` | High
13 | File | `/if.cgi` | Low
14 | File | `/IISADMPWD` | Medium
15 | File | `/mifs/c/i/reg/reg.html` | High
16 | File | `/modules/profile/index.php` | High
17 | File | `/news.dtl.php` | High
18 | File | `/see_more_details.php` | High
19 | File | `/services/details.asp` | High
20 | File | `/setup` | Low
21 | File | `/spip.php` | Medium
22 | File | `/uncpath/` | Medium
23 | File | `/var/log/nginx` | High
24 | File | `/VPortal/mgtconsole/Subscriptions.jsp` | High
25 | File | `/wp-content/plugins/updraftplus/admin.php` | High
26 | File | `/zm/index.php` | High
27 | File | `0.php` | Low
28 | File | `act.php` | Low
29 | File | `adclick.php` | Medium
30 | File | `admin` | Low
31 | File | `admin.php` | Medium
32 | File | `admin/adminsignin.html` | High
33 | File | `admin/movieview.php` | High
34 | File | `admin/versions.html` | High
35 | File | `agenda.php` | Medium
36 | File | `ajax_calls.php` | High
37 | File | `api.php` | Low
38 | File | `army.php` | Medium
39 | ... | ... | ...

There are 337 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_sn.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_sn.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_sn.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
