# Socks5 Systemz - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Socks5 Systemz](https://vuldb.com/?actor.socks5_systemz). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.socks5_systemz](https://vuldb.com/?actor.socks5_systemz)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Socks5 Systemz:

* [NL](https://vuldb.com/?country.nl)
* [FR](https://vuldb.com/?country.fr)
* [US](https://vuldb.com/?country.us)
* ...

There are 12 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Socks5 Systemz.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [34.29.85.190](https://vuldb.com/?ip.34.29.85.190) | 190.85.29.34.bc.googleusercontent.com | - | Medium
2 | [37.187.122.227](https://vuldb.com/?ip.37.187.122.227) | 519.gra.ovh.abcd.network | - | High
3 | [37.187.142.187](https://vuldb.com/?ip.37.187.142.187) | 2416.gra1.ovh.abcd.network | - | High
4 | [37.187.143.172](https://vuldb.com/?ip.37.187.143.172) | ns372109.ip-37-187-143.eu | - | High
5 | [37.187.148.204](https://vuldb.com/?ip.37.187.148.204) | ns3010993.ip-37-187-148.eu | - | High
6 | [45.155.250.90](https://vuldb.com/?ip.45.155.250.90) | - | - | High
7 | [51.159.66.125](https://vuldb.com/?ip.51.159.66.125) | 51-159-66-125.rev.poneytelecom.eu | - | High
8 | [62.210.204.131](https://vuldb.com/?ip.62.210.204.131) | 62-210-204-131.rev.poneytelecom.eu | - | High
9 | [65.109.80.185](https://vuldb.com/?ip.65.109.80.185) | static.185.80.109.65.clients.your-server.de | - | High
10 | [69.30.215.106](https://vuldb.com/?ip.69.30.215.106) | lumpet.peardong.org.uk | - | High
11 | [69.30.233.162](https://vuldb.com/?ip.69.30.233.162) | - | - | High
12 | [69.30.253.122](https://vuldb.com/?ip.69.30.253.122) | - | - | High
13 | [79.132.130.163](https://vuldb.com/?ip.79.132.130.163) | - | - | High
14 | [81.31.197.8](https://vuldb.com/?ip.81.31.197.8) | vm4755017.34ssd.had.wf | - | High
15 | ... | ... | ... | ...

There are 56 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Socks5 Systemz_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Socks5 Systemz. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/students.php` | High
2 | File | `/admin/subnets/ripe-query.php` | High
3 | File | `/admin/theme-edit.php` | High
4 | File | `/alphaware/details.php` | High
5 | File | `/api/jolokia org.jolokia.http.HttpRequestHandler#handlePostRequest` | High
6 | File | `/app/sys1.php` | High
7 | File | `/apply.cgi` | Medium
8 | File | `/cgi-bin/downloadFile.cgi` | High
9 | File | `/cgi/loginDefaultUser` | High
10 | File | `/core/conditions/AbstractWrapper.java` | High
11 | File | `/debug/pprof` | Medium
12 | File | `/export` | Low
13 | File | `/file?action=download&file` | High
14 | File | `/h/autoSaveDraft` | High
15 | File | `/hardware` | Medium
16 | File | `/librarian/bookdetails.php` | High
17 | File | `/monitoring` | Medium
18 | File | `/opt/zimbra/jetty/webapps/zimbra/public` | High
19 | File | `/plugin/LiveChat/getChat.json.php` | High
20 | File | `/plugins/servlet/audit/resource` | High
21 | File | `/plugins/servlet/project-config/PROJECT/roles` | High
22 | File | `/product/savenewproduct.php?flag=1` | High
23 | File | `/PROD_ar/twbkwbis.P_FirstMenu` | High
24 | File | `/RestAPI` | Medium
25 | File | `/server-status` | High
26 | File | `/tmp/zarafa-vacation-*` | High
27 | File | `/uncpath/` | Medium
28 | File | `/upload` | Low
29 | File | `/user/loader.php?api=1` | High
30 | File | `/usr/bin/sonia` | High
31 | File | `/var/log/nginx` | High
32 | File | `/var/run/sudo-rs/ts` | High
33 | File | `/var/run/watchman.pid` | High
34 | ... | ... | ...

There are 287 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://threatfox.abuse.ch
* https://twitter.com/g0njxa/status/1701212547305607283
* https://www.bitsight.com/blog/unveiling-socks5systemz-rise-new-proxy-service-privateloader-and-amadey

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
