# TA551 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [TA551](https://vuldb.com/?actor.ta551). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ta551](https://vuldb.com/?actor.ta551)

## Campaigns

The following _campaigns_ are known and can be associated with TA551:

* Cobalt Strike
* DarkVNC
* Hancitor
* ...

There are 1 more campaign items available. Please use our online service to access the data.

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with TA551:

* [RU](https://vuldb.com/?country.ru)
* [DE](https://vuldb.com/?country.de)
* [IT](https://vuldb.com/?country.it)
* ...

There are 11 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of TA551.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [8.209.76.110](https://vuldb.com/?ip.8.209.76.110) | - | Hancitor | High
2 | [23.82.141.241](https://vuldb.com/?ip.23.82.141.241) | - | Cobalt Strike | High
3 | [23.106.223.174](https://vuldb.com/?ip.23.106.223.174) | - | - | High
4 | [43.128.225.230](https://vuldb.com/?ip.43.128.225.230) | - | Hancitor | High
5 | [43.128.229.136](https://vuldb.com/?ip.43.128.229.136) | - | Hancitor | High
6 | [43.128.232.152](https://vuldb.com/?ip.43.128.232.152) | - | Hancitor | High
7 | [43.129.239.78](https://vuldb.com/?ip.43.129.239.78) | - | Hancitor | High
8 | [43.133.160.144](https://vuldb.com/?ip.43.133.160.144) | - | Hancitor | High
9 | [45.8.146.139](https://vuldb.com/?ip.45.8.146.139) | vm580483.stark-industries.solutions | IcedID | High
10 | [45.89.67.166](https://vuldb.com/?ip.45.89.67.166) | srbtv.ru | - | High
11 | [45.95.11.151](https://vuldb.com/?ip.45.95.11.151) | vm220095.pq.hosting | - | High
12 | [45.95.11.153](https://vuldb.com/?ip.45.95.11.153) | vm284420.pq.hosting | - | High
13 | [45.95.11.154](https://vuldb.com/?ip.45.95.11.154) | 4ser-1640356836.4server.su | - | High
14 | [45.95.11.155](https://vuldb.com/?ip.45.95.11.155) | slfk.lz | - | High
15 | ... | ... | ... | ...

There are 58 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _TA551_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-24, CWE-36 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by TA551. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/#ProductSerie/view/` | High
2 | File | `/?r=recruit/resume/edit&op=status` | High
3 | File | `/academy/tutor/filter` | High
4 | File | `/account/delivery` | High
5 | File | `/accounts_con/register_account` | High
6 | File | `/ad-list` | Medium
7 | File | `/add_classes.php` | High
8 | File | `/admin/` | Low
9 | File | `/admin/?page=bike` | High
10 | File | `/admin/?page=user/list` | High
11 | File | `/admin/action/delete-vaccine.php` | High
12 | File | `/admin/action/new-feed.php` | High
13 | File | `/admin/add-category.php` | High
14 | File | `/admin/add-services.php` | High
15 | File | `/admin/addproduct.php` | High
16 | File | `/admin/admin-profile.php` | High
17 | File | `/admin/admin_content_tag.php?action=save_content` | High
18 | File | `/admin/admin_user.php` | High
19 | File | `/admin/ajax.php?action=confirm_order` | High
20 | File | `/admin/article/article-edit-run.php` | High
21 | File | `/admin/borrow_add.php` | High
22 | File | `/admin/bwdates-report-details.php` | High
23 | File | `/admin/category/cate-edit-run.php` | High
24 | File | `/admin/cms_content.php` | High
25 | File | `/admin/course.php` | High
26 | File | `/admin/courses/view_course.php` | High
27 | File | `/admin/del_feedback.php` | High
28 | File | `/admin/del_service.php` | High
29 | File | `/admin/departments/manage_department.php` | High
30 | File | `/admin/edit-accepted-appointment.php` | High
31 | File | `/admin/edit-services.php` | High
32 | File | `/admin/edit_category.php` | High
33 | File | `/admin/edit_product.php` | High
34 | File | `/admin/edit_teacher.php` | High
35 | File | `/admin/forgot-password.php` | High
36 | File | `/admin/index.php` | High
37 | File | `/admin/index.php?act=reset_admin_psw` | High
38 | File | `/admin/index/index.html#/admin/mall.goods/index.html` | High
39 | File | `/admin/invoice.php` | High
40 | File | `/admin/list_addr_fwresource_ip.php` | High
41 | File | `/admin/manage-pages.php` | High
42 | File | `/admin/manage-users.php` | High
43 | File | `/admin/modal_add_product.php` | High
44 | File | `/Admin/News.php` | High
45 | File | `/admin/order.php` | High
46 | File | `/admin/pages/edit_chicken.php` | High
47 | File | `/admin/pages/subjects.php` | High
48 | File | `/admin/pages/yearlevel.php` | High
49 | File | `/admin/project/update/2` | High
50 | File | `/admin/reg.php` | High
51 | File | `/admin/regester.php` | High
52 | File | `/admin/search-appointment.php` | High
53 | File | `/admin/settings/` | High
54 | File | `/admin/students/manage_academic.php` | High
55 | File | `/admin/students/update_status.php` | High
56 | File | `/admin/sys_sql_query.php` | High
57 | File | `/admin/update-clients.php` | High
58 | File | `/admin_route/inc_service_credits.php` | High
59 | File | `/adplanet/PlanetCommentList` | High
60 | File | `/ample/app/action/edit_product.php` | High
61 | File | `/ample/app/ajax/member_data.php` | High
62 | File | `/api/` | Low
63 | File | `/api/authentication/login` | High
64 | File | `/api/controllers/admin/app/AppController.php` | High
65 | File | `/api/controllers/merchant/design/MaterialController.php` | High
66 | File | `/api/controllers/merchant/shop/PosterController.php` | High
67 | File | `/api/DataDictionary/GetItemList` | High
68 | File | `/api/es/admin/v3/security/user/1` | High
69 | File | `/api/log/killJob` | High
70 | File | `/api/sys/set_passwd` | High
71 | File | `/app/api/controller/collect.php` | High
72 | File | `/app/api/controller/default/File.php` | High
73 | File | `/app/api/controller/default/Sqlite.php` | High
74 | File | `/app/sys1.php` | High
75 | File | `/application/index/controller/Databasesource.php` | High
76 | File | `/application/index/controller/Icon.php` | High
77 | File | `/application/index/controller/Pay.php` | High
78 | File | `/application/index/controller/Service.php` | High
79 | File | `/application/index/controller/Unity.php` | High
80 | File | `/application/pay/controller/Api.php` | High
81 | File | `/apply/index.php` | High
82 | File | `/apps/reg_go.php` | High
83 | File | `/App_Resource/UEditor/server/upload.aspx` | High
84 | File | `/article/DelectArticleById/` | High
85 | File | `/bin/boa` | Medium
86 | File | `/blog` | Low
87 | File | `/boaform/wlan_basic_set.cgi` | High
88 | File | `/book-services.php` | High
89 | File | `/booking/show_bookings/` | High
90 | File | `/catalog/compare` | High
91 | File | `/cgi-bin/adm.cgi` | High
92 | File | `/cgi-bin/cstecgi.cgi` | High
93 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
94 | File | `/cgi-bin/koha/catalogue/search.pl` | High
95 | File | `/cgi-bin/mainfunction.cgi` | High
96 | File | `/cgi-bin/vitogate.cgi` | High
97 | File | `/changeimage.php` | High
98 | File | `/classes/Master.php?f=delete_inquiry` | High
99 | File | `/classes/Master.php?f=save_inquiry` | High
100 | ... | ... | ...

There are 887 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://isc.sans.edu/diary/28092
* https://isc.sans.edu/diary/IcedID+%28Bokbot%29+with+Dark+VNC+and+Cobalt+Strike/28884
* https://isc.sans.edu/diary/Monster+Libra+%28TA551Shathak%29+--%3E+IcedID+%28Bokbot%29+--%3E+Cobalt+Strike+%26+DarkVNC/28974
* https://isc.sans.edu/diary/Monster+Libra+%28TA551Shathak%29+pushes+IcedID+%28Bokbot%29+with+Dark+VNC+and+Cobalt+Strike/28934
* https://isc.sans.edu/diary/rss/27738
* https://isc.sans.edu/forums/diary/More+TA551+Shathak+Word+docs+push+IcedID+Bokbot/26674/
* https://isc.sans.edu/forums/diary/TA551+Shathak+Word+docs+push+IcedID+Bokbot/26438/
* https://www.malware-traffic-analysis.net/2021/09/14/index.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
