# Togo Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Togo Unknown](https://vuldb.com/?actor.togo_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.togo_unknown](https://vuldb.com/?actor.togo_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Togo Unknown:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [ES](https://vuldb.com/?country.es)
* ...

There are 21 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Togo Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.62.61.180](https://vuldb.com/?ip.5.62.61.180) | r-180-61-62-5.consumer-pool.prcdn.net | - | High
2 | [5.62.63.160](https://vuldb.com/?ip.5.62.63.160) | r-160-63-62-5.consumer-pool.prcdn.net | - | High
3 | [41.78.136.0](https://vuldb.com/?ip.41.78.136.0) | - | - | High
4 | [41.207.160.0](https://vuldb.com/?ip.41.207.160.0) | - | - | High
5 | [45.12.70.218](https://vuldb.com/?ip.45.12.70.218) | scenes.globalhilive.com | - | High
6 | [45.12.71.218](https://vuldb.com/?ip.45.12.71.218) | - | - | High
7 | [45.42.169.0](https://vuldb.com/?ip.45.42.169.0) | - | - | High
8 | ... | ... | ... | ...

There are 30 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Togo Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Togo Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/acms/admin/cargo_types/view_cargo_type.php` | High
3 | File | `/admin/` | Low
4 | File | `/admin/addemployee.php` | High
5 | File | `/admin/index.php` | High
6 | File | `/apilog.php` | Medium
7 | File | `/appliance/users?action=edit` | High
8 | File | `/filemanager/upload.php` | High
9 | File | `/forum/away.php` | High
10 | File | `/healthcare/Admin/consulting_detail.php` | High
11 | File | `/if.cgi` | Low
12 | File | `/mifs/c/i/reg/reg.html` | High
13 | File | `/modules/profile/index.php` | High
14 | File | `/news.dtl.php` | High
15 | File | `/see_more_details.php` | High
16 | File | `/services/details.asp` | High
17 | File | `/setup` | Low
18 | File | `/spip.php` | Medium
19 | File | `/uncpath/` | Medium
20 | File | `/var/log/nginx` | High
21 | File | `/VPortal/mgtconsole/Subscriptions.jsp` | High
22 | File | `/wp-content/plugins/updraftplus/admin.php` | High
23 | File | `/zm/index.php` | High
24 | File | `act.php` | Low
25 | File | `adclick.php` | Medium
26 | File | `admin` | Low
27 | File | `admin.php` | Medium
28 | File | `admin/adminsignin.html` | High
29 | File | `admin/movieview.php` | High
30 | File | `admin/versions.html` | High
31 | File | `agenda.php` | Medium
32 | File | `ajax_calls.php` | High
33 | File | `al_initialize.php` | High
34 | File | `api.php` | Low
35 | File | `army.php` | Medium
36 | File | `attendancy.php` | High
37 | ... | ... | ...

There are 320 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_tg.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ip2location_country/ip2location_country_tg.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_tg.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
