# U.S. Minor Outlying Islands Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [U.S. Minor Outlying Islands Unknown](https://vuldb.com/?actor.u.s._minor_outlying_islands_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.u.s._minor_outlying_islands_unknown](https://vuldb.com/?actor.u.s._minor_outlying_islands_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with U.S. Minor Outlying Islands Unknown:

* [US](https://vuldb.com/?country.us)
* [PL](https://vuldb.com/?country.pl)
* [LU](https://vuldb.com/?country.lu)
* ...

There are 19 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of U.S. Minor Outlying Islands Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [8.37.233.83](https://vuldb.com/?ip.8.37.233.83) | - | - | High
2 | [45.12.70.233](https://vuldb.com/?ip.45.12.70.233) | spatially.globalhilive.com | - | High
3 | [45.12.71.233](https://vuldb.com/?ip.45.12.71.233) | - | - | High
4 | [46.36.201.251](https://vuldb.com/?ip.46.36.201.251) | - | - | High
5 | [46.36.201.252](https://vuldb.com/?ip.46.36.201.252) | - | - | High
6 | ... | ... | ... | ...

There are 22 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _U.S. Minor Outlying Islands Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | T1068 | CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
7 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by U.S. Minor Outlying Islands Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.travis.yml` | Medium
2 | File | `/$({curl` | Medium
3 | File | `/action/ipcamRecordPost` | High
4 | File | `/admin/ajax.php` | High
5 | File | `/admin/ajax.php?action=delete_window` | High
6 | File | `/admin/inquiries/view_details.php` | High
7 | File | `/admin/maintenance/manage_category.php` | High
8 | File | `/admin/maintenance/view_designation.php` | High
9 | File | `/admin/mechanics/manage_mechanic.php` | High
10 | File | `/admin/service_requests/manage_inventory.php` | High
11 | File | `/admin/syslog` | High
12 | File | `/administrator/components/table_manager/` | High
13 | File | `/ajax/GetInheritedProperties` | High
14 | File | `/alphaware/details.php` | High
15 | File | `/Api/ASF` | Medium
16 | File | `/api/public/signup` | High
17 | File | `/appConfig/userDB.json` | High
18 | File | `/catcompany.php` | High
19 | File | `/cgi-bin/` | Medium
20 | File | `/cgi-bin/activate.cgi` | High
21 | File | `/classes/Login.php` | High
22 | File | `/classes/Master.php` | High
23 | File | `/classes/Users.php` | High
24 | File | `/common/run_cross_report.php` | High
25 | File | `/dashboard/contact` | High
26 | File | `/dbhcms/ext/news/ext.news.be.php` | High
27 | File | `/dcim/sites/add/` | High
28 | File | `/dev/ptpX` | Medium
29 | File | `/etc/passwd` | Medium
30 | File | `/file-manager/upload.php` | High
31 | File | `/forum/away.php` | High
32 | File | `/goform/WifiBasicSet` | High
33 | File | `/hrm/employeeview.php` | High
34 | File | `/inc/topBarNav.php` | High
35 | File | `/index.php?case=table&act=add&table=archive&admin_dir=admin` | High
36 | File | `/members/view_member.php` | High
37 | File | `/mgm_dev_reboot.asp` | High
38 | File | `/MicroStrategyWS/happyaxis.jsp` | High
39 | ... | ... | ...

There are 334 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_um.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
