# Ultimate Member - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Ultimate Member](https://vuldb.com/?actor.ultimate_member). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.ultimate_member](https://vuldb.com/?actor.ultimate_member)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Ultimate Member:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 13 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Ultimate Member.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [13.115.254.242](https://vuldb.com/?ip.13.115.254.242) | ec2-13-115-254-242.ap-northeast-1.compute.amazonaws.com | - | Medium
2 | [18.183.89.3](https://vuldb.com/?ip.18.183.89.3) | ec2-18-183-89-3.ap-northeast-1.compute.amazonaws.com | - | Medium
3 | [43.207.157.215](https://vuldb.com/?ip.43.207.157.215) | ec2-43-207-157-215.ap-northeast-1.compute.amazonaws.com | - | Medium
4 | ... | ... | ... | ...

There are 14 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Ultimate Member_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-425 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Ultimate Member. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/+CSCOE+/logon.html` | High
2 | File | `/.env` | Low
3 | File | `/academy/tutor/filter` | High
4 | File | `/admin/admin_user.php` | High
5 | File | `/admin/category_row.php` | High
6 | File | `/admin/index2.html` | High
7 | File | `/admin/project/update/2` | High
8 | File | `/admin/upload/img` | High
9 | File | `/api/authentication/login` | High
10 | File | `/api/baskets/{name}` | High
11 | File | `/api/jolokia org.jolokia.http.HttpRequestHandler#handlePostRequest` | High
12 | File | `/api/wechat/app_auth` | High
13 | File | `/api2/html/` | Medium
14 | File | `/books` | Low
15 | File | `/cas/logout` | Medium
16 | File | `/cgi-bin/supervisor/CloudSetup.cgi` | High
17 | File | `/cgi-bin/wlogin.cgi` | High
18 | File | `/ckeditor/samples/old/ajax.html` | High
19 | File | `/classes/Master.php` | High
20 | File | `/classes/Master.php?f=delete_item` | High
21 | File | `/classes/Master.php?f=delete_service` | High
22 | File | `/classes/Master.php?f=save_service` | High
23 | File | `/config/getuser` | High
24 | File | `/contact.php` | Medium
25 | File | `/controller/OnlinePreviewController.java` | High
26 | File | `/controllers/api/user.php` | High
27 | File | `/dayrui/My/Config/Install.txt` | High
28 | File | `/debug/pprof` | Medium
29 | File | `/designer/add/layout` | High
30 | File | `/dialog/select_media.php` | High
31 | ... | ... | ...

There are 264 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.wpscan.com/hacking-campaign-actively-exploiting-ultimate-member-plugin/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
