# V3G4 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [V3G4](https://vuldb.com/?actor.v3g4). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.v3g4](https://vuldb.com/?actor.v3g4)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with V3G4:

* [US](https://vuldb.com/?country.us)
* [LU](https://vuldb.com/?country.lu)
* [ES](https://vuldb.com/?country.es)
* ...

There are 7 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of V3G4.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [104.244.72.64](https://vuldb.com/?ip.104.244.72.64) | winging.co.uk | - | High
2 | [176.123.9.238](https://vuldb.com/?ip.176.123.9.238) | - | - | High
3 | [198.98.49.79](https://vuldb.com/?ip.198.98.49.79) | - | - | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _V3G4_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | T1068 | CWE-250, CWE-264, CWE-266, CWE-269, CWE-284 | J2EE Misconfiguration: Weak Access Permissions for EJB Methods | High
7 | ... | ... | ... | ...

There are 23 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by V3G4. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `%APPDATA%\Securepoint SSL VPN` | High
2 | File | `//proc/kcore` | Medium
3 | File | `/action/iperf` | High
4 | File | `/admin.php/admin/plog/index.html` | High
5 | File | `/admin.php/singer/admin/singer/del` | High
6 | File | `/admin.php?id=siteoptions&social=display&value=0&sid=2` | High
7 | File | `/admin/?page=orders/view_order` | High
8 | File | `/admin/comn/service/update.json` | High
9 | File | `/admin/siteoptions.php&action=displaygoal&value=1&roleid=1` | High
10 | File | `/admin/transactions/update_status.php` | High
11 | File | `/admin/uesrs.php&action=display&value=Hide` | High
12 | File | `/administrator/components/menu/` | High
13 | File | `/assets/php/upload.php` | High
14 | File | `/auparse/auparse.c` | High
15 | File | `/back/index.php/user/User/?1` | High
16 | File | `/backups/` | Medium
17 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
18 | File | `/cgi-bin/logs.ha` | High
19 | File | `/claire_blake` | High
20 | File | `/classes/Master.php?f=delete_service` | High
21 | File | `/common/info.cgi` | High
22 | File | `/core/table/query` | High
23 | File | `/cupseasylive/costcentercreate.php` | High
24 | File | `/damicms-master/admin.php?s=/Article/doedit` | High
25 | File | `/feedback/post/` | High
26 | File | `/gaia-job-admin/user/add` | High
27 | File | `/goform/dir_setWanWifi` | High
28 | File | `/goform/login` | High
29 | File | `/goform/SetInternetLanInfo` | High
30 | File | `/goform/setportList` | High
31 | File | `/goform/SetPptpServerCfg` | High
32 | File | `/goform/WifiBasicSet` | High
33 | File | `/group/apply` | Medium
34 | File | `/gusetbook/save` | High
35 | File | `/hdf5/src/H5Fint.c` | High
36 | File | `/includes/login.php` | High
37 | File | `/index.cfm/_api/asset/image/` | High
38 | File | `/insurance/editClient.php` | High
39 | File | `/linkedcontent/editfolder.php` | High
40 | ... | ... | ...

There are 340 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://unit42.paloaltonetworks.com/mirai-variant-v3g4/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
