# Vatican City Unknown - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Vatican City Unknown](https://vuldb.com/?actor.vatican_city_unknown). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.vatican_city_unknown](https://vuldb.com/?actor.vatican_city_unknown)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Vatican City Unknown:

* [US](https://vuldb.com/?country.us)
* [TR](https://vuldb.com/?country.tr)
* [FR](https://vuldb.com/?country.fr)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Vatican City Unknown.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.228.55.184](https://vuldb.com/?ip.2.228.55.184) | 2-228-55-184.ip190.fastwebnet.it | - | High
2 | [2.228.243.180](https://vuldb.com/?ip.2.228.243.180) | 2-228-243-180.ip193.fastwebnet.it | - | High
3 | [5.62.61.208](https://vuldb.com/?ip.5.62.61.208) | r-208-61-62-5.consumer-pool.prcdn.net | - | High
4 | [5.62.63.196](https://vuldb.com/?ip.5.62.63.196) | r-196-63-62-5.consumer-pool.prcdn.net | - | High
5 | [31.220.29.160](https://vuldb.com/?ip.31.220.29.160) | - | - | High
6 | [45.12.70.237](https://vuldb.com/?ip.45.12.70.237) | flattemp-help.globalhilive.com | - | High
7 | [45.12.70.251](https://vuldb.com/?ip.45.12.70.251) | presentational.globalhilive.com | - | High
8 | [45.12.71.237](https://vuldb.com/?ip.45.12.71.237) | - | - | High
9 | [45.42.143.0](https://vuldb.com/?ip.45.42.143.0) | - | - | High
10 | [45.61.44.128](https://vuldb.com/?ip.45.61.44.128) | - | - | High
11 | [46.36.200.0](https://vuldb.com/?ip.46.36.200.0) | - | - | High
12 | [46.36.200.128](https://vuldb.com/?ip.46.36.200.128) | - | - | High
13 | [46.36.200.192](https://vuldb.com/?ip.46.36.200.192) | - | - | High
14 | [46.36.200.224](https://vuldb.com/?ip.46.36.200.224) | - | - | High
15 | [46.36.200.228](https://vuldb.com/?ip.46.36.200.228) | - | - | High
16 | [46.36.200.230](https://vuldb.com/?ip.46.36.200.230) | - | - | High
17 | [46.36.200.236](https://vuldb.com/?ip.46.36.200.236) | - | - | High
18 | [46.36.200.240](https://vuldb.com/?ip.46.36.200.240) | - | - | High
19 | ... | ... | ... | ...

There are 71 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Vatican City Unknown_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Vatican City Unknown. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/acms/admin/cargo_types/view_cargo_type.php` | High
2 | File | `/admin/?page=orders/view_order` | High
3 | File | `/admin/addemployee.php` | High
4 | File | `/api/V2/internal/TaskPermissions/CheckTaskAccess` | High
5 | File | `/appliance/users?action=edit` | High
6 | File | `/bibliography/marcsru.php` | High
7 | File | `/card_scan.php` | High
8 | File | `/ci_ssms/index.php/orders/create` | High
9 | File | `/claire_blake` | High
10 | File | `/classes/Master.php?f=delete_payment` | High
11 | File | `/com` | Low
12 | File | `/com.biepie/shared_prefs/com.bitpie_preferences.xml` | High
13 | File | `/drivers/infiniband/core/cm.c` | High
14 | File | `/feegroups/tgrt_group.jsf` | High
15 | File | `/fm-data.lua` | Medium
16 | File | `/forum/away.php` | High
17 | File | `/goform/SetLEDCfg` | High
18 | File | `/goform/setMacFilterCfg` | High
19 | File | `/goform/setSysAdm` | High
20 | File | `/healthcare/Admin/consulting_detail.php` | High
21 | File | `/inc/campaign_save.php` | High
22 | File | `/jerry-core/ecma/operations/ecma-get-put-value.c` | High
23 | File | `/leave_system/classes/Master.php?f=delete_department` | High
24 | File | `/linux/main.cpp` | High
25 | File | `/magick/quantize.c` | High
26 | File | `/Monitoring-History.php` | High
27 | File | `/plugin/rundeck/webhook/` | High
28 | File | `/publisher` | Medium
29 | File | `/release-x64/otfccdump` | High
30 | File | `/RestAPI` | Medium
31 | File | `/sacco_shield/ajax.php?action=delete_plan` | High
32 | File | `/SASWebReportStudio/logonAndRender.do` | High
33 | File | `/SiteServer/Ajax/ajaxOtherService.aspx` | High
34 | File | `/spip.php` | Medium
35 | File | `/staff/delete.php` | High
36 | File | `/sws/swsAlert.sws` | High
37 | File | `/v1/sql-runner` | High
38 | File | `/var/mail` | Medium
39 | File | `/zm/index.php` | High
40 | File | `actions.c` | Medium
41 | File | `actions/doreport.php` | High
42 | File | `adclick.php` | Medium
43 | File | `addcustomer.asp/addprod.asp/process.asp` | High
44 | File | `addressbookprovider.php` | High
45 | File | `admin.html` | Medium
46 | File | `admin/admin_users.php` | High
47 | File | `agenda.php` | Medium
48 | File | `alert.php` | Medium
49 | File | `api.php` | Low
50 | File | `AppRestrictionController.java` | High
51 | File | `arch/x86/kvm/lapic.c` | High
52 | ... | ... | ...

There are 451 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/firehol/blocklist-ipsets/blob/master/geolite2_country/country_va.netset
* https://github.com/firehol/blocklist-ipsets/blob/master/ipip_country/ipip_country_va.netset

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
