# VertexNet - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [VertexNet](https://vuldb.com/?actor.vertexnet). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.vertexnet](https://vuldb.com/?actor.vertexnet)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with VertexNet:

* [DE](https://vuldb.com/?country.de)
* [US](https://vuldb.com/?country.us)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of VertexNet.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [5.57.226.202](https://vuldb.com/?ip.5.57.226.202) | - | - | High
2 | [18.211.9.206](https://vuldb.com/?ip.18.211.9.206) | ec2-18-211-9-206.compute-1.amazonaws.com | - | Medium
3 | [23.20.239.12](https://vuldb.com/?ip.23.20.239.12) | ec2-23-20-239-12.compute-1.amazonaws.com | - | Medium
4 | [31.170.160.57](https://vuldb.com/?ip.31.170.160.57) | - | - | High
5 | [35.186.238.101](https://vuldb.com/?ip.35.186.238.101) | 101.238.186.35.bc.googleusercontent.com | - | Medium
6 | ... | ... | ... | ...

There are 20 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _VertexNet_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by VertexNet. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.plan` | Low
2 | File | `.tin` | Low
3 | File | `/configs/application.ini` | High
4 | File | `/search-result/` | High
5 | File | `/usr/bin/sonia` | High
6 | File | `3dsimp.cpp` | Medium
7 | File | `123flashchat.php` | High
8 | File | `abook_database.php` | High
9 | File | `admin.asp` | Medium
10 | File | `admin.php` | Medium
11 | File | `admin/stat.ratings.php` | High
12 | File | `akocomment.php` | High
13 | File | `album.php` | Medium
14 | File | `allmanageup.pl` | High
15 | File | `archive_read_support_format_lha.c` | High
16 | File | `ardeaCore/lib/core/ardeaInit.php` | High
17 | File | `asm.js` | Low
18 | File | `bar.phtml` | Medium
19 | File | `bible.php` | Medium
20 | File | `bin/named/query.c` | High
21 | File | `blocks.php` | Medium
22 | File | `blog.cgi` | Medium
23 | File | `c2c_service.exe` | High
24 | File | `cadastro_usuario.php` | High
25 | File | `Calc` | Low
26 | File | `calender.pl` | Medium
27 | File | `categoria.php` | High
28 | File | `category_list.php` | High
29 | File | `cgiforum.pl` | Medium
30 | File | `classes/class.model.php` | High
31 | File | `classifieds.cgi` | High
32 | File | `cloud.php` | Medium
33 | File | `Code/Routines.pl` | High
34 | File | `collectivite.class.php` | High
35 | File | `command.c` | Medium
36 | File | `command/user.cgi` | High
37 | File | `ContentRender.class.php` | High
38 | File | `conversations.c` | High
39 | File | `core/includes/gfw_smarty.php` | High
40 | ... | ... | ...

There are 347 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.talosintelligence.com/2019/08/threat-roundup-0823-0830.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
