# Vjw0rm - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Vjw0rm](https://vuldb.com/?actor.vjw0rm). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.vjw0rm](https://vuldb.com/?actor.vjw0rm)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Vjw0rm:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [IR](https://vuldb.com/?country.ir)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Vjw0rm.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.56.57.84](https://vuldb.com/?ip.2.56.57.84) | dean.imatee.com | - | High
2 | [2.59.254.205](https://vuldb.com/?ip.2.59.254.205) | - | - | High
3 | [3.24.145.55](https://vuldb.com/?ip.3.24.145.55) | ec2-3-24-145-55.ap-southeast-2.compute.amazonaws.com | - | Medium
4 | [5.135.43.179](https://vuldb.com/?ip.5.135.43.179) | - | - | High
5 | [5.253.114.102](https://vuldb.com/?ip.5.253.114.102) | - | - | High
6 | [18.192.43.230](https://vuldb.com/?ip.18.192.43.230) | ec2-18-192-43-230.eu-central-1.compute.amazonaws.com | - | Medium
7 | [18.222.96.210](https://vuldb.com/?ip.18.222.96.210) | ec2-18-222-96-210.us-east-2.compute.amazonaws.com | - | Medium
8 | [23.101.205.83](https://vuldb.com/?ip.23.101.205.83) | - | - | High
9 | [31.210.20.129](https://vuldb.com/?ip.31.210.20.129) | - | - | High
10 | [37.0.8.115](https://vuldb.com/?ip.37.0.8.115) | brownfarmer.capitolreservations.com | - | High
11 | [37.0.14.195](https://vuldb.com/?ip.37.0.14.195) | - | - | High
12 | [37.0.14.201](https://vuldb.com/?ip.37.0.14.201) | - | - | High
13 | [37.0.14.204](https://vuldb.com/?ip.37.0.14.204) | - | - | High
14 | [37.0.14.211](https://vuldb.com/?ip.37.0.14.211) | - | - | High
15 | [37.120.141.147](https://vuldb.com/?ip.37.120.141.147) | - | - | High
16 | [37.120.141.190](https://vuldb.com/?ip.37.120.141.190) | - | - | High
17 | [37.139.128.51](https://vuldb.com/?ip.37.139.128.51) | - | - | High
18 | [40.121.49.138](https://vuldb.com/?ip.40.121.49.138) | - | - | High
19 | [45.77.146.176](https://vuldb.com/?ip.45.77.146.176) | 45.77.146.176.vultrusercontent.com | - | High
20 | [45.81.39.90](https://vuldb.com/?ip.45.81.39.90) | - | - | High
21 | [45.81.233.69](https://vuldb.com/?ip.45.81.233.69) | 45.81.233.69.mc-host24.de | - | High
22 | ... | ... | ... | ...

There are 82 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Vjw0rm_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Vjw0rm. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/addWhiteListDomain.imss` | High
2 | File | `/admin/index2.html` | High
3 | File | `/admin_giant/add_team_member.php` | High
4 | File | `/api/baskets/{name}` | High
5 | File | `/api/v4/users/ids` | High
6 | File | `/apply.cgi` | Medium
7 | File | `/cgi-bin/wlogin.cgi` | High
8 | File | `/common/info.cgi` | High
9 | File | `/etc/shadow` | Medium
10 | File | `/forum/away.php` | High
11 | File | `/get_getnetworkconf.cgi` | High
12 | File | `/goform/setmac` | High
13 | File | `/index.php?p=admin/actions/users/send-password-reset-email` | High
14 | File | `/integrations.json` | High
15 | File | `/lists/admin/` | High
16 | File | `/phppath/php` | Medium
17 | File | `/services/details.asp` | High
18 | File | `/spip.php` | Medium
19 | File | `adclick.php` | Medium
20 | ... | ... | ...

There are 166 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/executemalware/Malware-IOCs/blob/main/2021-09-21%20Vjw0rm%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2021-11-08%20Vjw0rm%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-01-21%20Vjw0rm%20IOCs
* https://github.com/executemalware/Malware-IOCs/blob/main/2022-05-26%20vjw0rm%20IOCs
* https://threatfox.abuse.ch
* https://tria.ge/211102-znybpscfe
* https://tria.ge/211213-vsj8esdhg5
* https://tria.ge/220121-v4fdlsagbj
* https://tria.ge/220127-v75gxagean
* https://tria.ge/220613-d169gsdeen
* https://tria.ge/220714-3f73qaegg6
* https://tria.ge/220722-sb92eagbbm
* https://tria.ge/220727-rxwv8segbr
* https://twitter.com/petrovic082/status/1580612096152068099

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
