# WASP Stealer - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [WASP Stealer](https://vuldb.com/?actor.wasp_stealer). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.wasp_stealer](https://vuldb.com/?actor.wasp_stealer)

## Campaigns

The following _campaigns_ are known and can be associated with WASP Stealer:

* Invisible Challenge

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with WASP Stealer:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [JP](https://vuldb.com/?country.jp)
* ...

There are 2 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of WASP Stealer.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [3.86.190.205](https://vuldb.com/?ip.3.86.190.205) | ec2-3-86-190-205.compute-1.amazonaws.com | - | Medium
2 | [4.201.87.248](https://vuldb.com/?ip.4.201.87.248) | - | - | High
3 | [18.204.35.132](https://vuldb.com/?ip.18.204.35.132) | ec2-18-204-35-132.compute-1.amazonaws.com | - | Medium
4 | ... | ... | ... | ...

There are 8 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _WASP Stealer_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Pathname Traversal | High
2 | T1059 | CWE-94 | Cross Site Scripting | High
3 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 8 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by WASP Stealer. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/admin.php` | High
2 | File | `/admin/index2.html` | High
3 | File | `/api/baskets/{name}` | High
4 | File | `/view-pass-detail.php` | High
5 | File | `/wp-admin/options-general.php` | High
6 | File | `admin.color.php` | High
7 | File | `admin.cropcanvas.php` | High
8 | File | `admin.joomlaradiov5.php` | High
9 | File | `admin.php` | Medium
10 | File | `admin/addons/archive/archive.php` | High
11 | File | `administrator/components/com_media/helpers/media.php` | High
12 | File | `admin\model\catalog\download.php` | High
13 | File | `akocomments.php` | High
14 | File | `album_portal.php` | High
15 | File | `al_initialize.php` | High
16 | ... | ... | ...

There are 130 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.virustotal.com/2023/06/inside-of-wasps-nest-deep-dive-into.html
* https://checkmarx.com/blog/attacker-uses-a-popular-tiktok-challenge-to-lure-users-into-installing-malicious-package/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
