# WastedLocker - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [WastedLocker](https://vuldb.com/?actor.wastedlocker). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.wastedlocker](https://vuldb.com/?actor.wastedlocker)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with WastedLocker:

* [US](https://vuldb.com/?country.us)
* [IR](https://vuldb.com/?country.ir)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 14 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of WastedLocker.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [1.2.22.0](https://vuldb.com/?ip.1.2.22.0) | - | - | High
2 | [38.135.104.189](https://vuldb.com/?ip.38.135.104.189) | h189-us104.fcsrv.net | - | High
3 | [88.119.175.104](https://vuldb.com/?ip.88.119.175.104) | 12366-22299.bacloud.info | - | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _WastedLocker_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-37 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by WastedLocker. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.encfs6.xml` | Medium
2 | File | `.htaccess` | Medium
3 | File | `/admin/admin_manage/delete` | High
4 | File | `/admin/index.php` | High
5 | File | `/admin/video/list` | High
6 | File | `/bdswebui/assignusers/` | High
7 | File | `/cgi-bin/supervisor/PwdGrp.cgi` | High
8 | File | `/dev/snd/seq` | Medium
9 | File | `/dl/dl_sendmail.php` | High
10 | File | `/etc/passwd` | Medium
11 | File | `/etc/qci/answers` | High
12 | File | `/forum/away.php` | High
13 | File | `/function/booksave.php` | High
14 | File | `/GetCSSashx/?CP=%2fwebconfig` | High
15 | File | `/goform/SysToolChangePwd` | High
16 | File | `/horde/util/go.php` | High
17 | File | `/login.html` | Medium
18 | File | `/romfile.cfg` | Medium
19 | File | `/see_more_details.php` | High
20 | File | `/tmp` | Low
21 | File | `/uncpath/` | Medium
22 | File | `/usr/local` | Medium
23 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
24 | File | `actions.hsp` | Medium
25 | File | `adclick.php` | Medium
26 | File | `add_comment.php` | High
27 | File | `add_edit_user.asp` | High
28 | File | `admin.php` | Medium
29 | File | `admin/?page=reports` | High
30 | File | `admin/index.php` | High
31 | File | `admin/setleaves.php` | High
32 | ... | ... | ...

There are 269 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://research.nccgroup.com/2020/06/23/wastedlocker-a-new-ransomware-variant-developed-by-the-evil-corp-group/
* https://symantec-enterprise-blogs.security.com/blogs/threat-intelligence/wastedlocker-ransomware-us

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
