# Wiper - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Wiper](https://vuldb.com/?actor.wiper). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.wiper](https://vuldb.com/?actor.wiper)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Wiper:

* [US](https://vuldb.com/?country.us)
* [FR](https://vuldb.com/?country.fr)
* [IT](https://vuldb.com/?country.it)
* ...

There are 4 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Wiper.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [2.230.110.137](https://vuldb.com/?ip.2.230.110.137) | 2-230-110-137.ip201.fastwebnet.it | - | High
2 | [24.199.247.222](https://vuldb.com/?ip.24.199.247.222) | webmail.capefearclinic.org | - | High
3 | [37.71.147.186](https://vuldb.com/?ip.37.71.147.186) | 186.147.71.37.rev.sfr.net | - | High
4 | [37.99.163.162](https://vuldb.com/?ip.37.99.163.162) | mail.futuregrp.org | - | High
5 | [50.255.126.65](https://vuldb.com/?ip.50.255.126.65) | 50-255-126-65-static.hfc.comcastbusiness.net | - | High
6 | [58.185.154.99](https://vuldb.com/?ip.58.185.154.99) | - | - | High
7 | ... | ... | ... | ...

There are 25 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Wiper_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-425 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Wiper. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/cgi-bin/nobody` | High
2 | File | `/doorgets/app/views/ajax/commentView.php` | High
3 | File | `/etc/passwd` | Medium
4 | File | `/GponForm/device_Form?script/` | High
5 | File | `/index.php` | Medium
6 | File | `/index.php?controller=GzUser&action=edit&id=1` | High
7 | File | `/rom-0` | Low
8 | File | `/timeline2.php` | High
9 | File | `/tmp` | Low
10 | File | `/uncpath/` | Medium
11 | File | `/user-utils/users/md5.json` | High
12 | File | `/wp-admin/admin-ajax.php` | High
13 | File | `AbstractController.php` | High
14 | File | `ActBar.ocx` | Medium
15 | File | `adclick.php` | Medium
16 | File | `add_comment.php` | High
17 | File | `add_ons.php` | Medium
18 | File | `admin.comms.php` | High
19 | File | `admin.php` | Medium
20 | File | `admin/bad.php` | High
21 | File | `admin/users/new` | High
22 | File | `admincp.php?app=user&do=save` | High
23 | File | `ajax.php?type=../admin-panel/autoload&page=manage-users` | High
24 | File | `apc.php` | Low
25 | ... | ... | ...

There are 208 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.cyble.com/2022/03/04/ongoing-cyberwarfare-a-look-at-the-key-cyberattacks/
* https://blog.cyble.com/2022/03/11/ongoing-russia-ukraine-warfare-significant-cyber-incidents/
* https://www.threatminer.org/report.php?q=TA14-353A_wiper.pdf&y=2014

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
