# YoroTrooper - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [YoroTrooper](https://vuldb.com/?actor.yorotrooper). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.yorotrooper](https://vuldb.com/?actor.yorotrooper)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with YoroTrooper:

* [RU](https://vuldb.com/?country.ru)
* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 8 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of YoroTrooper.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [45.61.136.64](https://vuldb.com/?ip.45.61.136.64) | - | - | High
2 | [45.61.136.175](https://vuldb.com/?ip.45.61.136.175) | - | - | High
3 | [45.61.138.243](https://vuldb.com/?ip.45.61.138.243) | - | - | High
4 | [45.227.252.247](https://vuldb.com/?ip.45.227.252.247) | - | - | High
5 | [46.161.27.151](https://vuldb.com/?ip.46.161.27.151) | - | - | High
6 | ... | ... | ... | ...

There are 19 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _YoroTrooper_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by YoroTrooper. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/index2.html` | High
2 | File | `/cgi-bin/system_mgr.cgi` | High
3 | File | `/devices/ProcessRequest.do` | High
4 | File | `/dus/shopliste/index.php` | High
5 | File | `/etc/path` | Medium
6 | File | `/fax/fax_send.php` | High
7 | File | `/hotel.php` | Medium
8 | File | `/jeecg-boot/sys/common/upload` | High
9 | File | `/lam/tmp/` | Medium
10 | File | `/nagiosql/admin/checkcommands.php` | High
11 | File | `/thruk/#cgi-bin/extinfo.cgi?type=2` | High
12 | File | `/tmp` | Low
13 | File | `/usr/5bin/su` | Medium
14 | File | `/usr/bin/mail` | High
15 | File | `/web/entry/en/address/adrsSetUserWizard.cgi` | High
16 | File | `/zm/index.php` | High
17 | File | `add_edit_download.asp` | High
18 | File | `admin.asp` | Medium
19 | File | `admin.php` | Medium
20 | File | `admin/` | Low
21 | File | `admin/admin.php` | High
22 | File | `admin/manage-comments.php` | High
23 | File | `admin/moduleinterface.php` | High
24 | File | `AdminViewError/AdminAddadmin` | High
25 | File | `agentdisplay.php` | High
26 | File | `and/or` | Low
27 | File | `auction.cgi` | Medium
28 | File | `authent.php4` | Medium
29 | File | `autologin.jsp` | High
30 | File | `axspawn.c` | Medium
31 | File | `base_ag_main.php` | High
32 | File | `base_qry_main.php` | High
33 | File | `bigsam_guestbook.php` | High
34 | ... | ... | ...

There are 295 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://github.com/Cisco-Talos/IOCs/blob/main/2023/03/YoroTrooper.txt
* https://github.com/Cisco-Talos/IOCs/blob/main/2023/10/attributing-yorotrooper.txt

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
