# Zloader - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [Zloader](https://vuldb.com/?actor.zloader). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.zloader](https://vuldb.com/?actor.zloader)

## Campaigns

The following _campaigns_ are known and can be associated with Zloader:

* Microsoft Signature Verification

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Zloader:

* [GB](https://vuldb.com/?country.gb)
* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 4 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Zloader.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [31.3.135.232](https://vuldb.com/?ip.31.3.135.232) | mirror.tillo.ch | - | High
2 | [37.228.151.133](https://vuldb.com/?ip.37.228.151.133) | - | - | High
3 | [45.63.25.55](https://vuldb.com/?ip.45.63.25.55) | 45.63.25.55.vultr.com | - | Medium
4 | [51.83.216.232](https://vuldb.com/?ip.51.83.216.232) | a1c.s.cuk.pl | - | High
5 | [62.113.203.55](https://vuldb.com/?ip.62.113.203.55) | - | - | High
6 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _Zloader_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-24 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94, CWE-1321 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by Zloader. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/?page=user/list` | High
2 | File | `/admin/action/edit_chicken.php` | High
3 | File | `/admin/add-services.php` | High
4 | File | `/admin/add_user_modal.php` | High
5 | File | `/admin/admin-profile.php` | High
6 | File | `/admin/ajax.php?action=confirm_order` | High
7 | File | `/admin/ind_backstage.php` | High
8 | File | `/admin/pages/student-print.php` | High
9 | File | `/admin/pages/subjects.php` | High
10 | File | `/admin/service.php` | High
11 | File | `/admin/sys_sql_query.php` | High
12 | File | `/admin/user/team` | High
13 | File | `/adplanet/PlanetCommentList` | High
14 | File | `/ajax.php?action=read_msg` | High
15 | File | `/api/ping` | Medium
16 | File | `/apply/index.php` | High
17 | File | `/baseOpLog.do` | High
18 | File | `/bcms/admin/?page=user/list` | High
19 | File | `/blog` | Low
20 | File | `/blog-single.php` | High
21 | File | `/cgi-bin/adm.cgi` | High
22 | File | `/cgi-bin/jumpto.php?class=user&page=config_save&isphp=1` | High
23 | File | `/cgi-bin/koha/catalogue/search.pl` | High
24 | File | `/classes/Master.php?f=save_inquiry` | High
25 | File | `/classes/Users.php?f=save` | High
26 | File | `/collection/all` | High
27 | File | `/Duty/AjaxHandle/UpLoadFloodPlanFile.ashx` | High
28 | File | `/Duty/AjaxHandle/UploadHandler.ashx` | High
29 | File | `/home/cavesConsole` | High
30 | File | `/include/file.php` | High
31 | File | `/index.php` | Medium
32 | ... | ... | ...

There are 268 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blogs.blackberry.com/en/2017/12/threat-spotlight-terdot-a-zloader-malicious-downloader
* https://community.blueliv.com/#!/s/6141e29b82df417a0032fc18
* https://isc.sans.edu/forums/diary/German+malspam+pushes+ZLoader+malware/25996/
* https://isc.sans.edu/forums/diary/Job+applicationthemed+malspam+pushes+ZLoader/26222/
* https://isc.sans.edu/forums/diary/Polish+malspam+pushes+ZLoader+malware/26196/
* https://research.checkpoint.com/2022/can-you-trust-a-files-digital-signature-new-zloader-campaign-exploits-microsofts-signature-verification-putting-users-at-risk/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
