# m8220 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [m8220](https://vuldb.com/?actor.m8220). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.m8220](https://vuldb.com/?actor.m8220)

## Campaigns

The following _campaigns_ are known and can be associated with m8220:

* Log4Shell

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with m8220:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [IN](https://vuldb.com/?country.in)

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of m8220.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [205.185.113.59](https://vuldb.com/?ip.205.185.113.59) | - | Log4Shell | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _m8220_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-29 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Cross Site Scripting | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 15 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by m8220. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/category_view.php` | High
2 | File | `/forum/away.php` | High
3 | File | `/frontend/x3/cpanelpro/filelist-thumbs.html` | High
4 | File | `/fs/cifs/file.c` | High
5 | File | `/highlight/index.html` | High
6 | File | `/hotel.php` | Medium
7 | File | `/Login.do` | Medium
8 | File | `/register.php` | High
9 | File | `/var/etc/shadow` | High
10 | File | `/var/log/cgred` | High
11 | File | `/var/run/hostapd` | High
12 | File | `add.php` | Low
13 | File | `AddEvent.php` | Medium
14 | File | `addlisting.asp` | High
15 | File | `add_tmsp.php` | Medium
16 | File | `admin.php` | Medium
17 | File | `admin/handlers.php` | High
18 | File | `admin/help.php` | High
19 | File | `admin/modules/system/app_user.php` | High
20 | File | `admin/tools/trackback/index.php` | High
21 | File | `admin/users_edit.php` | High
22 | File | `administrators/backups/` | High
23 | File | `afmparse.c` | Medium
24 | File | `ajax.php` | Medium
25 | File | `answers.php` | Medium
26 | File | `apsetup.php` | Medium
27 | File | `arch/powerpc/kernel/process.c` | High
28 | File | `arch/x86/kvm/vmx.c` | High
29 | File | `ArchiveUtil.java` | High
30 | File | `bmp.c` | Low
31 | File | `browse.php` | Medium
32 | File | `buy.php` | Low
33 | File | `calendar.class.php` | High
34 | File | `calendar/submit/` | High
35 | File | `category.php` | Medium
36 | File | `cc_guestbook.pl` | High
37 | File | `centipaid_class.php` | High
38 | File | `channel.c` | Medium
39 | File | `chetcpasswd.cgi` | High
40 | File | `clastree.htm` | Medium
41 | File | `client-assist.php` | High
42 | File | `coders/dds.c` | Medium
43 | File | `coders/webp.c` | High
44 | ... | ... | ...

There are 383 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://blog.netlab.360.com/yi-jing-you-xxxge-jia-zu-de-botnetli-yong-log4shelllou-dong-chuan-bo-wei-da-bu-ding-de-gan-jin-liao/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
