# xHunt - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the actor known as [xHunt](https://vuldb.com/?actor.xhunt). The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor.xhunt](https://vuldb.com/?actor.xhunt)

## Campaigns

The following _campaigns_ are known and can be associated with xHunt:

* BumbleBee

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with xHunt:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [NL](https://vuldb.com/?country.nl)
* ...

There are 28 more country items available. Please use our online service to access the data.

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of xHunt.

ID | IP address | Hostname | Campaign | Confidence
-- | ---------- | -------- | -------- | ----------
1 | [23.92.127.18](https://vuldb.com/?ip.23.92.127.18) | - | BumbleBee | High
2 | [46.246.3.253](https://vuldb.com/?ip.46.246.3.253) | - | BumbleBee | High
3 | [46.246.3.254](https://vuldb.com/?ip.46.246.3.254) | - | BumbleBee | High
4 | [77.243.191.20](https://vuldb.com/?ip.77.243.191.20) | - | BumbleBee | High
5 | [82.102.21.219](https://vuldb.com/?ip.82.102.21.219) | - | BumbleBee | High
6 | [84.17.55.68](https://vuldb.com/?ip.84.17.55.68) | unn-84-17-55-68.cdn77.com | BumbleBee | High
7 | ... | ... | ... | ...

There are 24 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used by _xHunt_. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-24, CWE-36, CWE-37 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Cross Site Scripting | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration by xHunt. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.env` | Low
2 | File | `//proc/kcore` | Medium
3 | File | `/?ajax-request=jnews` | High
4 | File | `/?r=recruit/resume/edit&op=status` | High
5 | File | `/admin/?page=user/list` | High
6 | File | `/admin/?page=user/manage` | High
7 | File | `/admin/?page=user/manage_user&id=3` | High
8 | File | `/admin/about-us.php` | High
9 | File | `/admin/action/new-father.php` | High
10 | File | `/admin/del_category.php` | High
11 | File | `/admin/del_service.php` | High
12 | File | `/admin/edit-accepted-appointment.php` | High
13 | File | `/admin/edit-services.php` | High
14 | File | `/admin/edit.php` | High
15 | File | `/admin/edit_category.php` | High
16 | File | `/admin/edit_subject.php` | High
17 | File | `/admin/forgot-password.php` | High
18 | File | `/admin/index.php` | High
19 | File | `/admin/maintenance/view_designation.php` | High
20 | File | `/admin/manage_academic.php` | High
21 | File | `/admin/products/manage_product.php` | High
22 | File | `/admin/reg.php` | High
23 | File | `/admin/search-appointment.php` | High
24 | File | `/admin/sys_sql_query.php` | High
25 | File | `/adms/admin/?page=vehicles/view_transaction` | High
26 | File | `/alerts/alertConfigField.php` | High
27 | File | `/api/baskets/{name}` | High
28 | File | `/api/sys/login` | High
29 | File | `/api/v4/teams//channels/deleted` | High
30 | File | `/appliance/users?action=edit` | High
31 | File | `/auth/auth.php?user=1` | High
32 | File | `/backup.pl` | Medium
33 | File | `/belegungsplan/monatsuebersicht.inc.php` | High
34 | File | `/bin/boa` | Medium
35 | File | `/blog` | Low
36 | File | `/boafrm/formMapDelDevice` | High
37 | File | `/booking/show_bookings/` | High
38 | File | `/building/backmgr/urlpage/mobileurl/configfile/jx2_config.ini` | High
39 | File | `/cgi-bin/cstecgi.cgi` | High
40 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
41 | File | `/cgi-bin/luci;stok=/locale` | High
42 | File | `/cgi-bin/wlogin.cgi` | High
43 | File | `/classes/Master.php` | High
44 | File | `/classes/Master.php?f=save_category` | High
45 | File | `/classes/Master.php?f=save_sub_category` | High
46 | File | `/classes/Users.php?f=save` | High
47 | File | `/collection/all` | High
48 | File | `/dashboard/settings` | High
49 | File | `/dashboard/system/basics/name` | High
50 | File | `/dipam/athlete-profile.php` | High
51 | File | `/E-mobile/App/System/File/downfile.php` | High
52 | File | `/edoc/doctor/patient.php` | High
53 | File | `/emap/devicePoint_addImgIco?hasSubsystem=true` | High
54 | File | `/etc/passwd` | Medium
55 | File | `/etc/shadow` | Medium
56 | File | `/forum/away.php` | High
57 | File | `/function/login.php` | High
58 | File | `/fusion/portal/action/Link` | High
59 | File | `/gadgets/definitions/uptime.CapacityWhatIfGadget/getmetrics.php` | High
60 | File | `/gadgets/definitions/uptime.CapacityWhatifGadget/getxenmetrics.php` | High
61 | File | `/hedwig.cgi` | Medium
62 | File | `/HNAP1/` | Low
63 | File | `/importexport.php` | High
64 | File | `/index.php` | Medium
65 | File | `/index.php?app=main&func=passport&action=login` | High
66 | File | `/kelasdosen/data` | High
67 | File | `/listplace/user/coverPhotoUpdate` | High
68 | ... | ... | ...

There are 597 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the actor and the associated activities:

* https://unit42.paloaltonetworks.com/bumblebee-webshell-xhunt-campaign/
* https://unit42.paloaltonetworks.com/xhunt-campaign-backdoors/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
