# Accellion FTA Webshell - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Accellion FTA Webshell_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Accellion FTA Webshell:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 24 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Accellion FTA Webshell or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Accellion FTA Webshell.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [45.135.229.179](https://vuldb.com/?ip.45.135.229.179) | ipcore3.example.com | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [79.141.162.82](https://vuldb.com/?ip.79.141.162.82) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [92.38.135.29](https://vuldb.com/?ip.92.38.135.29) | camerotn1.com | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Accellion FTA Webshell. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Accellion FTA Webshell. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.FBCIndex` | Medium
2 | File | `.htaccess` | Medium
3 | File | `/+CSCOE+/logon.html` | High
4 | File | `/anony/mjpg.cgi` | High
5 | File | `/api/` | Low
6 | File | `/api/RecordingList/DownloadRecord?file=` | High
7 | File | `/authenticate.php` | High
8 | File | `/cache/backup/` | High
9 | File | `/cameras/XXXX/clips` | High
10 | File | `/category.php` | High
11 | File | `/cgi-bin` | Medium
12 | File | `/cgi-bin/wapopen` | High
13 | File | `/cwp_{SESSION_HASH}/admin/loader_ajax.php` | High
14 | File | `/data/vendor/tcl` | High
15 | File | `/dayrui/My/View/main.html` | High
16 | File | `/debug/pprof` | Medium
17 | File | `/DLSnap` | Low
18 | File | `/etc/postfix/sender_login` | High
19 | File | `/exec/` | Low
20 | File | `/index.php` | Medium
21 | File | `/items/view_item.php` | High
22 | File | `/ldclient/ldprov.cgi` | High
23 | File | `/librarian/bookdetails.php` | High
24 | File | `/login` | Low
25 | File | `/login/index.php` | High
26 | File | `/mail/index.html` | High
27 | File | `/mgmt/tm/util/bash` | High
28 | File | `/mygym/admin/index.php?view_exercises` | High
29 | File | `/plugin/extended-choice-parameter/js/` | High
30 | File | `/plugins/servlet/gadgets/makeRequest` | High
31 | File | `/PreviewHandler.ashx` | High
32 | File | `/products/details.asp` | High
33 | File | `/rest/api/2/user/picker` | High
34 | File | `/rest/api/latest/groupuserpicker` | High
35 | File | `/rom-0` | Low
36 | File | `/secure/QueryComponent!Default.jspa` | High
37 | File | `/services/details.asp` | High
38 | File | `/ServletAPI/accounts/login` | High
39 | File | `/student/bookdetails.php` | High
40 | File | `/sys/replicate/check` | High
41 | File | `/templates/header.inc.php` | High
42 | File | `/uncpath/` | Medium
43 | File | `/usr/bin/pkexec` | High
44 | ... | ... | ...

There are 380 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://us-cert.cisa.gov/ncas/analysis-reports/ar21-055a

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
