# CVE-2017-10271 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2017-10271_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2017-10271:

* [US](https://vuldb.com/?country.us)
* [NL](https://vuldb.com/?country.nl)
* [DE](https://vuldb.com/?country.de)
* ...

There are 7 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2017-10271 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Muhstik](https://vuldb.com/?actor.muhstik) | High
2 | [NoodRAT](https://vuldb.com/?actor.noodrat) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2017-10271.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [1.117.165.141](https://vuldb.com/?ip.1.117.165.141) | - | [NoodRAT](https://vuldb.com/?actor.noodrat) | High
2 | [13.214.222.35](https://vuldb.com/?ip.13.214.222.35) | ec2-13-214-222-35.ap-southeast-1.compute.amazonaws.com | [NoodRAT](https://vuldb.com/?actor.noodrat) | Medium
3 | [23.100.88.61](https://vuldb.com/?ip.23.100.88.61) | - | [NoodRAT](https://vuldb.com/?actor.noodrat) | High
4 | [42.51.40.184](https://vuldb.com/?ip.42.51.40.184) | - | [NoodRAT](https://vuldb.com/?actor.noodrat) | High
5 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2017-10271. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-24 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | ... | ... | ... | ...

There are 8 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2017-10271. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/rom-0` | Low
2 | File | `Attachment.pm/code-error.html.tmpl` | High
3 | File | `category.cfm` | Medium
4 | File | `cgi.c` | Low
5 | File | `crypto/asn1/asn_mime.c` | High
6 | ... | ... | ...

There are 39 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://asec.ahnlab.com/en/62144/
* https://blog.netlab.360.com/botnet-muhstik-is-actively-exploiting-drupal-cve-2018-7600-in-a-worm-style-en/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
