# CVE-2017-11882 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2017-11882_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2017-11882:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [JP](https://vuldb.com/?country.jp)
* ...

There are 1 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2017-11882 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2017-11882.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [35.77.84.215](https://vuldb.com/?ip.35.77.84.215) | ec2-35-77-84-215.ap-northeast-1.compute.amazonaws.com | [Unknown](https://vuldb.com/?actor.unknown) | Medium
2 | [79.110.48.52](https://vuldb.com/?ip.79.110.48.52) | - | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High
3 | [193.42.33.51](https://vuldb.com/?ip.193.42.33.51) | - | [Agent Tesla](https://vuldb.com/?actor.agent_tesla) | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2017-11882. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-36 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | ... | ... | ... | ...

There are 10 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2017-11882. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/about-us.php` | High
2 | File | `/admin/add-services.php` | High
3 | File | `/admin/admin.php` | High
4 | File | `/admin/edit.php` | High
5 | File | `/admin/index3.php` | High
6 | File | `/admin/maintenance/view_designation.php` | High
7 | File | `/admin/reg.php` | High
8 | File | `/admin/service.php` | High
9 | File | `/admin/view_order.php` | High
10 | File | `/apply.cgi` | Medium
11 | File | `/artist-display.php` | High
12 | File | `/cgi-bin/ping.cgi` | High
13 | File | `/Controller/Ajaxfileupload.ashx` | High
14 | File | `/Controls/Generic/EBMK/Handlers/EStatements/DownloadEStatement.ashx` | High
15 | File | `/coreframe/app/order/admin/card.php` | High
16 | File | `/dashboard/add-service.php` | High
17 | File | `/dede/group_store.php` | High
18 | File | `/dipam/athlete-profile.php` | High
19 | File | `/ecommerce/admin/category/controller.php` | High
20 | File | `/edit-db.php` | Medium
21 | File | `/forum/PostPrivateMessage` | High
22 | File | `/forums.php?action=post` | High
23 | File | `/index1.html` | Medium
24 | File | `/items/view_item.php` | High
25 | File | `/LEPTON_stable_2.2.2/upload/admins/media/index.php` | High
26 | File | `/list.php` | Medium
27 | File | `/login/index.php` | High
28 | File | `/mkshop/Men/profile.php` | High
29 | File | `/Moosikay/order.php` | High
30 | File | `/php-opos/index.php` | High
31 | ... | ... | ...

There are 261 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://isc.sans.edu/forums/diary/A+Good+Old+Equation+Editor+Vulnerability+Delivering+Malware/28368/
* https://www.zscaler.com/blogs/security-research/threat-actors-exploit-cve-2017-11882-deliver-agent-tesla

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
