# CVE-2021-44077 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2021-44077_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2021-44077:

* [SH](https://vuldb.com/?country.sh)
* [US](https://vuldb.com/?country.us)

## Actors

These _actors_ are associated with CVE-2021-44077 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2021-44077.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [2.58.56.14](https://vuldb.com/?ip.2.58.56.14) | powered.by.rdp.sh | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [5.113.111.4](https://vuldb.com/?ip.5.113.111.4) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [5.114.3.200](https://vuldb.com/?ip.5.114.3.200) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | ... | ... | ... | ...

There are 6 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2021-44077. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2021-44077. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?p=products` | Medium
2 | File | `/academy/home/courses` | High
3 | File | `/admin/?page=product/manage_product&id=2` | High
4 | File | `/admin/casedetails.php` | High
5 | File | `/admin/del_feedback.php` | High
6 | File | `/admin/maintenance/brand.php` | High
7 | File | `/admin/mechanics/manage_mechanic.php` | High
8 | File | `/admin/modal_add_product.php` | High
9 | File | `/admin/positions_add.php` | High
10 | File | `/admin/user/manage_user.php` | High
11 | File | `/admin/voters_row.php` | High
12 | File | `/ad_js.php` | Medium
13 | File | `/ajax.php?action=save_company` | High
14 | File | `/ajax.php?action=save_user` | High
15 | File | `/ajax/myshop` | Medium
16 | File | `/alogin.html` | Medium
17 | File | `/alumni/admin/ajax.php?action=save_settings` | High
18 | File | `/api/database` | High
19 | File | `/api/gen/clients/{language}` | High
20 | File | `/api/upload.php` | High
21 | File | `/application/index/controller/Pay.php` | High
22 | File | `/App_Resource/UEditor/server/upload.aspx` | High
23 | File | `/APR/signup.php` | High
24 | File | `/authenticationendpoint/login.do` | High
25 | File | `/aux` | Low
26 | File | `/backup.pl` | Medium
27 | File | `/c/PluginsController.php` | High
28 | File | `/cas/logout` | Medium
29 | File | `/category.php` | High
30 | File | `/categorypage.php` | High
31 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
32 | File | `/cgi-bin/system_mgr.cgi` | High
33 | File | `/cha.php` | Medium
34 | File | `/chaincity/user/ticket/create` | High
35 | File | `/collection/all` | High
36 | File | `/College/admin/teacher.php` | High
37 | File | `/contactform/contactform.php` | High
38 | File | `/Controller/Ajaxfileupload.ashx` | High
39 | File | `/dayrui/Fcms/View/system_log.html` | High
40 | File | `/drivers/block/floppy.c` | High
41 | File | `/ecommerce/admin/category/controller.php` | High
42 | File | `/ecommerce/support_ticket` | High
43 | File | `/ecrire/exec/puce_statut.php` | High
44 | File | `/etc/shadow` | Medium
45 | File | `/files/` | Low
46 | File | `/fos/admin/ajax.php` | High
47 | File | `/friends/ajax_invite` | High
48 | File | `/goform/aspForm` | High
49 | File | `/goform/telnet` | High
50 | File | `/goform/WifiGuestSet` | High
51 | File | `/gui/terminal_tool.cgi` | High
52 | File | `/home/filter_listings` | High
53 | File | `/include/file.php` | High
54 | File | `/index.php` | Medium
55 | File | `/index.php/client/message/message_read/xxxxxxxx[random-msg-hash]` | High
56 | File | `/index.php?s=/article/ApiAdminArticle/itemAdd` | High
57 | File | `/instance/detail` | High
58 | ... | ... | ...

There are 505 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://thedfirreport.com/2022/06/06/will-the-real-msiexec-please-stand-up-exploit-leads-to-data-exfiltration/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
