# CVE-2021-44228 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2021-44228_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2021-44228:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 4 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2021-44228 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [APT41](https://vuldb.com/?actor.apt41) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2021-44228.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.254.101.167](https://vuldb.com/?ip.5.254.101.167) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [8.38.148.63](https://vuldb.com/?ip.8.38.148.63) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [37.120.189.247](https://vuldb.com/?ip.37.120.189.247) | support.lgtron.de | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | [41.157.42.239](https://vuldb.com/?ip.41.157.42.239) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
5 | [45.83.64.1](https://vuldb.com/?ip.45.83.64.1) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
6 | [45.83.64.62](https://vuldb.com/?ip.45.83.64.62) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
7 | [45.83.64.103](https://vuldb.com/?ip.45.83.64.103) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
8 | [45.83.64.253](https://vuldb.com/?ip.45.83.64.253) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
9 | [45.83.65.48](https://vuldb.com/?ip.45.83.65.48) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
10 | ... | ... | ... | ...

There are 37 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2021-44228. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24, CWE-28, CWE-29, CWE-36 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2021-44228. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/academy/home/courses` | High
2 | File | `/ad-list` | Medium
3 | File | `/admin/action/new-father.php` | High
4 | File | `/admin/ajax.php?action=confirm_order` | High
5 | File | `/admin/ajax.php?action=delete_user` | High
6 | File | `/admin/ajax.php?action=delete_window` | High
7 | File | `/admin/ajax.php?action=save_area` | High
8 | File | `/admin/article/article-add.php` | High
9 | File | `/admin/book_add.php` | High
10 | File | `/admin/book_row.php` | High
11 | File | `/admin/borrow_add.php` | High
12 | File | `/admin/category_row.php` | High
13 | File | `/admin/config/uploadicon.php` | High
14 | File | `/admin/contacts/organizations/edit/2` | High
15 | File | `/admin/courses/view_course.php` | High
16 | File | `/admin/edit_category.php` | High
17 | File | `/admin/edit_subject.php` | High
18 | File | `/admin/edit_teacher.php` | High
19 | File | `/admin/index.php` | High
20 | File | `/admin/index/index.html#/admin/mall.goods/index.html` | High
21 | File | `/admin/list_onlineuser.php` | High
22 | File | `/admin/login.php` | High
23 | File | `/admin/makehtml_freelist_action.php` | High
24 | File | `/admin/modal_add_product.php` | High
25 | File | `/admin/pages/update_go.php` | High
26 | File | `/admin/report/index.php` | High
27 | File | `/admin/save_teacher.php` | High
28 | File | `/admin/services/manage_service.php` | High
29 | File | `/admin/settings/` | High
30 | File | `/admin/sign/out` | High
31 | File | `/admin/students/update_status.php` | High
32 | File | `/admin/subject.php` | High
33 | File | `/admin/upload.php` | High
34 | File | `/admin/user/manage_user.php` | High
35 | File | `/admin_route/dec_service_credits.php` | High
36 | File | `/ajax.php?action=save_company` | High
37 | File | `/ample/app/ajax/member_data.php` | High
38 | File | `/api/admin/store/product/list` | High
39 | File | `/app/ajax/sell_return_data.php` | High
40 | File | `/app/api/controller/default/Sqlite.php` | High
41 | File | `/app/index/controller/Common.php` | High
42 | File | `/application/common.php#action_log` | High
43 | File | `/application/index/controller/Databasesource.php` | High
44 | File | `/application/index/controller/File.php` | High
45 | File | `/apply/index.php` | High
46 | File | `/apps/login_auth.php` | High
47 | File | `/apps/reg_go.php` | High
48 | File | `/article/DelectArticleById/` | High
49 | File | `/auth/auth.php?user=1` | High
50 | File | `/b2b-supermarket/shopping-cart` | High
51 | File | `/blog` | Low
52 | File | `/bsms_ci/index.php/book` | High
53 | File | `/cas/logout` | Medium
54 | File | `/category/list?limit=10&offset=0&order=desc` | High
55 | File | `/cgi-bin/adm.cgi` | High
56 | File | `/cgi-bin/cstecgi.cgi` | High
57 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
58 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=ie8` | High
59 | File | `/cgi-bin/jumpto.php?class=user&page=config_save&isphp=1` | High
60 | File | `/cgi-bin/ping.cgi` | High
61 | File | `/change-language/de_DE` | High
62 | File | `/changeimage.php` | High
63 | File | `/classes/Master.php` | High
64 | File | `/classes/Master.php?f=delete_category` | High
65 | File | `/classes/Master.php?f=delete_inquiry` | High
66 | File | `/classes/Master.php?f=delete_item` | High
67 | File | `/classes/Master.php?f=save_item` | High
68 | File | `/classes/Master.php?f=save_reminder` | High
69 | File | `/classes/Users.php` | High
70 | File | `/cms/category/list` | High
71 | File | `/collection/all` | High
72 | File | `/common/download?filename=1.jsp&delete=false` | High
73 | File | `/company/store` | High
74 | File | `/config` | Low
75 | File | `/course/filterRecords/` | High
76 | File | `/crmeb/crmeb/services/UploadService.php` | High
77 | File | `/dashboard/createblog` | High
78 | File | `/data/remove` | Medium
79 | File | `/debug/pprof` | Medium
80 | File | `/dede/group_store.php` | High
81 | File | `/dialog/select_media.php` | High
82 | File | `/download.php?file=author.png` | High
83 | ... | ... | ...

There are 733 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://blogs.infoblox.com/cyber-threat-intelligence/cyber-campaign-briefs/log4j-exploit-harvesting/
* https://gist.github.com/gnremy/c546c7911d5f876f263309d7161a7217
* https://isc.sans.edu/forums/diary/Log4Shell+Attacks+Getting+Smarter/28246/
* https://isc.sans.edu/forums/diary/The+Rise+and+Fall+of+log4shell/28372/
* https://pastebin.com/PhnaB0ac
* https://www.cisa.gov/uscert/ncas/alerts/aa22-174a
* https://www.mandiant.com/resources/apt41-us-state-governments

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
