# CVE-2022-35803 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2022-35803_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2022-35803:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [TR](https://vuldb.com/?country.tr)
* ...

There are 14 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2022-35803 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [TrickBot](https://vuldb.com/?actor.trickbot) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2022-35803.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [37.139.129.216](https://vuldb.com/?ip.37.139.129.216) | - | [TrickBot](https://vuldb.com/?actor.trickbot) | High
2 | [85.208.139.28](https://vuldb.com/?ip.85.208.139.28) | - | [TrickBot](https://vuldb.com/?actor.trickbot) | High
3 | [190.2.141.128](https://vuldb.com/?ip.190.2.141.128) | 190-2-141-128.hosted-by-worldstream.net | [TrickBot](https://vuldb.com/?actor.trickbot) | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2022-35803. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-425 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 22 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2022-35803. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//proc/kcore` | Medium
2 | File | `/admin.php/Admin/adminadd.html` | High
3 | File | `/admin/about-us.php` | High
4 | File | `/admin/action/delete-vaccine.php` | High
5 | File | `/Admin/add-student.php` | High
6 | File | `/admin/index2.html` | High
7 | File | `/admin/settings/save.php` | High
8 | File | `/admin/userprofile.php` | High
9 | File | `/api/baskets/{name}` | High
10 | File | `/app/index/controller/Common.php` | High
11 | File | `/Applications/Google\ Drive.app/Contents/MacOS` | High
12 | File | `/apply.cgi` | Medium
13 | File | `/bitrix/admin/ldap_server_edit.php` | High
14 | File | `/cgi-bin/wlogin.cgi` | High
15 | File | `/College/admin/teacher.php` | High
16 | File | `/Controls/Generic/EBMK/Handlers/EStatements/DownloadEStatement.ashx` | High
17 | File | `/dcim/rack-roles/` | High
18 | File | `/dev/kmem` | Medium
19 | File | `/forms/doLogin` | High
20 | File | `/forum/away.php` | High
21 | File | `/goform/addUserName` | High
22 | File | `/goform/aspForm` | High
23 | File | `/goform/delAd` | High
24 | File | `/goform/wifiSSIDset` | High
25 | File | `/gpac/src/bifs/unquantize.c` | High
26 | File | `/inc/topBarNav.php` | High
27 | File | `/index.asp` | Medium
28 | File | `/index.php` | Medium
29 | File | `/index.php?app=main&func=passport&action=login` | High
30 | File | `/jfinal_cms/system/role/list` | High
31 | File | `/kelas/data` | Medium
32 | File | `/listplace/user/ticket/create` | High
33 | File | `/Main_Login.asp?flag=1&productname=RT-AC88U&url=/downloadmaster/task.asp` | High
34 | File | `/Moosikay/order.php` | High
35 | File | `/novel/author/list` | High
36 | File | `/php-sms/admin/quotes/manage_remark.php` | High
37 | File | `/search.php` | Medium
38 | File | `/secure/QueryComponent!Default.jspa` | High
39 | ... | ... | ...

There are 337 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://exchange.xforce.ibmcloud.com/report/details/guid:b5f95c5f2b6cfa6f560de99a1a2dd371

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
