# CVE-2023-22952 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-22952_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-22952:

* [US](https://vuldb.com/?country.us)
* [GB](https://vuldb.com/?country.gb)
* [GR](https://vuldb.com/?country.gr)
* ...

There are 25 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-22952 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-22952.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [13.90.77.93](https://vuldb.com/?ip.13.90.77.93) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [31.132.2.66](https://vuldb.com/?ip.31.132.2.66) | no.rdns.ukservers.com | [Unknown](https://vuldb.com/?actor.unknown) | High

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-22952. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 18 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-22952. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `.procmailrc` | Medium
2 | File | `/about.php` | Medium
3 | File | `/admin-ajax.php?action=eps_redirect_save` | High
4 | File | `/admin.php` | Medium
5 | File | `/admin.php/accessory/filesdel.html` | High
6 | File | `/admin/` | Low
7 | File | `/Admin/add-student.php` | High
8 | File | `/admin/api/theme-edit/` | High
9 | File | `/admin/index3.php` | High
10 | File | `/admin/manage-users.php` | High
11 | File | `/admin/photo.php` | High
12 | File | `/adms/admin/?page=vehicles/view_transaction` | High
13 | File | `/auth` | Low
14 | File | `/catcompany.php` | High
15 | File | `/cms/category/list` | High
16 | File | `/dashboard/view-chair-list.php` | High
17 | File | `/Default/Bd` | Medium
18 | File | `/ebics-server/ebics.aspx` | High
19 | File | `/egroupware/index.php` | High
20 | File | `/etc/hosts` | Medium
21 | File | `/forum/away.php` | High
22 | File | `/GponForm/device_Form?script/` | High
23 | File | `/GponForm/fsetup_Form` | High
24 | File | `/GponForm/usb_restore_Form?script/` | High
25 | File | `/hrm/employeeview.php` | High
26 | File | `/importexport.php` | High
27 | File | `/includes/decorators/global-translations.jsp` | High
28 | File | `/index.php` | Medium
29 | File | `/loginsave.php` | High
30 | File | `/param.file.tgz` | High
31 | File | `/product_list.php` | High
32 | File | `/public_html/users.php` | High
33 | File | `/secure/QueryComponent!Default.jspa` | High
34 | File | `/see_more_details.php` | High
35 | File | `/server-status` | High
36 | File | `/setSystemAdmin` | High
37 | File | `/uncpath/` | Medium
38 | File | `/user/s.php` | Medium
39 | File | `/usr/local/WowzaStreamingEngine/bin/` | High
40 | File | `/WEB-INF/web.xml` | High
41 | File | `/wireless/guestnetwork.asp` | High
42 | File | `?r=recruit/interview/export&interviews=x` | High
43 | File | `adclick.php` | Medium
44 | File | `add-locker-form.php` | High
45 | File | `addentry.php` | Medium
46 | File | `admin.php` | Medium
47 | ... | ... | ...

There are 403 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://unit42.paloaltonetworks.com/sugarcrm-cloud-incident-black-hat/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
