# CVE-2023-2868 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-2868_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-2868:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 13 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-2868 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [UNC4841](https://vuldb.com/?actor.unc4841) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-2868.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [23.224.42.5](https://vuldb.com/?ip.23.224.42.5) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [23.224.42.29](https://vuldb.com/?ip.23.224.42.29) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
3 | [23.224.78.130](https://vuldb.com/?ip.23.224.78.130) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | [23.224.78.131](https://vuldb.com/?ip.23.224.78.131) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
5 | [23.224.78.132](https://vuldb.com/?ip.23.224.78.132) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
6 | [23.224.78.133](https://vuldb.com/?ip.23.224.78.133) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
7 | [23.224.78.134](https://vuldb.com/?ip.23.224.78.134) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
8 | [37.9.35.217](https://vuldb.com/?ip.37.9.35.217) | cdwk201570.example.com | [UNC4841](https://vuldb.com/?actor.unc4841) | High
9 | [38.54.1.82](https://vuldb.com/?ip.38.54.1.82) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
10 | [38.54.113.205](https://vuldb.com/?ip.38.54.113.205) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
11 | [38.60.254.165](https://vuldb.com/?ip.38.60.254.165) | - | [UNC4841](https://vuldb.com/?actor.unc4841) | High
12 | [45.63.76.67](https://vuldb.com/?ip.45.63.76.67) | 45.63.76.67.vultrusercontent.com | [UNC4841](https://vuldb.com/?actor.unc4841) | High
13 | [45.148.16.42](https://vuldb.com/?ip.45.148.16.42) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
14 | ... | ... | ... | ...

There are 50 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-2868. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-250, CWE-264, CWE-269, CWE-284 | Execution with Unnecessary Privileges | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-2868. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/link/link_mod.php` | High
2 | File | `/api/` | Low
3 | File | `/api/RecordingList/DownloadRecord?file=` | High
4 | File | `/api/sys/login` | High
5 | File | `/api/trackedEntityInstances` | High
6 | File | `/app/options.py` | High
7 | File | `/cgi-bin/luci;stok=/locale` | High
8 | File | `/cgi-bin/wlogin.cgi` | High
9 | File | `/cgi/sshcheck.cgi` | High
10 | File | `/classes/Master.php` | High
11 | File | `/classes/Users.php?f=save` | High
12 | File | `/common/download?filename=1.jsp&delete=false` | High
13 | File | `/context/%2e/WEB-INF/web.xml` | High
14 | File | `/crmeb/crmeb/services/UploadService.php` | High
15 | File | `/debug/pprof` | Medium
16 | File | `/etc/postfix/sender_login` | High
17 | File | `/example/editor` | High
18 | File | `/filemanager/php/connector.php` | High
19 | File | `/filemanager/upload.php` | High
20 | File | `/forgetpassword.php` | High
21 | File | `/forum/away.php` | High
22 | File | `/ghost/preview` | High
23 | File | `/home/www/cgi-bin/login.cgi` | High
24 | File | `/index.php` | Medium
25 | File | `/Items/*/RemoteImages/Download` | High
26 | File | `/items/view_item.php` | High
27 | File | `/jeecg-boot/sys/common/upload` | High
28 | File | `/librarian/bookdetails.php` | High
29 | File | `/mail/index.html` | High
30 | File | `/medical/inventories.php` | High
31 | File | `/members/view_member.php` | High
32 | File | `/mhds/clinic/view_details.php` | High
33 | File | `/modules/profile/index.php` | High
34 | File | `/out.php` | Medium
35 | File | `/owa/auth/logon.aspx` | High
36 | File | `/php-jms/updateTxtview.php` | High
37 | File | `/proxy` | Low
38 | File | `/question.php` | High
39 | File | `/replication` | Medium
40 | File | `/resources//../` | High
41 | File | `/rest/api/latest/projectvalidate/key` | High
42 | File | `/RestAPI` | Medium
43 | File | `/secure/QueryComponent!Default.jspa` | High
44 | File | `/SSOPOST/metaAlias/%realm%/idpv2` | High
45 | File | `/start_apply.htm` | High
46 | File | `/student/bookdetails.php` | High
47 | File | `/templates/header.inc.php` | High
48 | ... | ... | ...

There are 413 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.barracuda.com/company/legal/esg-vulnerability
* https://www.cisa.gov/news-events/alerts/2023/08/29/cisa-releases-iocs-associated-malicious-barracuda-activity
* https://www.mandiant.com/resources/blog/barracuda-esg-exploited-globally

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
