# CVE-2023-34362 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-34362_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-34362:

* [CN](https://vuldb.com/?country.cn)
* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 11 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-34362 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [Clop](https://vuldb.com/?actor.clop) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-34362.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.34.180.205](https://vuldb.com/?ip.5.34.180.205) | bkp-vm-ams.layer6.net | [Clop](https://vuldb.com/?actor.clop) | High
2 | [5.149.248.68](https://vuldb.com/?ip.5.149.248.68) | - | [Clop](https://vuldb.com/?actor.clop) | High
3 | [5.149.250.74](https://vuldb.com/?ip.5.149.250.74) | verizon.com | [Clop](https://vuldb.com/?actor.clop) | High
4 | [5.149.250.92](https://vuldb.com/?ip.5.149.250.92) | digiable.net | [Clop](https://vuldb.com/?actor.clop) | High
5 | [5.188.86.114](https://vuldb.com/?ip.5.188.86.114) | - | [Clop](https://vuldb.com/?actor.clop) | High
6 | [5.188.86.250](https://vuldb.com/?ip.5.188.86.250) | - | [Clop](https://vuldb.com/?actor.clop) | High
7 | [5.188.87.27](https://vuldb.com/?ip.5.188.87.27) | - | [Clop](https://vuldb.com/?actor.clop) | High
8 | [5.188.87.194](https://vuldb.com/?ip.5.188.87.194) | - | [Clop](https://vuldb.com/?actor.clop) | High
9 | [5.188.87.226](https://vuldb.com/?ip.5.188.87.226) | - | [Clop](https://vuldb.com/?actor.clop) | High
10 | [5.252.23.116](https://vuldb.com/?ip.5.252.23.116) | vm1120066.stark-industries.solutions | [Clop](https://vuldb.com/?actor.clop) | High
11 | [5.252.25.88](https://vuldb.com/?ip.5.252.25.88) | free.ds | [Clop](https://vuldb.com/?actor.clop) | High
12 | [5.252.189.0](https://vuldb.com/?ip.5.252.189.0) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
13 | [5.252.190.0](https://vuldb.com/?ip.5.252.190.0) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
14 | [5.252.191.0](https://vuldb.com/?ip.5.252.191.0) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
15 | ... | ... | ... | ...

There are 56 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-34362. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23, CWE-24 | Path Traversal | High
2 | T1040 | CWE-294, CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94, CWE-1321 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 21 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-34362. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/?p=products` | Medium
2 | File | `/admin.php/accessory/filesdel.html` | High
3 | File | `/admin/?page=user/manage` | High
4 | File | `/admin/add-new.php` | High
5 | File | `/admin/controller/JobLogController.java` | High
6 | File | `/admin/doctors.php` | High
7 | File | `/admin/user/manage_user.php` | High
8 | File | `/alphaware/summary.php` | High
9 | File | `/api/` | Low
10 | File | `/api/admin/store/product/list` | High
11 | File | `/api/baskets/{name}` | High
12 | File | `/api/stl/actions/search` | High
13 | File | `/api/sys/login` | High
14 | File | `/api/sys/set_passwd` | High
15 | File | `/api/trackedEntityInstances` | High
16 | File | `/api/v2/cli/commands` | High
17 | File | `/aux` | Low
18 | File | `/bin/ate` | Medium
19 | File | `/boat/login.php` | High
20 | File | `/booking/show_bookings/` | High
21 | File | `/cgi-bin` | Medium
22 | File | `/cgi-bin/wlogin.cgi` | High
23 | File | `/changePassword` | High
24 | File | `/Content/Template/root/reverse-shell.aspx` | High
25 | File | `/dashboard/add-blog.php` | High
26 | File | `/data/remove` | Medium
27 | File | `/debug/pprof` | Medium
28 | File | `/ecshop/admin/template.php` | High
29 | File | `/env` | Low
30 | File | `/etc/passwd` | Medium
31 | File | `/forum/away.php` | High
32 | File | `/group1/uploa` | High
33 | File | `/index.php` | Medium
34 | File | `/mhds/clinic/view_details.php` | High
35 | File | `/nagiosxi/admin/banner_message-ajaxhelper.php` | High
36 | File | `/php-sms/admin/?page=user/manage_user` | High
37 | File | `/reservation/add_message.php` | High
38 | File | `/resources//../` | High
39 | File | `/rest/api/latest/projectvalidate/key` | High
40 | File | `/testConnection` | High
41 | File | `/tmp/ppd.trace` | High
42 | File | `/user/inc/workidajax.php` | High
43 | File | `/user/updatePwd` | High
44 | File | `/userLogin.asp` | High
45 | File | `/vendor/htmlawed/htmlawed/htmLawedTest.php` | High
46 | ... | ... | ...

There are 402 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://community.progress.com/s/article/MOVEit-Transfer-Critical-Vulnerability-31May2023
* https://www.cisa.gov/news-events/cybersecurity-advisories/aa23-158a

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
