# CVE-2023-42793 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-42793_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-42793:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [RU](https://vuldb.com/?country.ru)
* ...

There are 13 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-42793 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Onyx Sleet](https://vuldb.com/?actor.onyx_sleet) | High
2 | [APT29](https://vuldb.com/?actor.apt29) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-42793.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [20.222.6.225](https://vuldb.com/?ip.20.222.6.225) | - | [APT29](https://vuldb.com/?actor.apt29) | High
2 | [43.248.34.77](https://vuldb.com/?ip.43.248.34.77) | - | [APT29](https://vuldb.com/?actor.apt29) | High
3 | [45.133.7.124](https://vuldb.com/?ip.45.133.7.124) | - | [APT29](https://vuldb.com/?actor.apt29) | High
4 | [45.133.7.129](https://vuldb.com/?ip.45.133.7.129) | - | [APT29](https://vuldb.com/?actor.apt29) | High
5 | ... | ... | ... | ...

There are 16 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-42793. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | T1068 | CWE-264, CWE-269, CWE-284 | Execution with Unnecessary Privileges | High
6 | ... | ... | ... | ...

There are 20 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-42793. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/.dbus-keyrings` | High
2 | File | `/admin.php?action=themeinstall` | High
3 | File | `/admin/` | Low
4 | File | `/admin/maintenance/view_designation.php` | High
5 | File | `/admin/question/edit` | High
6 | File | `/admin/reg.php` | High
7 | File | `/api/v1/terminal/sessions/?limit=1` | High
8 | File | `/controllers/api/user.php` | High
9 | File | `/dashboard/updatelogo.php` | High
10 | File | `/dev/fd0` | Medium
11 | File | `/dipam/save-delegates.php` | High
12 | File | `/ecrire/tools/blogroll/edit_link.php` | High
13 | File | `/etc/gsissh/sshd_config` | High
14 | File | `/etc/nologin` | Medium
15 | File | `/etc/shadow` | Medium
16 | File | `/eval/admin/manage_subject.php` | High
17 | File | `/EXCU_SHELL` | Medium
18 | File | `/forum/away.php` | High
19 | File | `/goform/aspForm` | High
20 | File | `/home/cavesConsole` | High
21 | File | `/importexport.php` | High
22 | File | `/index.php` | Medium
23 | File | `/isec/index.php` | High
24 | File | `/lam/tmp/` | Medium
25 | File | `/main/doctype.php` | High
26 | File | `/mkshop/Men/profile.php` | High
27 | File | `/oauth/authorized_applications.json` | High
28 | File | `/ok_jpg.c` | Medium
29 | File | `/out.php` | Medium
30 | File | `/owui/block/send-receive-updates` | High
31 | File | `/php_action/createUser.php` | High
32 | File | `/spip.php` | Medium
33 | File | `/user/upload/upload` | High
34 | File | `/userLogin.asp` | High
35 | File | `/wp-admin/admin-ajax.php` | High
36 | File | `/wp-json` | Medium
37 | File | `?page=rooms` | Medium
38 | ... | ... | ...

There are 323 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://www.cisa.gov/news-events/cybersecurity-advisories/aa23-347a
* https://www.fortinet.com/blog/threat-research/teamcity-intrusion-saga-apt29-suspected-exploiting-cve-2023-42793
* https://www.microsoft.com/en-us/security/blog/2023/10/18/multiple-north-korean-threat-actors-exploiting-the-teamcity-cve-2023-42793-vulnerability/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
