# CVE-2023-46604 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-46604_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-46604:

* [RU](https://vuldb.com/?country.ru)
* [PL](https://vuldb.com/?country.pl)
* [US](https://vuldb.com/?country.us)
* ...

There are 6 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-46604 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Andariel](https://vuldb.com/?actor.andariel) | High
2 | [Kinsing](https://vuldb.com/?actor.kinsing) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-46604.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [27.191.193.193](https://vuldb.com/?ip.27.191.193.193) | - | [Andariel](https://vuldb.com/?actor.andariel) | High
2 | [46.17.43.156](https://vuldb.com/?ip.46.17.43.156) | - | [Kinsing](https://vuldb.com/?actor.kinsing) | High
3 | [62.233.50.97](https://vuldb.com/?ip.62.233.50.97) | - | [Andariel](https://vuldb.com/?actor.andariel) | High
4 | [62.233.50.101](https://vuldb.com/?ip.62.233.50.101) | - | [Andariel](https://vuldb.com/?actor.andariel) | High
5 | [78.153.140.30](https://vuldb.com/?ip.78.153.140.30) | hostglobal.plus | [Kinsing](https://vuldb.com/?actor.kinsing) | High
6 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-46604. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23 | Pathname Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-88, CWE-94 | Cross Site Scripting | High
4 | ... | ... | ... | ...

There are 14 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-46604. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin/index2.html` | High
2 | File | `/api/baskets/{name}` | High
3 | File | `/dev/kvm` | Medium
4 | File | `/Duty/AjaxHandle/UploadFloodPlanFileUpdate.ashx` | High
5 | File | `/medical/inventories.php` | High
6 | File | `/myprofile` | Medium
7 | File | `5.2.9\syscrb.exe` | High
8 | ... | ... | ...

There are 52 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://asec.ahnlab.com/en/59318/
* https://asec.ahnlab.com/en/59904/
* https://blog.sekoia.io/activemq-cve-2023-46604-exploited-by-kinsing-and-overview-of-this-threat/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
