# CVE-2023-46805 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-46805_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-46805:

* [US](https://vuldb.com/?country.us)
* [CN](https://vuldb.com/?country.cn)
* [GB](https://vuldb.com/?country.gb)
* ...

There are 11 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-46805 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [UNC5221](https://vuldb.com/?actor.unc5221) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-46805.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [8.137.112.245](https://vuldb.com/?ip.8.137.112.245) | - | [UNC5221](https://vuldb.com/?actor.unc5221) | High
2 | [45.61.136.14](https://vuldb.com/?ip.45.61.136.14) | - | [UNC5221](https://vuldb.com/?actor.unc5221) | High
3 | [47.207.9.89](https://vuldb.com/?ip.47.207.9.89) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | [50.213.208.89](https://vuldb.com/?ip.50.213.208.89) | 50-213-208-89-static.hfc.comcastbusiness.net | [Unknown](https://vuldb.com/?actor.unknown) | High
5 | ... | ... | ... | ...

There are 17 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-46805. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Path Traversal | High
2 | T1040 | CWE-294 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-88, CWE-94 | Argument Injection | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-46805. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/action/factory` | High
2 | File | `/action/import_aaa_cert_file/` | High
3 | File | `/action/import_authorized_keys/` | High
4 | File | `/action/import_file/` | High
5 | File | `/action/import_firmware/` | High
6 | File | `/action/import_https_cert_file/` | High
7 | File | `/action/import_nodejs_app/` | High
8 | File | `/action/import_sdk_file/` | High
9 | File | `/action/import_xml_file/` | High
10 | File | `/action/ipcamRecordPost` | High
11 | File | `/action/ipcamSetParamPost` | High
12 | File | `/action/iperf` | High
13 | File | `/action/wirelessConnect` | High
14 | File | `/admin/scripts/pi-hole/phpqueryads.php` | High
15 | File | `/admin/students/manage.php` | High
16 | File | `/ajax/remove/` | High
17 | File | `/apiadmin/notice/add` | High
18 | File | `/apiadmin/upload/attach` | High
19 | File | `/app1/admin#foo` | High
20 | File | `/Applications/Google\ Drive.app/Contents/MacOS` | High
21 | File | `/cgi-bin/wapopen` | High
22 | ... | ... | ...

There are 187 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://isc.sans.edu/diary/rss/30568
* https://www.cybereason.com/blog/threat-alert-ivanti-connect-secure-vpn-zero-day-exploitation
* https://www.mandiant.com/resources/blog/investigating-ivanti-zero-day-exploitation
* https://www.volexity.com/blog/2024/01/10/active-exploitation-of-two-zero-day-vulnerabilities-in-ivanti-connect-secure-vpn/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
