# CVE-2023-49103 - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _CVE-2023-49103_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with CVE-2023-49103:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [NL](https://vuldb.com/?country.nl)
* ...

There are 19 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with CVE-2023-49103 or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of CVE-2023-49103.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [85.203.44.5](https://vuldb.com/?ip.85.203.44.5) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [85.203.44.8](https://vuldb.com/?ip.85.203.44.8) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
3 | [104.255.175.10](https://vuldb.com/?ip.104.255.175.10) | - | [Unknown](https://vuldb.com/?actor.unknown) | High
4 | ... | ... | ... | ...

There are 1 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within CVE-2023-49103. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-21, CWE-22, CWE-23 | Path Traversal | High
2 | T1055 | CWE-74 | Injection | High
3 | T1059 | CWE-94 | Argument Injection | High
4 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during CVE-2023-49103. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/admin.php?mod=admin&func=panel` | High
2 | File | `/admin/article.php?active_savedraft` | High
3 | File | `/admin/model/database.class.php` | High
4 | File | `/bin/login.php` | High
5 | File | `/cgi-bin/api-get_line_status` | High
6 | File | `/cgi-bin/delete_CA` | High
7 | File | `/common/info.cgi` | High
8 | File | `/cwp_{SESSION_HASH}/admin/loader_ajax.php` | High
9 | File | `/etc/config/image_sign` | High
10 | File | `/ext/phar/phar_object.c` | High
11 | File | `/forum/away.php` | High
12 | File | `/getcfg.php` | Medium
13 | File | `/goform/` | Medium
14 | File | `/lists/admin/` | High
15 | File | `/movie.php` | Medium
16 | File | `/oauth/idp/.well-known/openid-configuration` | High
17 | File | `/plugins/in_mqtt/mqtt_prot.c` | High
18 | File | `/PreviewHandler.ashx` | High
19 | File | `/product.php` | Medium
20 | File | `/rom-0` | Low
21 | File | `/secure/QueryComponent!Default.jspa` | High
22 | File | `/server-status` | High
23 | File | `/src/Illuminate/Laravel.php` | High
24 | File | `/uapi/doc` | Medium
25 | File | `/uncpath/` | Medium
26 | File | `/updown/upload.cgi` | High
27 | File | `/var/etc/hnapasswd` | High
28 | File | `/ViewUserHover.jspa` | High
29 | File | `/WiKIDAdmin/adm_usrs.jsp` | High
30 | File | `/wp-content/plugins/woocommerce/templates/emails/plain/` | High
31 | File | `2fly_gift.php` | High
32 | File | `14all.cgi/14all-1.1.cgi/traffic.cgi/mrtg.cgi` | High
33 | File | `account.asp` | Medium
34 | File | `account/main.php` | High
35 | File | `acid_qry_main.php` | High
36 | File | `addToWishlist.asp` | High
37 | File | `admin.php` | Medium
38 | File | `admin/admin_process.php` | High
39 | File | `admin/category.inc.php` | High
40 | File | `admin/dashboard.php` | High
41 | File | `admin/general.php` | High
42 | File | `admin/review.php` | High
43 | File | `admin/show.php?rec=update` | High
44 | File | `administrator/components/com_joomgallery/views/config/tmpl/default.php` | High
45 | File | `adverts/assets/plugins/ultimate/content/downloader.php` | High
46 | File | `affich.php` | Medium
47 | File | `ajax.php` | Medium
48 | File | `AjaxFileUploadHandler.axd` | High
49 | File | `album_portal.php` | High
50 | File | `announce.php` | Medium
51 | File | `anonymous/authenticated` | High
52 | File | `app/admin/controller/themecontroller.php` | High
53 | File | `apply.cgi` | Medium
54 | File | `article.php` | Medium
55 | File | `assets/add/registrar-accounts.php` | High
56 | File | `auths/spa.c` | Medium
57 | ... | ... | ...

There are 499 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://isc.sans.edu/diary/rss/30432

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
