# Iran - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Iran_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Iran:

* [US](https://vuldb.com/?country.us)
* [RU](https://vuldb.com/?country.ru)
* [ES](https://vuldb.com/?country.es)
* ...

There are 15 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Iran or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Iran Unknown](https://vuldb.com/?actor.iran_unknown) | High
2 | [Indra](https://vuldb.com/?actor.indra) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Iran.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [46.30.189.66](https://vuldb.com/?ip.46.30.189.66) | - | [Iran Unknown](https://vuldb.com/?actor.iran_unknown) | High
2 | [51.89.181.64](https://vuldb.com/?ip.51.89.181.64) | ip64.ip-51-89-181.eu | [Iran Unknown](https://vuldb.com/?actor.iran_unknown) | High
3 | [66.219.22.235](https://vuldb.com/?ip.66.219.22.235) | core96.hostingmadeeasy.com | [Iran Unknown](https://vuldb.com/?actor.iran_unknown) | High
4 | [68.183.79.77](https://vuldb.com/?ip.68.183.79.77) | - | [Indra](https://vuldb.com/?actor.indra) | High
5 | ... | ... | ... | ...

There are 18 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Iran. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22 | Pathname Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Cross Site Scripting | High
5 | ... | ... | ... | ...

There are 17 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Iran. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `//etc/RT2870STA.dat` | High
2 | File | `/admin/maintenance/view_designation.php` | High
3 | File | `/administration/theme.php` | High
4 | File | `/api/` | Low
5 | File | `/api/index.php` | High
6 | File | `/boafrm/formFilter` | High
7 | File | `/cgi-bin/webproc` | High
8 | File | `/clinic/medical_records_view.php` | High
9 | File | `/coreframe/app/pay/admin/index.php` | High
10 | File | `/forum/away.php` | High
11 | File | `/importexport.php` | High
12 | File | `/index.php` | Medium
13 | File | `/mobileredir/openApp.jsp` | High
14 | File | `/ofrs/admin/?page=requests/manage_request` | High
15 | File | `/search` | Low
16 | File | `/spip.php` | Medium
17 | File | `/usr/www/ja/mnt_cmd.cgi` | High
18 | File | `/wp-admin/admin-ajax.php` | High
19 | File | `active.log` | Medium
20 | ... | ... | ...

There are 164 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://github.com/blackorbird/APT_REPORT/blob/master/muddywater/Clearsky-Iranian-APT-group-%E2%80%98MuddyWater%E2%80%99-Adds-Exploits-to-Their-Arsenal.pdf
* https://research.checkpoint.com/2021/indra-hackers-behind-recent-attacks-on-iran/
* https://us-cert.cisa.gov/ncas/alerts/aa21-321a
* https://www.cisa.gov/uscert/ncas/alerts/aa22-320a
* https://www.microsoft.com/security/blog/2022/09/08/microsoft-investigates-iranian-attacks-against-the-albanian-government/

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
