# Proxy - Cyber Threat Intelligence

These _indicators_ were reported, collected, and generated during the [VulDB CTI analysis](https://vuldb.com/?kb.cti) of the campaign known as _Proxy_. The _activity monitoring_ correlates data from social media, forums, chat rooms, and darknet markets. It helps to determine associated actors, specific activities, expected intentions, emerging research, and ongoing attacks. Our unique _predictive model_ uses _big data_ to forecast activities and their characteristics.

_Live data_ and more _analysis capabilities_ are available at [https://vuldb.com/?actor](https://vuldb.com/?actor)

## Countries

These _countries_ are directly (e.g. origin of attacks) or indirectly (e.g. access by proxy) associated with Proxy:

* [US](https://vuldb.com/?country.us)
* [LU](https://vuldb.com/?country.lu)
* [CN](https://vuldb.com/?country.cn)
* ...

There are 17 more country items available. Please use our online service to access the data.

## Actors

These _actors_ are associated with Proxy or other actors linked to the campaign.

ID | Actor | Confidence
-- | ----- | ----------
1 | [Unknown](https://vuldb.com/?actor.unknown) | High
2 | [Squirrelwaffle](https://vuldb.com/?actor.squirrelwaffle) | High
3 | [China Unknown](https://vuldb.com/?actor.china_unknown) | High

## IOC - Indicator of Compromise

These _indicators of compromise_ (IOC) indicate associated network resources which are known to be part of research and attack activities of Proxy.

ID | IP address | Hostname | Actor | Confidence
-- | ---------- | -------- | ----- | ----------
1 | [5.180.61.17](https://vuldb.com/?ip.5.180.61.17) | - | [China Unknown](https://vuldb.com/?actor.china_unknown) | High
2 | [23.111.163.242](https://vuldb.com/?ip.23.111.163.242) | 23-111-163-242.static.hvvc.us | [Squirrelwaffle](https://vuldb.com/?actor.squirrelwaffle) | High
3 | [24.229.150.54](https://vuldb.com/?ip.24.229.150.54) | 24.229.150.54.cmts-static.sm.ptd.net | [Squirrelwaffle](https://vuldb.com/?actor.squirrelwaffle) | High
4 | [47.242.39.92](https://vuldb.com/?ip.47.242.39.92) | - | [China Unknown](https://vuldb.com/?actor.china_unknown) | High
5 | [61.244.94.85](https://vuldb.com/?ip.61.244.94.85) | 061244094085.ctinets.com | [China Unknown](https://vuldb.com/?actor.china_unknown) | High
6 | [69.192.185.238](https://vuldb.com/?ip.69.192.185.238) | a69-192-185-238.deploy.static.akamaitechnologies.com | [Squirrelwaffle](https://vuldb.com/?actor.squirrelwaffle) | High
7 | ... | ... | ... | ...

There are 24 more IOC items available. Please use our online service to access the data.

## TTP - Tactics, Techniques, Procedures

_Tactics, techniques, and procedures_ (TTP) summarize the suspected MITRE ATT&CK techniques used within Proxy. This data is unique as it uses our predictive model for actor profiling.

ID | Technique | Weakness | Description | Confidence
-- | --------- | -------- | ----------- | ----------
1 | T1006 | CWE-22, CWE-23, CWE-24, CWE-36, CWE-425 | Path Traversal | High
2 | T1040 | CWE-319 | Authentication Bypass by Capture-replay | High
3 | T1055 | CWE-74 | Injection | High
4 | T1059 | CWE-94 | Argument Injection | High
5 | T1059.007 | CWE-79, CWE-80 | Cross Site Scripting | High
6 | ... | ... | ... | ...

There are 19 more TTP items available. Please use our online service to access the data.

## IOA - Indicator of Attack

These _indicators of attack_ (IOA) list the potential fragments used for technical activities like reconnaissance, exploitation, privilege escalation, and exfiltration during Proxy. This data is unique as it uses our predictive model for actor profiling.

ID | Type | Indicator | Confidence
-- | ---- | --------- | ----------
1 | File | `/#ProductSerie/view/` | High
2 | File | `/Account/login.php` | High
3 | File | `/admin/` | Low
4 | File | `/admin/?page=user/manage_user&id=3` | High
5 | File | `/admin/action/add_con.php` | High
6 | File | `/admin/action/new-father.php` | High
7 | File | `/admin/action/new-feed.php` | High
8 | File | `/admin/add_user_modal.php` | High
9 | File | `/admin/admin-profile.php` | High
10 | File | `/admin/ajax.php?action=confirm_order` | High
11 | File | `/admin/article/article-add.php` | High
12 | File | `/admin/article/article-edit-run.php` | High
13 | File | `/admin/book_add.php` | High
14 | File | `/admin/book_row.php` | High
15 | File | `/admin/borrow_add.php` | High
16 | File | `/admin/bwdates-report-details.php` | High
17 | File | `/admin/category/cate-edit-run.php` | High
18 | File | `/admin/category_row.php` | High
19 | File | `/admin/cms_admin.php` | High
20 | File | `/admin/course.php` | High
21 | File | `/admin/courses/manage_course.php` | High
22 | File | `/admin/edit_teacher.php` | High
23 | File | `/admin/index/index.html#/admin/mall.goods/index.html` | High
24 | File | `/admin/inquiries/view_inquiry.php` | High
25 | File | `/admin/leancloud.php` | High
26 | File | `/Admin/login.php` | High
27 | File | `/admin/makehtml_freelist_action.php` | High
28 | File | `/admin/manage-pages.php` | High
29 | File | `/admin/modal_add_product.php` | High
30 | File | `/Admin/News.php` | High
31 | File | `/admin/pages/edit_chicken.php` | High
32 | File | `/admin/pages/update_go.php` | High
33 | File | `/admin/pages/yearlevel.php` | High
34 | File | `/admin/php/crud.php` | High
35 | File | `/admin/read.php?mudi=announContent` | High
36 | File | `/admin/services/manage_service.php` | High
37 | File | `/admin/settings/` | High
38 | File | `/admin/students/manage_academic.php` | High
39 | File | `/admin/students/update_status.php` | High
40 | File | `/admin/subject.php` | High
41 | File | `/admin/theme-edit.php` | High
42 | File | `/admin/upload.php` | High
43 | File | `/admin/user/manage_user.php` | High
44 | File | `/adminapi/system/crud` | High
45 | File | `/adminapi/system/file/openfile` | High
46 | File | `/admin_route/dec_service_credits.php` | High
47 | File | `/adplanet/PlanetUser` | High
48 | File | `/ample/app/action/edit_product.php` | High
49 | File | `/ample/app/ajax/member_data.php` | High
50 | File | `/api.php` | Medium
51 | File | `/api/authentication/login` | High
52 | File | `/api/clusters/local/topics/{topic}/messages` | High
53 | File | `/api/controllers/admin/app/AppController.php` | High
54 | File | `/api/controllers/common/UploadsController.php` | High
55 | File | `/api/DataDictionary/GetItemList` | High
56 | File | `/api/es/admin/v3/security/user/1` | High
57 | File | `/api/ping` | Medium
58 | File | `/api/runscript` | High
59 | File | `/api/sys/login` | High
60 | File | `/api/sys/set_passwd` | High
61 | File | `/application/index/controller/Datament.php` | High
62 | File | `/application/index/controller/Pay.php` | High
63 | File | `/application/index/controller/Screen.php` | High
64 | File | `/application/pay/controller/Api.php` | High
65 | File | `/apply/index.php` | High
66 | File | `/apps/reg_go.php` | High
67 | File | `/att_add.php` | Medium
68 | File | `/autheditpwd.php` | High
69 | File | `/b2b-supermarket/catalog/all-products` | High
70 | File | `/bin/boa` | Medium
71 | File | `/boaform/device_reset.cgi` | High
72 | File | `/boaform/wlan_basic_set.cgi` | High
73 | File | `/boafrm/formMapDelDevice` | High
74 | File | `/building/backmgr/urlpage/mobileurl/configfile/jx2_config.ini` | High
75 | File | `/category.php` | High
76 | File | `/cgi-bin/` | Medium
77 | File | `/cgi-bin/cstecgi.cgi` | High
78 | File | `/cgi-bin/cstecgi.cgi?action=login` | High
79 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=1` | High
80 | File | `/cgi-bin/cstecgi.cgi?action=login&flag=ie8` | High
81 | File | `/changeimage.php` | High
82 | File | `/Cinema-Reservation/booking.php` | High
83 | File | `/classes/Master.php` | High
84 | File | `/classes/Master.php?f=delete_service` | High
85 | File | `/classes/Users.php?f=save` | High
86 | File | `/collection/all` | High
87 | File | `/config,admin.jsp` | High
88 | File | `/Controller/Ajaxfileupload.ashx` | High
89 | File | `/course/filterRecords/` | High
90 | File | `/currentsetting.htm` | High
91 | File | `/dashboard/createblog` | High
92 | File | `/debuginfo.htm` | High
93 | File | `/dosen/data` | Medium
94 | File | `/download.php?file=author.png` | High
95 | File | `/download/image` | High
96 | File | `/E-mobile/App/System/File/downfile.php` | High
97 | File | `/edit.php` | Medium
98 | File | `/endpoint/delete-user.php` | High
99 | File | `/EventBookingCalendar/load.php?controller=GzFront/action=checkout/cid=1/layout=calendar/show_header=T/local=3` | High
100 | File | `/ext/collect/filter_text.do` | High
101 | File | `/ext/collect/find_text.do` | High
102 | ... | ... | ...

There are 900 more IOA items available (file, library, argument, input value, pattern, network port). Please use our online service to access the data.

## References

The following list contains _external sources_ which discuss the campaign and the associated activities:

* https://github.com/vishalyadav70/Proxy-Server/blob/main/proxy/blacklist.txt
* https://www.gteltsc.vn/blog/warning-new-attack-campaign-utilized-a-new-0day-rce-vulnerability-on-microsoft-exchange-server-12715.html
* https://www.trendmicro.com/content/dam/trendmicro/global/en/research/21/k/squirrelwaffle-exploits-proxyshell-and-proxylogon-vulnerabilities-in-microsoft-exchange-to-hijack-email-chains/IOCs-squirrelwaffle-exploits-proxyshell-and-proxylogon-to-hijack-email
* https://www.trendmicro.com/en_us/research/21/k/analyzing-proxyshell-related-incidents-via-trend-micro-managed-x.html

## Literature

The following _articles_ explain our unique predictive cyber threat intelligence:

* [VulDB Cyber Threat Intelligence Documentation](https://vuldb.com/?kb.cti)
* [Cyber Threat Intelligence - Early Anticipation of Attacks](https://www.scip.ch/en/?labs.20201022)

## License

(c) [1997-2024](https://vuldb.com/?kb.changelog) by [vuldb.com](https://vuldb.com/?kb.about). All data on this page is shared under the license [CC BY-NC-SA 4.0](https://creativecommons.org/licenses/by-nc-sa/4.0/). Questions? Check the [FAQ](https://vuldb.com/?kb.faq), read the [documentation](https://vuldb.com/?kb) or [contact us](https://vuldb.com/?contact)!
